---------------------------------------------------------------------------------------
-- NxMapData - Map code
-- Copyright 2007-2012 Carbon Based Creations, LLC
---------------------------------------------------------------------------------------
---------------------------------------------------------------------------------------
-- Carbonite - Addon for World of Warcraft(tm)
-- Copyright 2007-2012 Carbon Based Creations, LLC
--
-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program.  If not, see <http://www.gnu.org/licenses/>.
---------------------------------------------------------------------------------------

local Map = Nx.Map
local L = LibStub("AceLocale-3.0"):GetLocale("Carbonite")

-- X and Y are the absolute position (lower-left corner) on the overall
-- super-zoomed-out continent image (https://github.com/dratr/Carbonite/commits/map-zonesdocs)
Map.MapInfo = {
	[0] = {		-- Dummy
		Name = "Instance",
		X = 0,
		Y = 0,
	},
	[1] = {
		Name = L["Kalimdor"],
		FileName = "Kalimdor",
		X = -2500,
		Y = 200,
		TileX = 15,
		TileY = 10,
	},
	[2] = {
		Name = L["Eastern Kingdoms"],
		FileName = "EasternKingdoms",
		X = 6284,
		Y = -200,
		TileX = 15,
		TileY = 10,
	},
	[3] = {
		Name = L["Outland"],
		FileName = "Expansion01",
		X = 7400,
		Y = -4000,
	},
	[4] = {
		Name = L["Northrend"],
		FileName = "Northrend",
		X = 2500,
		Y = -3000,
	},
	[5] = {
		Name = L["The Maelstrom"],
		FileName = "TheMaelstromContinent",
		X = 1700,
		Y = 1350,
	},
	[6] = {
		Name = L["Pandaria"],
		FileName = "Pandaria",
		X = 2500,
		Y = 4500,
	},
	[7] = {
		Name = L["Draenor"],
		FileName = "Draenor",
		X = -2000,
		Y = -3300,
	},
	[8] = {
		Name = L["Broken Isles"],
		FileName = "BrokenIsles",
		X = 3000,
		Y = -300,
	},
	[9] = {
		Name = L["Argus"],
		FileName = "Argus",
		X = 4250,
		Y = -1800,
	},
	[10] = {
		Name = L["Zandalar"],
		FileName = "zandalar",
		X = -1800,
		Y = 3750,
		TileX = 15,
		TileY = 10,
	},
	[11] = {
		Name = L["Kul Tiras"],
		FileName = "kultiras",
		X = 7000,
		Y = 4200,
		TileX = 15,
		TileY = 10,
	},
	[12] = {
		Name = L["Nazjatar"],
		FileName = "nazjatar",
		X = -1300,
		Y = 3400,
		TileX = 15,
		TileY = 10,
		ZXOff = -1300 + -317.35,
		ZYOff = 3000 + -157.43,
		ZWOff = -153.59,
		ZHOff = -98,10
	},
	[13] = {
		Name = L["The Shadowlands"],
		FileName = "theshadowlands",
		X = -7500,
		Y = -400,
		TileX = 15,
		TileY = 10,
	},
	[90] = {
		Name = "BG",
		X = 2000,
		Y = 200,
	},
	[100] = {
		Name = "Instance",
		X = 2000,
		Y = 100,
	},
}

Map.BloodelfXO = -503
Map.BloodelfYO = 516
Map.DraeneiXO = -3500
Map.DraeneiYO = -2010

-- UIMapAssignment
Map.MapWorldInfo = {

	-- Dummy if we get a zero on startup
	[-1] = {
		1.0,
		0,0,
	},
	[0] = {
		10,
		0, 0,
		0, 0,		-- Index 4,5 XY world position created for zones in continents 1-5, 9
		Overlay = "barrens",
	},
	[1] = {
		Scale = 10.574999267578,
		X = 392.49997558594,
		Y = -361.66665039063,
		Overlay = "durotar",
		Name = L["Durotar"],
	},
	[7] = {
		Scale = 10.899999511719,
		X = -440.83330078125,
		Y = 33.75,
		Overlay = "mulgore",
		Name = L["Mulgore"],
	},
	[10] = {
		Scale = 11.491666656494,
		X = -40.416665649414,
		Y = -362.08332519531,
		Overlay = "barrens",
		Name = L["Northern Barrens"],
		QAchievementIdH = 4933,
	},
	[12] = {
		Scale = 73.5996,
		X = -3413.32,
		Y = -2459.98,
	},
	[13] = {
		Scale = 81.48236,
		X = -3634.394,
		Y = -2235.268,
	},
	[14] = {
		Scale = 6.9541665039062,
		X = 225.41665039063,
		Y = 28.333331298828,
		Overlay = "arathi",
		Name = L["Arathi Highlands"],
		QAchievementId = 4896,
	},
	[15] = {
		Scale = 6.1416665039062,
		X = 380.41665039063,
		Y = 1170.8333007813,
		Overlay = "badlands",
		Name = L["Badlands"],
		QAchievementId = 4900,
	},
	[17] = {
		Scale = 7.325,
		X = 238.75,
		Y = 2116.6666015625,
		Overlay = "blastedlands",
		Name = L["Blasted Lands"],
		QAchievementId = 4909,
	},
	[18] = {
		Scale = 9.0374997558594,
		X = -606.66665039063,
		Y = -767.49995117188,
		Overlay = "tirisfal",
		Name = L["Tirisfal Glades"],
	},
	[21] = {
		Scale = 8.3999995117188,
		X = -689.99995117188,
		Y = -333.33332519531,
		Overlay = "silverpine",
		Name = L["Silverpine Forest"],
		QAchievementIdH = 4894,
	},
	[22] = {
		Scale = 8.5999998168945,
		X = -83.333331298828,
		Y = -673.33330078125,
		Overlay = "westernplaguelands",
		Name = L["Western Plaguelands"],
		QAchievementId = 4893,
	},
	[23] = {
		Scale = 8.0625,
		X = 457.5,
		Y = -740.83330078125,
		Overlay = "easternplaguelands",
		Name = L["Eastern Plaguelands"],
		QAchievementId = 4892,
	},
	[25] = {
		Scale = 9.7249997558594,
		X = -369.99997558594,
		Y = -296.25,
		Overlay = "hillsbradfoothills",
		Name = L["Hillsbrad Foothills"],
		QAchievementIdH = 4895,
	},
	[26] = {
		Scale = 7.7,
		X = 315,
		Y = -293.33332519531,
		Overlay = "hinterlands",
		Name = L["The Hinterlands"],
		QAchievementId = 4897,
	},
	[27] = {
		Scale = 9.7958330078125,
		X = -427.5,
		Y = 788.33330078125,
		Overlay = "dunmorogh",
		Name = L["Dun Morogh"],
	},
	[32] = {
		Scale = 4.4624996948242,
		X = 64.583331298828,
		Y = 1220,
		Overlay = "searinggorge",
		Name = L["Searing Gorge"],
		QAchievementId = 4910,
	},
	[36] = {
		Scale = 6.3041663818359,
		X = 92.916662597656,
		Y = 1397.0833007813,
		Overlay = "burningsteppes",
		Name = L["Burning Steppes"],
		QAchievementId = 4901,
	},
	[37] = {
		Scale = 6.9416665039062,
		X = -307.08332519531,
		Y = 1587.9166015625,
		Overlay = "elwynn",
		Name = L["Elwynn Forest"],
	},
	[42] = {
		Scale = 4.9999998779297,
		X = 166.66666259766,
		Y = 1973.333203125,
		Overlay = "deadwindpass",
		Name = L["Deadwind Pass"],
	},
	[47] = {
		Scale = 5.3999998779297,
		X = -166.66666259766,
		Y = 1943.333203125,
		Overlay = "duskwood",
		Name = L["Duskwood"],
		QAchievementIdA = 4907,
	},
	[48] = {
		Scale = 5.5166662597656,
		X = 398.74997558594,
		Y = 897.5,
		Overlay = "lochmodan",
		Name = L["Loch Modan"],
		QAchievementIdA = 4899,
	},
	[49] = {
		Scale = 5.1374997558594,
		X = 295.83332519531,
		Y = 1702.9166015625,
		Overlay = "redridge",
		Name = L["Redridge Mountains"],
		QAchievementIdA = 4902,
	},
	[50] = {
		Scale = 8.1999997558594,
		X = -348.74997558594,
		Y = 2203.333203125,
		Overlay = "stranglethornjungle",
		Name = L["Northern Stranglethorn"],
		QAchievementId = 4906,
	},
	[51] = {
		Scale = 5.016666015625,
		X = 416.25,
		Y = 1907.083203125,
		Overlay = "swampofsorrows",
		Name = L["Swamp of Sorrows"],
		QAchievementId = 4904,
	},
	[52] = {
		Scale = 6.9999996337891,
		X = -603.33330078125,
		Y = 1880,
		Overlay = "westfall",
		Name = L["Westfall"],
		QAchievementIdA = 4903,
	},
	[56] = {
		Scale = 8.2708333740234,
		X = 77.916662597656,
		Y = 429.58330078125,
		Overlay = "wetlands",
		Name = L["Wetlands"],
		QAchievementIdA = 4898,
	},
	[57] = {
		Scale = 11.749999511719,
		X = -847.08330078125,
		Y = -2369.583203125,
		Overlay = "teldrassil",
		Name = L["Teldrassil"],
	},
	[62] = {
		Scale = 12.929166015625,
		X = -603.33330078125,
		Y = -1644.583203125,
		Overlay = "darkshore",
		Name = L["Darkshore"],
		QAchievementIdA = 4928,
	},
	[63] = {
		Scale = 11.533332763672,
		X = -339.99997558594,
		Y = -934.58330078125,
		Overlay = "ashenvale",
		Name = L["Ashenvale"],
		QAchievementId = 4925,
		QAchievementIdH = 4976,
	},
	[64] = {
		Scale = 8.7999993896484,
		X = 86.666662597656,
		Y = 793.33330078125,
		Overlay = "thousandneedles",
		Name = L["Thousand Needles"],
		QAchievementId = 4938,
	},
	[65] = {
		Scale = 11.799999755859,
		X = -780.41665039063,
		Y = -680.83330078125,
		Overlay = "stonetalonmountains",
		Name = L["Stonetalon Mountains"],
		QAchievementId = 4936,
		QAchievementIdH = 4980,
	},
	[66] = {
		Scale = 8.991666015625,
		X = -846.6666015625,
		Y = -90.416662597656,
		Overlay = "desolace",
		Name = L["Desolace"],
		QAchievementId = 4930,
	},
	[69] = {
		Scale = 13.899999511719,
		X = -1088.3333007813,
		Y = 473.33330078125,
		Overlay = "feralas",
		Name = L["Feralas"],
		QAchievementId = 4932,
		QAchievementIdH = 4979,
	},
	[70] = {
		Scale = 10.5,
		X = 195,
		Y = 406.666796875,
		Overlay = "dustwallow",
		Name = L["Dustwallow Marsh"],
		QAchievementId = 4929,
		QAchievementIdH = 4978,
	},
	[71] = {
		Scale = 14.424999031067,
		X = 12.499999237061,
		Y = 1154.1666015625,
		Overlay = "tanaris",
		Name = L["Tanaris"],
		QAchievementId = 4935,
	},
	[76] = {
		Scale = 11.029166992188,
		X = 674.58330078125,
		Y = -1076.25,
		Overlay = "aszhara",
		Name = L["Azshara"],
		QAchievementIdH = 4927,
	},
	[77] = {
		Scale = 12.124999267578,
		X = -359.58332519531,
		Y = -1447.4999023437,
		Overlay = "felwood",
		Name = L["Felwood"],
		QAchievementId = 4931,
	},
	[78] = {
		Scale = 7.3999996337891,
		X = -106.66666259766,
		Y = 1193.3333007813,
		Overlay = "ungorocrater",
		Name = L["Un'Goro Crater"],
		QAchievementId = 4939,
	},
	[80] = {
		Scale = 4.6166665039063,
		X = 276.25,
		Y = -1698.333203125,
		Overlay = "moonglade",
		Name = L["Moonglade"],
	},
	[81] = {
		Scale = 8.1166665039063,
		X = -596.66665039063,
		Y = 1174.5833007813,
		Overlay = "silithus",
		Name = L["Silithus"],
		QAchievementIdA = 4934,
	},
	[83] = {
		Scale = 12.299999755859,
		X = 198.33332519531,
		Y = -1758.75,
		Overlay = "winterspring",
		Name = L["Winterspring"],
		QAchievementId = 4940,
	},
	[84] = {
		Scale = 3.474999917984,
		X = -344.58332519531,
		Y = 1599.1666015625,
		Overlay = "stormwindcity",
		Name = L["Stormwind City"],
		City = true,
		MMOutside = true,
	},
	[85] = {
		Scale = 3.47875,
		X = 701.27080078125,
		Y = -497.33334960938,
		Overlay = "orgrimmar",
		Name = L["Orgrimmar"],
		City = true,
		MMOutside = true,
	},
	[86] = {
		Scale = 3.47875,
		X = 701.27080078125,
		Y = -497.33334960938,
		Overlay = "orgrimmar",
		MapBaseName = "orgrimmar1_",
		Name = L["Orgrimmar"],
		City = true,
		MMOutside = true,
	},
	[87] = {
		Scale = 1.5812501220703,
		X = 142.71827392578,
		Y = 913.8482421875,
		Overlay = "ironforge",
		Name = L["Ironforge"],
		City = true,
	},
	[88] = {
		Scale = 2.0874998779297,
		X = -103.33332519531,
		Y = 169.99998779297,
		Overlay = "thunderbluff",
		Name = L["Thunder Bluff"],
		City = true,
		MMOutside = true,
	},
	[89] = {
		Scale = 3.0791667480469,
		X = -637.5,
		Y = -2092.9166015625,
		Overlay = "darnassus",
		Name = L["Darnassus"],
		City = true,
		MMOutside = true,
	},
	[90] = {
		Scale = 1.9187500610352,
		X = -174.63852539063,
		Y = -375.5890625,
		Overlay = "undercity",
		Name = L["Undercity"],
		City = true,
	},
	[91] = {
		Name = L["Alterac Valley"],
		Scale = 8.4749997558594,
		X = 16000,
		Y = 2000,
		Short = "AV",
	},
	[92] = {
		Name = L["Warsong Gulch"],
		Scale = 2.2916666259766,
		X = -16000,
		Y = 1000,
		Short = "WG",
	},
	[93] = {
		Name = L["Arathi Basin"],
		Scale = 3.5124998474121,
		X = -16000,
		Y = 0,
		Short = "AB",
	},
	[94] = {
		Scale = 9.85,
		X = 897.5,
		Y = -2208.333203125,
		Overlay = "eversongwoods",
		Name = L["Eversong Woods"],
		XOff = Map.BloodelfXO,
		YOff = Map.BloodelfYO,
		MId = 94,
	},
	[95] = {
		Scale = 6.6,
		X = 1056.6666015625,
		Y = -1653.333203125,
		Overlay = "ghostlands",
		Name = L["Ghostlands"],
		XOff = Map.BloodelfXO,
		YOff = Map.BloodelfYO,
		MId = 94,
		QAchievementIdH = 4908,
	},
	[97] = {
		Scale = 8.141666015625,
		X = 2100,
		Y = 558.75,
		Overlay = "azuremystisle",
		Name = L["Azuremyst Isle"],
		XOff = Map.DraeneiXO,
		YOff = Map.DraeneiYO,
		MId = 97,
	},
	[100] = {
		Scale = 10.329166015625,
		X = -1107.9166015625,
		Y = -296.25,
		Overlay = "hellfire",
		Name = L["Hellfire Peninsula"],
		QAchievementId = 1189,
		QAchievementIdH = 1271,
	},
	[101] = {
		Scale = 34.92815625,
		X = -2599.2078125,
		Y = -1164.271875,
	},
	[102] = {
		Scale = 10.054166992188,
		X = -1895,
		Y = -387.08332519531,
		Overlay = "zangarmarsh",
		Name = L["Zangarmarsh"],
		QAchievementId = 1190,
	},
	[103] = {
		Scale = 2.113541015625,
		X = 2213.2734375,
		Y = 721.93666992188,
		Overlay = "theexodar",
		Name = L["The Exodar"],
		XOff = Map.DraeneiXO,
		YOff = Map.DraeneiYO,
		City = true,
		MId = 97,
	},
	[104] = {
		Scale = 11,
		X = -845,
		Y = 389.58332519531,
		Overlay = "shadowmoonvalley",
		Name = L["Shadowmoon Valley"],
		QAchievementId = 1195,
	},
	[105] = {
		Scale = 10.849999511719,
		X = -1769.1666015625,
		Y = -881.6666015625,
		Overlay = "bladesedgemountains",
		Name = L["Blade's Edge Mountains"],
		QAchievementId = 1193,
	},
	[106] = {
		Scale = 6.524998046875,
		X = 2015,
		Y = 151.66666259766,
		Overlay = "bloodmystisle",
		Name = L["Bloodmyst Isle"],
		XOff = Map.DraeneiXO,
		YOff = Map.DraeneiYO,
		MId = 97,
		QAchievementIdA = 4926,
	},
	[107] = {
		Scale = 11.05,
		X = -2059.1666015625,
		Y = -8.333332824707,
		Overlay = "nagrand",
		Name = L["Nagrand"],
		QAchievementId = 1192,
		QAchievementIdH = 1273,
	},
	[108] = {
		Scale = 10.799999511719,
		X = -1416.6666015625,
		Y = 199.99998779297,
		Overlay = "terokkarforest",
		Name = L["Terokkar Forest"],
		QAchievementId = 1191,
		QAchievementIdH = 1272,
	},
	[109] = {
		Scale = 11.149999343872,
		X = -1096.6666015625,
		Y = -1091.25,
		Overlay = "netherstorm",
		Name = L["Netherstorm"],
		QAchievementId = 1194,
	},
	[110] = {
		Scale = 2.4229169921875,
		X = 1280.15,
		Y = -2030.741796875,
		Overlay = "silvermooncity",
		Name = L["Silvermoon City"],
		XOff = Map.BloodelfXO,
		YOff = Map.BloodelfYO,
		City = true,
		MId = 94,
	},
	[111] = {
		Scale = 2.6125,
		X = -1227.0517578125,
		Y = 294.79089355469,
		Overlay = "shattrathcity",
		Name = L["Shattrath City"],
		MMOutside = true,
	},
	[112] = {
		Name = L["Eye of the Storm"],
		Scale = 4.5416663818359,
		X = -16000,
		Y = 3000,
		Short = "EOS",
	},
	[113] = {
		Scale = 35.502796875,
		X = -1843.43046875,
		Y = -2118.675,
	},
	[114] = {
		Scale = 11.529166015625,
		X = -1714.1666015625,
		Y = -979.58330078125,
		Overlay = "boreantundra",
		Name = L["Borean Tundra"],
		QAchievementId = 33,
		QAchievementIdH = 1358,
	},
	[115] = {
		Scale = 11.216666259766,
		X = -725.41665039063,
		Y = -1115,
		Overlay = "dragonblight",
		Name = L["Dragonblight"],
		QAchievementId = 35,
		QAchievementIdH = 1359,
	},
	[116] = {
		Scale = 10.499999755859,
		X = 222.08332519531,
		Y = -1103.3333007813,
		Overlay = "grizzlyhills",
		Name = L["Grizzly Hills"],
		QAchievementId = 37,
		QAchievementIdH = 1357,
	},
	[117] = {
		Scale = 12.091665771484,
		X = 279.58332519531,
		Y = -623.33330078125,
		Overlay = "howlingfjord",
		Name = L["Howling Fjord"],
		QAchievementId = 34,
		QAchievementIdH = 1356,
	},
	[118] = {
		Scale = 12.541666625977,
		X = -1088.75,
		Y = -1885.4166015625,
		Overlay = "icecrownglacier",
		Name = L["Icecrown"],
		QAchievementId = 40,
	},
	[119] = {
		Scale = 8.7125,
		X = -1385.8333007813,
		Y = -1457.4999023437,
		Overlay = "sholazarbasin",
		Name = L["Sholazar Basin"],
		QAchievementId = 39,
	},
	[120] = {
		Scale = 14.224999267578,
		X = -368.33332519531,
		Y = -2039.583203125,
		Overlay = "thestormpeaks",
		Name = L["The Storm Peaks"],
		QAchievementId = 38,
	},
	[121] = {
		Scale = 9.9875,
		X = 120,
		Y = -1533.7499023437,
		Overlay = "zuldrak",
		Name = L["Zul'Drak"],	-- [11]
		QAchievementId = 36,
	},
	[122] = {
		Scale = 6.654166015625,
		X = 1060.4166015625,
		Y = -2713.7498046875,
		Overlay = "sunwell",
		Name = L["Isle of Quel'Danas"],
		XOff = Map.BloodelfXO,
		YOff = Map.BloodelfYO,
		MId = 94,
	},
	[123] = {
		Scale = 5.9499997558594,
		X = -865.83330078125,
		Y = -1143.3333007813,
		Overlay = "lakewintergrasp",
		Name = L["Wintergrasp"],
		Explored = true,
	},
	[124] = {
		Scale = 6.325,
		X = 809.58330078125,
		Y = -617.5,
		Overlay = "scarletenclave",
		Name = L["Plaguelands: The Scarlet Enclave"],
		XOff = 400,
		YOff = -33,
		City = true,
	},
	[125] = {
		Name = L["Dalaran"],
		Scale = 1.6589 / 1.3,
		X = -200.95,
		Y = -1199.17260156,
		Overlay = "dalaran",
		MapBaseName = "dalaran1_",
		City = true,
		Alpha = .85,
		ScaleAdjust = 1.3,
		--MapLevel = 1,
	},
	[127] = {
		Scale = 5.4458332519531,
		X = -288.75,
		Y = -1300.4166015625,
		Overlay = "crystalsongforest",
		Name = L["Crystalsong Forest"],
	},
	[128] = {
		Name = L["Strand of the Ancients"],
		Scale = 3.4874998779297,
		X = -14500,
		Y = 0,
		Short = "SoA",
	},
	[169] = {
		Name = L["Isle of Conquest"],
		Scale = 5.3,
		X = -14500,
		Y = 1000,
		Short = "IC",
	},
	[170] = {
		Scale = 7.3541662597656,
		X = -559.58330078125,
		Y = -2156.25,
		Overlay = "hrothgarslanding",
		Name = L["Hrothgar's Landing"],
		Explored = true,
	},
	[174] = {
		Scale = 9.029166015625,
		X = -876.6666015625,
		Y = -576.25,
		Overlay = "thelostisles_terrain2",
		Name = L["The Lost Isles"],
		XOff = 470,
		YOff = 980,
	},
	[179] = {
		Scale = 6.2916665039063,
		X = -687.91665039063,
		Y = 106.66666259766,
		Overlay = "gilneas",
		Name = L["Gilneas"],
	},
	[194] = {
		Scale = 2.7041663818359,
		X = -425.83330078125,
		Y = 1546.2499023437,
		Overlay = "kezan",
		Name = L["Kezan"],
		XOff = 946,
		YOff = -832,
		MId = 194,
	},
	[198] = {
		Scale = 8.4916667480469,
		X = 185.83332519531,
		Y = -1239.1666015625,
		Overlay = "hyjal",
		Name = L["Mount Hyjal"],
		QAchievementId = 4870,
	},
	[199] = {
		Scale = 14.825,
		X = -271.25,
		Y = -40.833331298828,
		Overlay = "southernbarrens",
		Name = L["Southern Barrens"],
		QAchievementId = 4937,
		QAchievementIdH = 4981,
	},
	[201] = {
		Scale = 5.604166015625,
		X = -1014.1666015625,
		Y = 803.74995117188,
		Overlay = "vashjirkelpforest",
		Name = L["Kelp'thar Forest"],
		QAchievementId = 4869,
		QAchievementIdH = 4982,
	},
	[202] = {
		Scale = 1.7791665039063,
		X = -386.66665039063,
		Y = 261.25,
		Overlay = "gilneascity",
		Name = L["Gilneas City"],
	},
	[203] = {
		Scale = 13.891665527344,
		X = -1750.833203125,
		Y = 744.16665039063,
		Overlay = "vashjir",
		Name = L["Vashj'ir"],
	},
	[204] = {
		Scale = 8.15,
		X = -1646.6666015625,
		Y = 981.25,
		Overlay = "vashjirdepths",
		Name = L["Abyssal Depths"],
		QAchievementId = 4869,
		QAchievementIdH = 4982,
	},
	[205] = {
		Scale = 9.6999992675781,
		X = -1336.2499023437,
		Y = 951.25,
		Overlay = "vashjirruins",
		Name = L["Shimmering Expanse"],
		QAchievementId = 4869,
		QAchievementIdH = 4982,
	},
	[206] = {
		Name = L["Twin Peaks"],
		Scale = 2.4291665039062,
		X = -14500,
		Y = 3000,
		Short = "TP",
	},
	[207] = {
		Scale = 10.199999755859,
		X = -610.41665039063,
		Y = -559.16665039063,
		Overlay = "deepholm",
		Name = L["Deepholm"],
		XOff = 1580,
		YOff = 700,
		QAchievementId = 4871,
		MId = 207,
	},
	[210] = {
		Scale = 7.8916662597656,
		X = -421.66665039063,
		Y = 2503.333203125,
		Overlay = "thecapeofstranglethorn",
		Name = L["The Cape of Stranglethorn"],
		QAchievementId = 4905,
	},
	[217] = {
		Scale = 6.2916665039063,
		X = -687.91665039063,
		Y = 106.66666259766,
		Overlay = "ruinsofgilneas",
		Name = L["Ruins of Gilneas"],
		Explored = true,
	},
	[218] = {
		Scale = 1.7791665039063,
		X = -386.66665039063,
		Y = 261.25,
		Overlay = "ruinsofgilneascity",
		Name = L["Ruins of Gilneas City"],
		City = true,
		StartZone = true,
	},
	[224] = {
		Scale = 13.104166015625,
		X = -595.41665039063,
		Y = 2192.9166015625,
		Overlay = "stranglethornvale",
		Name = L["Stranglethorn Vale"],
	},
	[241] = {
		Scale = 10.541666015625,
		X = 487.5,
		Y = 431.25,
		Overlay = "twilighthighlands_terrain1",
		Name = L["Twilight Highlands"],
		QAchievementId = 4873,
		QAchievementIdH = 5501,
	},
	[244] = {
		Scale = 4.0291665849686,
		X = -402.08332519531,
		Y = 112.08332519531,
		Overlay = "tolbarad",
		Name = L["Tol Barad"],
		XOff = -600,
		YOff = 320,
		MId = 244,
		Explored = true,
	},
	[245] = {
		Scale = 3.675,
		X = -482.5,
		Y = -75.416662597656,
		Overlay = "tolbaraddailyarea",
		Name = L["Tol Barad Peninsula"],
		XOff = -600,
		YOff = 320,
		MId = 244,
		Explored = true,
	},
	[249] = {
		Scale = 12.387499511719,
		X = -488.33330078125,
		Y = 1605.8333007813,
		Overlay = "uldum",
		Name = L["Uldum"],
		QAchievementId = 4872,
	},
	[275] = {
		Name = L["The Battle for Gilneas"],
		Scale = 2.6041665649414,
		X = -14500,
		Y = 2000,
		Short = "TBG",
	},
	[276] = {
		Scale = 3.1,
		X = -311.25,
		Y = -274.16665039063,
		Overlay = "themaelstrom",
		Name = L["The Maelstrom"],
		XOff = 1000,
		YOff = 600,
		City = true,
		Explored = true,
	},
	[327] = {
		Scale = 8.0999996643066,
		X = -778.33330078125,
		Y = 1606.6666015625,
		Overlay = "ahnqirajthefallenkingdom",
		Name = L["Ahn'Qiraj: The Fallen Kingdom"],
	},
	[338] = {
		Scale = 2.3791666259766,
		X = -186.66666259766,
		Y = -340.41665039063,
		Overlay = "moltenfront",
		Name = L["Molten Front"],
		MId = 338,
		UseAId = true,
		Explored = true,
	},
	[371] = {
		Scale = 13.966666015625,
		X = -290.4166015625,
		Y = -730.4166015625,
		Overlay = "thejadeforest",
		Name=L["The Jade Forest"],
	},
	[376] = {
		Scale = 7.850001953125,
		X = -535.8333984375,
		Y = -219.1666015625,
		Overlay = "valleyofthefourwinds",
		Name=L["Valley of the Four Winds"],
	},
	[378] = {
		Scale = 5.341666015625,
		X = -995.833203125,
		Y = -357.0833984375,
		Overlay = "thewanderingisle",
		Name=L["The Wandering Isle"],
		StartZone = true,
		XOff = 500,
		YOff = -1500,
		MId = 378,
		MMOutside = true,
	},
	[379] = {
		Scale = 12.516666015625,
		X = -967.9166015625,
		Y = -1123.75,
		Overlay = "kunlaisummit",
		Name=L["Kun-Lai Summit"],
	},
	[388] = {
		Scale = 11.487498046875,
		X = -1415.833203125,
		Y = -911.6666015625,
		Overlay = "townlongwastes",
		Name=L["Townlong Steppes"],
	},
	[390] = {
		Scale = 5.06666796875,
		X = -496.25,
		Y = -389.5833984375,
		Overlay = "valeofeternalblossoms",
		Name=L["Vale of Eternal Blossoms"],
	},
	[397] = {
		BaseMap = 112,
		Short = "EOS",
	},
	[407] = {
		Scale = 3.716666015625,
		X = -953.7499023437,
		Y = 664.58330078125,
		Overlay = "darkmoonfaireisland",
		Name = L["Darkmoon Island"],
		Explored = true,
		MMOutside = true,
		MId=407,
	},
	[417] = {
		Name = L["Temple of Kotmogu"],
		Scale = 1.679166015625,
		X = -14500,
		Y = 4000,
		Short = "TK",
	},
	[418] = {
		Scale = 9.375001953125,
		X = -589.5833984375,
		Y = 22.083204650879,
		Overlay = "krasarang",
		Name=L["Krasarang Wilds"],
	},
	[422] = {
		Name=L["Dread Wastes"],
		Scale = 10.704166015625,
		X = -1227.9166015625,
		Y = -283.3333984375,
		Overlay = "dreadwastes",
	},
	[423] = {
		Name = L["Silvershard Mines"],
		Scale = 4.499998046875,
		X = -14500,
		Y = 5000,
		Short = "SSM",
		MapBaseName = "STVDiamondMineBG1_",
	},
	[424] = {
		Scale = 31.030600585937,
		X = -1750.5720703125,
		Y = -1335.83203125,
	},
	[425] = {
		Scale = 1.9375,
		X = -37.5,
		Y = 1714.16640625,
		Overlay = "northshire",
		Name = L["Northshire"],
		StartZone = true,
	},
	[427] = {
		Scale = 1.929166015625,
		X = -195.8333984375,
		Y = 1192.5,
		Overlay = "coldridgevalley",
		Name = L["Coldridge Valley"],
		StartZone = true,
	},
	[433] = {
		Scale = 3.5875,
		X = -162.5,
		Y = -337.9166015625,
		Overlay = "thehiddenpass",
		Name=L["The Veiled Stair"],
	},
	[460] = {
		Scale = 2.900001953125,
		X = -298.3333984375,
		Y = -2206.6666015625,
		Overlay = "shadowglenstart",
		Name = L["Shadowglen"],
		StartZone = true,
	},
	[461] = {
		Scale = 2.7,
		X = 728.333203125,
		Y = 0,
		Overlay = "valleyoftrialsstart",
		Name = L["Valley of Trials"],
		StartZone = true,
	},
	[462] = {
		Scale = 3.5333359375,
		X = -46.666796875,
		Y = 515.416796875,
		Overlay = "campnarachestart",
		Name = L["Camp Narache"],
		StartZone = true,
	},
	[463] = {
		Scale = 3.6125,
		X = 898.333203125,
		Y = 105,
		Overlay = "echoislesstart",
		Name = L["Echo Isles"],
		StartZone = true,
	},
	[465] = {
		Scale = 2.17916796875,
		X = -429.5833984375,
		Y = -454.1666015625,
		Overlay = "deathknellstart",
		Name = L["Deathknell"],
		StartZone = true,
	},
	[467] = {
		Scale = 3.2,
		X = 1076.666796875,
		Y = -2166.6666015625,
		Overlay = "sunstriderislestart",
		Name = L["Sunstrider Isle"],
		XOff = Map.BloodelfXO,
		YOff = Map.BloodelfYO,
		MId = 94,
		StartZone = true,
	},
	[468] = {
		Scale = 3.6375,
		X = 2562.91640625,
		Y = 720.833203125,
		Overlay = "ammenvalestart",
		Name = L["Ammen Vale"],
		XOff = Map.DraeneiXO,
		YOff = Map.DraeneiYO,
		MId = 97,
		StartZone = true,
	},
	[469] = {
		Scale = 3.7,
		X = -241.25,
		Y = 945.416796875,
		Overlay = "newtinkertownstart",
		Name = L["New Tinkertown"],
		StartZone = true,
	},
	[504] = {
		Scale = 8.27083203125,
		X = -1530.833203125,
		Y = -1629.583203125,
		Overlay = "isleofthethunderking",
		Name = L["Isle of Thunder"],
		Explored = true,
	},
	[507] = {
		Scale = 3.575001953125,
		X = -400.8333984375,
		Y = -1339.583203125,
		Overlay = "isleofgiants",
		Name = L["Isle of Giants"],
		Explored = true,
	},
	[519] = {
		Name = L["Deepwind Gorge"],
		Scale = 2.16666796875,
		X = -13000,
		Y = 0,
		MapBaseName = "GoldRush",
		Short = "DG",
	},
	[525] = {
		Scale = 12.229159912109,
		X = -1501.25,
		Y = -1655,
		Overlay = "frostfireridge",
	},
	[534] = {
		Scale = 10.499999755859,
		X = -341.66599121094,
		Y = -1186.666015625,
		Overlay = "TanaanJungle",
	},
	[535] = {
		Scale = 11.924992156982,
		X = -1166.666015625,
		Y = -885.833984375,
		Overlay = "talador",
	},
	[539] = {
		Scale = 13.4,
		X = -453.75,
		Y = -532.083984375,
		Overlay = "shadowmoonvalleydr",
	},
	[542] = {
		Scale = 12.120840087891,
		X = -936.25,
		Y = -276.66599121094,
		Overlay = "spiresofarak",
	},
	[543] = {
		Scale = 16.3541796875,
		X = -1013.333984375,
		Y = -1917.916015625,
		Overlay = "gorgrond",
	},
	[550] = {
		Scale = 11.35,
		X = -1861.666015625,
		Y = -984.583984375,
		Overlay = "nagranddraenor",
	},
	[554] = {
		Scale = 4.8,
		X = 816.666796875,
		Y = -46.666796875,
		Overlay = "timelessisle",
		Name = L["Timeless Isle"],
		Explored = true,
	},
	[572] = {
		Scale = 45.471564453125,
		X = -2448.46875,
		Y = -2238.6,
	},
	[577] = {
		Scale = 4.8166599121094,
		X = 210.83400878906,
		Y = -968.333984375,
		Overlay = "tanaanjungleintro",
	},
	[579] = {
		BaseMap = 582,
	},
	[580] = {
		BaseMap = 582,
	},
	[581] = {
		BaseMap = 582,
	},
	[582] = {
		Scale = 1.36666796875,
		X = -109.166796875,
		Y = -418.3333984375,
		Garrison = true,
		Instance = true,
		City = true,
		MMOutside = true,
		Explored = true,
		MapBaseName = "garrisonsmvalliance_tier",
		Overlay = "garrisonsmvalliance_tier1",
	},
	[585] = {
		BaseMap = 590
	},
	[586] = {
		BaseMap = 590
	},
	[587] = {
		BaseMap = 590
	},
	[588] = {
		Scale = 6.2458203125,
		X = 534.583984375,
		Y = -1115.416015625,
		Explored = true,
		Overlay = "ashran",
	},
	[590] = {
		Scale = 1.404166015625,
		X = -977.083203125,
		Y = -1162.9166015625,
		Garrison = true,
		Instance = true,
		City = true,
		MMOutside = true,
		Explored = true,
		MapBaseName = "garrisonffhorde_tier",
		Overlay = "garrisonffhorde_tier1",
	},	
	[619] = {
		Scale = 37.67636,
		X = -2620.02,
		Y = -1452.426,		
	},	
	[622] = {
		Scale = 1.375,
		X = 725,
		Y = -781.6666015625,
		Explored = true,
		City = true,
		Overlay = "ashranalliancefactionhub",
	},
	[623] = {
		Name = L["Tarren Mills vs Southshore"],
		Scale = 4.337498046875,
		X = -13000,
		Y = 1000,
		MapBaseName = "HillsbradFoothillsBG",
		Short = "TvS",
	},
	[624] = {
		Scale = 1.6,
		X = 717.916796875,
		Y = -1108.333203125,
		Explored = true,
		City = true,
		Overlay = "ashranhordefactionhub",
	},
	[625] = {
		Scale = 1.8,
		X = -983,
		Y = 112,
		Overlay = "dalaran7",
		MapBaseName = "Dalaran7010_",
		City = true,
		Alpha = .85,
		MapLevel = 1,		
	},
	[627] = {
		BaseMap = 625,
		City = true,
		MapLevel = 1,
	},
	[630] = {
		 Scale = 13.179166,
		 X = -1966.25,
		 Y = -361.25,
		 Overlay = "azsuna",
		 Name = L["Azsuna"],
	},
	[634] = {
		 Scale = 11.60416,
		 X = -1006.666,
		 Y = -1035.416,
		 Overlay = "stormheim",
		 Name = L["Stormheim"],
	},
	[641] = {
		 Scale = 11.020834,
		 X = -1921.25,
		 Y = -992.9166,
		 Overlay = "valsharah",
		 Name = L["Val'Sharah"]
	},
	[646] = {
		 Scale = 7.7,
		 X = -983.334,
		 Y = 0.833204,
		 Overlay = "brokenshore",
		 Name = L["Broken Shore"],
	},
	[650] = {
		 Scale = 14.141666,
		 X = -1537.9166,
		 Y = -1392.5,
		 Overlay = "highmountain",
		 Name = L["Highmountain"],
	},
	[672] = {
		 Scale = 7.487501968,
		 X = -3105.8334,
		 Y = -514.5834,
		 Overlay = "mardumtheshatteredabyss",
		Name = L["Mardum, The Shattered Abyss"],
		Explored = true,
	},
	[680] = {
		 Scale = 11.10416,
		 X = -1331.666,
		 Y = -689.166,
		 Overlay = "suramar",
		 Name = L["Suramar"],
	},
	[750] = {
		Scale = 1.8625,
		X = -960,
		Y = -879.5832,
		Explored = true,
		City = true,		
		Overlay = "thundertotem",
	},
	[830] = {
		Scale = 7.429172,
		X = -754.584,
		Y = -530.834,
		Name = L["Krokuun"],
		Overlay = "argussurface",
		MId = 830,
		XOff = -100,
		YOff = 100,
	},
	[862] = {
		X = -1142.0832,
		Y = -275.8334,
		Scale = 16.929164,
		Name = L["Zuldazar"],
		Overlay = "zuldazar"
	},
	[863] = {
		X = -689.1666,
		Y = -705.4166,
		Scale = 10.504166,
		Name = L["Nazmir"],
		Overlay = "nazmir"
	},
	[864] = {
		X = -1337.9166,
		Y = -867.5,
		Scale = 13.624998046,
		Name = L["Vol'Dun"],
		Overlay = "voldun"
	},	
	[875] = {
		X = -1745.58,
		Y = -906.1,
		Scale = 27.33296
	},
	[876] = {
		X = -1504.16,
		Y = -1095,
		Scale = 26.212498
	},	
	[882] = {
		 Scale = 6.5166,
		 X = -2309.16,
		 Y = -1324.584,
		 Name = L["Mac'Aree"],
		 Overlay = "argusmacaree",		 
		 MId = 882,
		 XOff = 1400,
		 YOff = 500,
	},
	[885] = {
		 Scale = 6.80006,
		 X = -2255.84,
		 Y = 357.916,
		 Name = L["Antoran Wastes"],
		 Overlay = "arguscore",
		 MId = 885,
		 XOff = 800,
		 YOff = -900,
	},
	[895] = {
		X = -997.0832,
		Y = -462.0834,
		Scale = 14.829164,
		Name = L["Tiragarde Sound"],
		Overlay = "tiragardesound"
	},
	[896] = {
		X = -1060.834,
		Y = -252.916,
		Scale = 11.475008,
		Name = L["Drustvar"],
		Overlay = "drustvar"
	},
	[905] = {
		 Scale = 13.53196,
		 X = -1457.47,
		 Y = -852.756,
	},
	[942] = {
		X = -668.75,
		Y = -1032.5,
		Scale = 11.354168,
		Name = L["Stormsong Valley"],
		Overlay = "stormsongvalley"
	},
	[948] = {
		Scale = 26,
		X = -311.25,
		Y = -274.16665039063,
	},	
	[1161] = {
		Scale = 3.587506,
		X = -146.6666,
		Y = -266.666,
		TileX = 15,
		TileY = 10,
		Overlay = "BoralusCity",
		MapBaseName = "BoralusCity",
		City = true,
		Alpha = .85,
		MapLevel = 1,		
	},
	[1165] = {
		Scale = 5.629172,
		X = -442.084,
		Y = 52.5,
		TileX = 15,
		TileY = 10,
		Overlay = "ZuldazarCity_Exterior",
		MapBaseName = "ZuldazarCity_Exterior",
		City = true,
		Alpha = .85,
		MapLevel = 1,		
	},
	[1169] = {
		Scale = 1.2458203125,
		X = 483.583984375,
		Y = -60.416015625,
		Name = L["Tol Dagor"],
		Overlay = "toldagor"
	},
	[1355] = {
		Scale = 8.529166,
		X = -319.5834,
		Y = -557.5,
		Name = L["Nazjatar"],
		Overlay = "nazjatar",
	},
	
	-- The Shadowlands
	
	[1550] = {
		Scale = 48.3125,
		X = -2513.75,
		Y = -1266.25,
	},

	[1525] = {
		Scale = 11.254166,
		X = -1883.3332,
		Y = 68.75,
		Name = L["Revendreth"],
		Overlay = "revendreth",
	},
	[1533] = {
		Scale = 13.3375,
		X = 284.1668,
		Y = 172.5,
		Name = L["Bastion"],
		Overlay = "bastion",
	},
	[1536] = {
		Scale = 12.6,
		X = -125.4168,
		Y = -963.3332,
		Name = L["Maldraxxus"],
		Overlay = "maldraxxus",
	},
	[1543] = {
		Scale = 8.279166,
		X = -1733.3332,
		Y = -1146.6666,
		Name = L["The Maw"],
		Overlay = "themaw",
	},
	[1648] = {
		BaseMap = 1543
	},
	[1565] = {
		Scale = 14.27916,
		X = -863.75,
		Y = 871.666,
		Name = L["Ardenweald"],
		Overlay = "ardenweald",
	},
	
	[1670] = {
		Scale = 1.635,
		X = -341.75,
		Y = 312,
		Name = L["Oribos - Ring of Fates"],
		Overlay = "oribos_main",
		MapBaseName = "oribos_arbiter",
		City = true,
		Alpha = .85,
		MapLevel = 1,
	},
	[1671] = {
		Scale = 1.635,
		X = -341.75,
		Y = 312,
		Name = L["Oribos - Ring of Transference"],
		Overlay = "oribos_portals",
		MapBaseName = "oribos_arbiter",
		City = true,
		Alpha = .85,
		MapLevel = 2,
	},
	[1672] = {
		Scale = 1.635,
		X = -341.75,
		Y = 312,
		Name = L["Oribos - The Broker's Den"],
		Overlay = "oribos_vip",
		MapBaseName = "oribos_arbiter",
		City = true,
		Alpha = .85,
		MapLevel = 2,
	},
	[1673] = {
		Scale = 1.635,
		X = -341.75,
		Y = 312,
		Name = L["Oribos - The Crucible"],
		Overlay = "oribos_arbiter",
		MapBaseName = "oribos_arbiter",
		City = true,
		Alpha = .85,
		MapLevel = 2,
	},
	
	-- 1726 NPE SHIP
	
	[1409] = {
		Scale = 6.7625,
		X = 4150,
		Y = -2850,
		Name = L["Exile's Reach"],
		Overlay = "npe",
		Explored = true,
		MId = 1409,
	},
	
	[1462] = {
		Scale = 4.675,
		X = -1324.166,
		Y = -736.25,
		Name = L["Mechagon Island"],
		Overlay = "mechagonisland"		
	},
	[1469] = {
		Scale = 3.47875,
		X = 701.27080078125,
		Y = -497.33334960938,
		Overlay = "orgrimmar",
		Name = L["Orgrimmar"],
		City = true,
		MMOutside = true,
	},
	[1470] = {
		Scale = 3.474999917984,
		X = -344.58332519531,
		Y = 1599.1666015625,
		Overlay = "stormwindcity",
		Name = L["Stormwind City"],
		City = true,
		MMOutside = true,
	},
	[1527] = {
		Scale = 12.387499511719,
		X = -488.33330078125,
		Y = 1605.8333007813,
		Overlay = "uldum",
		Name = L["Uldum"],
	},
	[1530] = {
		Scale = 5.06666796875,
		X = -496.25,
		Y = -389.5833984375,
		Overlay = "valeofeternalblossoms",
		Name=L["Vale of Eternal Blossoms"],
	},
	[9005] = {		-- Blade's Edge Arena
		Name = L["Blade's Edge Arena"],
		1,
		-16000,4000,
		Short = "BEA",
		Arena = true
	},
	[9006] = {		-- Nagrand Arena
		Name = L["Nagrand Arena"],
		1,
		-16000,5000,
		Short = "NA",
		Arena = true
	},
	[9007] = {		-- Ruins of Lordaeron
		Name = L["Ruins of Lordaeron"],
		1,
		-16000,6000,
		Short = "RL",
		Arena = true
	},
	[9014] = {
		Name = L["Tol'vir Proving Grounds"],
		3.0,
		-14500,6000,
		Short = "TPG",
		Arena = true
	},

	[9016] = {
		Name = L["Tigers Peak Arena"],
		1,
		-13000,1000,
		Short = "TPA",
		Arena = true,
	},
}

--------

Map.InstanceInfo = {		-- Blizzard instance maps (SetInstanceMap uses size of 3 for table entries)
}

-- UIMapXMapArt -> WorldMapOverlay -> WorldMapOverlayTitle
Map.ZoneOverlays = {

	-- Kalimdor

		["moonglade"] = {
			["shrineofremulos"] = "209,91,271,296",
			["lakeeluneara"] = "219,273,431,319",
			["stormragebarrowdens"] = "542,210,275,346",
			["nighthaven"] = "370,135,346,244",
		},
		["barrens"] = {
			["dreadmistpeak"] = "290,104,241,195",
			["thornhill"] = "481,254,239,231",
			["thestagnantoasis"] = "344,379,336,289",
			["farwatchpost"] = "555,129,207,332",
			["thesludgefen"] = "403,6,257,249",
			["thewailingcaverns"] = "152,318,377,325",
			["thedryhills"] = "116,57,283,270",
			["themerchantcoast"] = "556,456,315,212",
			["boulderlodemine"] = "511,7,278,209",
			["theforgottenpools"] = "100,208,446,256",
			["morshanrampart"] = "258,6,261,216",
			["ratchet"] = "547,379,219,175",
			["thecrossroads"] = "362,275,233,193",
			["groldomfarm"] = "448,127,243,217",
		},
		["winterspring"] = {
			["icethistlehills"] = "581,314,249,217",
			["lakekeltheril"] = "372,268,271,258",
			["starfallvillage"] = "229,33,367,340",
			["mazthoril"] = "399,340,257,238",
			["frostsaberrock"] = "304,0,332,268",
			["timbermawpost"] = "92,302,362,252",
			["thehiddengrove"] = "500,17,333,255",
			["frostwhispergorge"] = "424,474,317,183",
			["everlook"] = "482,195,194,229",
			["owlwingthicket"] = "556,439,254,150",
			["winterfallvillage"] = "588,181,221,209",
			["frostfirehotsprings"] = "93,118,376,289",
		},
		["uldum_terrain1"] = {
			["thegateofunendingcycles"] = "647,15,161,236",
			["thecursedlanding"] = "752,170,237,316",
			["ruinsofammon"] = "217,289,203,249",
			["akhenetfields"] = "471,277,164,185",
			["orsis"] = "264,136,249,243",
			["nahom"] = "583,162,237,194",
			["ramkahen"] = "411,67,228,227",
			["obeliskofthemoon"] = "110,0,400,224",
			["obeliskofthesun"] = "340,282,269,203",
			["thetrailofdevestation"] = "657,349,206,204",
			["cradeloftheancient"] = "341,402,202,169",
			["schnottzslanding"] = "28,221,312,289",
			["marat"] = "406,174,160,193",
			["virnaaldam"] = "479,215,151,144",
			["throneofthefourwinds"] = "229,433,270,229",
			["thevortexpinnacle"] = "656,473,213,195",
			["hallsoforigination"] = "599,184,269,242",
			["templeofuldum"] = "132,127,296,209",
			["obeliskofthestars"] = "551,121,196,170",
			["ruinsofahmtul"] = "365,0,278,173",
			["khartutstomb"] = "542,0,203,215",
			["neferset"] = "407,384,209,254",
			["tahretgrounds"] = "545,193,150,159",
			["lostcityofthetolvir"] = "527,291,233,321",
		},
		["ashenvale"] = {
			["theshrineofassenia"] = "40,275,306,283",
			["nightrun"] = "595,253,221,257",
			["fallenskylake"] = "529,385,287,276",
			["warsonglumbercamp"] = "771,265,231,223",
			["lakefalathim"] = "112,148,184,232",
			["satyrnaar"] = "696,154,235,236",
			["thehowlingvale"] = "473,97,325,239",
			["raynewoodretreat"] = "481,221,231,256",
			["thezoramstrand"] = "0,0,262,390",
			["felfirehill"] = "714,317,277,333",
			["maelstraspost"] = "188,0,246,361",
			["thunderpeak"] = "377,121,203,310",
			["theruinsofstardust"] = "210,331,236,271",
			["orendilsretreat"] = "143,0,244,251",
			["astranaar"] = "255,164,251,271",
			["thistlefurvillage"] = "255,78,314,241",
			["silverwindrefuge"] = "338,335,347,308",
			["boughshadow"] = "836,148,166,211",
		},
		["teldrassil"] = {
			["banethilhollow"] = "374,221,175,235",
			["shadowglen"] = "481,104,241,217",
			["gnarlpinehold"] = "347,355,198,181",
			["thecleft"] = "432,109,144,226",
			["theoracleglade"] = "276,90,194,244",
			["rutheranvillage"] = "329,448,317,220",
			["lakealameth"] = "422,310,289,202",
			["wellspringlake"] = "382,83,165,249",
			["starbreezevillage"] = "544,217,187,196",
			["galardellvalley"] = "466,237,178,186",
			["poolsofarlithrien"] = "345,243,140,210",
			["darnassus"] = "149,181,298,337",
		},
		["mulgore"] = {
			["baeldundigsite"] = "226,220,218,192",
			["winterhoofwaterwell"] = "449,340,174,185",
			["redcloudmesa"] = "286,401,446,264",
			["redrocks"] = "514,43,186,185",
			["ravagedcaravan"] = "435,224,187,165",
			["thunderhornwaterwell"] = "333,202,201,167",
			["theventurecomine"] = "530,138,208,300",
			["wildmanewaterwell"] = "331,0,190,172",
			["thunderbluff"] = "208,62,373,259",
			["windfuryridge"] = "400,0,222,202",
			["bloodhoofvillage"] = "319,273,302,223",
			["stonetalonpass"] = "201,0,237,184",
			["therollingplains"] = "527,291,260,243",
			["palemanerock"] = "248,321,172,205",
			["thegoldenplains"] = "448,101,186,216",
		},
		["hyjal"] = {
			["archimondesvengeance"] = "320,5,270,300",
			["shrineofgoldrinn"] = "116,17,291,321",
			["nordrassil"] = "392,0,537,323",
			["gatesofsothann"] = "622,320,272,334",
			["sethriasroost"] = "139,436,277,232",
			["theregrowth"] = "52,253,441,319",
			["direforgehill"] = "303,197,270,173",
			["ashenlake"] = "6,78,282,418",
			["thescorchedplain"] = "411,216,365,264",
			["thethroneofflame"] = "318,378,419,290",
			["darkwhispergorge"] = "682,128,320,471",
		},
		["felwood"] = {
			["irontreewoods"] = "406,55,261,273",
			["morlosaran"] = "476,484,187,176",
			["bloodvenomfalls"] = "220,231,345,192",
			["jaedenar"] = "234,317,319,176",
			["felpawvillage"] = "471,0,307,161",
			["jadefirerun"] = "303,9,263,199",
			["ruinsofconstellas"] = "278,359,268,214",
			["deadwoodvillage"] = "410,505,173,163",
			["emeraldsanctuary"] = "394,382,274,212",
			["shatterscarvale"] = "243,107,343,250",
			["talonbranchglade"] = "531,57,209,226",
			["jadefireglen"] = "288,458,229,210",
		},
		["darkshore"] = {
			["lordanel"] = "391,54,277,281",
			["eyeofthevortex"] = "300,239,330,192",
			["nazjvel"] = "207,467,244,201",
			["wildbendriver"] = "280,378,314,193",
			["ruinsofauberdine"] = "280,182,203,194",
			["witheringthicket"] = "305,118,328,250",
			["shatterspearvale"] = "596,16,250,241",
			["shatterspearwarcamp"] = "565,0,245,147",
			["ametharan"] = "294,330,326,145",
			["ruinsofmathystra"] = "517,28,200,263",
			["themastersglaive"] = "277,483,303,185",
		},
		["aszhara"] = {
			["bearshead"] = "113,141,256,224",
			["thesecretlab"] = "353,396,184,213",
			["ruinsofarkkoran"] = "575,121,219,193",
			["darnassianbasecamp"] = "343,3,243,262",
			["lakemennar"] = "245,377,210,232",
			["ravencrestmonument"] = "476,401,295,267",
			["stormcliffs"] = "407,403,207,232",
			["theshatteredstrand"] = "316,168,206,329",
			["gallywixpleasurepalace"] = "70,222,250,230",
			["blackmawhold"] = "204,53,260,267",
			["bilgewaterharbor"] = "395,127,587,381",
			["towerofeldara"] = "684,22,306,337",
			["orgimmarreargate"] = "22,344,352,274",
			["bitterreaches"] = "477,0,321,247",
			["ruinsofeldarath"] = "228,229,218,237",
		},
		["ungorocrater"] = {
			["lakkaritarpits"] = "305,0,432,294",
			["ironstoneplateau"] = "706,201,197,222",
			["therollinggarden"] = "565,39,337,321",
			["golakkahotsprings"] = "145,226,309,277",
			["theslitheringscar"] = "335,384,381,274",
			["thescreamingreaches"] = "157,0,332,332",
			["mossypile"] = "328,179,186,185",
			["themarshlands"] = "573,256,263,412",
			["fireplumeridge"] = "356,192,321,288",
			["terrorrun"] = "162,357,316,293",
			["fungalrock"] = "557,0,224,191",
			["marshalsstand"] = "462,330,204,170",
		},
		["desolace"] = {
			["valleyofspears"] = "170,196,321,275",
			["gelkisvillage"] = "207,472,274,196",
			["mannoroccoven"] = "381,357,326,311",
			["thunderaxefortress"] = "440,49,220,205",
			["shokthokar"] = "589,319,309,349",
			["cenarionwildlands"] = "415,156,312,285",
			["sargeron"] = "655,0,317,293",
			["nijelspoint"] = "573,0,231,257",
			["magramterritory"] = "613,170,289,244",
			["thargadscamp"] = "275,376,212,186",
			["tethrisaran"] = "399,0,274,145",
			["kodograveyard"] = "360,273,250,215",
			["ranzjarisle"] = "210,0,161,141",
			["shadowbreakravine"] = "637,402,292,266",
			["shadowpreyvillage"] = "142,369,222,299",
			["slitherbladeshore"] = "208,24,338,342",
		},
		["tanaris"] = {
			["landsendbeach"] = "431,452,224,216",
			["southbreakshore"] = "437,289,274,186",
			["zulfarrak"] = "184,0,315,190",
			["valleryofthewatchers"] = "255,431,269,190",
			["southmoonruins"] = "301,349,232,211",
			["brokenpillar"] = "413,211,195,163",
			["thegapingchasm"] = "448,364,225,187",
			["cavernsoftime"] = "507,238,213,173",
			["gadgetzan"] = "412,92,189,180",
			["dunemaulcompound"] = "305,257,231,177",
			["gadgetzanbay"] = "479,9,254,341",
			["lostriggercover"] = "615,201,178,243",
			["eastmoonruins"] = "380,341,173,163",
			["abyssalsands"] = "297,148,255,194",
			["thistleshrubvalley"] = "185,280,221,293",
			["thenoxiouslair"] = "258,211,179,190",
			["sandsorrowwatch"] = "293,99,214,149",
		},
		["uldum"] = {
			["thegateofunendingcycles"] = "647,15,161,236",
			["thecursedlanding"] = "752,170,237,316",
			["ruinsofammon"] = "217,289,203,249",
			["akhenetfields"] = "471,277,164,185",
			["orsis"] = "264,136,249,243",
			["nahom"] = "583,162,237,194",
			["ramkahen"] = "411,67,228,227",
			["obeliskofthemoon"] = "110,0,400,224",
			["obeliskofthesun"] = "340,282,269,203",
			["thetrailofdevestation"] = "657,349,206,204",
			["cradeloftheancient"] = "341,402,202,169",
			["schnottzslanding"] = "28,221,312,289",
			["marat"] = "406,174,160,193",
			["virnaaldam"] = "479,215,151,144",
			["throneofthefourwinds"] = "229,433,270,229",
			["thevortexpinnacle"] = "656,473,213,195",
			["hallsoforigination"] = "599,184,269,242",
			["templeofuldum"] = "132,127,296,209",
			["obeliskofthestars"] = "551,121,196,170",
			["ruinsofahmtul"] = "365,0,278,173",
			["khartutstomb"] = "542,0,203,215",
			["neferset"] = "407,384,209,254",
			["tahretgrounds"] = "545,193,150,159",
			["lostcityofthetolvir"] = "527,291,233,321",
		},
		["ahnqirajthefallenkingdom"] = {
			["aqkingdom"] = "115,0,887,668",
		},
		["durotar"] = {
			["razormanegrounds"] = "302,264,248,158",
			["echoisles"] = "429,413,330,255",
			["thunderridge"] = "295,48,220,218",
			["skullrock"] = "438,0,208,157",
			["tiragardekeep"] = "462,298,210,200",
			["valleyoftrials"] = "304,312,254,258",
			["southfurywatershed"] = "282,174,244,222",
			["drygulchravine"] = "415,60,236,196",
			["senjinvillage"] = "457,406,192,184",
			["razorhill"] = "431,157,224,227",
			["northwatchfoothold"] = "399,440,162,157",
			["orgrimmar"] = "309,0,259,165",
		},
		["feralas"] = {
			["campmojache"] = "671,181,174,220",
			["feathermoonstronghold"] = "362,237,217,192",
			["darkmistruins"] = "568,287,172,198",
			["writhingdeep"] = "652,298,232,206",
			["ruinsoffeathermoon"] = "186,229,208,204",
			["theforgottencoast"] = "375,343,194,304",
			["feralscar"] = "457,281,191,179",
			["grimtotemcompund"] = "607,170,159,218",
			["ruinsofisildien"] = "467,354,206,237",
			["gordunnioutpost"] = "663,116,192,157",
			["thetwincolossals"] = "271,0,350,334",
			["diremaul"] = "485,101,265,284",
			["lowerwilds"] = "756,191,207,209",
		},
		["silithus"] = {
			["thescarabwall"] = "0,455,580,213",
			["valorsrest"] = "614,0,315,285",
			["twilightbasecamp"] = "100,151,434,231",
			["southwindvillage"] = "550,181,309,243",
			["thecrystalvale"] = "126,0,329,246",
			["hiveashi"] = "345,4,405,267",
			["cenarionhold"] = "427,143,292,260",
			["hiveregal"] = "380,310,489,358",
			["hivezora"] = "0,206,542,367",
		},
		["stonetalonmountains"] = {
			["windshearcrag"] = "533,179,374,287",
			["kromgarfortress"] = "588,341,183,196",
			["stonetalonpeak"] = "265,0,305,244",
			["unearthedgrounds"] = "654,369,265,206",
			["greatwoodvale"] = "602,448,322,220",
			["boulderslideravine"] = "532,512,194,156",
			["cliffwalkerpost"] = "366,95,241,192",
			["webwinderpath"] = "468,263,267,352",
			["sunrockretreat"] = "353,285,222,222",
			["webwinderhollow"] = "479,401,164,258",
			["ruinsofeldrethar"] = "367,411,221,235",
			["battlescarvalley"] = "220,189,290,297",
			["windshearhold"] = "516,289,176,189",
			["thaldarahoverlook"] = "252,121,210,189",
			["malakajin"] = "618,537,211,131",
			["mirkfallonlake"] = "417,143,244,247",
			["thecharredvale"] = "199,368,277,274",
		},
		["southernbarrens"] = {
			["huntershill"] = "300,64,218,178",
			["honorsstand"] = "201,0,315,170",
			["ruinsoftaurajo"] = "244,286,285,171",
			["razorfenkraul"] = "273,528,214,140",
			["vendettapoint"] = "267,196,254,214",
			["forwardcommand"] = "423,251,216,172",
			["battlescar"] = "274,307,384,248",
			["theovergrowth"] = "289,117,355,226",
			["baelmodan"] = "398,457,269,211",
			["northwatchhold"] = "548,147,280,279",
			["frazzlecrazmotherload"] = "269,436,242,195",
		},
		["dustwallow"] = {
			["witchhill"] = "428,0,270,353",
			["theramoreisle"] = "542,223,305,247",
			["direhornpost"] = "358,169,279,301",
			["blackhoofvillage"] = "199,0,344,183",
			["brackenwllvillage"] = "133,59,384,249",
			["alcazisland"] = "656,21,206,200",
			["mudsprocket"] = "109,313,433,351",
			["shadyrestinn"] = "137,188,317,230",
			["thewyrmbog"] = "359,369,436,299",
		},
		["hyjal_terrain1"] = {
			["archimondesvengeance"] = "320,5,270,300",
			["shrineofgoldrinn"] = "116,17,291,321",
			["nordrassil"] = "392,0,537,323",
			["gatesofsothann"] = "622,320,272,334",
			["sethriasroost"] = "139,436,277,232",
			["theregrowth"] = "52,253,441,319",
			["direforgehill"] = "303,197,270,173",
			["ashenlake"] = "6,78,282,418",
			["thescorchedplain"] = "411,216,365,264",
			["thethroneofflame"] = "318,378,419,290",
			["darkwhispergorge"] = "682,128,320,471",
		},
		["thousandneedles"] = {
			["southseaholdfast"] = "756,412,246,256",
			["thetwilightwithering"] = "347,329,374,339",
			["splithoofheights"] = "571,49,431,410",
			["thegreatlift"] = "136,0,272,232",
			["razorfendowns"] = "298,0,361,314",
			["theshimmeringdeep"] = "591,257,411,411",
			["freewindpost"] = "276,186,436,271",
			["highperch"] = "0,134,246,380",
			["rustmauldivesite"] = "527,465,234,203",
			["westreachsummit"] = "0,0,280,325",
			["twilightbulwark"] = "125,241,358,418",
			["darkcloudpinnacle"] = "169,116,317,252",
		},

	-- Eastern Kingdoms

		["vashjirruins"] = {
			["nespirah"] = "460,261,286,269",
			["glimmeringdeepgorge"] = "270,222,272,180",
			["silvertidehollow"] = "150,32,480,319",
			["shimmeringgrotto"] = "400,0,339,278",
			["ruinsofvashjir"] = "217,268,349,361",
			["ruinsoftherseral"] = "554,175,197,223",
			["bethmoraridge"] = "407,445,335,223",
		},
		["duskwood"] = {
			["theyorgenfarmstead"] = "401,396,233,248",
			["addlesstead"] = "32,348,299,296",
			["thetranquilgardenscemetary"] = "627,344,291,244",
			["darkshire"] = "640,128,329,314",
			["brightwoodgrove"] = "497,112,279,399",
			["vulgologremound"] = "228,355,268,282",
			["thehushedbank"] = "0,152,189,307",
			["thedarkenedbank"] = "71,26,931,235",
			["manormistmantle"] = "661,122,219,182",
			["racenhill"] = "96,292,205,157",
			["thetwilightgrove"] = "314,101,320,388",
			["therottingorchard"] = "539,368,291,263",
			["ravenhillcemetary"] = "91,132,323,309",
		},
		["vashjirkelpforest"] = {
			["darkwhispergorge"] = "528,228,220,189",
			["honorstomb"] = "380,43,291,206",
			["legionsfate"] = "210,35,278,315",
			["gnawsboneyard"] = "451,325,311,217",
			["theaccursedreef"] = "365,162,340,225",
			["gubogglesledge"] = "399,280,227,207",
			["holdingpens"] = "456,401,316,267",
		},
		["twilighthighlands_terrain1"] = {
			["victorypoint"] = "302,306,177,159",
			["dragonmawpass"] = "76,120,283,206",
			["bloodgulch"] = "416,205,215,157",
			["obsidianforest"] = "436,380,342,288",
			["thundermar"] = "374,93,238,229",
			["grimbatol"] = "83,223,230,276",
			["theblackbreach"] = "498,121,211,210",
			["wyrmsbend"] = "205,232,191,198",
			["dragonmawport"] = "631,245,251,207",
			["crucibleofcarnage"] = "387,268,203,208",
			["twilightshore"] = "610,345,260,202",
			["vermillionredoubt"] = "71,16,324,264",
			["thegullet"] = "269,179,175,180",
			["humboldtconflaguration"] = "344,89,143,141",
			["gorshakwarcamp"] = "543,220,194,170",
			["highbank"] = "697,403,220,227",
			["crushblow"] = "370,447,182,195",
			["thetwilightcitadel"] = "151,314,361,354",
			["highlandforest"] = "482,330,239,232",
			["thetwilightbreach"] = "312,192,199,212",
			["thekrazzworks"] = "654,0,226,232",
			["slitheringcove"] = "622,169,198,201",
			["thetwilightgate"] = "327,356,165,199",
			["ruinsofdrakgor"] = "296,0,206,182",
			["firebeardspatrol"] = "499,265,215,181",
			["dunwaldruins"] = "395,367,197,218",
			["weepingwound"] = "358,0,214,190",
			["kirthaven"] = "482,0,308,267",
			["glopgutshollow"] = "291,89,174,190",
		},
		["hinterlands"] = {
			["queldanillodge"] = "220,181,241,211",
			["thealtarofzul"] = "357,343,225,196",
			["shaolwatha"] = "565,208,281,261",
			["thecreepingruin"] = "390,252,199,199",
			["zunwatha"] = "152,284,226,225",
			["plaguemistravine"] = "133,105,191,278",
			["shadraalor"] = "220,379,240,196",
			["aeriepeak"] = "0,236,238,267",
			["valorwindlake"] = "286,269,199,212",
			["agolwatha"] = "367,159,208,204",
			["jinthaalor"] = "487,334,287,289",
			["skulkrock"] = "490,195,176,235",
			["seradane"] = "475,5,303,311",
			["theoverlookcliffs"] = "677,267,244,401",
		},
		["blastedlands"] = {
			["serpentscoil"] = "459,97,218,183",
			["nethergardekeep"] = "530,6,295,205",
			["dreadmaulpost"] = "327,182,235,188",
			["altarofstorms"] = "225,110,238,195",
			["riseofthedefiler"] = "375,102,168,170",
			["dreadmaulhold"] = "258,0,272,206",
			["thetaintedforest"] = "132,311,348,357",
			["surwich"] = "333,474,199,191",
			["thedarkportal"] = "368,179,370,298",
			["theredreaches"] = "533,268,268,354",
			["shattershore"] = "578,91,240,270",
			["sunveilexcursion"] = "386,374,233,266",
			["nethergardesupplycamps"] = "436,0,195,199",
			["thetaintedscar"] = "144,175,308,226",
		},
		["wetlands"] = {
			["sundownmarsh"] = "121,63,276,243",
			["blackchannelmarsh"] = "37,240,301,232",
			["dunalgaz"] = "346,419,298,215",
			["slabchiselssurvey"] = "532,352,300,316",
			["satlspray"] = "218,0,250,282",
			["greenwardensgrove"] = "460,102,250,269",
			["raptorridge"] = "599,123,256,245",
			["thelganrock"] = "371,335,258,207",
			["bluegillmarsh"] = "31,102,321,248",
			["mosshidefen"] = "506,232,369,235",
			["direforgehills"] = "506,34,329,228",
			["angerfangencampment"] = "359,201,236,256",
			["whelgarsexcavationsite"] = "185,195,298,447",
			["dunmodr"] = "356,7,257,185",
			["ironbeardstomb"] = "372,76,185,224",
			["menethilharbor"] = "0,297,325,363",
		},
		["easternplaguelands"] = {
			["zulmashar"] = "528,0,286,176",
			["thefungalvale"] = "183,211,274,216",
			["theundercroft"] = "56,457,280,211",
			["lightshopechapel"] = "687,271,196,220",
			["corinscrossing"] = "493,289,186,213",
			["tyrshand"] = "651,414,214,254",
			["eastwalltower"] = "541,184,181,176",
			["northpasstower"] = "401,69,250,192",
			["acherus"] = "774,102,228,273",
			["thondorilriver"] = "0,100,262,526",
			["themarrisstead"] = "133,335,202,202",
			["thenoxiousglade"] = "650,55,297,299",
			["thepestilentscar"] = "383,348,182,320",
			["theinfectisscar"] = "595,263,177,266",
			["terrordale"] = "0,10,258,320",
			["blackwoodlake"] = "382,151,238,231",
			["stratholme"] = "118,0,310,178",
			["quellithienlodge"] = "351,0,277,175",
			["plaguewood"] = "144,40,328,253",
			["darrowshire"] = "211,462,248,206",
			["ruinsofthescarletenclave"] = "738,295,264,373",
			["lightsshieldtower"] = "391,271,243,162",
			["northdale"] = "570,61,265,232",
			["crownguardtower"] = "258,351,202,191",
			["lakemereldar"] = "462,427,266,241",
		},
		["badlands"] = {
			["agmondsend"] = "230,315,342,353",
			["apocryphansrest"] = "0,66,252,353",
			["campcagg"] = "0,281,339,347",
			["uldaman"] = "336,0,266,210",
			["lethlorravine"] = "533,55,469,613",
			["campboff"] = "407,220,274,448",
			["hammertoesdigsite"] = "411,116,209,196",
			["campkosh"] = "504,19,236,260",
			["angorfortress"] = "230,68,285,223",
			["deathwingscar"] = "175,178,328,313",
			["thedustbowl"] = "144,99,214,285",
		},
		["silverpine"] = {
			["northtidesrun"] = "147,0,281,345",
			["thesepulcher"] = "341,157,218,200",
			["forsakenhighcommand"] = "445,0,361,175",
			["thedecrepitfields"] = "471,156,176,152",
			["northtidesbeachhead"] = "323,68,174,199",
			["theforsakenfront"] = "433,327,152,189",
			["valgansfield"] = "461,77,162,172",
			["deepelemmine"] = "483,212,217,198",
			["thebattlefront"] = "349,429,255,180",
			["fenrisisle"] = "581,15,352,302",
			["shadowfangkeep"] = "337,337,179,165",
			["olsensfarthing"] = "312,249,251,167",
			["ambermill"] = "509,250,283,243",
			["berensperil"] = "505,405,318,263",
			["forsakenrearguard"] = "369,0,186,238",
			["thegreymanewall"] = "318,506,409,162",
			["theskitteringdark"] = "236,0,227,172",
		},
		["thecapeofstranglethorn"] = {
			["bootybay"] = "289,341,225,255",
			["gurubashiarena"] = "345,0,238,260",
			["mistvalevalley"] = "408,248,253,242",
			["crystalveinmine"] = "528,73,271,204",
			["wildshore"] = "340,392,236,276",
			["nekmaniwellspring"] = "292,213,246,221",
			["ruinsofaboraz"] = "533,181,184,176",
			["jagueroisle"] = "471,404,240,264",
			["thesundering"] = "452,0,244,209",
			["hardwrenchhideaway"] = "208,116,356,221",
			["ruinsofjubuwal"] = "468,119,155,221",
		},
		["vashjirdepths"] = {
			["abyssalbreach"] = "497,0,491,470",
			["seabrush"] = "415,183,225,250",
			["fireplumetrench"] = "315,110,298,251",
			["lghorek"] = "162,210,306,293",
			["coldlightchasm"] = "266,280,267,374",
			["abandonedreef"] = "50,263,371,394",
			["korthunsend"] = "412,283,370,385",
			["deepfinridge"] = "275,32,363,262",
		},
		["stranglethornjungle"] = {
			["kurzenscompound"] = "499,0,244,238",
			["balalruins"] = "267,168,159,137",
			["thevilereef"] = "140,208,236,224",
			["moshoggogremound"] = "543,253,234,206",
			["ruinsofzulkunda"] = "158,0,228,265",
			["fortlivingston"] = "398,375,230,170",
			["mazthoril"] = "488,364,350,259",
			["nesingwarysexpedition"] = "306,63,227,190",
			["zuuldalaruins"] = "9,22,324,263",
			["kalairuins"] = "354,184,139,150",
			["zulgurub"] = "626,0,376,560",
			["baliamahruins"] = "397,243,239,205",
			["bambala"] = "566,164,190,176",
			["mizjahruins"] = "387,246,157,173",
			["lakenazferiti"] = "413,95,240,228",
			["gromgolbasecamp"] = "298,228,167,179",
			["rebelcamp"] = "306,0,302,166",
		},
		["ruinsofgilneas"] = {
			["gilneaspuzzle"] = "0,0,1002,668",
		},

		["gilneas_terrain2"] = {
			["greymanemanor"] = "141,202,244,241",
			["theblackwald"] = "504,394,280,224",
			["theheadlands"] = "160,0,328,336",
			["crowleyorchard"] = "261,427,210,166",
			["emberstonemine"] = "639,43,281,351",
			["duskhaven"] = "272,333,286,178",
			["tempestsreach"] = "652,290,350,345",
			["korothsden"] = "393,386,222,268",
			["hammondfarmstead"] = "167,352,194,236",
			["haywardfishery"] = "293,449,177,219",
			["stormglenvillage"] = "516,465,321,203",
			["northgatewoods"] = "482,14,282,298",
			["northernheadlands"] = "387,0,267,314",
			["keelharbor"] = "298,95,280,342",
		},
		["searinggorge"] = {
			["blackrockmountain"] = "243,424,304,244",
			["thoriumpoint"] = "255,38,429,301",
			["tannercamp"] = "413,360,571,308",
			["thecauldron"] = "232,171,481,360",
			["blackcharcave"] = "0,361,375,307",
			["grimsiltworksite"] = "531,241,441,266",
			["firewatchridge"] = "0,75,365,393",
			["dustfirevalley"] = "588,0,392,355",
		},
		["elwynn"] = {
			["westbrookgarrison"] = "116,355,269,313",
			["jerodslanding"] = "396,430,230,206",
			["northshirevalley"] = "355,138,295,296",
			["goldshire"] = "247,294,276,231",
			["stromwind"] = "0,0,512,422",
			["stonecairnlake"] = "552,186,340,272",
			["crystallake"] = "417,327,220,207",
			["towerofazora"] = "529,287,270,241",
			["ridgepointtower"] = "708,442,285,194",
			["brackwellpumpkinpatch"] = "532,424,287,216",
			["fargodeepmine"] = "240,420,269,248",
			["eastvaleloggingcamp"] = "703,292,294,243",
		},
		["arathi"] = {
			["refugepoint"] = "293,145,196,270",
			["galensfall"] = "0,144,212,305",
			["northfoldmanor"] = "132,105,227,268",
			["circleofeastbinding"] = "506,126,183,238",
			["bouldergor"] = "171,123,249,278",
			["goshekfarm"] = "430,249,306,248",
			["cirecleofouterbinding"] = "332,273,215,188",
			["hammerfall"] = "581,118,270,271",
			["thandolspan"] = "261,416,237,252",
			["boulderfisthall"] = "327,367,252,258",
			["faldirscove"] = "77,400,273,268",
			["witherbarkvillage"] = "476,359,260,220",
			["stromgardekeep"] = "21,269,284,306",
			["dabyriesfarmstead"] = "404,144,210,227",
			["circleofinnerbinding"] = "201,312,228,227",
			["circleofwestbinding"] = "85,24,220,287",
		},
		["dunmorogh"] = {
			["thegrizzledden"] = "374,287,211,160",
			["coldridgepass"] = "360,340,225,276",
			["kharanos"] = "449,220,184,188",
			["gnomeregan"] = "0,27,409,318",
			["thetundridhills"] = "579,306,174,249",
			["theshimmeringdeep"] = "397,132,171,234",
			["golbolarquarry"] = "663,288,198,251",
			["iceflowlake"] = "263,0,236,358",
			["amberstillranch"] = "595,225,249,183",
			["ironforgeairfield"] = "630,0,308,335",
			["frostmanehold"] = "50,227,437,249",
			["coldridgevalley"] = "100,366,398,302",
			["ironforge"] = "398,0,376,347",
			["helmsbedlake"] = "760,268,218,234",
			["northgateoutpost"] = "765,43,237,366",
			["frostmanefront"] = "469,256,226,335",
		},
		["westfall"] = {
			["thedaggerhills"] = "303,395,292,273",
			["furlbrowspumpkinfarm"] = "394,0,197,213",
			["thegapingchasm"] = "294,168,184,217",
			["jangoloadmine"] = "311,0,196,229",
			["goldcoastquarry"] = "199,79,235,306",
			["themolsenfarm"] = "348,118,202,224",
			["westfalllighthouse"] = "221,477,211,167",
			["sentinelhill"] = "404,226,229,265",
			["demontsplace"] = "203,376,201,195",
			["alexstonfarmstead"] = "167,263,346,222",
			["saldeansfarm"] = "451,81,244,237",
			["moonbrook"] = "308,325,232,213",
			["thedustplains"] = "480,378,317,261",
			["thedeadacre"] = "531,200,193,273",
			["thejansenstead"] = "474,0,202,179",
		},
		["burningsteppes"] = {
			["blackrockpass"] = "419,258,298,410",
			["dreadmaulrock"] = "568,151,274,263",
			["dracodar"] = "0,237,362,431",
			["altarofstorms"] = "0,0,182,360",
			["ruinsofthaurissan"] = "421,0,324,354",
			["blackrockmountain"] = "79,0,281,388",
			["terrorwingpath"] = "646,7,350,341",
			["blackrockstronghold"] = "235,0,320,385",
			["morgansvigil"] = "615,255,383,413",
			["pillarofash"] = "253,255,274,413",
		},
		["westernplaguelands"] = {
			["thebulwark"] = "48,235,316,316",
			["hearthglen"] = "235,0,432,271",
			["caerdarrow"] = "601,390,194,208",
			["sorrowhill"] = "261,448,368,220",
			["felstonefield"] = "229,228,241,212",
			["darrowmerelake"] = "510,354,492,314",
			["northridgelumbercamp"] = "231,123,359,182",
			["thewrithinghaunt"] = "472,332,169,195",
			["thondrorilriver"] = "533,0,311,436",
			["theweepingcave"] = "551,151,185,230",
			["redpinedell"] = "286,211,290,133",
			["dalsonsfarm"] = "300,232,325,192",
			["andorhal"] = "96,343,464,325",
			["gahrronswithering"] = "495,213,241,252",
		},
		["tirisfal"] = {
			["balnirfarmstead"] = "594,324,242,179",
			["venomwebvale"] = "752,150,250,279",
			["thebulwark"] = "709,330,293,338",
			["brill"] = "480,252,199,182",
			["scarletmonastery"] = "740,47,262,262",
			["scarletwatchpost"] = "692,99,161,234",
			["agamandmills"] = "324,90,285,260",
			["brightwaterlake"] = "573,122,210,292",
			["ruinsoflorderon"] = "423,359,390,267",
			["sollidenfarmstead"] = "201,192,286,225",
			["calstonestate"] = "389,255,179,169",
			["coldhearthmanor"] = "418,317,212,177",
			["deathknell"] = "9,207,431,407",
			["nightmarevale"] = "347,325,225,281",
			["crusaderoutpost"] = "686,232,175,210",
			["garrenshaunt"] = "477,129,190,214",
		},
		["redridge"] = {
			["rendersvalley"] = "451,377,427,291",
			["stonewatchkeep"] = "480,0,228,420",
			["lakeridgehighway"] = "148,316,392,352",
			["campeverstill"] = "445,286,189,193",
			["renderscamp"] = "214,0,357,246",
			["lakeeverstill"] = "81,214,464,250",
			["lakeshire"] = "0,110,410,256",
			["althersmill"] = "350,139,228,247",
			["shalewindcanyon"] = "688,283,306,324",
			["stonewatchfalls"] = "525,302,316,182",
			["galardellvalley"] = "574,0,428,463",
			["threecorners"] = "0,256,323,406",
			["redridgecanyons"] = "37,0,413,292",
		},
		["swampofsorrows"] = {
			["splinterspearjunction"] = "194,236,238,343",
			["stagalbog"] = "540,360,347,303",
			["marshtidewatch"] = "478,0,330,342",
			["pooloftears"] = "575,238,257,229",
			["theshiftingmire"] = "331,24,292,360",
			["sorrowmurk"] = "703,80,229,418",
			["ithariuscave"] = "7,242,268,316",
			["mistyreedstrand"] = "600,0,402,668",
			["stonard"] = "297,258,357,308",
			["mistyvalley"] = "0,80,268,285",
			["theharborage"] = "161,79,266,284",
			["bogpaddle"] = "600,0,262,193",
		},
		["lochmodan"] = {
			["thefarstriderlodge"] = "570,209,349,292",
			["stronewroughtdam"] = "339,0,333,200",
			["silverstreammine"] = "221,0,225,252",
			["northgatepass"] = "16,0,319,289",
			["ironbandsexcavationsite"] = "481,296,397,291",
			["stonesplintervalley"] = "177,345,273,294",
			["thelsamar"] = "0,146,455,295",
			["grizzlepawridge"] = "245,324,273,230",
			["valleyofkings"] = "0,311,310,345",
			["theloch"] = "340,81,330,474",
			["mogroshstronghold"] = "549,52,294,249",
		},
		["deadwindpass"] = {
			["deadmanscrossing"] = "83,0,617,522",
			["thevice"] = "433,208,350,449",
			["karazhan"] = "92,310,513,358",
		},
		["hillsbradfoothills"] = {
			["tarrenmill"] = "494,226,165,203",
			["gavinsnaze"] = "344,254,116,129",
			["lordamereinternmentcamp"] = "194,216,250,167",
			["mistyshore"] = "321,42,158,169",
			["nethandersteed"] = "502,373,204,244",
			["hillsbradfields"] = "191,302,302,175",
			["growlesscave"] = "359,191,171,136",
			["theheadland"] = "390,255,105,148",
			["azurelodemine"] = "287,399,180,182",
			["dalarancrater"] = "102,137,316,238",
			["gallowscorner"] = "451,140,155,147",
			["strahnbrad"] = "505,44,275,193",
			["darrowhill"] = "425,279,147,160",
			["southpointtower"] = "59,310,312,254",
			["dandredsfold"] = "341,0,258,113",
			["slaughterhollow"] = "413,55,148,120",
			["soferasnaze"] = "484,166,148,146",
			["ruinsofalterac"] = "347,85,189,181",
			["corrahnsdagger"] = "426,224,135,160",
			["purgationisle"] = "200,505,144,139",
			["crushridgehold"] = "463,101,134,124",
			["dungarok"] = "542,410,269,258",
			["durnholdekeep"] = "565,217,437,451",
			["chillwindpoint"] = "555,68,447,263",
			["theuplands"] = "441,0,212,160",
			["southshore"] = "383,352,229,219",
		},

	-- Jamie exports

	["azuremystisle"] =
	{
		["ammenford"] = "515,279,256,256",
		["ammenvale"] = "527,104,475,512",
		["azurewatch"] = "383,249,256,256",
		["bristlelimbvillage"] = "174,363,256,256",
		["emberglade"] = "488,24,256,256",
		["fairbridgestrand"] = "356,0,256,128",
		["greezlescamp"] = "507,350,256,256",
		["moongrazewoods"] = "449,183,256,256",
		["odesyuslanding"] = "352,378,256,256",
		["podcluster"] = "281,305,256,256",
		["podwreckage"] = "462,349,128,256",
		["siltingshore"] = "291,3,256,256",
		["silvermystisle"] = "23,446,256,222",
		["stillpinehold"] = "365,49,256,256",
		["theexodar"] = "74,85,512,512",
		["valaarsberth"] = "176,303,256,256",
		["wrathscalepoint"] = "220,421,256,247",
	},
	["bladesedgemountains"] =
	{
		["bashirlanding"] = "422,0,256,256",
		["bladedgulch"] = "623,147,256,256",
		["bladesiprehold"] = "314,161,256,507",
		["bloodmaulcamp"] = "412,95,256,256",
		["bloodmauloutpost"] = "342,371,256,297",
		["brokenwilds"] = "733,109,256,256",
		["circleofwrath"] = "439,210,256,256",
		["deathsdoor"] = "512,249,256,419",
		["forgecampanger"] = "586,147,416,256",
		["forgecampterror"] = "144,416,512,252",
		["forgecampwrath"] = "254,176,256,256",
		["grishnath"] = "286,28,256,256",
		["gruulslayer"] = "527,81,256,256",
		["jaggedridge"] = "446,414,256,254",
		["moknathalvillage"] = "658,297,256,256",
		["ravenswood"] = "214,55,512,256",
		["razorridge"] = "533,332,256,336",
		["ridgeofmadness"] = "554,258,256,410",
		["ruuanweald"] = "479,98,256,512",
		["skald"] = "673,71,256,256",
		["sylvanaar"] = "289,350,256,318",
		["thecrystalpine"] = "585,0,256,256",
		["thunderlordstronghold"] = "405,272,256,396",
		["veillashh"] = "271,428,256,240",
		["veilruuan"] = "563,151,256,128",
		["vekhaarstand"] = "629,406,256,256",
		["vortexpinnacle"] = "166,206,256,462",
	},
	["bloodmystisle"] =
	{
		["amberwebpass"] = "44,62,256,512",
		["axxarien"] = "297,136,256,256",
		["blacksiltshore"] = "177,426,512,242",
		["bladewood"] = "367,209,256,256",
		["bloodscaleisle"] = "763,256,239,256",
		["bloodwatch"] = "437,258,256,256",
		["bristlelimbenclave"] = "546,410,256,256",
		["kesselscrossing"] = "517,527,485,141",
		["middenvale"] = "414,406,256,256",
		["mystwood"] = "309,483,256,185",
		["nazzivian"] = "250,404,256,256",
		["ragefeatherridge"] = "481,117,256,256",
		["ruinsofloretharan"] = "556,216,256,256",
		["talonstand"] = "657,78,256,256",
		["telathionscamp"] = "180,216,128,128",
		["thebloodcursedreef"] = "729,54,256,256",
		["thebloodwash"] = "302,27,256,256",
		["thecrimsonreach"] = "555,87,256,256",
		["thecryocore"] = "293,285,256,256",
		["thefoulpool"] = "221,136,256,256",
		["thehiddenreef"] = "205,39,256,256",
		["thelostfold"] = "503,470,256,198",
		["thevectorcoil"] = "43,238,512,430",
		["thewarppiston"] = "451,29,256,256",
		["veridianpoint"] = "637,0,256,256",
		["vindicatorsrest"] = "232,242,256,256",
		["wrathscalelair"] = "598,338,256,256",
		["wyrmscarisland"] = "613,82,256,256",
	},
	["eversongwoods"] =
	{
		["azurebreezecoast"] = "669,228,256,256",
		["duskwithergrounds"] = "605,253,256,256",
		["eastsanctum"] = "460,373,256,256",
		["elrendarfalls"] = "580,399,128,256",
		["fairbreezevilliage"] = "386,386,256,256",
		["farstriderretreat"] = "524,359,256,128",
		["goldenboughpass"] = "243,469,256,128",
		["lakeelrendar"] = "584,471,128,197",
		["northsanctum"] = "361,298,256,256",
		["ruinsofsilvermoon"] = "307,136,256,256",
		["runestonefalithas"] = "378,496,256,172",
		["runestoneshandor"] = "464,494,256,174",
		["satherilshaven"] = "324,384,256,256",
		["silvermooncity"] = "440,87,512,512",
		["stillwhisperpond"] = "474,314,256,256",
		["sunsailanchorage"] = "231,404,256,128",
		["sunstriderisle"] = "195,5,512,512",
		["thegoldenstrand"] = "183,415,128,253",
		["thelivingwood"] = "511,420,128,248",
		["thescortchedgrove"] = "255,507,256,128",
		["thuronslivery"] = "539,305,256,128",
		["torwatha"] = "648,315,256,353",
		["tranquilshore"] = "215,298,256,256",
		["westsanctum"] = "292,319,128,256",
		["zebwatha"] = "554,475,128,193",
	},
	["ghostlands"] =
	{
		["amanipass"] = "598,232,404,436",
		["bleedingziggurat"] = "184,238,256,256",
		["dawnstarspire"] = "575,0,427,256",
		["deatholme"] = "95,375,512,293",
		["elrendarcrossing"] = "326,0,512,256",
		["farstriderenclave"] = "573,136,429,256",
		["goldenmistvillage"] = "44,0,512,512",
		["howlingziggurat"] = "340,219,256,449",
		["isleoftribulations"] = "585,0,256,256",
		["sanctumofthemoon"] = "210,126,256,256",
		["sanctumofthesun"] = "448,150,256,512",
		["suncrownvillage"] = "460,0,512,256",
		["thalassiapass"] = "364,406,256,262",
		["tranquillien"] = "365,2,256,512",
		["windrunnerspire"] = "40,287,256,256",
		["windrunnervillage"] = "60,117,256,512",
		["zebnowa"] = "466,237,512,431",
	},
	["hellfire"] =
	{
		["denofhaalesh"] = "182,412,256,256",
		["expeditionarmory"] = "261,413,512,255",
		["falconwatch"] = "183,326,512,342",
		["fallenskyridge"] = "34,142,256,256",
		["forgecamprage"] = "478,25,512,512",
		["hellfirecitadel"] = "338,210,256,458",
		["honorhold"] = "469,298,256,256",
		["magharpost"] = "206,110,256,256",
		["poolsofaggonar"] = "326,45,256,512",
		["ruinsofshanaar"] = "25,290,256,378",
		["templeoftelhamat"] = "38,152,512,512",
		["thelegionfront"] = "579,128,256,512",
		["thestairofdestiny"] = "737,156,256,512",
		["thrallmar"] = "467,154,256,256",
		["throneofkiljaeden"] = "477,6,512,256",
		["voidridge"] = "705,368,256,256",
		["warpfields"] = "308,408,256,260",
		["zethgor"] = "580,430,422,238",
	},
	["nagrand"] =
	{
		["burningbladeruins"] = "660,334,256,334",
		["clanwatch"] = "532,363,256,256",
		["forgecampfear"] = "36,248,512,420",
		["forgecamphate"] = "162,154,256,256",
		["garadar"] = "431,143,256,256",
		["halaa"] = "335,193,256,256",
		["kilsorrowfortress"] = "558,427,256,241",
		["laughingskullruins"] = "351,52,256,256",
		["oshugun"] = "168,334,512,334",
		["ringoftrials"] = "533,267,256,256",
		["southwindcleft"] = "391,258,256,256",
		["sunspringpost"] = "219,199,256,256",
		["telaar"] = "387,390,256,256",
		["throneoftheelements"] = "504,53,256,256",
		["twilightridge"] = "10,107,256,512",
		["warmaulhill"] = "157,32,256,256",
		["windyreedpass"] = "598,79,256,256",
		["windyreedvillage"] = "666,233,256,256",
		["zangarridge"] = "277,54,256,256",
	},
	["netherstorm"] =
	{
		["area52"] = "241,388,256,128",
		["arklonruins"] = "328,397,256,256",
		["celestialridge"] = "644,173,256,256",
		["ecodomefarfield"] = "396,10,256,256",
		["etheriumstaginggrounds"] = "481,208,256,256",
		["forgebaseog"] = "237,22,256,256",
		["kirinvarvillage"] = "490,523,256,145",
		["manaforgebanar"] = "147,281,256,387",
		["manaforgecoruu"] = "357,489,256,179",
		["manaforgeduro"] = "465,336,256,256",
		["manafrogeara"] = "171,155,256,256",
		["netherstone"] = "411,20,256,256",
		["netherstormbridge"] = "132,294,256,256",
		["ruinedmanaforge"] = "513,138,256,256",
		["ruinsofenkaat"] = "253,301,256,256",
		["ruinsoffarahlon"] = "354,49,512,256",
		["socretharsseat"] = "229,38,256,256",
		["sunfuryhold"] = "454,451,256,217",
		["tempestkeep"] = "593,284,409,384",
		["theheap"] = "239,455,256,213",
		["thescrapfield"] = "356,261,256,256",
		["thestormspire"] = "298,134,256,256",
	},
	["shadowmoonvalley"] =
	{
		["altarofshatar"] = "520,93,256,256",
		["coilskarpoint"] = "348,8,512,512",
		["eclipsepoint"] = "343,310,512,358",
		["illadarpoint"] = "143,256,256,256",
		["legionhold"] = "104,155,512,512",
		["netherwingcliffs"] = "554,308,256,256",
		["netherwingledge"] = "510,445,492,223",
		["shadowmoonvilliage"] = "116,35,512,512",
		["theblacktemple"] = "606,126,396,512",
		["thedeathforge"] = "290,129,256,512",
		["thehandofguldan"] = "394,90,512,512",
		["thewardenscage"] = "469,258,512,410",
		["wildhammerstronghold"] = "168,229,512,439",
	},
	["terokkarforest"] =
	{
		["allerianstronghold"] = "480,277,256,256",
		["auchenaigrounds"] = "247,434,256,234",
		["bleedinghollowclanruins"] = "103,301,256,367",
		["bonechewerruins"] = "521,275,256,256",
		["carrionhill"] = "377,272,256,256",
		["cenarionthicket"] = "314,0,256,256",
		["firewingpoint"] = "617,149,385,512",
		["grangolvarvilliage"] = "143,171,512,256",
		["raastokglade"] = "505,154,256,256",
		["razorthornshelf"] = "478,19,256,256",
		["refugecaravan"] = "316,268,128,256",
		["ringofobservance"] = "310,345,256,256",
		["sethekktomb"] = "245,289,256,256",
		["shattrathcity"] = "104,4,512,512",
		["skethylmountains"] = "449,348,512,320",
		["smolderingcaravan"] = "321,460,256,208",
		["stonebreakerhold"] = "397,165,256,256",
		["thebarrierhills"] = "116,4,256,256",
		["tuurem"] = "455,34,256,512",
		["veilrhaze"] = "222,362,256,256",
		["writhingmound"] = "417,327,256,256",
	},
	["zangarmarsh"] =
	{
		["angoroshgrounds"] = "88,50,256,256",
		["angoroshstronghold"] = "124,0,256,128",
		["bloodscaleenclave"] = "596,412,256,256",
		["cenarionrefuge"] = "694,321,308,256",
		["coilfangreservoir"] = "462,90,256,512",
		["feralfenvillage"] = "314,332,512,336",
		["marshlightlake"] = "81,152,256,256",
		["oreborharborage"] = "329,25,256,512",
		["quaggridge"] = "141,325,256,343",
		["sporeggar"] = "20,202,512,256",
		["telredor"] = "569,112,256,512",
		["thedeadmire"] = "716,128,286,512",
		["thehewnbog"] = "219,51,256,512",
		["thelagoon"] = "512,303,256,256",
		["thespawningglen"] = "31,339,256,256",
		["twinspireruins"] = "342,249,256,256",
		["umbrafenvillage"] = "720,461,256,207",
		["zabrajin"] = "175,232,256,256",
	},

	-- Manually added for patch 2.4
	["sunwell"] =
	{
		["sunsreachharbor"] = "252,252,512,416",
		["sunsreachsanctum"] = "251,4,512,512",
	},

	-- WotLK

	["scarletenclave"] =
	{
		["scarletenclave"] = "0,0,1024,768",	-- FIX!!
	},
	["lakewintergrasp"] = {
		["lakewintergrasp"] = "0,0,1024,768",
	},
	["dalaran"] = {
		["dalaran1_"] = "0,0,1024,768",		-- FIX!!
	},
	
	["npe"] = {
		["npe"] = "0,0,1024,768",		-- FIX!!
	},

	["boreantundra"] = {
		["deathsstand"] = "707,181,289,279",
		["templecityofenkilah"] = "712,15,290,292",
		["warsongstronghold"] = "329,237,260,278",
		["riplashstrand"] = "293,383,382,258",
		["thedensofdying"] = "662,11,203,209",
		["thegeyserfields"] = "480,0,375,342",
		["torpsfarm"] = "272,237,186,276",
		["valiancekeep"] = "457,264,259,302",
		["garroshslanding"] = "153,238,267,378",
		["borgorokoutpost"] = "314,0,396,203",
		["amberledge"] = "325,140,244,214",
		["kaskala"] = "509,214,385,316",
		["steeljawscaravan"] = "397,66,244,319",
		["coldarra"] = "50,0,460,381",
	},
	["sholazarbasin"] = {
		["kartakshold"] = "76,375,329,293",
		["theavalanche"] = "596,92,322,265",
		["thesavagethicket"] = "396,51,293,229",
		["thesuntouchedpillar"] = "82,186,455,316",
		["themakersperch"] = "172,135,249,248",
		["themakersoverlook"] = "705,236,233,286",
		["rainspeakercanopy"] = "427,244,207,235",
		["themosslightpillar"] = "265,355,239,313",
		["theglimmeringpillar"] = "308,34,294,327",
		["thelifebloodpillar"] = "501,134,312,369",
		["thestormwrightsshelf"] = "138,58,268,288",
		["riversheart"] = "359,339,468,329",
	},
	["dragonblight"] = {
		["lightsrest"] = "703,7,299,278",
		["galakrondsrest"] = "433,118,258,225",
		["newhearthglen"] = "614,358,214,261",
		["rubydragonshrine"] = "374,208,188,211",
		["icemistvillage"] = "134,165,235,337",
		["venomspite"] = "661,264,226,212",
		["westwindrefugeecamp"] = "42,187,229,299",
		["obsidiandragonshrine"] = "256,104,304,203",
		["naxxramas"] = "691,160,311,272",
		["wyrmresttemple"] = "453,219,317,353",
		["scarletpoint"] = "569,7,235,354",
		["emeralddragonshrine"] = "543,362,196,218",
		["agmarshammer"] = "258,203,236,218",
		["theforgottenshore"] = "698,332,301,286",
		["thecrystalvice"] = "487,0,229,259",
		["angrathar"] = "210,0,306,242",
		["lakeindule"] = "217,313,356,300",
		["coldwindheights"] = "403,0,213,219",
	},
	["crystalsongforest"] = {
		["windrunnersoverlook"] = "444,383,558,285",
		["theunboundthicket"] = "500,105,502,477",
		["theazurefront"] = "0,244,416,424",
		["forlornwoods"] = "129,0,544,668",
		["violetstand"] = "0,176,264,303",
		["thegreattree"] = "0,91,252,260",
		["thedecrepitflow"] = "0,0,288,222",
		["sunreaverscommand"] = "536,40,446,369",
	},
	["howlingfjord"] = {
		["scalawagpoint"] = "168,410,350,258",
		["baleheim"] = "576,170,174,173",
		["giantsrun"] = "572,0,298,306",
		["halgrind"] = "397,208,187,263",
		["utgardekeep"] = "477,216,248,382",
		["vengeancelanding"] = "664,25,223,338",
		["nifflevar"] = "595,240,178,208",
		["emberclutch"] = "283,203,213,256",
		["ivaldsruin"] = "668,223,193,201",
		["cauldrosisle"] = "490,161,181,178",
		["fortwildervar"] = "490,0,251,192",
		["thetwistedglade"] = "420,57,266,210",
		["newagamand"] = "415,360,284,308",
		["baelgunsexcavationsite"] = "621,327,244,305",
		["apothecarycamp"] = "99,37,263,265",
		["ancientlift"] = "342,351,177,191",
		["kamagua"] = "99,278,333,265",
		["gjalerbron"] = "225,0,242,189",
		["explorersleagueoutpost"] = "585,336,232,216",
		["westguardkeep"] = "90,180,347,220",
		["skorn"] = "343,108,238,232",
		["campwinterhoof"] = "354,0,223,209",
		["steelgate"] = "222,100,222,168",
	},
	["zuldrak"] = {
		["zeramas"] = "7,412,307,256",
		["draksotrafields"] = "326,358,286,265",
		["altarofrhunok"] = "431,127,247,304",
		["altarofsseratus"] = "288,168,237,248",
		["kolramas"] = "380,437,302,231",
		["gundrak"] = "629,0,336,297",
		["altarofquetzlun"] = "607,251,261,288",
		["altarofharkoa"] = "533,345,265,257",
		["lightsbreach"] = "181,363,321,305",
		["thrymsend"] = "0,247,272,268",
		["amphitheaterofanguish"] = "289,287,266,254",
		["voltarus"] = "174,191,218,291",
		["altarofmamtoth"] = "575,88,291,258",
		["zimtorga"] = "479,241,249,258",
	},
	["grizzlyhills"] = {
		["grizzlemaw"] = "358,187,294,227",
		["voldrune"] = "176,421,283,247",
		["conquesthold"] = "17,307,332,294",
		["dunargol"] = "547,257,455,400",
		["ragefangshrine"] = "312,294,475,362",
		["drakiljinruins"] = "607,41,351,284",
		["venturebay"] = "18,461,274,207",
		["thormodan"] = "509,0,329,246",
		["granitesprings"] = "7,207,356,224",
		["blueskylogginggrounds"] = "232,129,249,235",
		["draktheronkeep"] = "0,46,382,285",
		["amberpinelodge"] = "217,244,278,290",
		["ursocsden"] = "331,32,328,260",
		["camponeqwah"] = "548,137,324,265",
	},
	["thestormpeaks"] = {
		["frosthold"] = "134,429,244,220",
		["templeofstorms"] = "239,301,169,164",
		["ulduar"] = "218,0,369,265",
		["sparksocketminefield"] = "242,468,251,200",
		["borsbreath"] = "109,375,322,195",
		["engineofthemakers"] = "316,296,210,179",
		["garmsbane"] = "395,470,184,191",
		["dunniffelem"] = "481,285,309,383",
		["narvirscradle"] = "214,144,180,239",
		["nidavelir"] = "108,206,221,200",
		["brunnhildarvillage"] = "339,370,305,298",
		["snowdriftplains"] = "162,143,205,232",
		["valkyrion"] = "98,318,228,158",
		["templeoflife"] = "570,113,182,270",
		["terraceofthemakers"] = "292,122,363,341",
		["thunderfall"] = "627,179,306,484",
	},
	["icecrownglacier"] = {
		["aldurthar"] = "355,37,373,375",
		["corprethar"] = "342,392,308,212",
		["thebombardment"] = "538,181,248,243",
		["onslaughtharbor"] = "0,167,204,268",
		["sindragosasfall"] = "626,31,300,343",
		["thefleshwerks"] = "218,291,219,283",
		["jotunheim"] = "22,122,393,474",
		["valleyofechoes"] = "715,390,269,217",
		["theconflagration"] = "327,305,227,210",
		["thebrokenfront"] = "558,329,283,231",
		["scourgeholme"] = "690,267,245,239",
		["ymirheim"] = "444,276,223,207",
		["theshadowvault"] = "321,15,223,399",
		["argenttournamentground"] = "616,30,314,224",
		["icecrowncitadel"] = "392,466,308,202",
		["valhalas"] = "217,50,238,240",
	},

	-- Patch 3.2
	["hrothgarslanding"] =
	{
--		["hrothgarslanding"] = "0,0,1024,768",
		["hrothgarslanding2"] = "256,0,256,256,1",	-- Just draw 4 parts
		["hrothgarslanding3"] = "512,0,256,256,1",
		["hrothgarslanding6"] = "256,256,256,256,1",
		["hrothgarslanding7"] = "512,256,256,256,1",
	},

	-- Cataclysm
	["tolbarad"] = {
		["tolbarad"] = "0,0,1024,768",			-- Manual
	},
	["tolbaraddailyarea"] = {
		["tolbaraddailyarea"] = "0,0,1024,768",		-- Manual
	},

	["themaelstrom"] = {
		["themaelstrom"] = "0,0,1024,768",		-- Manual
	},
	["thelostisles_terrain2"] = {
		["gallywixdocks"] = "351,21,173,180",
		["alliancebeachhead"] = "129,348,177,172",
		["bilgewaterlumberyard"] = "462,43,248,209",
		["thesavageglen"] = "213,325,231,216",
		["oostan"] = "492,161,210,258",
		["raptorrise"] = "416,368,168,205",
		["warchiefslookout"] = "264,144,159,230",
		["ooomlotvillage"] = "508,345,221,211",
		["scorchedgully"] = "323,185,305,288",
		["ktcoilplatform"] = "433,11,156,142",
		["hordebasecamp"] = "244,458,222,190",
		["lostpeak"] = "581,21,350,517",
		["shipwreckshore"] = "189,408,172,175",
		["skyfalls"] = "416,131,190,186",
		["ruinsofvashelan"] = "440,452,212,216",
		["landingsite"] = "377,359,142,133",
		["theslavepits"] = "279,68,212,193",
	},
	["kezan"] = {
		["bilgewaterport"] = "163,148,694,290",
		["firstbankofkezan"] = "98,325,376,343",
		["swindlestreet"] = "317,232,168,213",
		["theslick"] = "219,108,592,202",
		["kajamine"] = "586,308,354,360",
		["kajarofield"] = "383,260,250,307",
		["gallywixsvilla"] = "0,41,303,452",
		["kezanmap"] = "0,4,1002,664",
		["drudgetown"] = "180,367,351,301",
	},
	["deepholm"] = {
		["stonehearth"] = "0,314,371,354",
		["twilightterrace"] = "297,384,237,198",
		["scouredreach"] = "448,0,516,287",
		["needlerockchasm"] = "20,0,378,359",
		["stormsfurywreckage"] = "458,383,292,285",
		["twilightoverlook"] = "570,420,411,248",
		["deathwingsfall"] = "549,297,454,343",
		["thepaleroost"] = "85,0,467,273",
		["needlerockslag"] = "0,146,370,285",
		["theshatteredfield"] = "141,438,430,230",
		["therazanesthrone"] = "434,0,274,156",
		["crimsonexpanse"] = "540,12,462,400",
		["templeofearth"] = "287,177,355,345",
	},

	["moltenfront"] = {
		["moltenfront"] = "0,0,1024,768",		-- Manual
	},
	-- Pandaria
	["thejadeforest"] = {
		["chuntianmonastery"] = "300,56,227,198",
		["dawnsblossom"] = "325,178,234,210",
		["dreamerspavillion"] = "474,520,218,148",
		["emperorsomen"] = "430,21,202,204",
		["glassfinvillage"] = "525,358,278,310",
		["grookinmound"] = "182,214,253,229",
		["hellscreamshope"] = "181,75,196,166",
		["jademines"] = "400,146,236,142",
		["nectarbreezeorchard"] = "290,330,219,256",
		["nookanooka"] = "189,151,219,205",
		["ruinsofganshi"] = "316,0,196,158",
		["serpentsspine"] = "388,299,191,216",
		["slingtailpits"] = "428,416,179,180",
		["templeofthejadeserpent"] = "468,295,264,211",
		["thearboretum"] = "481,215,242,210",
		["waywardlanding"] = "346,482,219,186",
		["windlessisle"] = "539,43,251,348",
		["wreckoftheskyshark"] = "202,0,210,158",
	},
	["dreadwastes"] = {
		["klaxxivess"] = "458,110,236,204",
		["zanvess"] = "162,385,290,283",
		["brewgarden"] = "351,0,250,218",
		["dreadwaterlake"] = "437,313,322,211",
		["clutchesofshekzeer"] = "341,125,209,318",
		["horridmarch"] = "441,224,323,194",
		["brinymuck"] = "214,311,325,270",
		["soggysgamble"] = "450,406,268,241",
		["terraceofgurthan"] = "593,92,209,234",
		["rikkitunvillage"] = "236,32,218,186",
		["heartoffear"] = "191,122,262,293",
		["kyparivor"] = "485,0,325,190",
	},
	["krasarang"] = {
		["redwingrefuge"] = "317,63,212,265",
		["anglersoutpost"] = "545,205,265,194",
		["templeoftheredcrane"] = "300,215,219,259",
		["dojaniriver"] = "513,3,190,282",
		["krasarangcove"] = "701,19,286,268",
		["thedeepwild"] = "397,59,188,412",
		["lostdynasty"] = "589,27,217,279",
		["fallsongriver"] = "218,77,214,393",
		["thesouthernisles"] = "23,267,252,313",
		["zhusbastion"] = "612,0,306,204",
		["ruinsofdojan"] = "444,44,204,383",
		["theforbiddenjungle"] = "0,79,257,300",
		["ruinsofkorja"] = "125,88,211,395",
		["cradleofchiji"] = "176,376,272,250",
		["ungaingoo"] = "330,498,258,170",
		["nayelilagoon"] = "343,373,246,240",
	},
	["krasarang_terrain1"] = {
		["redwingrefuge"] = "317,63,212,265",
		["anglersoutpost"] = "545,205,265,194",
		["templeoftheredcrane"] = "300,215,219,259",
		["dojaniriver"] = "513,3,190,282",
		["krasarangcove"] = "701,19,295,293",
		["thedeepwild"] = "397,59,188,412",
		["lostdynasty"] = "589,27,217,279",
		["fallsongriver"] = "218,77,214,393",
		["thesouthernisles"] = "0,267,275,329",
		["zhusbastion"] = "612,0,306,204",
		["ruinsofdojan"] = "444,44,204,383",
		["theforbiddenjungle"] = "0,79,257,300",
		["ruinsofkorja"] = "125,88,211,395",
		["cradleofchiji"] = "176,376,272,250",
		["ungaingoo"] = "330,498,258,170",
		["nayelilagoon"] = "343,373,246,240",
	},
	["kunlaisummit"] = {
		["binanvillage"] = "607,470,240,198",
		["mogujia"] = "462,411,253,208",
		["muskpawranch"] = "603,313,229,262",
		["mountneverset"] = "228,264,313,208",
		["zouchinvillage"] = "502,64,298,219",
		["templeofthewhitetiger"] = "587,170,250,260",
		["gateoftheaugust"] = "449,506,261,162",
		["shadopanmonastery"] = "88,92,385,385",
		["theburlaptrail"] = "398,310,310,276",
		["peakofserenity"] = "333,63,287,277",
		["valleyofemperors"] = "453,191,224,241",
		["kotapeak"] = "233,360,252,257",
		["iseoflostsouls"] = "602,4,259,233",
		["fireboughnook"] = "322,496,224,172",
	},
	["valeofeternalblossoms"] = {
		["guolairuins"] = "87,3,337,349",
		["whitemoonshrine"] = "482,10,298,262",
		["mistfallvillage"] = "200,363,310,305",
		["settingsuntraining"] = "0,234,350,429",
		["tushenburialground"] = "349,316,267,308",
		["thestairsascent"] = "556,267,446,359",
		["winterboughglade"] = "4,107,361,333",
		["thegoldenstair"] = "328,16,242,254",
		["whitepetallake"] = "278,170,267,281",
		["thetwinmonoliths"] = "444,97,272,522",
		["mogushanpalace"] = "629,22,373,385",
	},
	["valleyofthefourwinds"] = {
		["thunderfootfields"] = "622,0,380,317",
		["poolsofpurity"] = "513,58,213,246",
		["rumblingterrace"] = "582,301,277,245",
		["paoquanhollow"] = "12,105,273,246",
		["stormsoutbrewery"] = "227,380,257,288",
		["dustbackgorge"] = "0,343,209,308",
		["cliffsofdispair"] = "215,404,510,264",
		["theheartland"] = "253,75,286,392",
		["silkenfields"] = "530,253,254,259",
		["harvesthome"] = "5,239,260,251",
		["gildedfan"] = "438,41,208,292",
		["grandgranery"] = "334,325,314,212",
		["singingmarshes"] = "170,130,175,291",
		["zhusdecent"] = "699,114,303,323",
		["halfhill"] = "438,177,206,245",
		["nesingwarysafari"] = "104,326,249,342",
		["mudmugsplace"] = "561,161,230,217",
		["kuzenvillage"] = "224,74,199,304",
	},
	["townlongwastes"] = {
		["niuzaotemple"] = "213,241,296,359",
		["shanzedao"] = "125,0,300,246",
		["thesumprushes"] = "545,369,271,205",
		["sikvess"] = "306,433,261,235",
		["gaoranblockade"] = "546,468,353,200",
		["mingchicrossroads"] = "417,447,247,221",
		["palewindvillage"] = "692,362,282,306",
		["osulmesa"] = "560,185,238,296",
		["shadopangarrison"] = "413,385,213,170",
		["krivess"] = "420,209,255,269",
		["srivess"] = "92,192,294,283",
	},
	["thewanderingisle"] = {
		["thedawningvalley"] = "325,0,677,667",
		["templeoffivedawns"] = "395,182,607,461",
		["mandorivillage"] = "392,294,610,374",
		["ridgeoflaughingwinds"] = "183,198,313,321",
		["pei-wuforest"] = "351,406,651,262",
		["poolofthepaw"] = "297,324,220,188",
		["skyfirecrash-site"] = "124,405,346,263",
		["therows"] = "504,295,385,373",
		["thesingingpools"] = "545,12,372,475",
		["morningbreezevillage"] = "203,36,261,315",
		["fe-fangvillage"] = "134,9,234,286",
		["thewoodofstaves"] = "13,202,989,466",
	},
	["darkmoonfaireisland"] = {
		["darkmoonfaireisland"] = "0,0,1024,768",
	},
	["thehiddenpass"] = {
		["thehiddencliffs"] = "443,0,294,220",
		["theblackmarket"] = "371,175,479,493",
		["thehiddensteps"] = "412,477,290,191",
	},

	["isleofgiants"] = {
		["isleofgiants"] = "0,0,1024,768",		-- Manual
	},
	["timelessisle"] = {
		["timelessisle"] = "0,0,1024,768",
	},
	["isleofthethunderking"] = {
		["isleofthethunderking"] = "0,0,1024,768",	-- Manual
		--["dynamic"] = "0,0,0,0",
	},

	-- Draenor

	["ashranhordefactionhub"] = {		-- 1011
		["ashranhordefactionhub"] = "0,0,1024,768",
	},
	["ashranalliancefactionhub"] = {	-- 1009
		["ashranalliancefactionhub"] = "0,0,1024,768",
	},
	["ashran"] = {				-- 978
		["ashran"] = "0,0,1024,768",
	},
	["frostfireridge"] = {			-- 941
		["bladespirefortress"] = "38,117,356,303",
		["bloodmaulstronghold"] = "311,4,258,217",
		["bonesofagurak"] = "729,319,273,349",
		["daggermawravine"] = "284,91,255,191",
		["frostwinddunes"] = "121,0,274,214",
		["grimfrosthill"] = "597,210,178,203",
		["grombolash"] = "483,33,217,239",
		["gromgar"] = "505,323,282,341",
		["hordegarrison"] = "336,327,267,257",
		["ironsiegeworks"] = "673,156,329,294",
		["ironwaystation"] = "641,304,199,335",
		["magnarok"] = "609,33,213,278",
		["nogarrison"] = "336,327,267,257",
		["stonefangoutpost"] = "306,281,251,191",
		["theboneslag"] = "290,192,256,210",
		["thecracklingplains"] = "439,137,266,293",
		["worgol"] = "72,292,317,233",
	},
	["garrisonffhorde_tier1"] = {		-- 976
		["garrisonffhorde_tier1"] = "0,0,1024,768",
	},
	["garrisonsmvalliance_tier1"] = {	-- 971
		["garrisonsmvalliance_tier1"] = "0,0,1024,768",
	},
	["gorgrond"] = {			-- 949
		["bastionrise"] = "283,507,324,161",
		["beastwatch"] = "383,371,166,161",
		["easternruin"] = "525,260,210,193",
		["evermorn"] = "281,444,297,181",
		["foundry"] = "455,74,211,221",
		["foundrysouth"] = "454,183,217,180",
		["gronncanyon"] = "258,213,279,241",
		["highlandpass"] = "547,73,285,323",
		["highpass"] = "411,250,209,225",
		["irondocks"] = "350,0,315,180",
		["mushrooms"] = "444,323,253,198",
		["stonemaularena"] = "259,335,217,178",
		["stonemaulsouth"] = "275,416,208,142",
		["stripmine"] = "312,77,250,232",
		["tangleheart"] = "451,372,262,221",
	},
	["nagranddraenor"] = {			-- 950
		["ancestral"] = "239,259,234,191",
		["brokenprecipice"] = "256,12,305,227",
		["elementals"] = "588,0,286,274",
		["grommashar"] = "600,367,256,301",
		["hallvalor"] = "766,118,236,372",
		["highmaul"] = "0,0,471,437",
		["ironfistharbor"] = "283,354,236,242",
		["lokrath"] = "382,187,316,221",
		["margoks"] = "753,380,249,288",
		["mushrooms"] = "746,25,250,287",
		["oshugun"] = "366,323,262,266",
		["ringofblood"] = "430,0,263,287",
		["ringoftrials"] = "523,159,354,315",
		["sunspringwatch"] = "312,98,274,254",
		["telaar"] = "461,353,296,272",
	},
	["spiresofarak"] = {			-- 948
		["bloodbladeredoubt"] = "334,210,209,154",
		["bloodmanevalley"] = "410,350,229,246",
		["centerravennest"] = "444,255,188,190",
		["clutchpop"] = "533,382,217,224",
		["eastmushrooms"] = "649,155,182,244",
		["emptygarrison"] = "282,261,190,187",
		["howlingcrag"] = "459,0,382,274",
		["nwcorner"] = "102,0,314,304",
		["sethekkhollow"] = "520,127,238,295",
		["skettis"] = "289,0,371,174",
		["solospirenorth"] = "429,84,196,284",
		["solospiresouth"] = "374,276,169,178",
		["southport"] = "310,328,197,179",
		["veilakraz"] = "281,83,252,230",
		["veilzekk"] = "521,268,198,232",
		["venturecove"] = "465,475,226,193",
		["writhingmire"] = "197,198,229,213",
	},
	["shadowmoonvalleydr"] = {		-- 947
		["anguishfortress"] = "140,160,309,264",
		["darktideroost"] = "468,467,282,201",
		["elodor"] = "426,0,291,266",
		["embaari"] = "270,158,346,252",
		["garrison"] = "194,0,223,279",
		["gloomshade"] = "319,5,229,240",
		["gulvar"] = "26,0,260,309",
		["karabor"] = "537,150,393,318",
		["nogarrison"] = "194,0,223,279",
		["shazgul"] = "259,315,282,225",
		["shimmeringmoor"] = "453,306,288,261",
		["socrethar"] = "383,411,202,201",
		["swisland"] = "309,460,173,160",
	},
	["talador"] = {				-- 946
		["aruuna"] = "597,178,389,234",
		["auchindoun"] = "338,356,309,262",
		["centerisles"] = "546,228,252,280",
		["courtofsouls"] = "150,264,307,229",
		["fortwrynn"] = "567,42,292,235",
		["gordalfortress"] = "548,378,423,290",
		["gulrok"] = "165,364,278,270",
		["northgate"] = "571,0,398,149",
		["orunaicoast"] = "427,0,279,267",
		["seentrance"] = "685,298,308,276",
		["shattrath"] = "173,22,406,367",
		["telmor"] = "207,511,497,157",
		["tomboflights"] = "352,271,326,212",
		["tuurem"] = "472,148,225,224",
		["zangarra"] = "713,35,287,277",
	},
	["TanaanJungle"] = {			-- 945
		["darkportal"] = "637,136,333,437",		
		["draeneisw"] = "81,367,174,208",
		["fangrila"] = "429,392,343,264",
		["felforge"] = "392,187,223,183",
		["ironfront"] = "0,264,209,245",	
		["ironharbor"] = "303,62,189,294",		
		["kiljaeden"] = "392,23,365,276",
		["kranak"] = "54,94,338,254",
		["lionswatch"] = "465,313,270,208",
		["marshlands"] = "296,383,246,218",
		["shanaar"] = "170,354,248,314",
		["volmar"] = "501,171,238,229",
		["zethgol"] = "118,194,274,251",
		["hellfirecitadel"] = "254,262,327,241",										
	},
	["tanaanjungleintro"] = {		-- 970
		["tanaanjungleintro"] = "0,0,1024,768",
	},
	["azsuna"] = {
		["faronaar"] = "166,202,330,265",
		["felblaze"] = "594,0,239,303",
		["greenway"] = "450,95,247,184",
		["isleofthewatchers"] = "281,401,321,267",
		["llothienhighlands"] = "219,69,351,245",
		["lostorchard"] = "257,0,315,185",
		["narthalas"] = "441,173,272,192",
		["oceanuscove"] = "396,244,206,266",
		["ruinedsanctum"] = "523,233,220,288",
		["templelights"] = "481,340,181,243",
		["zarkhenar"] = "477,0,288,195",
	},
    ["stormheim"] = {
		["aggrammarsvault"] = "361,210,199,185",
		["blackbeakoverlook"] = "154,129,297,210",
		["dreadwake"] = "457,412,215,247",
		["dreyrgrot"] = "689,266,132,145",
		["greywatch"] = "648,339,173,163",
		["hallsofvalor"] = "585,372,252,280",
		["haustvald"] = "612,187,200,174",
		["hrydshal"] = "0,353,631,315",
		["mawofnashal"] = "17,0,509,251",
		["morheim"] = "741,313,150,180",
		["nastrondir"] = "345,95,241,194",
		["qatchmansrock"] = "623,81,135,162",
		["runewood"] = "592,226,194,214",
		["shieldsrest"] = "689,0,289,172",
		["skoldashil"] = "506,345,177,169",
		["stormsreach"] = "510,118,180,160",
		["talonrest"] = "316,282,291,208",
		["tideskornharbor"] = "479,183,205,199",
		["valdisdall"] = "522,288,186,158",
		["weepingbluffs"] = "56,185,386,314",		
    },	
	["valsharah"] = {
		["andutalah"] = "587,250,241,240",
		["blackrookhold"] = "262,175,250,253",
		["bradensbrook"] = "259,275,311,244",
		["dreamgrove"] = "283,0,294,364",
		["gloamingreef"] = "136,274,239,301",
		["groveofcenarius"] = "457,351,171,150",
		["lorlathil"] = "467,413,177,156",
		["mistvale"] = "610,18,274,344",
		["moonclawvale"] = "549,380,254,281",
		["shalanir"] = "419,0,326,360",
		["smolderhide"] = "324,480,341,188",
		["templeofelune"] = "459,240,216,219",
		["thastalah"] = "342,416,218,168",		
	},
	["brokenshore"] = {
	    ["brokenvalley"] = "254,84,338,322",	
	    ["deadwoodlanding"] = "220,260,182,245",
	    ["deliverancepoint"] = "312,302,387,314",
	    ["felragestrand"] = "596,100,332,276",
	    ["soulruin"] = "389,180,338,270",	    
		["thelosttemple"] = "632,169,308,244",
	    ["theweepingterrace"] = "350,13,276,213",
	    ["tombofsargeras"] = "500,0,312,301",		
	},
	["highmountain"] = {
		["bloodhunthighlands"] = "307,75,297,250",
		["feltotem"] = "172,31,256,326",
		["frosthoofwatch"] = "391,408,186,213",
		["ironhornenclave"] = "452,410,288,258",
		["nightwatchersperch"] = "0,244,344,295",
		["pinerockbasin"] = "323,249,217,148",
		["riverbend"] = "314,360,214,308",
		["rockawayshallows"] = "469,45,207,302",
		["shipwreckcove"] = "331,0,283,170",
		["skyhorn"] = "357,179,311,229",
		["stonehoofwatch"] = "494,236,341,328",
		["sylvanfalls"] = "0,342,445,326",
		["thundertotem"] = "332,302,244,199",
		["trueshotlodge"] = "249,236,172,204",
		["cavea"] = "445,190,110,98",
	},	
	["suramar"] = {
		["ambervale"] = "132,179,222,311",
		["crimsonthicket"] = "492,0,327,381",
		["falanaar"] = "23,136,248,317",
		["felsoulhold"] = "183,305,289,363",
		["grandpromenade"] = "344,285,355,291",
		["jandvik"] = "583,0,419,538",
		["moonguardstronghold"] = "58,0,480,245",
		["moonwhispergulch"] = "201,0,428,316",
		["ruinsofeluneeth"] = "264,226,221,224",
		["suramarcity"] = "390,331,470,337",
		["telanor"] = "327,0,387,372",
	},
	["mardumtheshatteredabyss"] = {
		["mardumtheshatteredabyss"] = "0,0,1024,768",
	},	
	["argussurface"] = {
		["annihilanpits"] = "371,178,296,336",
		["krokulhovel"] = "428,364,307,304",
		["nathraxas"] = "167,0,835,422",
		["petrifiedforest"] = "557,289,445,379",
		["shatteredfields"] = "37,138,498,530",
	},
	["argusmacaree"] = {
		["conservatory"] = "498,111,313,353",
		["ruinsoforonaar"] = "278,284,265,310",
		["seatoftriumvirate"] = "265,54,463,519",
		["shadowguard"] = "0,0,498,461",
		["triumvirates"] = "410,375,284,264",
		["upperterrace"] = "0,0,701,323",
	},
	["arguscore"] = {
		["defiledpath"] = "293,0,626,385",
		["felfirearmory"] = "0,0,660,668",
		["terminus"] = "535,238,467,430",
	},	
	
	-- BfA
	
["voldun"] = {
        ["_shatterstone,1024,1024"] = "1006,341,881,897",
        ["_akunda,2048,1024"] = "1469,1684,1287,876",
        ["_atulaman,2048,1024"] = "1569,1281,1139,822",
        ["_centerdesert,1024,1024"] = "1316,895,849,672",
        ["_eastcoast,1024,1024"] = "2063,517,913,727",
        ["_eastdesert,1024,1024"] = "1880,859,969,835",
        ["_portzemlan,1024,1024"] = "807,1801,926,688",
        ["_slithering,1024,1024"] = "1579,220,915,966",
        ["_southcoast,1024,1024"] = "1362,2018,794,542",
        ["_southerndesert,1024,1024"] = "1180,1255,666,856",
        ["_swcoast,1024,1024"] = "739,1332,769,816",
        ["_terracedevoted,2048,1024"] = "576,902,1086,703",
        ["_tortanka,2048,1024"] = "1733,0,1223,843",
},
["nazmir"] = {
        ["_frogmarsh,2048,1024"] = "2349,871,1098,996",
        ["_heartofdarkness,1024,1024"] = "1511,1043,800,991",
        ["_nazwatha,2048,2048"] = "2309,210,1065,1103",
        ["_necropolis,2048,2048"] = "1097,281,1534,1119",
        ["_primalwetlands,2048,1024"] = "484,1539,1157,967",
        ["_rivermarsh,2048,1024"] = "1072,1676,1289,809",
        ["_torgasrest,2048,2048"] = "1682,0,1349,1029",
        ["_zalamak,1024,2048"] = "1807,1043,841,1075",
        ["_zalamar,2048,2048"] = "620,565,1225,1249",
},
["zuldazar"] = {
        ["_atalgral,1024,1024"] = "2685,633,793,668",
        ["_ataldazar,2048,2048"] = "321,378,1650,1565",
        ["_bloodgate,2048,1024"] = "1357,0,1130,672",
        ["_dazaralor,1024,2048"] = "1815,260,699,1207",
        ["_dreadpearl,1024,1024"] = "2325,1270,934,830",
        ["_savagelands,1024,2048"] = "2144,0,943,1559",
        ["_sliver,1024,1024"] = "2107,327,769,967",
        ["_southdocks,1024,2048"] = "1825,1216,999,1344",
        ["_kingsmouth,1024,2048"] = "1312,82,888,1512",
        ["_xibala,2048,2048"] = "1046,1273,1243,1287",
        ["_zebhari,1024,1024"] = "2409,0,979,912",
        ["_talanji,1024,1024"] = "2631,1023,726,617",
},

["stormsongvalley"] = {
        ["_brennadam,2048,2048"] = "1750,1336,1167,1224",
        ["_briarback,2048,2048"] = "1288,1426,1030,1134",
        ["_brineworks,2048,2048"] = "2181,1069,1659,1491",
        ["_clearcut,1024,2048"] = "1365,0,929,1380",
        ["_deadwash,2048,1024"] = "1153,1056,1403,711",
        ["_fortdaelin,1024,2048"] = "840,475,859,1050",
        ["_sagehold,2048,2048"] = "1918,0,1052,1466",
        ["_shrineofstorm,2048,2048"] = "2515,0,1325,1981",
        ["_windfarmsw,2048,2048"] = "0,1103,1628,1457",
},
["drustvar"] = {
        ["_barrowknoll,2048,1024"] = "1812,760,1125,880",
        ["_fallhaven,1024,2048"] = "1644,361,948,1081",
        ["_aromsstand,2048,2048"] = "933,863,1188,1421",
        ["_carverharbor,2048,2048"] = "1839,0,1154,1059",
        ["_corlain,2048,1024"] = "388,570,1239,839",
        ["_crimsonforest,2048,2048"] = "377,939,1139,1154",
        ["_fletcherhollow,1024,2048"] = "2386,1049,770,1181",
        ["_golkoval,2048,2048"] = "1847,1025,1090,1169",
        ["_northmtns,2048,2048"] = "1261,0,1079,1204",
        ["_nwisland,2048,1024"] = "0,0,1373,1010",
        ["_southmtns,2048,2048"] = "1212,1237,1521,1323",
        ["_waycrest,2048,2048"] = "438,0,1424,1026",
},
["tiragardesound"] = {
        ["_anglepoint,1024,1024"] = "1108,451,859,788",
        ["_boralus,2048,1024"] = "2117,332,1432,1009",
        ["_fernwood,2048,1024"] = "1806,0,1777,900",
        ["_freehold,2048,1024"] = "2314,1739,1047,821",
        ["_norwington,1024,2048"] = "1538,176,908,1284",
        ["_nwport,1024,1024"] = "766,100,828,899",
        ["_rustedvault,1024,2048"] = "2054,995,978,1171",
        ["_seabove,2048,1024"] = "2451,1035,1242,944",
        ["_secorner,1024,2048"] = "2852,1503,891,1057",
        ["_vigilhill,1024,2048"] = "1772,1199,953,1223",
        ["_waningglacier,2048,1024"] = "802,0,1306,678",
},
["nazjatar"] = {
        ["_ashenstrand,1024,2048"] = "729,315,815,1065",
        ["_azshariterrace,1024,1024"] = "1876,340,648,650",
        ["_coralforest,1024,1024"] = "1863,804,795,866",
        ["_deepcoil,1024,1024"] = "2321,57,583,800",
        ["_dragonsteeth,1024,1024"] = "1360,1027,790,517",
        ["_drownedmarket,1024,1024"] = "2574,909,783,597",
        ["_elunalor,1024,512"] = "2502,692,979,480",
        ["_empressapproach,512,1024"] = "1653,708,510,520",
        ["_gateofthequeen,1024,1024"] = "1469,50,850,835",
        ["_hangingreef,2048,1024"] = "895,1151,1411,710",
        ["_kalmethir,1024,1024"] = "2213,691,703,905",
        ["_mezzamere,1024,512"] = "1007,1200,738,490",
        ["_newhome,1024,512"] = "1570,1432,737,461",
        ["_shirakess,1024,1024"] = "1987,49,527,528",
        ["_spearsofazshara,2048,2048"] = "935,1429,1224,1131",
        ["_zanjirterrace,1024,1024"] = "1110,118,770,835",
        ["_zanjirwash,1024,1024"] = "1297,693,558,602",
        ["_zinazshari,1024,1024"] = "2490,365,990,564",
},
["mechagonisland"] = {
        ["_fleetingforest,2048,2048"] = "1154,496,1169,1264",
        ["_heaps,1024,2048"] = "1910,557,1009,1191",
        ["_junkwattdepot,2048,2048"] = "1125,1222,1479,1338",
        ["_outflow,2048,2048"] = "2172,1134,1366,1426",
        ["_rustbolt,1024,1024"] = "2513,406,1014,1022",
        ["_scrapboneden,2048,1024"] = "1315,40,1723,945",
        ["_sparkweaver,2048,2048"] = "2791,121,1049,1055",
        ["_westernspray,2048,2048"] = "46,978,1424,1511",
},
	
["revendreth"] = {
        ["_destroyed,1024,1024"] = "1527,300,685,688",
        ["_archivam,1024,1024"] = "2290,474,1019,737",
        ["_caretakermanor,1024,1024"] = "2597,1316,718,847",
        ["_castlenathria,1024,2048"] = "1647,484,885,1060",
        ["_darkhaven,1024,2048"] = "1987,1377,711,1183",
        ["_darkwalltower,1024,2048"] = "1306,555,586,1091",
        ["_dominancekeep,2048,1024"] = "485,0,1192,963",
        ["_dreadhaven,2048,1024"] = "869,1682,1087,878",
        ["_hallsofatonement,2048,1024"] = "1974,919,1339,746",
        ["_intact,1024,1024"] = "1527,300,685,688",
        ["_nightmarket,1024,1024"] = "1487,1982,720,578",
        ["_pridefall,1024,2048"] = "2324,1520,835,1040",
        ["_shroudedasylem,2048,2048"] = "433,596,1207,1465",
        ["_waincrypthill,2048,2048"] = "1200,1407,1030,1129",
        ["_intact,1024,1024"] = "1527,300,685,688",
        ["_archivam,1024,1024"] = "2290,474,1019,737",
        ["_caretakermanor,1024,1024"] = "2597,1316,718,847",
        ["_darkhaven,1024,2048"] = "1987,1377,711,1183",
        ["_darkwalltower,1024,2048"] = "1306,555,586,1091",
        ["_dreadhaven,2048,1024"] = "869,1682,1087,878",
        ["_hallsofatonement,2048,1024"] = "1974,919,1339,746",
        ["_intact,1024,1024"] = "1527,300,685,688",
        ["_nightmarket,1024,1024"] = "1487,1982,720,578",
        ["_pridefall,1024,2048"] = "2324,1520,835,1040",
        ["_shroudedasylem,2048,2048"] = "433,596,1207,1465",
        ["_waincrypthill,2048,2048"] = "1200,1407,1030,1129",
},
["bastion"] = {
        ["_agthiarepose,1024,512"] = "1566,1551,591,503",
        ["_aspirantcrucible,1024,1024"] = "1626,1949,804,564",
        ["_braveheart,2048,1024"] = "881,993,1115,704",
        ["_citadelloyalty,2048,1024"] = "495,250,1357,856",
        ["_elysianhold,1024,1024"] = "1975,155,892,763",
        ["_eternalforge,1024,1024"] = "1400,48,984,847",
        ["_memoryextraction,1024,1024"] = "1793,1220,746,528",
        ["_orchard,1024,1024"] = "1475,706,985,652",
        ["_puritypinnacle,1024,512"] = "2004,1590,826,494",
        ["_templehumility,1024,1024"] = "2110,588,881,911",
        ["_unnamed,1024,1024"] = "1167,1387,783,542",
        ["_vestibuleeternity,1024,1024"] = "1068,1768,839,558",
},
["maldraxxus"] = {
        ["_burningthicket,2048,1024"] = "284,1085,1149,703",
        ["_forgottenwounds,1024,1024"] = "1815,517,694,666",
        ["_glutharnsdecay,1024,1024"] = "2028,894,719,802",
        ["_houseofconstructs,1024,2048"] = "631,46,951,1071",
        ["_houseofeyes,1024,1024"] = "1692,0,932,919",
        ["_houseofrituals,2048,2048"] = "2232,13,1363,1137",
        ["_houseofthechosen,2048,2048"] = "330,1351,1508,1209",
        ["_houseoftheplagues,2048,2048"] = "1582,1424,1925,1136",
        ["_rottingmound,2048,1024"] = "2438,785,1194,998",
        ["_seatoftheprimus,1024,1024"] = "1551,1342,757,985",
        ["_sepulcher,1024,2048"] = "1202,0,858,1178",
        ["_spearhead,1024,1024"] = "1171,836,673,788",
        ["_stitchyard,2048,2048"] = "261,65,1231,1391",
        ["_theaterofpain,1024,1024"] = "1566,862,730,730",
},
["themaw"] = {
        ["_altardamnation,1024,2048"] = "262,1423,954,1076",
        ["_beastwarrens,1024,1024"] = "1442,1262,1009,835",
        ["_calcis,2048,2048"] = "0,342,1232,1236",
        ["_cocyrus,2048,1024"] = "1100,696,1186,821",
        ["_crucibledamned,2048,1024"] = "49,918,1053,934",
        ["_desmotaeron,2048,2048"] = "1797,0,1488,1946",
        ["_gorgoa,2048,1024"] = "1171,0,1504,929",
        ["_marrow,1024,1024"] = "1404,1831,928,729",
        ["_perditionhold,1024,2048"] = "808,1201,928,1359",
        ["_planesoftorment,2048,1024"] = "183,0,1395,932",
        ["_ravener,2048,1024"] = "1856,1572,1408,988",
        ["_zovaalscauldron,2048,1024"] = "772,598,1078,824",
        ["_crucibledamned,2048,1024"] = "49,918,1053,934",
        ["_calcis,2048,2048"] = "0,342,1232,1236",
        ["_cocyrus,2048,1024"] = "1100,696,1186,821",
        ["_gorgoa,2048,1024"] = "1171,0,1504,929",
        ["_planesoftorment,2048,1024"] = "183,0,1395,932",
        ["_zovaalscauldron,2048,1024"] = "772,598,1078,824",
},
["ardenweald"] = {
        ["_blackthorn,1024,1024"] = "1036,316,847,783",
        ["_crubledridge,1024,1024"] = "2338,474,904,714",
        ["_darkreach,1024,2048"] = "1190,1242,845,1048",
        ["_fallentree,1024,1024"] = "2339,1049,886,821",
        ["_glitterfall,1024,2048"] = "1679,54,688,1139",
        ["_gormhive,1024,1024"] = "1701,1607,798,896",
        ["_heartoftheforest,1024,1024"] = "1487,945,686,742",
        ["_hibernalhollow,1024,1024"] = "1993,885,669,747",
        ["_mistvaletangle,2048,2048"] = "379,811,1179,1340",
        ["_shimmerbough,1024,1024"] = "1736,1234,770,603",
        ["_starlitoverlook,1024,1024"] = "2211,168,803,645",
        ["_thestalks,1024,1024"] = "946,723,864,650",
        ["_tirnavaal,1024,1024"] = "2107,638,563,685",
},
	
	["threatvaleofeternalblossoms"] =
	{
		["threatvaleofeternalblossoms1"] = "0,0,256,256,1",
		["threatvaleofeternalblossoms2"] = "256,0,256,256,1",
		["threatvaleofeternalblossoms3"] = "512,0,256,256,1",
		["threatvaleofeternalblossoms4"] = "768,0,256,256,1",
		
		["threatvaleofeternalblossoms5"] = "0,256,256,256,1",
		["threatvaleofeternalblossoms6"] = "256,256,256,256,1",
		["threatvaleofeternalblossoms7"] = "512,256,256,256,1",
		["threatvaleofeternalblossoms8"] = "768,256,256,256,1",
		
		["threatvaleofeternalblossoms9"] = "0,512,256,256,1",
		["threatvaleofeternalblossoms10"] = "256,512,256,256,1",
		["threatvaleofeternalblossoms11"] = "512,512,256,256,1",
		["threatvaleofeternalblossoms12"] = "768,512,256,256,1",
	},
}

--------
-- OLD From Textures\Minimap\md5translate.trs
-- From art.mpq World\Minimaps

Map.KalMapBlks = {
	[2341] = 207604,
	[2342] = 207605,
	[2343] = 207606,
	[2344] = 207607,
	[2345] = 207608,
	[2439] = 207622,
	[2440] = 207623,
	[2441] = 207624,
	[2442] = 207625,
	[2443] = 207626,
	[2444] = 207627,
	[2445] = 207628,
	[2512] = 207632,
	[2513] = 207633,
	[2514] = 207634,
	[2515] = 207635,
	[2533] = 207653,
	[2534] = 207654,
	[2535] = 207655,
	[2536] = 207656,
	[2537] = 207657,
	[2538] = 207658,
	[2539] = 207659,
	[2540] = 207660,
	[2541] = 207661,
	[2542] = 207662,
	[2543] = 207663,
	[2544] = 207664,
	[2545] = 207665,
	[2546] = 207666,
	[2611] = 207678,
	[2612] = 207679,
	[2613] = 207680,
	[2614] = 207681,
	[2615] = 207682,
	[2616] = 207683,
	[2624] = 207691,
	[2625] = 207692,
	[2626] = 207693,
	[2627] = 207694,
	[2628] = 207695,
	[2629] = 207696,
	[2630] = 207697,
	[2631] = 207698,
	[2632] = 207699,
	[2633] = 207700,
	[2634] = 207701,
	[2635] = 207702,
	[2636] = 207703,
	[2637] = 207704,
	[2638] = 207705,
	[2639] = 207706,
	[2640] = 207707,
	[2641] = 207708,
	[2642] = 207709,
	[2643] = 207710,
	[2644] = 207711,
	[2645] = 207712,
	[2646] = 207713,
	[2647] = 207714,
	[2648] = 207715,
	[2649] = 207716,
	[2650] = 207717,
	[2651] = 207718,
	[2709] = 207723,
	[2710] = 207724,
	[2711] = 207725,
	[2712] = 207726,
	[2713] = 207727,
	[2714] = 207728,
	[2715] = 207729,
	[2716] = 207730,
	[2717] = 207731,
	[2718] = 207732,
	[2719] = 207733,
	[2720] = 207734,
	[2721] = 207735,
	[2722] = 207736,
	[2723] = 207737,
	[2724] = 207738,
	[2725] = 207739,
	[2726] = 207740,
	[2727] = 207741,
	[2728] = 207742,
	[2729] = 207743,
	[2730] = 207744,
	[2731] = 207745,
	[2732] = 207746,
	[2733] = 207747,
	[2734] = 207748,
	[2735] = 207749,
	[2736] = 207750,
	[2737] = 207751,
	[2738] = 207752,
	[2739] = 207753,
	[2740] = 207754,
	[2741] = 207755,
	[2742] = 207756,
	[2743] = 207757,
	[2744] = 207758,
	[2745] = 207759,
	[2746] = 207760,
	[2747] = 207761,
	[2748] = 207762,
	[2749] = 207763,
	[2750] = 207764,
	[2751] = 207765,
	[2752] = 207766,
	[2809] = 207770,
	[2810] = 207771,
	[2811] = 207772,
	[2812] = 207773,
	[2813] = 207774,
	[2814] = 207775,
	[2815] = 207776,
	[2816] = 207777,
	[2817] = 207778,
	[2818] = 207779,
	[2819] = 207780,
	[2820] = 207781,
	[2821] = 207782,
	[2822] = 207783,
	[2823] = 207784,
	[2824] = 207785,
	[2825] = 207786,
	[2826] = 207787,
	[2827] = 207788,
	[2828] = 207789,
	[2829] = 207790,
	[2830] = 207791,
	[2831] = 207792,
	[2832] = 207793,
	[2833] = 207794,
	[2834] = 207795,
	[2835] = 207796,
	[2836] = 207797,
	[2837] = 207798,
	[2838] = 207799,
	[2839] = 207800,
	[2840] = 207801,
	[2841] = 207802,
	[2842] = 207803,
	[2843] = 207804,
	[2844] = 207805,
	[2845] = 207806,
	[2846] = 207807,
	[2847] = 207808,
	[2848] = 207809,
	[2849] = 207810,
	[2850] = 207811,
	[2851] = 207812,
	[2852] = 207813,
	[2909] = 207817,
	[2910] = 207818,
	[2911] = 207819,
	[2912] = 207820,
	[2913] = 207821,
	[2914] = 207822,
	[2915] = 207823,
	[2916] = 207824,
	[2917] = 207825,
	[2918] = 207826,
	[2919] = 207827,
	[2920] = 207828,
	[2921] = 207829,
	[2922] = 207830,
	[2923] = 207831,
	[2924] = 207832,
	[2925] = 207833,
	[2926] = 207834,
	[2927] = 207835,
	[2928] = 207836,
	[2929] = 207837,
	[2930] = 207838,
	[2931] = 207839,
	[2932] = 207840,
	[2933] = 207841,
	[2934] = 207842,
	[2935] = 207843,
	[2936] = 207844,
	[2937] = 207845,
	[2938] = 207846,
	[2939] = 207847,
	[2940] = 207848,
	[2941] = 207849,
	[2942] = 207850,
	[2943] = 207851,
	[2944] = 207852,
	[2945] = 207853,
	[2946] = 207854,
	[2947] = 207855,
	[2948] = 207856,
	[2949] = 207857,
	[2950] = 207858,
	[2951] = 207859,
	[2952] = 207860,
	[3009] = 207864,
	[3010] = 207865,
	[3011] = 207866,
	[3012] = 207867,
	[3013] = 207868,
	[3014] = 207869,
	[3015] = 207870,
	[3016] = 207871,
	[3017] = 207872,
	[3018] = 207873,
	[3019] = 207874,
	[3020] = 207875,
	[3021] = 207876,
	[3022] = 207877,
	[3023] = 207878,
	[3024] = 207879,
	[3025] = 207880,
	[3026] = 207881,
	[3027] = 207882,
	[3028] = 207883,
	[3029] = 207884,
	[3030] = 207885,
	[3031] = 207886,
	[3032] = 207887,
	[3033] = 207888,
	[3034] = 207889,
	[3035] = 207890,
	[3036] = 207891,
	[3037] = 207892,
	[3038] = 207893,
	[3039] = 207894,
	[3040] = 207895,
	[3041] = 207896,
	[3042] = 207897,
	[3043] = 207898,
	[3044] = 207899,
	[3045] = 207900,
	[3046] = 207901,
	[3047] = 207902,
	[3048] = 207903,
	[3049] = 207904,
	[3050] = 207905,
	[3051] = 207906,
	[3052] = 207907,
	[3109] = 207911,
	[3110] = 207912,
	[3111] = 207913,
	[3112] = 207914,
	[3113] = 207915,
	[3114] = 207916,
	[3115] = 207917,
	[3116] = 207918,
	[3117] = 207919,
	[3118] = 207920,
	[3119] = 207921,
	[3120] = 207922,
	[3121] = 207923,
	[3122] = 207924,
	[3123] = 207925,
	[3124] = 207926,
	[3125] = 207927,
	[3126] = 207928,
	[3127] = 207929,
	[3128] = 207930,
	[3129] = 207931,
	[3130] = 207932,
	[3131] = 207933,
	[3132] = 207934,
	[3133] = 207935,
	[3134] = 207936,
	[3135] = 207937,
	[3136] = 207938,
	[3137] = 207939,
	[3138] = 207940,
	[3139] = 207941,
	[3140] = 207942,
	[3141] = 207943,
	[3142] = 207944,
	[3143] = 207945,
	[3144] = 207946,
	[3145] = 207947,
	[3146] = 207948,
	[3147] = 207949,
	[3148] = 207950,
	[3149] = 207951,
	[3150] = 207952,
	[3151] = 207953,
	[3152] = 207954,
	[3153] = 207955,
	[3210] = 207959,
	[3211] = 207960,
	[3212] = 207961,
	[3213] = 207962,
	[3214] = 207963,
	[3215] = 207964,
	[3216] = 207965,
	[3217] = 207966,
	[3218] = 207967,
	[3219] = 207968,
	[3220] = 207969,
	[3221] = 207970,
	[3222] = 207971,
	[3223] = 207972,
	[3224] = 207973,
	[3225] = 207974,
	[3226] = 207975,
	[3227] = 207976,
	[3228] = 207977,
	[3229] = 207978,
	[3230] = 207979,
	[3231] = 207980,
	[3232] = 207981,
	[3233] = 207982,
	[3234] = 207983,
	[3235] = 207984,
	[3236] = 207985,
	[3237] = 207986,
	[3238] = 207987,
	[3239] = 207988,
	[3240] = 207989,
	[3241] = 207990,
	[3242] = 207991,
	[3243] = 207992,
	[3244] = 207993,
	[3245] = 207994,
	[3246] = 207995,
	[3247] = 207996,
	[3248] = 207997,
	[3249] = 207998,
	[3250] = 207999,
	[3251] = 208000,
	[3252] = 208001,
	[3253] = 208002,
	[3311] = 208007,
	[3312] = 208008,
	[3313] = 208009,
	[3314] = 208010,
	[3315] = 208011,
	[3316] = 208012,
	[3317] = 208013,
	[3318] = 208014,
	[3319] = 208015,
	[3320] = 208016,
	[3321] = 208017,
	[3322] = 208018,
	[3323] = 208019,
	[3324] = 208020,
	[3325] = 208021,
	[3326] = 208022,
	[3327] = 208023,
	[3328] = 208024,
	[3329] = 208025,
	[3330] = 208026,
	[3331] = 208027,
	[3332] = 208028,
	[3333] = 208029,
	[3334] = 208030,
	[3335] = 208031,
	[3336] = 208032,
	[3337] = 208033,
	[3338] = 208034,
	[3339] = 208035,
	[3340] = 208036,
	[3341] = 208037,
	[3342] = 208038,
	[3343] = 208039,
	[3344] = 208040,
	[3345] = 208041,
	[3346] = 208042,
	[3347] = 208043,
	[3348] = 208044,
	[3349] = 208045,
	[3350] = 208046,
	[3351] = 208047,
	[3352] = 208048,
	[3353] = 208049,
	[3415] = 208055,
	[3416] = 208056,
	[3417] = 208057,
	[3418] = 208058,
	[3419] = 208059,
	[3420] = 208060,
	[3421] = 208061,
	[3422] = 208062,
	[3423] = 208063,
	[3424] = 208064,
	[3425] = 208065,
	[3426] = 208066,
	[3427] = 208067,
	[3428] = 208068,
	[3429] = 208069,
	[3430] = 208070,
	[3431] = 208071,
	[3432] = 208072,
	[3433] = 208073,
	[3434] = 208074,
	[3435] = 208075,
	[3436] = 208076,
	[3437] = 208077,
	[3438] = 208078,
	[3439] = 208079,
	[3440] = 208080,
	[3441] = 208081,
	[3442] = 208082,
	[3443] = 208083,
	[3444] = 208084,
	[3445] = 208085,
	[3446] = 208086,
	[3447] = 208087,
	[3448] = 208088,
	[3449] = 208089,
	[3450] = 208090,
	[3451] = 208091,
	[3452] = 208092,
	[3453] = 208093,
	[3515] = 208099,
	[3516] = 208100,
	[3517] = 208101,
	[3518] = 208102,
	[3519] = 208103,
	[3520] = 208104,
	[3521] = 208105,
	[3522] = 208106,
	[3523] = 208107,
	[3524] = 208108,
	[3525] = 208109,
	[3526] = 208110,
	[3527] = 208111,
	[3528] = 208112,
	[3529] = 208113,
	[3530] = 208114,
	[3531] = 208115,
	[3532] = 208116,
	[3533] = 208117,
	[3534] = 208118,
	[3535] = 208119,
	[3536] = 208120,
	[3537] = 208121,
	[3538] = 208122,
	[3539] = 208123,
	[3540] = 208124,
	[3541] = 208125,
	[3542] = 208126,
	[3543] = 208127,
	[3544] = 208128,
	[3545] = 208129,
	[3546] = 208130,
	[3547] = 208131,
	[3548] = 208132,
	[3549] = 208133,
	[3550] = 208134,
	[3551] = 208135,
	[3552] = 208136,
	[3553] = 208137,
	[3615] = 208143,
	[3616] = 208144,
	[3617] = 208145,
	[3618] = 208146,
	[3619] = 208147,
	[3620] = 208148,
	[3621] = 208149,
	[3622] = 208150,
	[3623] = 208151,
	[3624] = 208152,
	[3625] = 208153,
	[3626] = 208154,
	[3627] = 208155,
	[3628] = 208156,
	[3629] = 208157,
	[3630] = 208158,
	[3631] = 208159,
	[3632] = 208160,
	[3633] = 208161,
	[3634] = 208162,
	[3635] = 208163,
	[3636] = 208164,
	[3637] = 208165,
	[3638] = 208166,
	[3639] = 208167,
	[3640] = 208168,
	[3641] = 208169,
	[3642] = 208170,
	[3643] = 208171,
	[3644] = 208172,
	[3645] = 208173,
	[3646] = 208174,
	[3647] = 208175,
	[3648] = 208176,
	[3649] = 208177,
	[3650] = 208178,
	[3651] = 208179,
	[3652] = 208180,
	[3653] = 208181,
	[3714] = 208186,
	[3715] = 208187,
	[3716] = 208188,
	[3717] = 208189,
	[3718] = 208190,
	[3719] = 208191,
	[3720] = 208192,
	[3721] = 208193,
	[3722] = 208194,
	[3723] = 208195,
	[3724] = 208196,
	[3725] = 208197,
	[3726] = 208198,
	[3727] = 208199,
	[3728] = 208200,
	[3729] = 208201,
	[3730] = 208202,
	[3731] = 208203,
	[3732] = 208204,
	[3733] = 208205,
	[3734] = 208206,
	[3735] = 208207,
	[3736] = 208208,
	[3737] = 208209,
	[3738] = 208210,
	[3739] = 208211,
	[3740] = 208212,
	[3741] = 208213,
	[3742] = 208214,
	[3743] = 208215,
	[3744] = 208216,
	[3745] = 208217,
	[3746] = 208218,
	[3747] = 208219,
	[3748] = 208220,
	[3749] = 208221,
	[3750] = 208222,
	[3751] = 208223,
	[3752] = 208224,
	[3814] = 208230,
	[3815] = 208231,
	[3816] = 208232,
	[3817] = 208233,
	[3818] = 208234,
	[3819] = 208235,
	[3820] = 208236,
	[3821] = 208237,
	[3822] = 208238,
	[3823] = 208239,
	[3824] = 208240,
	[3825] = 208241,
	[3826] = 208242,
	[3827] = 208243,
	[3828] = 208244,
	[3829] = 208245,
	[3830] = 208246,
	[3831] = 208247,
	[3832] = 208248,
	[3833] = 208249,
	[3834] = 208250,
	[3835] = 208251,
	[3836] = 208252,
	[3837] = 208253,
	[3838] = 208254,
	[3839] = 208255,
	[3840] = 208256,
	[3841] = 208257,
	[3842] = 208258,
	[3843] = 208259,
	[3844] = 208260,
	[3845] = 208261,
	[3846] = 208262,
	[3847] = 208263,
	[3848] = 208264,
	[3849] = 208265,
	[3850] = 208266,
	[3851] = 208267,
	[3914] = 208274,
	[3915] = 208275,
	[3916] = 208276,
	[3917] = 208277,
	[3918] = 208278,
	[3919] = 208279,
	[3920] = 208280,
	[3921] = 208281,
	[3922] = 208282,
	[3923] = 208283,
	[3924] = 208284,
	[3925] = 208285,
	[3926] = 208286,
	[3927] = 208287,
	[3928] = 208288,
	[3929] = 208289,
	[3930] = 208290,
	[3931] = 208291,
	[3932] = 208292,
	[3933] = 208293,
	[3934] = 208294,
	[3935] = 208295,
	[3936] = 208296,
	[3937] = 208297,
	[3938] = 208298,
	[3939] = 208299,
	[3940] = 208300,
	[3941] = 208301,
	[3942] = 208302,
	[3943] = 208303,
	[3944] = 208304,
	[3945] = 208305,
	[3946] = 208306,
	[3947] = 208307,
	[3948] = 208308,
	[3949] = 208309,
	[3950] = 208310,
	[3951] = 208311,
	[4014] = 208318,
	[4015] = 208319,
	[4016] = 208320,
	[4017] = 208321,
	[4018] = 208322,
	[4019] = 208323,
	[4020] = 208324,
	[4021] = 208325,
	[4022] = 208326,
	[4023] = 208327,
	[4024] = 208328,
	[4025] = 208329,
	[4026] = 208330,
	[4027] = 208331,
	[4028] = 208332,
	[4029] = 208333,
	[4030] = 208334,
	[4031] = 208335,
	[4032] = 208336,
	[4033] = 208337,
	[4034] = 208338,
	[4035] = 208339,
	[4036] = 208340,
	[4037] = 208341,
	[4038] = 208342,
	[4039] = 208343,
	[4040] = 208344,
	[4041] = 208345,
	[4042] = 208346,
	[4043] = 208347,
	[4044] = 208348,
	[4045] = 208349,
	[4046] = 208350,
	[4047] = 208351,
	[4048] = 208352,
	[4049] = 208353,
	[4050] = 208354,
	[4051] = 208355,
	[4115] = 208363,
	[4116] = 208364,
	[4117] = 208365,
	[4118] = 208366,
	[4119] = 208367,
	[4120] = 208368,
	[4121] = 208369,
	[4122] = 208370,
	[4123] = 208371,
	[4124] = 208372,
	[4125] = 208373,
	[4126] = 208374,
	[4127] = 208375,
	[4128] = 208376,
	[4129] = 208377,
	[4130] = 208378,
	[4131] = 208379,
	[4132] = 208380,
	[4133] = 208381,
	[4134] = 208382,
	[4135] = 208383,
	[4136] = 208384,
	[4137] = 208385,
	[4138] = 208386,
	[4139] = 208387,
	[4140] = 208388,
	[4141] = 208389,
	[4142] = 208390,
	[4143] = 208391,
	[4144] = 208392,
	[4145] = 208393,
	[4146] = 208394,
	[4147] = 208395,
	[4148] = 208396,
	[4149] = 208397,
	[4150] = 208398,
	[4151] = 208399,
	[4216] = 208408,
	[4217] = 208409,
	[4218] = 208410,
	[4219] = 208411,
	[4220] = 208412,
	[4221] = 208413,
	[4222] = 208414,
	[4223] = 208415,
	[4224] = 208416,
	[4225] = 208417,
	[4226] = 208418,
	[4227] = 208419,
	[4228] = 208420,
	[4229] = 208421,
	[4230] = 208422,
	[4231] = 208423,
	[4232] = 208424,
	[4233] = 208425,
	[4234] = 208426,
	[4235] = 208427,
	[4236] = 208428,
	[4237] = 208429,
	[4238] = 208430,
	[4239] = 208431,
	[4240] = 208432,
	[4241] = 208433,
	[4242] = 208434,
	[4243] = 208435,
	[4244] = 208436,
	[4245] = 208437,
	[4246] = 208438,
	[4247] = 208439,
	[4248] = 208440,
	[4249] = 208441,
	[4250] = 208442,
	[4251] = 208443,
	[4316] = 208452,
	[4317] = 208453,
	[4318] = 208454,
	[4319] = 208455,
	[4320] = 208456,
	[4321] = 208457,
	[4322] = 208458,
	[4323] = 208459,
	[4324] = 208460,
	[4325] = 208461,
	[4326] = 208462,
	[4327] = 208463,
	[4328] = 208464,
	[4329] = 208465,
	[4330] = 208466,
	[4331] = 208467,
	[4332] = 208468,
	[4333] = 208469,
	[4334] = 208470,
	[4335] = 208471,
	[4344] = 208477,
	[4345] = 208478,
	[4346] = 208479,
	[4347] = 208480,
	[4348] = 208481,
	[4349] = 208482,
	[4421] = 208492,
	[4422] = 208493,
	[4423] = 208494,
	[4424] = 208495,
	[4425] = 208496,
	[4426] = 208497,
	[4427] = 208498,
	[4428] = 208499,
	[4429] = 208500,
	[4521] = 208518,
	[4522] = 208519,
	[4523] = 208520,
	[4524] = 208521,
	[4525] = 208522,
	[4526] = 208523,
	[4527] = 208524,
	[4528] = 208525,
	[4529] = 208526,
	[4621] = 208534,
	[4622] = 208535,
	[4623] = 208536,
	[4624] = 208537,
	[4625] = 208538,
	[4626] = 208539,
	[4627] = 208540,
	[4628] = 208541,
	[4629] = 208542,
	[4722] = 208551,
	[4723] = 208552,
	[4724] = 208553,
}

Map.EkMapBlks = {
	[1741] = 467255,
	[1742] = 467189,
	[1743] = 467193,
	[1744] = 467197,
	[1745] = 467134,
	[1746] = 467139,
	[1841] = 467256,
	[1842] = 467190,
	[1843] = 467194,
	[1844] = 467198,
	[1845] = 467135,
	[1846] = 467140,
	[1941] = 467246,
	[1942] = 467191,
	[1943] = 467195,
	[1944] = 467199,
	[1945] = 467136,
	[1946] = 467141,
	[2039] = 467241,
	[2040] = 467244,
	[2041] = 467247,
	[2042] = 467192,
	[2043] = 467196,
	[2044] = 467200,
	[2045] = 467137,
	[2046] = 467142,
	[2139] = 467242,
	[2140] = 467245,
	[2141] = 467248,
	[2142] = 467201,
	[2143] = 467203,
	[2144] = 467207,
	[2145] = 467138,
	[2146] = 467143,
	[2239] = 467232,
	[2240] = 467235,
	[2241] = 467236,
	[2242] = 467202,
	[2243] = 467204,
	[2244] = 467208,
	[2245] = 467149,
	[2246] = 467155,
	[2339] = 467233,
	[2340] = 466918,
	[2341] = 466921,
	[2342] = 466924,
	[2343] = 467205,
	[2344] = 467209,
	[2345] = 467150,
	[2346] = 467156,
	[2439] = 467234,
	[2440] = 466919,
	[2441] = 466922,
	[2442] = 466925,
	[2443] = 467206,
	[2444] = 467210,
	[2445] = 467151,
	[2446] = 467157,
	[2539] = 467222,
	[2540] = 466920,
	[2541] = 466923,
	[2542] = 466926,
	[2543] = 467213,
	[2544] = 467216,
	[2545] = 467152,
	[2546] = 467158,
	[2639] = 467223,
	[2640] = 467225,
	[2641] = 467227,
	[2642] = 467211,
	[2643] = 467214,
	[2644] = 467217,
	[2645] = 467153,
	[2627] = 204242,
	[2628] = 204243,
	[2629] = 204244,
	[2630] = 204245,
	[2631] = 204246,
	[2632] = 204247,
	[2633] = 204248,
	[2634] = 204249,
	[2635] = 204250,
	[2636] = 204251,
	[2637] = 253800,
	[2652] = 204260,
	[2653] = 204261,
	[2654] = 204262,
	[2726] = 204271,
	[2727] = 204272,
	[2728] = 204273,
	[2729] = 204274,
	[2730] = 204275,
	[2731] = 204276,
	[2732] = 204277,
	[2733] = 204278,
	[2734] = 204279,
	[2735] = 204280,
	[2736] = 204281,
	[2737] = 204282,
	[2749] = 204294,
	[2750] = 204295,
	[2751] = 204296,
	[2752] = 204297,
	[2753] = 204298,
	[2754] = 204299,
	[2825] = 204310,
	[2826] = 204311,
	[2827] = 204312,
	[2828] = 204313,
	[2829] = 204314,
	[2830] = 204315,
	[2831] = 204316,
	[2832] = 204317,
	[2833] = 204318,
	[2834] = 204319,
	[2835] = 204320,
	[2836] = 204321,
	[2837] = 204322,
	[2838] = 204323,
	[2839] = 204324,
	[2840] = 204325,
	[2841] = 204326,
	[2842] = 204327,
	[2843] = 204328,
	[2844] = 204329,
	[2845] = 204330,
	[2846] = 204331,
	[2847] = 204332,
	[2848] = 204333,
	[2849] = 204334,
	[2850] = 204335,
	[2851] = 204336,
	[2852] = 204337,
	[2853] = 204338,
	[2854] = 204339,
	[2855] = 204340,
	[2856] = 204341,
	[2857] = 204342,
	[2858] = 204343,
	[2859] = 204344,
	[2925] = 204350,
	[2926] = 204351,
	[2927] = 204352,
	[2928] = 204353,
	[2929] = 204354,
	[2930] = 204355,
	[2931] = 204356,
	[2932] = 204357,
	[2933] = 204358,
	[2934] = 204359,
	[2935] = 204360,
	[2936] = 204361,
	[2937] = 204362,
	[2938] = 204363,
	[2939] = 204364,
	[2940] = 204365,
	[2941] = 204366,
	[2942] = 204367,
	[2943] = 204368,
	[2944] = 204369,
	[2945] = 204370,
	[2946] = 204371,
	[2947] = 204372,
	[2948] = 204373,
	[2949] = 204374,
	[2950] = 204375,
	[2951] = 204376,
	[2952] = 204377,
	[2953] = 204378,
	[2954] = 204379,
	[2955] = 204380,
	[2956] = 204381,
	[2957] = 204382,
	[2958] = 204383,
	[2959] = 204384,
	[2960] = 204385,
	[3025] = 204390,
	[3026] = 204391,
	[3027] = 204392,
	[3028] = 204393,
	[3029] = 204394,
	[3030] = 204395,
	[3031] = 204396,
	[3032] = 204397,
	[3033] = 204398,
	[3034] = 204399,
	[3035] = 204400,
	[3036] = 204401,
	[3037] = 204402,
	[3038] = 204403,
	[3039] = 204404,
	[3040] = 204405,
	[3041] = 204406,
	[3042] = 204407,
	[3043] = 204408,
	[3044] = 204409,
	[3045] = 204410,
	[3046] = 204411,
	[3047] = 204412,
	[3048] = 204413,
	[3049] = 204414,
	[3050] = 204415,
	[3051] = 204416,
	[3052] = 204417,
	[3053] = 204418,
	[3054] = 204419,
	[3055] = 204420,
	[3056] = 204421,
	[3057] = 204422,
	[3058] = 204423,
	[3059] = 204424,
	[3060] = 204425,
	[3125] = 204430,
	[3126] = 204431,
	[3127] = 204432,
	[3128] = 204433,
	[3129] = 204434,
	[3130] = 204435,
	[3131] = 204436,
	[3132] = 204437,
	[3133] = 204438,
	[3134] = 204439,
	[3135] = 204440,
	[3136] = 204441,
	[3137] = 204442,
	[3138] = 204443,
	[3139] = 204444,
	[3140] = 204445,
	[3141] = 204446,
	[3142] = 204447,
	[3143] = 204448,
	[3144] = 204449,
	[3145] = 204450,
	[3146] = 204451,
	[3147] = 204452,
	[3148] = 204453,
	[3149] = 204454,
	[3150] = 204455,
	[3151] = 204456,
	[3152] = 204457,
	[3153] = 204458,
	[3154] = 204459,
	[3155] = 204460,
	[3156] = 204461,
	[3157] = 204462,
	[3158] = 204463,
	[3159] = 204464,
	[3160] = 204465,
	[3225] = 204470,
	[3226] = 204471,
	[3227] = 204472,
	[3228] = 204473,
	[3229] = 204474,
	[3230] = 204475,
	[3231] = 204476,
	[3232] = 204477,
	[3233] = 204478,
	[3234] = 204479,
	[3235] = 204480,
	[3236] = 204481,
	[3237] = 204482,
	[3238] = 204483,
	[3239] = 204484,
	[3240] = 204485,
	[3241] = 204486,
	[3242] = 204487,
	[3243] = 204488,
	[3244] = 204489,
	[3245] = 204490,
	[3246] = 204491,
	[3247] = 204492,
	[3248] = 204493,
	[3249] = 204494,
	[3250] = 204495,
	[3251] = 204496,
	[3252] = 204497,
	[3253] = 204498,
	[3254] = 204499,
	[3255] = 204500,
	[3256] = 204501,
	[3257] = 204502,
	[3258] = 204503,
	[3259] = 204504,
	[3260] = 204505,
	[3325] = 204510,
	[3326] = 204511,
	[3327] = 204512,
	[3328] = 204513,
	[3329] = 204514,
	[3330] = 204515,
	[3331] = 204516,
	[3332] = 204517,
	[3333] = 204518,
	[3334] = 204519,
	[3335] = 204520,
	[3336] = 204521,
	[3337] = 204522,
	[3338] = 204523,
	[3339] = 204524,
	[3340] = 204525,
	[3341] = 204526,
	[3342] = 204527,
	[3343] = 204528,
	[3344] = 204529,
	[3345] = 204530,
	[3346] = 204531,
	[3347] = 204532,
	[3348] = 204533,
	[3349] = 204534,
	[3350] = 204535,
	[3351] = 204536,
	[3352] = 204537,
	[3353] = 204538,
	[3354] = 204539,
	[3355] = 204540,
	[3356] = 204541,
	[3357] = 204542,
	[3358] = 204543,
	[3359] = 204544,
	[3360] = 204545,
	[3425] = 204550,
	[3426] = 204551,
	[3427] = 204552,
	[3428] = 204553,
	[3429] = 204554,
	[3430] = 204555,
	[3431] = 204556,
	[3432] = 204557,
	[3433] = 204558,
	[3434] = 204559,
	[3435] = 204560,
	[3436] = 204561,
	[3437] = 204562,
	[3438] = 204563,
	[3439] = 204564,
	[3440] = 204565,
	[3441] = 204566,
	[3442] = 204567,
	[3443] = 204568,
	[3444] = 204569,
	[3445] = 204570,
	[3446] = 204571,
	[3447] = 204572,
	[3448] = 204573,
	[3449] = 204574,
	[3450] = 204575,
	[3451] = 204576,
	[3452] = 204577,
	[3453] = 204578,
	[3454] = 204579,
	[3455] = 204580,
	[3456] = 204581,
	[3457] = 204582,
	[3458] = 204583,
	[3459] = 204584,
	[3460] = 204585,
	[3524] = 204591,
	[3525] = 204592,
	[3526] = 204593,
	[3527] = 204594,
	[3528] = 204595,
	[3529] = 204596,
	[3530] = 204597,
	[3531] = 204598,
	[3532] = 204599,
	[3533] = 204600,
	[3534] = 204601,
	[3535] = 204602,
	[3536] = 204603,
	[3537] = 204604,
	[3538] = 204605,
	[3539] = 204606,
	[3540] = 204607,
	[3541] = 204608,
	[3542] = 204609,
	[3543] = 204610,
	[3544] = 204611,
	[3545] = 204612,
	[3546] = 204613,
	[3547] = 204614,
	[3548] = 204615,
	[3549] = 204616,
	[3550] = 204617,
	[3551] = 204618,
	[3552] = 204619,
	[3553] = 204620,
	[3554] = 204621,
	[3555] = 204622,
	[3556] = 204623,
	[3557] = 204624,
	[3558] = 204625,
	[3623] = 204630,
	[3624] = 204631,
	[3625] = 204632,
	[3626] = 204633,
	[3627] = 204634,
	[3628] = 204635,
	[3629] = 204636,
	[3630] = 204637,
	[3631] = 204638,
	[3632] = 204639,
	[3633] = 204640,
	[3634] = 204641,
	[3635] = 204642,
	[3636] = 204643,
	[3637] = 204644,
	[3638] = 204645,
	[3639] = 204646,
	[3640] = 204647,
	[3641] = 204648,
	[3642] = 204649,
	[3643] = 204650,
	[3644] = 204651,
	[3645] = 204652,
	[3646] = 204653,
	[3647] = 204654,
	[3648] = 204655,
	[3649] = 204656,
	[3650] = 204657,
	[3651] = 204658,
	[3652] = 204659,
	[3653] = 204660,
	[3654] = 204661,
	[3655] = 204662,
	[3656] = 204663,
	[3723] = 204670,
	[3724] = 204671,
	[3725] = 204672,
	[3726] = 204673,
	[3727] = 204674,
	[3728] = 204675,
	[3729] = 204676,
	[3730] = 204677,
	[3731] = 204678,
	[3732] = 204679,
	[3733] = 204680,
	[3734] = 204681,
	[3735] = 204682,
	[3736] = 204683,
	[3737] = 204684,
	[3738] = 204685,
	[3739] = 204686,
	[3740] = 204687,
	[3741] = 204688,
	[3742] = 204689,
	[3743] = 204690,
	[3744] = 204691,
	[3745] = 204692,
	[3746] = 204693,
	[3747] = 204694,
	[3748] = 204695,
	[3749] = 204696,
	[3750] = 204697,
	[3751] = 204698,
	[3752] = 204699,
	[3753] = 204700,
	[3754] = 204701,
	[3755] = 204702,
	[3756] = 204703,
	[3823] = 204710,
	[3824] = 204711,
	[3825] = 204712,
	[3826] = 204713,
	[3827] = 204714,
	[3828] = 204715,
	[3829] = 204716,
	[3830] = 204717,
	[3831] = 204718,
	[3832] = 204719,
	[3833] = 204720,
	[3834] = 204721,
	[3835] = 204722,
	[3836] = 204723,
	[3837] = 204724,
	[3838] = 204725,
	[3839] = 204726,
	[3840] = 204727,
	[3841] = 204728,
	[3842] = 204729,
	[3843] = 204730,
	[3844] = 204731,
	[3845] = 204732,
	[3846] = 204733,
	[3847] = 204734,
	[3848] = 204735,
	[3849] = 204736,
	[3850] = 204737,
	[3851] = 204738,
	[3852] = 204739,
	[3853] = 204740,
	[3854] = 204741,
	[3855] = 204742,
	[3923] = 204750,
	[3924] = 204751,
	[3925] = 204752,
	[3926] = 204753,
	[3927] = 204754,
	[3928] = 204755,
	[3929] = 204756,
	[3930] = 204757,
	[3931] = 204758,
	[3932] = 204759,
	[3933] = 204760,
	[3934] = 204761,
	[3935] = 204762,
	[3936] = 204763,
	[3937] = 204764,
	[3938] = 204765,
	[3939] = 204766,
	[3940] = 204767,
	[3941] = 204768,
	[3942] = 204769,
	[3943] = 204770,
	[3944] = 204771,
	[3945] = 204772,
	[3946] = 204773,
	[3947] = 204774,
	[3948] = 204775,
	[3949] = 204776,
	[3950] = 204777,
	[3951] = 204778,
	[3952] = 204779,
	[3953] = 204780,
	[3954] = 204781,
	[3955] = 204782,
	[4023] = 204790,
	[4024] = 204791,
	[4025] = 204792,
	[4026] = 204793,
	[4027] = 204794,
	[4028] = 204795,
	[4029] = 204796,
	[4030] = 204797,
	[4031] = 204798,
	[4032] = 204799,
	[4033] = 204800,
	[4034] = 204801,
	[4035] = 204802,
	[4036] = 204803,
	[4037] = 204804,
	[4038] = 204805,
	[4039] = 204806,
	[4040] = 204807,
	[4041] = 204808,
	[4042] = 204809,
	[4043] = 204810,
	[4044] = 204811,
	[4045] = 204812,
	[4046] = 204813,
	[4047] = 204814,
	[4048] = 204815,
	[4049] = 204816,
	[4050] = 204817,
	[4051] = 204818,
	[4052] = 204819,
	[4053] = 204820,
	[4123] = 204828,
	[4124] = 204829,
	[4125] = 204830,
	[4126] = 204831,
	[4127] = 204832,
	[4128] = 204833,
	[4129] = 204834,
	[4130] = 204835,
	[4131] = 204836,
	[4132] = 204837,
	[4133] = 204838,
	[4136] = 204841,
	[4137] = 204842,
	[4138] = 204843,
	[4139] = 204844,
	[4140] = 204845,
	[4141] = 204846,
	[4142] = 204847,
	[4143] = 204848,
	[4144] = 204849,
	[4145] = 204850,
	[4146] = 204851,
	[4147] = 204852,
	[4148] = 204853,
	[4149] = 204854,
	[4150] = 204855,
	[4151] = 204856,
	[4152] = 204857,
	[4224] = 204861,
	[4225] = 204862,
	[4226] = 204863,
	[4227] = 204864,
	[4228] = 204865,
	[4229] = 204866,
	[4230] = 204867,
	[4236] = 204873,
	[4237] = 204874,
	[4238] = 204875,
	[4239] = 204876,
	[4240] = 204877,
	[4241] = 204878,
	[4242] = 204879,
	[4325] = 204893,
	[4326] = 204894,
	[4327] = 204895,
	[4328] = 204896,
	[4329] = 204897,
	[4336] = 341448,
	[4337] = 341449,
	[4338] = 341450,
	[4339] = 341451,
	[4340] = 341442,
	[4341] = 341444,
	[4425] = 204903,
	[4426] = 204904,
	[4436] = 341452,
	[4437] = 341453,
	[4438] = 341454,
	[4439] = 341455,
	[4440] = 341443,
	[4441] = 341445,
}

Map.OLMapBlks = {
	[1334] = 206599,
	[1335] = 206600,
	[1429] = 206610,
	[1430] = 206611,
	[1431] = 206612,
	[1432] = 206613,
	[1433] = 206614,
	[1434] = 206615,
	[1435] = 206616,
	[1436] = 206617,
	[1437] = 206618,
	[1528] = 206630,
	[1529] = 206631,
	[1530] = 206632,
	[1531] = 206633,
	[1532] = 206634,
	[1533] = 206635,
	[1534] = 206636,
	[1535] = 206637,
	[1536] = 206638,
	[1537] = 206639,
	[1538] = 206640,
	[1628] = 206651,
	[1629] = 206652,
	[1630] = 206653,
	[1631] = 206654,
	[1632] = 206655,
	[1633] = 206656,
	[1634] = 206657,
	[1635] = 206658,
	[1636] = 206659,
	[1637] = 206660,
	[1638] = 206661,
	[1725] = 206669,
	[1726] = 206670,
	[1727] = 206671,
	[1728] = 206672,
	[1729] = 206673,
	[1730] = 206674,
	[1731] = 206675,
	[1732] = 206676,
	[1733] = 206677,
	[1734] = 206678,
	[1735] = 206679,
	[1736] = 206680,
	[1737] = 206681,
	[1738] = 206682,
	[1824] = 206690,
	[1825] = 206691,
	[1826] = 206692,
	[1827] = 206693,
	[1828] = 206694,
	[1829] = 206695,
	[1830] = 206696,
	[1831] = 206697,
	[1832] = 206698,
	[1833] = 206699,
	[1834] = 206700,
	[1835] = 206701,
	[1836] = 206702,
	[1837] = 206703,
	[1838] = 206704,
	[1924] = 206712,
	[1925] = 206713,
	[1926] = 206714,
	[1927] = 206715,
	[1928] = 206716,
	[1929] = 206717,
	[1930] = 206718,
	[1931] = 206719,
	[1932] = 206720,
	[1933] = 206721,
	[1934] = 206722,
	[1935] = 206723,
	[1936] = 206724,
	[1937] = 206725,
	[1938] = 206726,
	[1939] = 206727,
	[1940] = 206728,
	[2024] = 206734,
	[2025] = 206735,
	[2026] = 206736,
	[2027] = 206737,
	[2028] = 206738,
	[2029] = 206739,
	[2030] = 206740,
	[2031] = 206741,
	[2032] = 206742,
	[2033] = 206743,
	[2034] = 206744,
	[2035] = 206745,
	[2036] = 206746,
	[2037] = 206747,
	[2038] = 206748,
	[2039] = 206749,
	[2040] = 206750,
	[2123] = 206755,
	[2124] = 206756,
	[2125] = 206757,
	[2126] = 206758,
	[2127] = 206759,
	[2128] = 206760,
	[2129] = 206761,
	[2130] = 206762,
	[2131] = 206763,
	[2132] = 206764,
	[2133] = 206765,
	[2134] = 206766,
	[2135] = 206767,
	[2136] = 206768,
	[2137] = 206769,
	[2138] = 206770,
	[2139] = 206771,
	[2140] = 206772,
	[2223] = 206777,
	[2224] = 206778,
	[2225] = 206779,
	[2226] = 206780,
	[2227] = 206781,
	[2228] = 206782,
	[2229] = 206783,
	[2230] = 206784,
	[2231] = 206785,
	[2232] = 206786,
	[2233] = 206787,
	[2234] = 206788,
	[2235] = 206789,
	[2236] = 206790,
	[2237] = 206791,
	[2238] = 206792,
	[2239] = 206793,
	[2240] = 206794,
	[2323] = 206799,
	[2324] = 206800,
	[2325] = 206801,
	[2326] = 206802,
	[2327] = 206803,
	[2328] = 206804,
	[2329] = 206805,
	[2330] = 206806,
	[2331] = 206807,
	[2332] = 206808,
	[2333] = 206809,
	[2334] = 206810,
	[2335] = 206811,
	[2336] = 206812,
	[2337] = 206813,
	[2338] = 206814,
	[2339] = 206815,
	[2340] = 206816,
	[2422] = 206820,
	[2423] = 206821,
	[2424] = 206822,
	[2425] = 206823,
	[2426] = 206824,
	[2427] = 206825,
	[2430] = 206828,
	[2431] = 206829,
	[2432] = 206830,
	[2433] = 206831,
	[2434] = 206832,
	[2435] = 206833,
	[2436] = 206834,
	[2437] = 206835,
	[2438] = 206836,
	[2439] = 206837,
	[2440] = 206838,
	[2522] = 206842,
	[2523] = 206843,
	[2524] = 206844,
	[2525] = 206845,
	[2526] = 206846,
	[2527] = 206847,
	[2528] = 206848,
	[2530] = 206850,
	[2531] = 206851,
	[2532] = 206852,
	[2533] = 206853,
	[2534] = 206854,
	[2535] = 206855,
	[2536] = 206856,
	[2537] = 206857,
	[2538] = 206858,
	[2539] = 206859,
	[2540] = 206860,
	[2622] = 206864,
	[2623] = 206865,
	[2624] = 206866,
	[2625] = 206867,
	[2626] = 206868,
	[2627] = 206869,
	[2628] = 206870,
	[2629] = 206871,
	[2630] = 206872,
	[2631] = 206873,
	[2632] = 206874,
	[2633] = 206875,
	[2634] = 206876,
	[2635] = 206877,
	[2636] = 206878,
	[2637] = 206879,
	[2638] = 206880,
	[2639] = 206881,
	[2640] = 206882,
	[2722] = 206886,
	[2723] = 206887,
	[2724] = 206888,
	[2725] = 206889,
	[2726] = 206890,
	[2727] = 206891,
	[2728] = 206892,
	[2729] = 206893,
	[2730] = 206894,
	[2731] = 206895,
	[2732] = 206896,
	[2733] = 206897,
	[2734] = 206898,
	[2735] = 206899,
	[2736] = 206900,
	[2737] = 206901,
	[2738] = 206902,
	[2739] = 206903,
	[2740] = 206904,
	[2823] = 206909,
	[2824] = 206910,
	[2825] = 206911,
	[2826] = 206912,
	[2827] = 206913,
	[2828] = 206914,
	[2829] = 206915,
	[2830] = 206916,
	[2831] = 206917,
	[2832] = 206918,
	[2833] = 206919,
	[2834] = 206920,
	[2836] = 206922,
	[2837] = 206923,
	[2838] = 206924,
	[2839] = 206925,
	[2840] = 206926,
	[2841] = 206927,
	[2923] = 206931,
	[2924] = 206932,
	[2925] = 206933,
	[2926] = 206934,
	[2930] = 206938,
	[2931] = 206939,
	[2932] = 206940,
	[2933] = 206941,
	[2934] = 206942,
	[2936] = 206944,
	[2937] = 206945,
	[2938] = 206946,
	[2939] = 206947,
	[2940] = 206948,
	[2941] = 206949,
	[3026] = 206956,
	[3031] = 206961,
	[3032] = 206962,
	[3033] = 206963,
	[3034] = 206964,
	[3036] = 206966,
	[3037] = 206967,
	[3038] = 206968,
	[3039] = 206969,
	[3040] = 206970,
	[3041] = 206971,
	[3042] = 206972,
	[3132] = 206984,
	[3136] = 206988,
	[3137] = 206989,
	[3138] = 206990,
	[3139] = 206991,
	[3140] = 206992,
	[3141] = 206993,
	[3142] = 206994,
	[3237] = 207002,
	[3238] = 207003,
	[3239] = 207004,
	[3240] = 207005,
	[3241] = 207006,
	[3242] = 207007,
	[3337] = 207015,
	[3338] = 207016,
	[3339] = 207017,
}

Map.NRMapBlks = {
	[1609] = 245287,
	[1610] = 245288,
	[1611] = 245289,
	[1612] = 208688,
	[1613] = 208689,
	[1614] = 208690,
	[1615] = 208691,
	[1616] = 208692,
	[1617] = 208693,
	[1618] = 208694,
	[1619] = 208695,
	[1620] = 208696,
	[1621] = 208697,
	[1622] = 208698,
	[1623] = 208699,
	[1624] = 208700,
	[1625] = 208701,
	[1626] = 208702,
	[1627] = 208703,
	[1628] = 208704,
	[1629] = 208705,
	[1630] = 208706,
	[1631] = 208707,
	[1632] = 208708,
	[1633] = 208709,
	[1709] = 245293,
	[1710] = 245294,
	[1711] = 245295,
	[1712] = 208711,
	[1713] = 208712,
	[1714] = 208713,
	[1715] = 208714,
	[1716] = 208715,
	[1717] = 208716,
	[1718] = 208717,
	[1719] = 208718,
	[1720] = 208719,
	[1721] = 208720,
	[1722] = 208721,
	[1723] = 208722,
	[1724] = 208723,
	[1725] = 208724,
	[1726] = 208725,
	[1727] = 208726,
	[1728] = 208727,
	[1729] = 208728,
	[1730] = 208729,
	[1731] = 208730,
	[1732] = 208731,
	[1733] = 208732,
	[1809] = 245299,
	[1810] = 245300,
	[1811] = 245301,
	[1812] = 208734,
	[1813] = 208735,
	[1814] = 208736,
	[1815] = 208737,
	[1816] = 208738,
	[1817] = 208739,
	[1818] = 208740,
	[1819] = 208741,
	[1820] = 208742,
	[1821] = 208743,
	[1822] = 208744,
	[1823] = 208745,
	[1824] = 208746,
	[1825] = 208747,
	[1826] = 208748,
	[1827] = 208749,
	[1828] = 208750,
	[1829] = 208751,
	[1830] = 208752,
	[1831] = 208753,
	[1832] = 208754,
	[1833] = 208755,
	[1909] = 245305,
	[1910] = 245306,
	[1911] = 245307,
	[1912] = 208757,
	[1913] = 208758,
	[1914] = 208759,
	[1915] = 208760,
	[1916] = 208761,
	[1917] = 208762,
	[1918] = 208763,
	[1919] = 208764,
	[1920] = 208765,
	[1921] = 208766,
	[1922] = 208767,
	[1923] = 208768,
	[1924] = 208769,
	[1925] = 208770,
	[1926] = 208771,
	[1927] = 208772,
	[1928] = 208773,
	[1929] = 208774,
	[1930] = 208775,
	[1931] = 208776,
	[1932] = 208777,
	[1933] = 208778,
	[2009] = 245311,
	[2010] = 245312,
	[2011] = 245313,
	[2012] = 208780,
	[2013] = 208781,
	[2014] = 208782,
	[2015] = 208783,
	[2016] = 208784,
	[2017] = 208785,
	[2018] = 208786,
	[2019] = 208787,
	[2020] = 208788,
	[2021] = 208789,
	[2022] = 208790,
	[2023] = 208791,
	[2024] = 208792,
	[2025] = 208793,
	[2026] = 208794,
	[2027] = 208795,
	[2028] = 208796,
	[2029] = 208797,
	[2030] = 208798,
	[2031] = 208799,
	[2032] = 208800,
	[2033] = 208801,
	[2109] = 245317,
	[2110] = 245318,
	[2111] = 245319,
	[2112] = 208803,
	[2113] = 208804,
	[2114] = 208805,
	[2115] = 208806,
	[2116] = 208807,
	[2117] = 208808,
	[2118] = 208809,
	[2119] = 208810,
	[2120] = 208811,
	[2121] = 208812,
	[2122] = 208813,
	[2123] = 208814,
	[2124] = 208815,
	[2125] = 208816,
	[2126] = 208817,
	[2127] = 208818,
	[2128] = 208819,
	[2129] = 208820,
	[2130] = 208821,
	[2131] = 208822,
	[2132] = 208823,
	[2133] = 208824,
	[2209] = 245323,
	[2210] = 245324,
	[2211] = 245325,
	[2212] = 208826,
	[2213] = 208827,
	[2214] = 208828,
	[2215] = 208829,
	[2216] = 208830,
	[2217] = 208831,
	[2218] = 208832,
	[2219] = 208833,
	[2220] = 208834,
	[2221] = 208835,
	[2222] = 208836,
	[2223] = 208837,
	[2224] = 208838,
	[2225] = 208839,
	[2226] = 208840,
	[2227] = 208841,
	[2228] = 208842,
	[2229] = 208843,
	[2230] = 208844,
	[2231] = 208845,
	[2232] = 208846,
	[2233] = 208847,
	[2309] = 245329,
	[2310] = 245330,
	[2311] = 245331,
	[2312] = 208849,
	[2313] = 208850,
	[2314] = 208851,
	[2315] = 208852,
	[2316] = 208853,
	[2317] = 208854,
	[2318] = 208855,
	[2319] = 208856,
	[2320] = 208857,
	[2321] = 208858,
	[2322] = 208859,
	[2323] = 208860,
	[2324] = 208861,
	[2325] = 208862,
	[2326] = 208863,
	[2327] = 208864,
	[2328] = 208865,
	[2329] = 208866,
	[2330] = 208867,
	[2331] = 208868,
	[2332] = 208869,
	[2333] = 208870,
	[2409] = 245335,
	[2410] = 245336,
	[2411] = 245337,
	[2412] = 208872,
	[2413] = 208873,
	[2414] = 208874,
	[2415] = 208875,
	[2416] = 208876,
	[2417] = 208877,
	[2418] = 208878,
	[2419] = 208879,
	[2420] = 208880,
	[2421] = 208881,
	[2422] = 208882,
	[2423] = 208883,
	[2424] = 208884,
	[2425] = 208885,
	[2426] = 208886,
	[2427] = 208887,
	[2428] = 208888,
	[2429] = 208889,
	[2430] = 208890,
	[2431] = 208891,
	[2432] = 208892,
	[2433] = 208893,
	[2509] = 245341,
	[2510] = 245342,
	[2511] = 245343,
	[2512] = 208895,
	[2513] = 208896,
	[2514] = 208897,
	[2515] = 208898,
	[2516] = 208899,
	[2517] = 208900,
	[2518] = 208901,
	[2519] = 208902,
	[2520] = 208903,
	[2521] = 208904,
	[2522] = 208905,
	[2523] = 208906,
	[2524] = 208907,
	[2525] = 208908,
	[2526] = 208909,
	[2527] = 208910,
	[2528] = 208911,
	[2529] = 208912,
	[2530] = 208913,
	[2531] = 208914,
	[2532] = 208915,
	[2533] = 208916,
	[2609] = 245347,
	[2610] = 245348,
	[2611] = 245349,
	[2612] = 208918,
	[2613] = 208919,
	[2614] = 208920,
	[2615] = 208921,
	[2616] = 208922,
	[2617] = 208923,
	[2618] = 208924,
	[2619] = 208925,
	[2620] = 208926,
	[2621] = 208927,
	[2622] = 208928,
	[2623] = 208929,
	[2624] = 208930,
	[2625] = 208931,
	[2626] = 208932,
	[2627] = 208933,
	[2628] = 208934,
	[2629] = 208935,
	[2630] = 208936,
	[2631] = 208937,
	[2632] = 208938,
	[2633] = 208939,
	[2709] = 245353,
	[2710] = 245354,
	[2711] = 245355,
	[2712] = 208941,
	[2713] = 208942,
	[2714] = 208943,
	[2715] = 208944,
	[2716] = 208945,
	[2717] = 208946,
	[2718] = 208947,
	[2719] = 208948,
	[2720] = 208949,
	[2721] = 208950,
	[2722] = 208951,
	[2723] = 208952,
	[2724] = 208953,
	[2725] = 208954,
	[2726] = 208955,
	[2727] = 208956,
	[2728] = 208957,
	[2729] = 208958,
	[2730] = 208959,
	[2731] = 208960,
	[2732] = 208961,
	[2733] = 208962,
	[2809] = 245359,
	[2810] = 245360,
	[2811] = 245361,
	[2812] = 208964,
	[2813] = 208965,
	[2814] = 208966,
	[2815] = 208967,
	[2816] = 208968,
	[2817] = 208969,
	[2818] = 208970,
	[2819] = 208971,
	[2820] = 208972,
	[2821] = 208973,
	[2822] = 208974,
	[2823] = 208975,
	[2824] = 208976,
	[2825] = 208977,
	[2826] = 208978,
	[2827] = 208979,
	[2828] = 208980,
	[2829] = 208981,
	[2830] = 208982,
	[2831] = 208983,
	[2832] = 208984,
	[2833] = 208985,
	[2909] = 245365,
	[2910] = 245366,
	[2911] = 245367,
	[2912] = 208987,
	[2913] = 208988,
	[2914] = 208989,
	[2915] = 208990,
	[2916] = 208991,
	[2917] = 208992,
	[2918] = 208993,
	[2919] = 208994,
	[2920] = 208995,
	[2921] = 208996,
	[2922] = 208997,
	[2923] = 208998,
	[2924] = 208999,
	[2925] = 209000,
	[2926] = 209001,
	[2927] = 209002,
	[2928] = 209003,
	[2929] = 209004,
	[2930] = 209005,
	[2931] = 209006,
	[2932] = 209007,
	[2933] = 209008,
	[3009] = 245371,
	[3010] = 245372,
	[3011] = 245373,
	[3012] = 209010,
	[3013] = 209011,
	[3014] = 209012,
	[3015] = 209013,
	[3016] = 209014,
	[3017] = 209015,
	[3018] = 209016,
	[3019] = 209017,
	[3020] = 209018,
	[3021] = 209019,
	[3022] = 209020,
	[3023] = 209021,
	[3024] = 209022,
	[3025] = 209023,
	[3026] = 209024,
	[3027] = 209025,
	[3028] = 209026,
	[3029] = 209027,
	[3030] = 209028,
	[3031] = 209029,
	[3032] = 209030,
	[3033] = 209031,
	[3109] = 245377,
	[3110] = 245378,
	[3111] = 245379,
	[3112] = 209033,
	[3113] = 209034,
	[3114] = 209035,
	[3115] = 209036,
	[3116] = 209037,
	[3117] = 209038,
	[3118] = 209039,
	[3119] = 209040,
	[3120] = 209041,
	[3121] = 209042,
	[3122] = 209043,
	[3123] = 209044,
	[3124] = 209045,
	[3125] = 209046,
	[3126] = 209047,
	[3127] = 209048,
	[3128] = 209049,
	[3129] = 209050,
	[3130] = 209051,
	[3131] = 209052,
	[3132] = 209053,
	[3133] = 209054,
	[3209] = 245383,
	[3210] = 245384,
	[3211] = 245385,
	[3212] = 209056,
	[3213] = 209057,
	[3214] = 209058,
	[3215] = 209059,
	[3216] = 209060,
	[3217] = 209061,
	[3218] = 209062,
	[3219] = 209063,
	[3220] = 209064,
	[3221] = 209065,
	[3222] = 209066,
	[3223] = 209067,
	[3224] = 209068,
	[3225] = 209069,
	[3226] = 209070,
	[3227] = 209071,
	[3228] = 209072,
	[3229] = 209073,
	[3230] = 209074,
	[3231] = 209075,
	[3232] = 209076,
	[3233] = 209077,
	[3309] = 245389,
	[3310] = 245390,
	[3311] = 245391,
	[3312] = 209079,
	[3313] = 209080,
	[3314] = 209081,
	[3315] = 209082,
	[3316] = 209083,
	[3317] = 209084,
	[3318] = 209085,
	[3319] = 209086,
	[3320] = 209087,
	[3321] = 209088,
	[3322] = 209089,
	[3323] = 209090,
	[3324] = 209091,
	[3325] = 209092,
	[3326] = 209093,
	[3327] = 209094,
	[3328] = 209095,
	[3329] = 209096,
	[3330] = 209097,
	[3331] = 209098,
	[3332] = 209099,
	[3333] = 209100,
	[3409] = 245395,
	[3410] = 245396,
	[3411] = 245397,
	[3412] = 209102,
	[3413] = 209103,
	[3414] = 209104,
	[3415] = 209105,
	[3416] = 209106,
	[3417] = 209107,
	[3418] = 209108,
	[3419] = 209109,
	[3420] = 209110,
	[3421] = 209111,
	[3422] = 209112,
	[3423] = 209113,
	[3424] = 209114,
	[3425] = 209115,
	[3426] = 209116,
	[3427] = 209117,
	[3428] = 209118,
	[3429] = 209119,
	[3430] = 209120,
	[3431] = 209121,
	[3432] = 209122,
	[3433] = 209123,
	[3509] = 245401,
	[3510] = 245402,
	[3511] = 245403,
	[3512] = 209125,
	[3513] = 209126,
	[3514] = 209127,
	[3515] = 209128,
	[3516] = 209129,
	[3517] = 209130,
	[3518] = 209131,
	[3519] = 209132,
	[3520] = 209133,
	[3521] = 209134,
	[3522] = 209135,
	[3523] = 209136,
	[3524] = 209137,
	[3525] = 209138,
	[3526] = 209139,
	[3527] = 209140,
	[3528] = 209141,
	[3529] = 209142,
	[3530] = 209143,
	[3531] = 209144,
	[3532] = 209145,
	[3533] = 209146,
	[3609] = 245407,
	[3610] = 245408,
	[3611] = 245409,
	[3612] = 209148,
	[3613] = 209149,
	[3614] = 209150,
	[3615] = 209151,
	[3616] = 209152,
	[3617] = 209153,
	[3618] = 209154,
	[3619] = 209155,
	[3620] = 209156,
	[3621] = 209157,
	[3622] = 209158,
	[3623] = 209159,
	[3624] = 209160,
	[3625] = 209161,
	[3626] = 209162,
	[3627] = 209163,
	[3628] = 209164,
	[3629] = 209165,
	[3630] = 209166,
	[3631] = 209167,
	[3632] = 209168,
	[3633] = 209169,
	[3709] = 245413,
	[3710] = 245414,
	[3711] = 245415,
	[3712] = 209171,
	[3713] = 209172,
	[3714] = 209173,
	[3715] = 209174,
	[3716] = 209175,
	[3717] = 209176,
	[3718] = 209177,
	[3719] = 209178,
	[3720] = 209179,
	[3721] = 209180,
	[3722] = 209181,
	[3723] = 209182,
	[3724] = 209183,
	[3725] = 209184,
	[3726] = 209185,
	[3727] = 209186,
	[3728] = 209187,
	[3729] = 209188,
	[3730] = 209189,
	[3731] = 209190,
	[3732] = 209191,
	[3733] = 209192,
	[3809] = 245419,
	[3810] = 245420,
	[3811] = 245421,
	[3812] = 209194,
	[3813] = 209195,
	[3814] = 209196,
	[3815] = 209197,
	[3816] = 209198,
	[3817] = 209199,
	[3818] = 209200,
	[3819] = 209201,
	[3820] = 209202,
	[3821] = 209203,
	[3822] = 209204,
	[3823] = 209205,
	[3824] = 209206,
	[3825] = 209207,
	[3826] = 209208,
	[3827] = 209209,
	[3828] = 209210,
	[3829] = 209211,
	[3830] = 209212,
	[3831] = 209213,
	[3832] = 209214,
	[3833] = 209215,
	[3909] = 245425,
	[3910] = 245426,
	[3911] = 245427,
	[3912] = 209217,
	[3913] = 209218,
	[3914] = 209219,
	[3915] = 209220,
	[3916] = 209221,
	[3917] = 209222,
	[3918] = 209223,
	[3919] = 209224,
	[3920] = 209225,
	[3921] = 209226,
	[3922] = 209227,
	[3923] = 209228,
	[3924] = 209229,
	[3925] = 209230,
	[3926] = 209231,
	[3927] = 209232,
	[3928] = 209233,
	[3929] = 209234,
	[3930] = 209235,
	[3931] = 209236,
	[3932] = 209237,
	[3933] = 209238,
	[4009] = 245431,
	[4010] = 245432,
	[4011] = 245433,
	[4012] = 209240,
	[4013] = 209241,
	[4014] = 209242,
	[4015] = 209243,
	[4016] = 209244,
	[4017] = 209245,
	[4018] = 209246,
	[4019] = 209247,
	[4020] = 209248,
	[4021] = 209249,
	[4022] = 209250,
	[4023] = 209251,
	[4024] = 209252,
	[4025] = 209253,
	[4026] = 209254,
	[4027] = 209255,
	[4028] = 209256,
	[4029] = 209257,
	[4030] = 209258,
	[4031] = 209259,
	[4032] = 209260,
	[4033] = 209261,
	[4109] = 245437,
	[4110] = 245438,
	[4111] = 245439,
	[4112] = 209263,
	[4113] = 209264,
	[4114] = 209265,
	[4115] = 209266,
	[4116] = 209267,
	[4117] = 209268,
	[4118] = 209269,
	[4119] = 209270,
	[4120] = 209271,
	[4121] = 209272,
	[4122] = 209273,
	[4123] = 209274,
	[4124] = 209275,
	[4125] = 209276,
	[4126] = 209277,
	[4127] = 209278,
	[4128] = 209279,
	[4129] = 209280,
	[4130] = 209281,
	[4131] = 209282,
	[4132] = 209283,
	[4133] = 209284,
	[4209] = 245443,
	[4210] = 245444,
	[4211] = 245445,
	[4212] = 209286,
	[4213] = 209287,
	[4214] = 209288,
	[4215] = 209289,
	[4216] = 209290,
	[4217] = 209291,
	[4218] = 209292,
	[4219] = 209293,
	[4220] = 209294,
	[4221] = 209295,
	[4222] = 209296,
	[4223] = 209297,
	[4224] = 209298,
	[4225] = 209299,
	[4226] = 209300,
	[4227] = 209301,
	[4228] = 209302,
	[4229] = 209303,
	[4230] = 209304,
	[4231] = 209305,
	[4232] = 209306,
	[4233] = 209307,
	[4309] = 245449,
	[4310] = 245450,
	[4311] = 245451,
	[4312] = 209309,
	[4313] = 209310,
	[4314] = 209311,
	[4315] = 209312,
	[4316] = 209313,
	[4317] = 209314,
	[4318] = 209315,
	[4319] = 209316,
	[4320] = 209317,
	[4321] = 209318,
	[4322] = 209319,
	[4323] = 209320,
	[4324] = 209321,
	[4325] = 209322,
	[4326] = 209323,
	[4327] = 209324,
	[4328] = 209325,
	[4329] = 209326,
	[4330] = 209327,
	[4331] = 209328,
	[4332] = 209329,
	[4333] = 209330,
	[4409] = 245455,
	[4410] = 245456,
	[4411] = 245457,
	[4412] = 209332,
	[4413] = 209333,
	[4414] = 209334,
	[4415] = 209335,
	[4416] = 209336,
	[4417] = 209337,
	[4418] = 209338,
	[4419] = 209339,
	[4420] = 209340,
	[4421] = 209341,
	[4422] = 209342,
	[4423] = 209343,
	[4424] = 209344,
	[4425] = 209345,
	[4426] = 209346,
	[4427] = 209347,
	[4428] = 209348,
	[4429] = 209349,
	[4430] = 209350,
	[4431] = 209351,
	[4432] = 209352,
	[4433] = 209353,
	[4509] = 245461,
	[4510] = 245462,
	[4511] = 245463,
	[4512] = 209355,
	[4513] = 209356,
	[4514] = 209357,
	[4515] = 209358,
	[4516] = 209359,
	[4517] = 209360,
	[4518] = 209361,
	[4519] = 209362,
	[4520] = 209363,
	[4521] = 209364,
	[4522] = 209365,
	[4523] = 209366,
	[4524] = 209367,
	[4525] = 209368,
	[4526] = 209369,
	[4527] = 209370,
	[4528] = 209371,
	[4529] = 209372,
	[4530] = 209373,
	[4531] = 209374,
	[4532] = 209375,
	[4533] = 209376,
}

Map.LIMapBlks = {
	[2426] = 306396,
	[2427] = 306406,
	[2428] = 306416,
	[2429] = 306426,
	[2430] = 306436,
	[2431] = 306446,
	[2432] = 306456,
	[2526] = 306397,
	[2527] = 306407,
	[2528] = 306417,
	[2529] = 306427,
	[2530] = 306437,
	[2531] = 306447,
	[2532] = 306457,
	[2626] = 306398,
	[2627] = 306408,
	[2628] = 306418,
	[2629] = 306428,
	[2630] = 306438,
	[2631] = 306448,
	[2632] = 306458,
	[2726] = 306399,
	[2727] = 306409,
	[2728] = 306419,
	[2729] = 306429,
	[2730] = 306439,
	[2731] = 306449,
	[2732] = 306459,
	[2826] = 306400,
	[2827] = 306410,
	[2828] = 306420,
	[2829] = 306430,
	[2830] = 306440,
	[2831] = 306450,
	[2832] = 306460,
	[2926] = 306401,
	[2927] = 306411,
	[2928] = 306421,
	[2929] = 306431,
	[2930] = 306441,
	[2931] = 306451,
	[2932] = 306461,
	[3026] = 306402,
	[3027] = 306412,
	[3028] = 306422,
	[3029] = 306432,
	[3030] = 306442,
	[3031] = 306452,
	[3032] = 306462,
	[3126] = 306403,
	[3127] = 306413,
	[3128] = 306423,
	[3129] = 306433,
	[3130] = 306443,
	[3131] = 306453,
}

Map.PandariaMapBlks = {
	[1818] = 610597,
	[1819] = 610598,
	[1820] = 610599,
	[1821] = 610600,
	[1822] = 610601,
	[1823] = 610602,
	[1824] = 610603,
	[1825] = 610604,
	[1826] = 610605,
	[1827] = 610606,
	[1828] = 610607,
	[1829] = 610608,
	[1830] = 646718,
	[1831] = 646721,
	[1832] = 646724,
	[1833] = 646727,
	[1834] = 646730,
	[1835] = 646733,
	[1836] = 646736,
	[1837] = 646739,
	[1838] = 646742,
	[1839] = 646745,
	[1840] = 646748,
	[1841] = 646751,
	[1918] = 610589,
	[1919] = 593293,
	[1920] = 590056,
	[1921] = 590063,
	[1922] = 590064,
	[1923] = 590065,
	[1924] = 590066,
	[1925] = 593300,
	[1926] = 593301,
	[1927] = 593302,
	[1928] = 593303,
	[1929] = 610482,
	[1930] = 610483,
	[1931] = 610484,
	[1932] = 610485,
	[1933] = 610486,
	[1934] = 610487,
	[1935] = 610488,
	[1936] = 610489,
	[1937] = 610490,
	[1938] = 610491,
	[1939] = 616303,
	[1940] = 646752,
	[1941] = 646755,
	[2018] = 610590,
	[2019] = 593294,
	[2020] = 590057,
	[2021] = 528850,
	[2022] = 528870,
	[2023] = 528884,
	[2024] = 528891,
	[2025] = 528898,
	[2026] = 528900,
	[2027] = 528902,
	[2028] = 528904,
	[2029] = 528906,
	[2030] = 528908,
	[2031] = 528910,
	[2032] = 528912,
	[2033] = 528914,
	[2034] = 528916,
	[2035] = 528918,
	[2036] = 528920,
	[2037] = 528922,
	[2038] = 589277,
	[2039] = 616304,
	[2040] = 646753,
	[2041] = 646756,
	[2118] = 610591,
	[2119] = 593295,
	[2120] = 590058,
	[2121] = 528851,
	[2122] = 528871,
	[2123] = 528885,
	[2124] = 528892,
	[2125] = 528899,
	[2126] = 528901,
	[2127] = 528903,
	[2128] = 528905,
	[2129] = 528907,
	[2130] = 528909,
	[2131] = 528911,
	[2132] = 528913,
	[2133] = 528915,
	[2134] = 528917,
	[2135] = 528919,
	[2136] = 528921,
	[2137] = 528923,
	[2138] = 589278,
	[2139] = 616305,
	[2140] = 646754,
	[2141] = 646757,
	[2218] = 610592,
	[2219] = 593296,
	[2220] = 590059,
	[2221] = 528852,
	[2222] = 528872,
	[2223] = 528886,
	[2224] = 528893,
	[2225] = 513020,
	[2226] = 513021,
	[2227] = 513022,
	[2228] = 513023,
	[2229] = 513024,
	[2230] = 513025,
	[2231] = 513026,
	[2232] = 513028,
	[2233] = 513157,
	[2234] = 513158,
	[2235] = 513159,
	[2236] = 513165,
	[2237] = 513171,
	[2238] = 589279,
	[2239] = 616306,
	[2240] = 646795,
	[2241] = 646801,
	[2318] = 610593,
	[2319] = 593297,
	[2320] = 590060,
	[2321] = 528853,
	[2322] = 528873,
	[2323] = 528887,
	[2324] = 528894,
	[2325] = 512995,
	[2326] = 512998,
	[2327] = 513001,
	[2328] = 513004,
	[2329] = 513007,
	[2330] = 513010,
	[2331] = 513027,
	[2332] = 513029,
	[2333] = 513059,
	[2334] = 513064,
	[2335] = 513160,
	[2336] = 513166,
	[2337] = 513172,
	[2338] = 589280,
	[2339] = 616307,
	[2340] = 646796,
	[2341] = 646802,
	[2418] = 610594,
	[2419] = 593298,
	[2420] = 590061,
	[2421] = 528854,
	[2422] = 528874,
	[2423] = 527736,
	[2424] = 527744,
	[2425] = 512996,
	[2426] = 512999,
	[2427] = 513002,
	[2428] = 513005,
	[2429] = 513008,
	[2430] = 513011,
	[2431] = 513035,
	[2432] = 513043,
	[2433] = 513060,
	[2434] = 513065,
	[2435] = 513161,
	[2436] = 513167,
	[2437] = 513173,
	[2438] = 589281,
	[2439] = 616308,
	[2440] = 646797,
	[2441] = 646803,
	[2518] = 610595,
	[2519] = 593299,
	[2520] = 590062,
	[2521] = 528855,
	[2522] = 528875,
	[2523] = 527737,
	[2524] = 527745,
	[2525] = 512997,
	[2526] = 513000,
	[2527] = 513003,
	[2528] = 513006,
	[2529] = 513009,
	[2530] = 513012,
	[2531] = 513036,
	[2532] = 513044,
	[2533] = 513061,
	[2534] = 513066,
	[2535] = 513162,
	[2536] = 513168,
	[2537] = 513174,
	[2538] = 589282,
	[2539] = 616309,
	[2540] = 646798,
	[2541] = 646804,
	[2618] = 610596,
	[2619] = 575352,
	[2620] = 575359,
	[2621] = 528856,
	[2622] = 528876,
	[2623] = 527738,
	[2624] = 527746,
	[2625] = 512980,
	[2626] = 512983,
	[2627] = 512986,
	[2628] = 512989,
	[2629] = 512992,
	[2630] = 513013,
	[2631] = 513037,
	[2632] = 513045,
	[2633] = 513062,
	[2634] = 513067,
	[2635] = 513163,
	[2636] = 513169,
	[2637] = 513175,
	[2638] = 589283,
	[2639] = 616310,
	[2640] = 646799,
	[2641] = 646805,
	[2718] = 646904,
	[2719] = 575353,
	[2720] = 575360,
	[2721] = 528857,
	[2722] = 528877,
	[2723] = 527739,
	[2724] = 527747,
	[2725] = 512981,
	[2726] = 512984,
	[2727] = 512987,
	[2728] = 512990,
	[2729] = 512993,
	[2730] = 513030,
	[2731] = 513038,
	[2732] = 513046,
	[2733] = 513063,
	[2734] = 513068,
	[2735] = 513164,
	[2736] = 513170,
	[2737] = 513176,
	[2738] = 589284,
	[2739] = 616311,
	[2740] = 646800,
	[2741] = 646806,
	[2818] = 646905,
	[2819] = 575354,
	[2820] = 575361,
	[2821] = 528858,
	[2822] = 528878,
	[2823] = 527740,
	[2824] = 527748,
	[2825] = 512982,
	[2826] = 512985,
	[2827] = 512988,
	[2828] = 512991,
	[2829] = 512994,
	[2830] = 513031,
	[2831] = 513039,
	[2832] = 513047,
	[2833] = 513054,
	[2834] = 513069,
	[2835] = 513124,
	[2836] = 513134,
	[2837] = 513144,
	[2838] = 589285,
	[2839] = 616312,
	[2840] = 646807,
	[2841] = 646813,
	[2918] = 646906,
	[2919] = 575355,
	[2920] = 575362,
	[2921] = 528859,
	[2922] = 528879,
	[2923] = 527741,
	[2924] = 527749,
	[2925] = 512843,
	[2926] = 512847,
	[2927] = 512851,
	[2928] = 512855,
	[2929] = 512859,
	[2930] = 513032,
	[2931] = 513040,
	[2932] = 513048,
	[2933] = 513055,
	[2934] = 513115,
	[2935] = 513125,
	[2936] = 513135,
	[2937] = 513145,
	[2938] = 589286,
	[2939] = 616313,
	[2940] = 646808,
	[2941] = 646814,
	[3018] = 646907,
	[3019] = 575356,
	[3020] = 575363,
	[3021] = 528860,
	[3022] = 528880,
	[3023] = 527742,
	[3024] = 527750,
	[3025] = 512844,
	[3026] = 512848,
	[3027] = 512852,
	[3028] = 512856,
	[3029] = 512860,
	[3030] = 513033,
	[3031] = 513041,
	[3032] = 513049,
	[3033] = 513056,
	[3034] = 513116,
	[3035] = 513126,
	[3036] = 513136,
	[3037] = 513146,
	[3038] = 589287,
	[3039] = 616314,
	[3040] = 646809,
	[3041] = 646815,
	[3118] = 646908,
	[3119] = 575357,
	[3120] = 575364,
	[3121] = 528861,
	[3122] = 524843,
	[3123] = 527743,
	[3124] = 527751,
	[3125] = 512845,
	[3126] = 512849,
	[3127] = 512853,
	[3128] = 512857,
	[3129] = 512861,
	[3130] = 513034,
	[3131] = 513042,
	[3132] = 513050,
	[3133] = 513057,
	[3134] = 513117,
	[3135] = 513127,
	[3136] = 513137,
	[3137] = 513147,
	[3138] = 589288,
	[3139] = 616315,
	[3140] = 646810,
	[3141] = 646816,
	[3218] = 646909,
	[3219] = 575358,
	[3220] = 575365,
	[3221] = 528862,
	[3222] = 524289,
	[3223] = 524294,
	[3224] = 524299,
	[3225] = 512846,
	[3226] = 512850,
	[3227] = 512854,
	[3228] = 512858,
	[3229] = 512862,
	[3230] = 513051,
	[3231] = 513052,
	[3232] = 513053,
	[3233] = 513058,
	[3234] = 513118,
	[3235] = 513128,
	[3236] = 513138,
	[3237] = 513148,
	[3238] = 589289,
	[3239] = 616316,
	[3240] = 646811,
	[3241] = 646817,
	[3318] = 646910,
	[3319] = 646912,
	[3320] = 646914,
	[3321] = 528863,
	[3322] = 524290,
	[3323] = 524295,
	[3324] = 524300,
	[3325] = 512758,
	[3326] = 512760,
	[3327] = 512762,
	[3328] = 512764,
	[3329] = 512766,
	[3330] = 512768,
	[3331] = 512770,
	[3332] = 512772,
	[3333] = 512774,
	[3334] = 513119,
	[3335] = 513129,
	[3336] = 513139,
	[3337] = 513149,
	[3338] = 589290,
	[3339] = 616317,
	[3340] = 646812,
	[3341] = 646818,
	[3418] = 646911,
	[3419] = 646913,
	[3420] = 646915,
	[3421] = 528864,
	[3422] = 524291,
	[3423] = 524296,
	[3424] = 524301,
	[3425] = 512759,
	[3426] = 512761,
	[3427] = 512763,
	[3428] = 512765,
	[3429] = 512767,
	[3430] = 512769,
	[3431] = 512771,
	[3432] = 512773,
	[3433] = 512775,
	[3434] = 513120,
	[3435] = 513130,
	[3436] = 513140,
	[3437] = 513150,
	[3438] = 589291,
	[3439] = 616318,
	[3440] = 646819,
	[3441] = 646825,
	[3518] = 646886,
	[3519] = 646892,
	[3520] = 646898,
	[3521] = 528865,
	[3522] = 524292,
	[3523] = 524297,
	[3524] = 524302,
	[3525] = 512722,
	[3526] = 512726,
	[3527] = 512730,
	[3528] = 512734,
	[3529] = 512738,
	[3530] = 512742,
	[3531] = 512746,
	[3532] = 512750,
	[3533] = 512754,
	[3534] = 513121,
	[3535] = 513131,
	[3536] = 513141,
	[3537] = 513151,
	[3538] = 589292,
	[3539] = 616319,
	[3540] = 646820,
	[3541] = 646826,
	[3618] = 646887,
	[3619] = 646893,
	[3620] = 646899,
	[3621] = 528866,
	[3622] = 524293,
	[3623] = 524298,
	[3624] = 524303,
	[3625] = 512723,
	[3626] = 512727,
	[3627] = 512731,
	[3628] = 512735,
	[3629] = 512739,
	[3630] = 512743,
	[3631] = 512747,
	[3632] = 512751,
	[3633] = 512755,
	[3634] = 513122,
	[3635] = 513132,
	[3636] = 513142,
	[3637] = 513152,
	[3638] = 589293,
	[3639] = 616320,
	[3640] = 646821,
	[3641] = 646827,
	[3718] = 646888,
	[3719] = 646894,
	[3720] = 646900,
	[3721] = 528867,
	[3722] = 528881,
	[3723] = 528888,
	[3724] = 528895,
	[3725] = 512724,
	[3726] = 512728,
	[3727] = 512732,
	[3728] = 512736,
	[3729] = 512740,
	[3730] = 512744,
	[3731] = 512748,
	[3732] = 512752,
	[3733] = 512756,
	[3734] = 513123,
	[3735] = 513133,
	[3736] = 513143,
	[3737] = 513153,
	[3738] = 589294,
	[3739] = 616321,
	[3740] = 646822,
	[3741] = 646828,
	[3818] = 646889,
	[3819] = 646895,
	[3820] = 646901,
	[3821] = 528868,
	[3822] = 528882,
	[3823] = 528889,
	[3824] = 528896,
	[3825] = 512725,
	[3826] = 512729,
	[3827] = 512733,
	[3828] = 512737,
	[3829] = 512741,
	[3830] = 512745,
	[3831] = 512749,
	[3832] = 512753,
	[3833] = 512757,
	[3834] = 513181,
	[3835] = 513183,
	[3836] = 513185,
	[3837] = 513187,
	[3838] = 589295,
	[3839] = 616322,
	[3840] = 646823,
	[3841] = 646829,
	[3918] = 646890,
	[3919] = 646896,
	[3920] = 646902,
	[3921] = 528869,
	[3922] = 528883,
	[3923] = 528890,
	[3924] = 528897,
	[3925] = 575288,
	[3926] = 575290,
	[3927] = 533444,
	[3928] = 533445,
	[3929] = 533443,
	[3930] = 513177,
	[3931] = 513178,
	[3932] = 513179,
	[3933] = 513180,
	[3934] = 513182,
	[3935] = 513184,
	[3936] = 513186,
	[3937] = 513188,
	[3938] = 589296,
	[3939] = 616323,
	[3940] = 646824,
	[3941] = 646830,
	[4018] = 646891,
	[4019] = 646897,
	[4020] = 646903,
	[4021] = 575284,
	[4022] = 575285,
	[4023] = 575286,
	[4024] = 575287,
	[4025] = 575289,
	[4026] = 575291,
	[4027] = 575292,
	[4028] = 575293,
	[4029] = 575294,
	[4030] = 575295,
	[4031] = 575296,
	[4032] = 575297,
	[4033] = 575298,
	[4034] = 575299,
	[4035] = 575300,
	[4036] = 575301,
	[4037] = 575302,
	[4038] = 589297,
	[4039] = 616324,
	[4040] = 646833,
	[4041] = 646837,
	[4118] = 646863,
	[4119] = 646866,
	[4120] = 646869,
	[4121] = 616326,
	[4122] = 616327,
	[4123] = 616328,
	[4124] = 616329,
	[4125] = 616330,
	[4126] = 616331,
	[4127] = 616332,
	[4128] = 616333,
	[4129] = 616334,
	[4130] = 616335,
	[4131] = 616336,
	[4132] = 616337,
	[4133] = 616338,
	[4134] = 616339,
	[4135] = 616340,
	[4136] = 616341,
	[4137] = 616342,
	[4138] = 616302,
	[4139] = 616325,
	[4140] = 646834,
	[4141] = 646838,
	[4218] = 646864,
	[4219] = 646867,
	[4220] = 646870,
	[4221] = 646872,
	[4222] = 646851,
	[4223] = 646853,
	[4224] = 646855,
	[4225] = 646857,
	[4226] = 646859,
	[4227] = 646861,
	[4228] = 646874,
	[4229] = 646876,
	[4230] = 646878,
	[4231] = 646880,
	[4232] = 646882,
	[4233] = 646884,
	[4234] = 646841,
	[4235] = 646843,
	[4236] = 646845,
	[4237] = 646847,
	[4238] = 646849,
	[4239] = 646831,
	[4240] = 646835,
	[4241] = 646839,
	[4318] = 646865,
	[4319] = 646868,
	[4320] = 646871,
	[4321] = 646873,
	[4322] = 646852,
	[4323] = 646854,
	[4324] = 646856,
	[4325] = 646858,
	[4326] = 646860,
	[4327] = 646862,
	[4328] = 646875,
	[4329] = 646877,
	[4330] = 646879,
	[4331] = 646881,
	[4332] = 646883,
	[4333] = 646885,
	[4334] = 646842,
	[4335] = 646844,
	[4336] = 646846,
	[4337] = 646848,
	[4338] = 646850,
	[4339] = 646832,
	[4340] = 646836,
	[4341] = 646840,
}

Map.DraenorMapBlks = {
	[1220] = 1024780,
	[1221] = 1024784,
	[1222] = 1024788,
	[1223] = 1024791,
	[1224] = 1024805,
	[1225] = 1024808,
	[1226] = 1024811,
	[1227] = 1024814,
	[1228] = 1024817,
	[1229] = 1024820,
	[1320] = 1024781,
	[1321] = 1024785,
	[1322] = 1024789,
	[1323] = 1024792,
	[1324] = 1024806,
	[1325] = 1024809,
	[1326] = 1024812,
	[1327] = 1024815,
	[1328] = 1024818,
	[1329] = 1024821,
	[1420] = 1024782,
	[1421] = 1024786,
	[1422] = 1024790,
	[1423] = 1024793,
	[1424] = 1024807,
	[1425] = 1024810,
	[1426] = 1024813,
	[1427] = 1024816,
	[1428] = 1024819,
	[1429] = 1024822,
	[1520] = 1024783,
	[1521] = 1024787,
	[1522] = 951978,
	[1523] = 951980,
	[1524] = 951981,
	[1525] = 951982,
	[1526] = 951983,
	[1527] = 951984,
	[1528] = 951985,
	[1529] = 951986,
	[1620] = 1024803,
	[1621] = 1024804,
	[1622] = 951979,
	[1623] = 950059,
	[1624] = 950060,
	[1625] = 950061,
	[1626] = 950062,
	[1627] = 950063,
	[1628] = 950064,
	[1629] = 951987,
	[1711] = 851316,
	[1712] = 851323,
	[1713] = 851330,
	[1714] = 851337,
	[1715] = 851344,
	[1716] = 841385,
	[1717] = 841386,
	[1718] = 841387,
	[1719] = 841388,
	[1720] = 841389,
	[1721] = 841390,
	[1722] = 841391,
	[1723] = 841392,
	[1724] = 841393,
	[1725] = 841394,
	[1726] = 841395,
	[1727] = 841396,
	[1728] = 841397,
	[1729] = 841398,
	[1730] = 841399,
	[1731] = 841400,
	[1732] = 841401,
	[1733] = 841402,
	[1734] = 841403,
	[1735] = 841404,
	[1736] = 841405,
	[1737] = 841406,
	[1738] = 937491,
	[1739] = 937494,
	[1811] = 851317,
	[1812] = 851324,
	[1813] = 851331,
	[1814] = 851338,
	[1815] = 851345,
	[1816] = 775534,
	[1817] = 775544,
	[1818] = 773691,
	[1819] = 773701,
	[1820] = 773711,
	[1821] = 773721,
	[1822] = 773731,
	[1823] = 773741,
	[1824] = 773749,
	[1825] = 773757,
	[1826] = 795783,
	[1827] = 795784,
	[1828] = 795797,
	[1829] = 795798,
	[1830] = 795799,
	[1831] = 795800,
	[1832] = 795827,
	[1833] = 795828,
	[1834] = 795829,
	[1835] = 795830,
	[1836] = 795867,
	[1837] = 795869,
	[1838] = 937492,
	[1839] = 937495,
	[1911] = 851318,
	[1912] = 851325,
	[1913] = 851332,
	[1914] = 851339,
	[1915] = 851346,
	[1916] = 775535,
	[1917] = 775545,
	[1918] = 773692,
	[1919] = 773702,
	[1920] = 773712,
	[1921] = 773722,
	[1922] = 773732,
	[1923] = 773742,
	[1924] = 773750,
	[1925] = 773758,
	[1926] = 773517,
	[1927] = 773525,
	[1928] = 773533,
	[1929] = 773541,
	[1930] = 773548,
	[1931] = 773555,
	[1932] = 773562,
	[1933] = 773569,
	[1934] = 773576,
	[1935] = 795831,
	[1936] = 795868,
	[1937] = 795870,
	[1938] = 937493,
	[1939] = 937496,
	[2011] = 851319,
	[2012] = 851326,
	[2013] = 851333,
	[2014] = 851340,
	[2015] = 851347,
	[2016] = 775536,
	[2017] = 775546,
	[2018] = 773693,
	[2019] = 773703,
	[2020] = 773713,
	[2021] = 773723,
	[2022] = 773733,
	[2023] = 773743,
	[2024] = 773751,
	[2025] = 773759,
	[2026] = 773518,
	[2027] = 773526,
	[2028] = 773534,
	[2029] = 773542,
	[2030] = 773549,
	[2031] = 773556,
	[2032] = 773563,
	[2033] = 773570,
	[2034] = 773577,
	[2035] = 795832,
	[2036] = 795871,
	[2037] = 795875,
	[2038] = 937501,
	[2039] = 937505,
	[2111] = 851320,
	[2112] = 851327,
	[2113] = 851334,
	[2114] = 851341,
	[2115] = 851348,
	[2116] = 775537,
	[2117] = 775547,
	[2118] = 773694,
	[2119] = 773704,
	[2120] = 773714,
	[2121] = 773724,
	[2122] = 773734,
	[2123] = 773744,
	[2124] = 773752,
	[2125] = 773760,
	[2126] = 773519,
	[2127] = 773527,
	[2128] = 773535,
	[2129] = 773543,
	[2130] = 773550,
	[2131] = 773557,
	[2132] = 773564,
	[2133] = 773571,
	[2134] = 773578,
	[2135] = 795833,
	[2136] = 795872,
	[2137] = 795876,
	[2138] = 937502,
	[2139] = 937506,
	[2211] = 851321,
	[2212] = 851328,
	[2213] = 851335,
	[2214] = 851342,
	[2215] = 851349,
	[2216] = 775538,
	[2217] = 775548,
	[2218] = 773695,
	[2219] = 773705,
	[2220] = 773715,
	[2221] = 773725,
	[2222] = 773735,
	[2223] = 773745,
	[2224] = 773753,
	[2225] = 773761,
	[2226] = 773520,
	[2227] = 773528,
	[2228] = 773536,
	[2229] = 773544,
	[2230] = 773551,
	[2231] = 773558,
	[2232] = 773565,
	[2233] = 773572,
	[2234] = 773579,
	[2235] = 795834,
	[2236] = 795873,
	[2237] = 795877,
	[2238] = 937503,
	[2239] = 937507,
	[2311] = 851322,
	[2312] = 851329,
	[2313] = 851336,
	[2314] = 851343,
	[2315] = 851350,
	[2316] = 775539,
	[2317] = 775549,
	[2318] = 773696,
	[2319] = 773706,
	[2320] = 773716,
	[2321] = 773726,
	[2322] = 773736,
	[2323] = 773746,
	[2324] = 773754,
	[2325] = 773762,
	[2326] = 773521,
	[2327] = 773529,
	[2328] = 773537,
	[2329] = 773545,
	[2330] = 773552,
	[2331] = 773559,
	[2332] = 773566,
	[2333] = 773573,
	[2334] = 773580,
	[2335] = 795835,
	[2336] = 795874,
	[2337] = 795878,
	[2338] = 937504,
	[2339] = 937508,
	[2411] = 851387,
	[2412] = 851392,
	[2413] = 851396,
	[2414] = 851400,
	[2415] = 851404,
	[2416] = 775540,
	[2417] = 775550,
	[2418] = 773697,
	[2419] = 773707,
	[2420] = 773717,
	[2421] = 773727,
	[2422] = 773737,
	[2423] = 773747,
	[2424] = 773755,
	[2425] = 773763,
	[2426] = 773522,
	[2427] = 773530,
	[2428] = 773538,
	[2429] = 773546,
	[2430] = 773553,
	[2431] = 773560,
	[2432] = 773567,
	[2433] = 773574,
	[2434] = 773581,
	[2435] = 795836,
	[2436] = 795879,
	[2437] = 795883,
	[2438] = 937509,
	[2439] = 937513,
	[2511] = 851388,
	[2512] = 851393,
	[2513] = 851397,
	[2514] = 851401,
	[2515] = 851405,
	[2516] = 775541,
	[2517] = 775551,
	[2518] = 773698,
	[2519] = 773708,
	[2520] = 773718,
	[2521] = 773728,
	[2522] = 773738,
	[2523] = 773748,
	[2524] = 773756,
	[2525] = 773764,
	[2526] = 773523,
	[2527] = 773531,
	[2528] = 773539,
	[2529] = 773547,
	[2530] = 773554,
	[2531] = 773561,
	[2532] = 773568,
	[2533] = 773575,
	[2534] = 773582,
	[2535] = 795837,
	[2536] = 795880,
	[2537] = 795884,
	[2538] = 937510,
	[2539] = 937514,
	[2611] = 851389,
	[2612] = 851394,
	[2613] = 851398,
	[2614] = 851402,
	[2615] = 851406,
	[2616] = 775542,
	[2617] = 775552,
	[2618] = 773699,
	[2619] = 773709,
	[2620] = 773719,
	[2621] = 773729,
	[2622] = 773739,
	[2623] = 773634,
	[2624] = 773640,
	[2625] = 773646,
	[2626] = 773524,
	[2627] = 773532,
	[2628] = 773540,
	[2629] = 773441,
	[2630] = 773446,
	[2631] = 773451,
	[2632] = 773456,
	[2633] = 773461,
	[2634] = 773466,
	[2635] = 795838,
	[2636] = 795881,
	[2637] = 795885,
	[2638] = 937511,
	[2639] = 937515,
	[2711] = 851390,
	[2712] = 851395,
	[2713] = 851399,
	[2714] = 851403,
	[2715] = 851407,
	[2716] = 775543,
	[2717] = 775553,
	[2718] = 773700,
	[2719] = 773710,
	[2720] = 773720,
	[2721] = 773730,
	[2722] = 773740,
	[2723] = 773635,
	[2724] = 773641,
	[2725] = 773647,
	[2726] = 773652,
	[2727] = 773657,
	[2728] = 773662,
	[2729] = 773442,
	[2730] = 773447,
	[2731] = 773452,
	[2732] = 773457,
	[2733] = 773462,
	[2734] = 773467,
	[2735] = 795839,
	[2736] = 795882,
	[2737] = 795886,
	[2738] = 937512,
	[2739] = 937516,
	[2811] = 851140,
	[2812] = 851144,
	[2813] = 851148,
	[2814] = 851152,
	[2815] = 851204,
	[2816] = 773667,
	[2817] = 773670,
	[2818] = 773673,
	[2819] = 773676,
	[2820] = 773679,
	[2821] = 773683,
	[2822] = 773687,
	[2823] = 773636,
	[2824] = 773642,
	[2825] = 773648,
	[2826] = 773653,
	[2827] = 773658,
	[2828] = 773663,
	[2829] = 773443,
	[2830] = 773448,
	[2831] = 773453,
	[2832] = 773458,
	[2833] = 773463,
	[2834] = 773468,
	[2835] = 795840,
	[2836] = 795887,
	[2837] = 795891,
	[2838] = 937517,
	[2839] = 937521,
	[2911] = 851141,
	[2912] = 851145,
	[2913] = 851149,
	[2914] = 851153,
	[2915] = 851205,
	[2916] = 773668,
	[2917] = 773671,
	[2918] = 773674,
	[2919] = 773677,
	[2920] = 773680,
	[2921] = 773684,
	[2922] = 773688,
	[2923] = 773637,
	[2924] = 773643,
	[2925] = 773649,
	[2926] = 773654,
	[2927] = 773659,
	[2928] = 773664,
	[2929] = 773444,
	[2930] = 773449,
	[2931] = 773454,
	[2932] = 773459,
	[2933] = 773464,
	[2934] = 773469,
	[2935] = 795841,
	[2936] = 795888,
	[2937] = 795892,
	[2938] = 937518,
	[2939] = 937522,
	[3011] = 851142,
	[3012] = 851146,
	[3013] = 851150,
	[3014] = 851154,
	[3015] = 851206,
	[3016] = 773669,
	[3017] = 773672,
	[3018] = 773675,
	[3019] = 773678,
	[3020] = 773681,
	[3021] = 773685,
	[3022] = 773689,
	[3023] = 773638,
	[3024] = 773644,
	[3025] = 773650,
	[3026] = 773655,
	[3027] = 773660,
	[3028] = 773665,
	[3029] = 773445,
	[3030] = 773450,
	[3031] = 773455,
	[3032] = 773460,
	[3033] = 773465,
	[3034] = 773470,
	[3035] = 795842,
	[3036] = 795889,
	[3037] = 795893,
	[3038] = 937519,
	[3039] = 937523,
	[3111] = 851143,
	[3112] = 851147,
	[3113] = 851151,
	[3114] = 851155,
	[3115] = 851207,
	[3116] = 773625,
	[3117] = 773631,
	[3118] = 773632,
	[3119] = 773633,
	[3120] = 773682,
	[3121] = 773686,
	[3122] = 773690,
	[3123] = 773639,
	[3124] = 773645,
	[3125] = 773651,
	[3126] = 773656,
	[3127] = 773661,
	[3128] = 773666,
	[3129] = 773405,
	[3130] = 773411,
	[3131] = 773417,
	[3132] = 773423,
	[3133] = 773429,
	[3134] = 773435,
	[3135] = 795843,
	[3136] = 795890,
	[3137] = 795894,
	[3138] = 937520,
	[3139] = 937524,
	[3211] = 851156,
	[3212] = 851160,
	[3213] = 851164,
	[3214] = 851168,
	[3215] = 851208,
	[3216] = 773626,
	[3217] = 773583,
	[3218] = 773590,
	[3219] = 773597,
	[3220] = 773604,
	[3221] = 773611,
	[3222] = 773618,
	[3223] = 773471,
	[3224] = 773478,
	[3225] = 773485,
	[3226] = 773492,
	[3227] = 773499,
	[3228] = 773506,
	[3229] = 773406,
	[3230] = 773412,
	[3231] = 773418,
	[3232] = 773424,
	[3233] = 773430,
	[3234] = 773436,
	[3235] = 795844,
	[3236] = 795895,
	[3237] = 795899,
	[3238] = 937526,
	[3239] = 937530,
	[3311] = 851157,
	[3312] = 851161,
	[3313] = 851165,
	[3314] = 851169,
	[3315] = 851209,
	[3316] = 773627,
	[3317] = 773584,
	[3318] = 773591,
	[3319] = 773598,
	[3320] = 773605,
	[3321] = 773612,
	[3322] = 773619,
	[3323] = 773472,
	[3324] = 773479,
	[3325] = 773486,
	[3326] = 773493,
	[3327] = 773500,
	[3328] = 773507,
	[3329] = 773407,
	[3330] = 773413,
	[3331] = 773419,
	[3332] = 773425,
	[3333] = 773431,
	[3334] = 773437,
	[3335] = 795845,
	[3336] = 795896,
	[3337] = 795900,
	[3338] = 937527,
	[3339] = 937531,
	[3411] = 851158,
	[3412] = 851162,
	[3413] = 851166,
	[3414] = 851170,
	[3415] = 851210,
	[3416] = 773628,
	[3417] = 773585,
	[3418] = 773592,
	[3419] = 773599,
	[3420] = 773606,
	[3421] = 773613,
	[3422] = 773620,
	[3423] = 773473,
	[3424] = 773480,
	[3425] = 773487,
	[3426] = 773494,
	[3427] = 773501,
	[3428] = 773508,
	[3429] = 773408,
	[3430] = 773414,
	[3431] = 773420,
	[3432] = 773426,
	[3433] = 773432,
	[3434] = 773438,
	[3435] = 795846,
	[3436] = 795897,
	[3437] = 795901,
	[3438] = 937528,
	[3439] = 937532,
	[3511] = 851159,
	[3512] = 851163,
	[3513] = 851167,
	[3514] = 851171,
	[3515] = 851211,
	[3516] = 773629,
	[3517] = 773586,
	[3518] = 773593,
	[3519] = 773600,
	[3520] = 773607,
	[3521] = 773614,
	[3522] = 773621,
	[3523] = 773474,
	[3524] = 773481,
	[3525] = 773488,
	[3526] = 773495,
	[3527] = 773502,
	[3528] = 773509,
	[3529] = 773409,
	[3530] = 773415,
	[3531] = 773421,
	[3532] = 773427,
	[3533] = 773433,
	[3534] = 773439,
	[3535] = 795847,
	[3536] = 795898,
	[3537] = 795902,
	[3538] = 937529,
	[3539] = 937533,
	[3611] = 851172,
	[3612] = 851176,
	[3613] = 851180,
	[3614] = 851184,
	[3615] = 851212,
	[3616] = 773630,
	[3617] = 773587,
	[3618] = 773594,
	[3619] = 773601,
	[3620] = 773608,
	[3621] = 773615,
	[3622] = 773622,
	[3623] = 773475,
	[3624] = 773482,
	[3625] = 773489,
	[3626] = 773496,
	[3627] = 773503,
	[3628] = 773510,
	[3629] = 773410,
	[3630] = 773416,
	[3631] = 773422,
	[3632] = 773428,
	[3633] = 773434,
	[3634] = 773440,
	[3635] = 795855,
	[3636] = 795903,
	[3637] = 795907,
	[3638] = 937534,
	[3639] = 937538,
	[3711] = 851173,
	[3712] = 851177,
	[3713] = 851181,
	[3714] = 851185,
	[3715] = 851213,
	[3716] = 775554,
	[3717] = 773588,
	[3718] = 773595,
	[3719] = 773602,
	[3720] = 773609,
	[3721] = 773616,
	[3722] = 773623,
	[3723] = 773476,
	[3724] = 773483,
	[3725] = 773490,
	[3726] = 773497,
	[3727] = 773504,
	[3728] = 773511,
	[3729] = 773513,
	[3730] = 773515,
	[3731] = 792435,
	[3732] = 792439,
	[3733] = 792441,
	[3734] = 795852,
	[3735] = 795856,
	[3736] = 795904,
	[3737] = 795908,
	[3738] = 937535,
	[3739] = 937539,
	[3811] = 851174,
	[3812] = 851178,
	[3813] = 851182,
	[3814] = 851186,
	[3815] = 851214,
	[3816] = 795758,
	[3817] = 773589,
	[3818] = 773596,
	[3819] = 773603,
	[3820] = 773610,
	[3821] = 773617,
	[3822] = 773624,
	[3823] = 773477,
	[3824] = 773484,
	[3825] = 773491,
	[3826] = 773498,
	[3827] = 773505,
	[3828] = 773512,
	[3829] = 773514,
	[3830] = 773516,
	[3831] = 795817,
	[3832] = 795848,
	[3833] = 795850,
	[3834] = 795853,
	[3835] = 795857,
	[3836] = 795905,
	[3837] = 795909,
	[3838] = 937536,
	[3839] = 937540,
	[3911] = 851175,
	[3912] = 851179,
	[3913] = 851183,
	[3914] = 851187,
	[3915] = 851215,
	[3916] = 795759,
	[3917] = 795760,
	[3918] = 795761,
	[3919] = 795762,
	[3920] = 795771,
	[3921] = 795772,
	[3922] = 795773,
	[3923] = 795774,
	[3924] = 795785,
	[3925] = 795786,
	[3926] = 795787,
	[3927] = 795788,
	[3928] = 795803,
	[3929] = 795815,
	[3930] = 795816,
	[3931] = 795818,
	[3932] = 795849,
	[3933] = 795851,
	[3934] = 795854,
	[3935] = 795858,
	[3936] = 795906,
	[3937] = 795910,
	[3938] = 937537,
	[3939] = 937541,
	[4011] = 851188,
	[4012] = 851192,
	[4013] = 851196,
	[4014] = 851200,
	[4015] = 851216,
	[4016] = 795763,
	[4017] = 795765,
	[4018] = 795767,
	[4019] = 795769,
	[4020] = 795775,
	[4021] = 795777,
	[4022] = 795779,
	[4023] = 795781,
	[4024] = 795789,
	[4025] = 795791,
	[4026] = 795793,
	[4027] = 795795,
	[4028] = 795819,
	[4029] = 795821,
	[4030] = 795823,
	[4031] = 795825,
	[4032] = 795859,
	[4033] = 795861,
	[4034] = 795863,
	[4035] = 795865,
	[4036] = 795911,
	[4037] = 795913,
	[4038] = 937542,
	[4039] = 937546,
	[4111] = 851189,
	[4112] = 851193,
	[4113] = 851197,
	[4114] = 851201,
	[4115] = 851217,
	[4116] = 795764,
	[4117] = 795766,
	[4118] = 795768,
	[4119] = 795770,
	[4120] = 795776,
	[4121] = 795778,
	[4122] = 795780,
	[4123] = 795782,
	[4124] = 795790,
	[4125] = 795792,
	[4126] = 795794,
	[4127] = 795796,
	[4128] = 795820,
	[4129] = 795822,
	[4130] = 795824,
	[4131] = 795826,
	[4132] = 795860,
	[4133] = 795862,
	[4134] = 795864,
	[4135] = 795866,
	[4136] = 795912,
	[4137] = 795914,
	[4138] = 937543,
	[4139] = 937547,
	[4211] = 851190,
	[4212] = 851194,
	[4213] = 851198,
	[4214] = 851202,
	[4215] = 851218,
	[4216] = 851220,
	[4217] = 851222,
	[4218] = 851224,
	[4219] = 851226,
	[4220] = 851228,
	[4221] = 851230,
	[4222] = 851232,
	[4223] = 851234,
	[4224] = 851236,
	[4225] = 851238,
	[4226] = 851240,
	[4227] = 851242,
	[4228] = 851424,
	[4229] = 851426,
	[4230] = 851428,
	[4231] = 851430,
	[4232] = 851436,
	[4233] = 851438,
	[4234] = 851440,
	[4235] = 851442,
	[4236] = 851448,
	[4237] = 851450,
	[4238] = 937544,
	[4239] = 937548,
	[4311] = 851191,
	[4312] = 851195,
	[4313] = 851199,
	[4314] = 851203,
	[4315] = 851219,
	[4316] = 851221,
	[4317] = 851223,
	[4318] = 851225,
	[4319] = 851227,
	[4320] = 851229,
	[4321] = 851231,
	[4322] = 851233,
	[4323] = 851235,
	[4324] = 851237,
	[4325] = 851239,
	[4326] = 851241,
	[4327] = 851243,
	[4328] = 851425,
	[4329] = 851427,
	[4330] = 851429,
	[4331] = 851431,
	[4332] = 851437,
	[4333] = 851439,
	[4334] = 851441,
	[4335] = 851443,
	[4336] = 851449,
	[4337] = 851451,
	[4338] = 937545,
	[4339] = 937549,
	[4411] = 851391,
	[4412] = 851408,
	[4413] = 851409,
	[4414] = 851410,
	[4415] = 851411,
	[4416] = 851412,
	[4417] = 851413,
	[4418] = 851414,
	[4419] = 851415,
	[4420] = 851416,
	[4421] = 851417,
	[4422] = 851418,
	[4423] = 851419,
	[4424] = 851420,
	[4425] = 851421,
	[4426] = 851422,
	[4427] = 851423,
	[4428] = 851432,
	[4429] = 851433,
	[4430] = 851434,
	[4431] = 851435,
	[4432] = 851444,
	[4433] = 851445,
	[4434] = 851446,
	[4435] = 851447,
	[4436] = 851452,
	[4437] = 851453,
	[4438] = 937550,
	[4439] = 937551,
}

Map.BrokenIslesMapBlks = {
	[1117] = 1338031,
	[1118] = 1338033,
	[1119] = 1338035,
	[1120] = 1338037,
	[1121] = 1338039,
	[1122] = 1338041,
	[1123] = 1338043,
	[1124] = 1338045,
	[1125] = 1338047,
	[1126] = 1338049,
	[1127] = 1338051,
	[1128] = 1338053,
	[1129] = 1338055,
	[1130] = 1338057,
	[1131] = 1338059,
	[1132] = 1338061,
	[1133] = 1338063,
	[1134] = 1338065,
	[1135] = 1338067,
	[1136] = 1338069,
	[1137] = 1338071,
	[1138] = 1338073,
	[1139] = 1338075,
	[1140] = 1338077,
	[1141] = 1338079,
	[1142] = 1338081,
	[1143] = 1338083,
	[1217] = 1338032,
	[1218] = 1338034,
	[1219] = 1338036,
	[1220] = 1338038,
	[1221] = 1338040,
	[1222] = 1338042,
	[1223] = 1338044,
	[1224] = 1338046,
	[1225] = 1338048,
	[1226] = 1338050,
	[1227] = 1338052,
	[1228] = 1338054,
	[1229] = 1338056,
	[1230] = 1338058,
	[1231] = 1338060,
	[1232] = 1338062,
	[1233] = 1338064,
	[1234] = 1338066,
	[1235] = 1338068,
	[1236] = 1338070,
	[1237] = 1338072,
	[1238] = 1338074,
	[1239] = 1338076,
	[1240] = 1338078,
	[1241] = 1338080,
	[1242] = 1338082,
	[1243] = 1338084,
	[1317] = 1255078,
	[1318] = 1255080,
	[1319] = 1255082,
	[1320] = 1255084,
	[1321] = 1255086,
	[1322] = 1255088,
	[1323] = 1118621,
	[1324] = 1255090,
	[1325] = 1104550,
	[1326] = 1104552,
	[1327] = 1104554,
	[1328] = 1104556,
	[1329] = 1255092,
	[1330] = 1255094,
	[1331] = 1255100,
	[1332] = 1255102,
	[1333] = 1255104,
	[1334] = 1255106,
	[1335] = 1255109,
	[1336] = 1255111,
	[1337] = 1255113,
	[1338] = 1255115,
	[1339] = 1255118,
	[1340] = 1255120,
	[1341] = 1255122,
	[1342] = 1316782,
	[1343] = 1316786,
	[1417] = 1255079,
	[1418] = 1255081,
	[1419] = 1255083,
	[1420] = 1255085,
	[1421] = 1255087,
	[1422] = 1255089,
	[1423] = 1118622,
	[1424] = 1118623,
	[1425] = 1104551,
	[1426] = 1104553,
	[1427] = 1104555,
	[1428] = 1104557,
	[1429] = 1255093,
	[1430] = 1255095,
	[1431] = 1255101,
	[1432] = 1255103,
	[1433] = 1255105,
	[1434] = 1255107,
	[1435] = 1255110,
	[1436] = 1255112,
	[1437] = 1255114,
	[1438] = 1255116,
	[1439] = 1255119,
	[1440] = 1255121,
	[1441] = 1255123,
	[1442] = 1316783,
	[1443] = 1316787,
	[1517] = 975412,
	[1518] = 975416,
	[1519] = 975420,
	[1520] = 952856,
	[1521] = 952860,
	[1522] = 952861,
	[1523] = 952862,
	[1524] = 952866,
	[1525] = 952867,
	[1526] = 952868,
	[1527] = 952869,
	[1528] = 952900,
	[1529] = 952901,
	[1530] = 952902,
	[1531] = 952903,
	[1532] = 952912,
	[1533] = 952913,
	[1534] = 952914,
	[1535] = 952915,
	[1536] = 952954,
	[1537] = 952955,
	[1538] = 952956,
	[1539] = 952957,
	[1540] = 953002,
	[1541] = 953003,
	[1542] = 1316784,
	[1543] = 1316788,
	[1617] = 975413,
	[1618] = 975417,
	[1619] = 975421,
	[1620] = 952857,
	[1621] = 952761,
	[1622] = 952765,
	[1623] = 952769,
	[1624] = 952773,
	[1625] = 952805,
	[1626] = 952809,
	[1627] = 952813,
	[1628] = 952817,
	[1629] = 952068,
	[1630] = 952072,
	[1631] = 952076,
	[1632] = 952080,
	[1633] = 952112,
	[1634] = 952116,
	[1635] = 952120,
	[1636] = 952124,
	[1637] = 952156,
	[1638] = 952160,
	[1639] = 952164,
	[1640] = 952168,
	[1641] = 953004,
	[1642] = 1316785,
	[1643] = 1316789,
	[1717] = 975414,
	[1718] = 975418,
	[1719] = 975422,
	[1720] = 952858,
	[1721] = 952762,
	[1722] = 952766,
	[1723] = 952770,
	[1724] = 952774,
	[1725] = 952806,
	[1726] = 952810,
	[1727] = 952814,
	[1728] = 952818,
	[1729] = 952069,
	[1730] = 952073,
	[1731] = 952077,
	[1732] = 952081,
	[1733] = 952113,
	[1734] = 952117,
	[1735] = 952121,
	[1736] = 952125,
	[1737] = 952157,
	[1738] = 952161,
	[1739] = 952165,
	[1740] = 952169,
	[1741] = 953005,
	[1742] = 1316790,
	[1743] = 1316794,
	[1817] = 975415,
	[1818] = 975419,
	[1819] = 975423,
	[1820] = 952859,
	[1821] = 952763,
	[1822] = 952767,
	[1823] = 952771,
	[1824] = 952775,
	[1825] = 952807,
	[1826] = 952811,
	[1827] = 952815,
	[1828] = 952819,
	[1829] = 952070,
	[1830] = 952074,
	[1831] = 952078,
	[1832] = 952082,
	[1833] = 952114,
	[1834] = 952118,
	[1835] = 952122,
	[1836] = 952126,
	[1837] = 952158,
	[1838] = 952162,
	[1839] = 952166,
	[1840] = 952170,
	[1841] = 953006,
	[1842] = 1316791,
	[1843] = 1316795,
	[1917] = 975424,
	[1918] = 975428,
	[1919] = 975432,
	[1920] = 952863,
	[1921] = 952764,
	[1922] = 952768,
	[1923] = 952772,
	[1924] = 952776,
	[1925] = 952808,
	[1926] = 952812,
	[1927] = 952816,
	[1928] = 952820,
	[1929] = 952071,
	[1930] = 952075,
	[1931] = 952079,
	[1932] = 952083,
	[1933] = 952115,
	[1934] = 952119,
	[1935] = 952123,
	[1936] = 952127,
	[1937] = 952159,
	[1938] = 952163,
	[1939] = 952167,
	[1940] = 952171,
	[1941] = 953007,
	[1942] = 1316792,
	[1943] = 1316796,
	[2017] = 975425,
	[2018] = 975429,
	[2019] = 975433,
	[2020] = 952864,
	[2021] = 952777,
	[2022] = 952781,
	[2023] = 952785,
	[2024] = 952789,
	[2025] = 952821,
	[2026] = 952825,
	[2027] = 952829,
	[2028] = 952833,
	[2029] = 952084,
	[2030] = 952088,
	[2031] = 952092,
	[2032] = 952096,
	[2033] = 952128,
	[2034] = 952132,
	[2035] = 952136,
	[2036] = 952140,
	[2037] = 952172,
	[2038] = 952176,
	[2039] = 952180,
	[2040] = 952184,
	[2041] = 953008,
	[2042] = 1316793,
	[2043] = 1316797,
	[2117] = 975426,
	[2118] = 975430,
	[2119] = 975434,
	[2120] = 952865,
	[2121] = 952778,
	[2122] = 952782,
	[2123] = 952786,
	[2124] = 952790,
	[2125] = 952822,
	[2126] = 952826,
	[2127] = 952830,
	[2128] = 952834,
	[2129] = 952085,
	[2130] = 952089,
	[2131] = 952093,
	[2132] = 952097,
	[2133] = 952129,
	[2134] = 952133,
	[2135] = 952137,
	[2136] = 952141,
	[2137] = 952173,
	[2138] = 952177,
	[2139] = 952181,
	[2140] = 952185,
	[2141] = 953009,
	[2142] = 1316798,
	[2143] = 1316802,
	[2217] = 975427,
	[2218] = 975431,
	[2219] = 975435,
	[2220] = 952870,
	[2221] = 952779,
	[2222] = 952783,
	[2223] = 952787,
	[2224] = 952791,
	[2225] = 952823,
	[2226] = 952827,
	[2227] = 952831,
	[2228] = 952835,
	[2229] = 952086,
	[2230] = 952090,
	[2231] = 952094,
	[2232] = 952098,
	[2233] = 952130,
	[2234] = 952134,
	[2235] = 952138,
	[2236] = 952142,
	[2237] = 952174,
	[2238] = 952178,
	[2239] = 952182,
	[2240] = 952186,
	[2241] = 953010,
	[2242] = 1316799,
	[2243] = 1316803,
	[2317] = 975436,
	[2318] = 975440,
	[2319] = 975444,
	[2320] = 952871,
	[2321] = 952780,
	[2322] = 952784,
	[2323] = 952788,
	[2324] = 952792,
	[2325] = 952824,
	[2326] = 952828,
	[2327] = 952832,
	[2328] = 952836,
	[2329] = 952087,
	[2330] = 952091,
	[2331] = 952095,
	[2332] = 952099,
	[2333] = 952131,
	[2334] = 952135,
	[2335] = 952139,
	[2336] = 952143,
	[2337] = 952175,
	[2338] = 952179,
	[2339] = 952183,
	[2340] = 952187,
	[2341] = 953011,
	[2342] = 1316800,
	[2343] = 1316804,
	[2417] = 975437,
	[2418] = 975441,
	[2419] = 975445,
	[2420] = 952872,
	[2421] = 952793,
	[2422] = 952796,
	[2423] = 952799,
	[2424] = 952802,
	[2425] = 952837,
	[2426] = 952840,
	[2427] = 952843,
	[2428] = 952846,
	[2429] = 952100,
	[2430] = 952103,
	[2431] = 952106,
	[2432] = 952109,
	[2433] = 952144,
	[2434] = 952147,
	[2435] = 952150,
	[2436] = 952153,
	[2437] = 952188,
	[2438] = 952191,
	[2439] = 952194,
	[2440] = 952197,
	[2441] = 953012,
	[2442] = 1316801,
	[2443] = 1316805,
	[2517] = 975438,
	[2518] = 975442,
	[2519] = 975446,
	[2520] = 952873,
	[2521] = 952794,
	[2522] = 952797,
	[2523] = 952800,
	[2524] = 952803,
	[2525] = 952838,
	[2526] = 952841,
	[2527] = 952844,
	[2528] = 952847,
	[2529] = 952101,
	[2530] = 952104,
	[2531] = 952107,
	[2532] = 952110,
	[2533] = 952145,
	[2534] = 952148,
	[2535] = 952151,
	[2536] = 952154,
	[2537] = 952189,
	[2538] = 952192,
	[2539] = 952195,
	[2540] = 952198,
	[2541] = 953013,
	[2542] = 1316806,
	[2543] = 1316810,
	[2617] = 975439,
	[2618] = 975443,
	[2619] = 975447,
	[2620] = 952874,
	[2621] = 952795,
	[2622] = 952798,
	[2623] = 952801,
	[2624] = 952804,
	[2625] = 952839,
	[2626] = 952842,
	[2627] = 952845,
	[2628] = 952848,
	[2629] = 952102,
	[2630] = 952105,
	[2631] = 952108,
	[2632] = 952111,
	[2633] = 952146,
	[2634] = 952149,
	[2635] = 952152,
	[2636] = 952155,
	[2637] = 952190,
	[2638] = 952193,
	[2639] = 952196,
	[2640] = 952199,
	[2641] = 953014,
	[2642] = 1316807,
	[2643] = 1316811,
	[2717] = 975448,
	[2718] = 975452,
	[2719] = 975456,
	[2720] = 952875,
	[2721] = 952662,
	[2722] = 952666,
	[2723] = 952670,
	[2724] = 952674,
	[2725] = 952698,
	[2726] = 952702,
	[2727] = 952706,
	[2728] = 952710,
	[2729] = 952734,
	[2730] = 952738,
	[2731] = 952742,
	[2732] = 952849,
	[2733] = 952852,
	[2734] = 952918,
	[2735] = 952922,
	[2736] = 952958,
	[2737] = 952962,
	[2738] = 952966,
	[2739] = 952970,
	[2740] = 953015,
	[2741] = 953019,
	[2742] = 1316808,
	[2743] = 1316812,
	[2817] = 975449,
	[2818] = 975453,
	[2819] = 975457,
	[2820] = 952876,
	[2821] = 952663,
	[2822] = 952667,
	[2823] = 952671,
	[2824] = 952675,
	[2825] = 952699,
	[2826] = 952703,
	[2827] = 952707,
	[2828] = 952711,
	[2829] = 952735,
	[2830] = 952739,
	[2831] = 952743,
	[2832] = 952850,
	[2833] = 952853,
	[2834] = 952919,
	[2835] = 952923,
	[2836] = 952959,
	[2837] = 952963,
	[2838] = 952967,
	[2839] = 952971,
	[2840] = 953016,
	[2841] = 953020,
	[2842] = 1316809,
	[2843] = 1316813,
	[2917] = 975450,
	[2918] = 975454,
	[2919] = 975458,
	[2920] = 952877,
	[2921] = 952664,
	[2922] = 952668,
	[2923] = 952672,
	[2924] = 952676,
	[2925] = 952700,
	[2926] = 952704,
	[2927] = 952708,
	[2928] = 952712,
	[2929] = 952736,
	[2930] = 952740,
	[2931] = 952744,
	[2932] = 952851,
	[2933] = 952854,
	[2934] = 952920,
	[2935] = 952924,
	[2936] = 952960,
	[2937] = 952964,
	[2938] = 952968,
	[2939] = 952972,
	[2940] = 953017,
	[2941] = 953021,
	[2942] = 1316814,
	[2943] = 1316818,
	[3017] = 975451,
	[3018] = 975455,
	[3019] = 975459,
	[3020] = 952878,
	[3021] = 952665,
	[3022] = 952669,
	[3023] = 952673,
	[3024] = 952677,
	[3025] = 952701,
	[3026] = 952705,
	[3027] = 952709,
	[3028] = 952713,
	[3029] = 952737,
	[3030] = 952741,
	[3031] = 952745,
	[3032] = 952916,
	[3033] = 952917,
	[3034] = 952921,
	[3035] = 952925,
	[3036] = 952961,
	[3037] = 952965,
	[3038] = 952969,
	[3039] = 952973,
	[3040] = 953018,
	[3041] = 953022,
	[3042] = 1316815,
	[3043] = 1316819,
	[3117] = 975460,
	[3118] = 975464,
	[3119] = 975468,
	[3120] = 952879,
	[3121] = 952678,
	[3122] = 952682,
	[3123] = 952686,
	[3124] = 952690,
	[3125] = 952714,
	[3126] = 952718,
	[3127] = 952722,
	[3128] = 952726,
	[3129] = 952746,
	[3130] = 952750,
	[3131] = 952754,
	[3132] = 952926,
	[3133] = 952930,
	[3134] = 952934,
	[3135] = 952938,
	[3136] = 952974,
	[3137] = 952978,
	[3138] = 952982,
	[3139] = 952986,
	[3140] = 953023,
	[3141] = 953027,
	[3142] = 1316816,
	[3143] = 1316820,
	[3217] = 975461,
	[3218] = 975465,
	[3219] = 975469,
	[3220] = 952880,
	[3221] = 952679,
	[3222] = 952683,
	[3223] = 952687,
	[3224] = 952691,
	[3225] = 952715,
	[3226] = 952719,
	[3227] = 952723,
	[3228] = 952727,
	[3229] = 952747,
	[3230] = 952751,
	[3231] = 952755,
	[3232] = 952927,
	[3233] = 952931,
	[3234] = 952935,
	[3235] = 952939,
	[3236] = 952975,
	[3237] = 952979,
	[3238] = 952983,
	[3239] = 952987,
	[3240] = 953024,
	[3241] = 953028,
	[3242] = 1316817,
	[3243] = 1316821,
	[3317] = 975462,
	[3318] = 975466,
	[3319] = 975470,
	[3320] = 952881,
	[3321] = 952680,
	[3322] = 952684,
	[3323] = 952688,
	[3324] = 952692,
	[3325] = 952716,
	[3326] = 952720,
	[3327] = 952724,
	[3328] = 952728,
	[3329] = 952748,
	[3330] = 952752,
	[3331] = 952756,
	[3332] = 952928,
	[3333] = 952932,
	[3334] = 952936,
	[3335] = 952940,
	[3336] = 952976,
	[3337] = 952980,
	[3338] = 952984,
	[3339] = 952988,
	[3340] = 953025,
	[3341] = 953029,
	[3342] = 1316822,
	[3343] = 1316826,
	[3417] = 975463,
	[3418] = 975467,
	[3419] = 975471,
	[3420] = 952882,
	[3421] = 952681,
	[3422] = 952685,
	[3423] = 952689,
	[3424] = 952693,
	[3425] = 952717,
	[3426] = 952721,
	[3427] = 952725,
	[3428] = 952729,
	[3429] = 952749,
	[3430] = 952753,
	[3431] = 952757,
	[3432] = 952929,
	[3433] = 952933,
	[3434] = 952937,
	[3435] = 952941,
	[3436] = 952977,
	[3437] = 952981,
	[3438] = 952985,
	[3439] = 952989,
	[3440] = 953026,
	[3441] = 953030,
	[3442] = 1316823,
	[3443] = 1316827,
	[3517] = 975472,
	[3518] = 975475,
	[3519] = 975478,
	[3520] = 952883,
	[3521] = 952694,
	[3522] = 952695,
	[3523] = 952696,
	[3524] = 952697,
	[3525] = 952730,
	[3526] = 952731,
	[3527] = 952732,
	[3528] = 952733,
	[3529] = 952758,
	[3530] = 952759,
	[3531] = 952760,
	[3532] = 952942,
	[3533] = 952945,
	[3534] = 952948,
	[3535] = 952951,
	[3536] = 952990,
	[3537] = 952993,
	[3538] = 952996,
	[3539] = 952999,
	[3540] = 953031,
	[3541] = 953034,
	[3542] = 1316824,
	[3543] = 1316828,
	[3617] = 975473,
	[3618] = 975476,
	[3619] = 975479,
	[3620] = 952884,
	[3621] = 952886,
	[3622] = 952888,
	[3623] = 952890,
	[3624] = 952892,
	[3625] = 952894,
	[3626] = 952896,
	[3627] = 952898,
	[3628] = 952904,
	[3629] = 952906,
	[3630] = 952908,
	[3631] = 952910,
	[3632] = 952943,
	[3633] = 952946,
	[3634] = 952949,
	[3635] = 952952,
	[3636] = 952991,
	[3637] = 952994,
	[3638] = 952997,
	[3639] = 953000,
	[3640] = 953032,
	[3641] = 953035,
	[3642] = 1316825,
	[3643] = 1316829,
	[3717] = 975474,
	[3718] = 975477,
	[3719] = 975480,
	[3720] = 952885,
	[3721] = 952887,
	[3722] = 952889,
	[3723] = 952891,
	[3724] = 952893,
	[3725] = 952895,
	[3726] = 952897,
	[3727] = 952899,
	[3728] = 952905,
	[3729] = 952907,
	[3730] = 952909,
	[3731] = 952911,
	[3732] = 952944,
	[3733] = 952947,
	[3734] = 952950,
	[3735] = 952953,
	[3736] = 952992,
	[3737] = 952995,
	[3738] = 952998,
	[3739] = 953001,
	[3740] = 953033,
	[3741] = 953036,
	[3742] = 1316830,
	[3743] = 1316831,
}

Map.ZandalarMapBlks = {
	[1616] = 1437494,
	[1617] = 1437536,
	[1618] = 1437579,
	[1619] = 1437623,
	[1620] = 1437669,
	[1621] = 1437714,
	[1622] = 1437761,
	[1623] = 1437810,
	[1624] = 1437857,
	[1625] = 1437904,
	[1626] = 1437944,
	[1627] = 1437976,
	[1628] = 1438007,
	[1629] = 1438039,
	[1630] = 1438069,
	[1631] = 1438102,
	[1632] = 1438134,
	[1633] = 1438164,
	[1634] = 1438198,
	[1635] = 1438231,
	[1636] = 1438268,
	[1637] = 1438303,
	[1638] = 1438341,
	[1639] = 1438378,
	[1640] = 1438416,
	[1641] = 1438458,
	[1642] = 1438497,
	[1643] = 1438533,
	[1644] = 1438570,
	[1645] = 1438608,
	[1716] = 1437495,
	[1717] = 1437537,
	[1718] = 1437581,
	[1719] = 1437625,
	[1720] = 1437671,
	[1721] = 1437715,
	[1722] = 1437764,
	[1723] = 1437811,
	[1724] = 1437859,
	[1725] = 1437905,
	[1726] = 1437945,
	[1727] = 1437977,
	[1728] = 1438008,
	[1729] = 1438040,
	[1730] = 1438070,
	[1731] = 1438103,
	[1732] = 1438135,
	[1733] = 1438166,
	[1734] = 1438199,
	[1735] = 1438232,
	[1736] = 1438269,
	[1737] = 1438304,
	[1738] = 1438342,
	[1739] = 1438380,
	[1740] = 1438418,
	[1741] = 1438459,
	[1742] = 1438498,
	[1743] = 1438534,
	[1744] = 1438571,
	[1745] = 1438609,
	[1816] = 1437496,
	[1817] = 1437540,
	[1818] = 1437582,
	[1819] = 1437627,
	[1820] = 1437673,
	[1821] = 1437716,
	[1822] = 1437765,
	[1823] = 1437814,
	[1824] = 1437860,
	[1825] = 1437908,
	[1826] = 1437947,
	[1827] = 1437978,
	[1828] = 1438009,
	[1829] = 1438041,
	[1830] = 1438071,
	[1831] = 1438104,
	[1832] = 1438136,
	[1833] = 1438167,
	[1834] = 1438200,
	[1835] = 1438234,
	[1836] = 1438270,
	[1837] = 1438305,
	[1838] = 1438343,
	[1839] = 1438381,
	[1840] = 1438420,
	[1841] = 1438460,
	[1842] = 1438499,
	[1843] = 1438535,
	[1844] = 1438572,
	[1845] = 1438611,
	[1916] = 1437497,
	[1917] = 1437541,
	[1918] = 1437583,
	[1919] = 1437629,
	[1920] = 1437674,
	[1921] = 1437719,
	[1922] = 1437766,
	[1923] = 1437815,
	[1924] = 1437861,
	[1925] = 1437909,
	[1926] = 1437948,
	[1927] = 1437979,
	[1928] = 1438010,
	[1929] = 1438042,
	[1930] = 1438072,
	[1931] = 1438105,
	[1932] = 1438137,
	[1933] = 1438168,
	[1934] = 1438201,
	[1935] = 1438235,
	[1936] = 1438271,
	[1937] = 1438307,
	[1938] = 1438344,
	[1939] = 1438382,
	[1940] = 1438421,
	[1941] = 1438461,
	[1942] = 1438500,
	[1943] = 1438537,
	[1944] = 1438573,
	[1945] = 1438612,
	[2016] = 1437498,
	[2017] = 1437542,
	[2018] = 1437584,
	[2019] = 1437630,
	[2020] = 1437675,
	[2021] = 1437721,
	[2022] = 1437767,
	[2023] = 1437816,
	[2024] = 1437864,
	[2025] = 1437910,
	[2026] = 1437949,
	[2027] = 1437981,
	[2028] = 1438011,
	[2029] = 1438043,
	[2030] = 1438073,
	[2031] = 1438108,
	[2032] = 1438138,
	[2033] = 1438170,
	[2034] = 1438202,
	[2035] = 1438236,
	[2036] = 1438272,
	[2037] = 1438308,
	[2038] = 1438345,
	[2039] = 1438384,
	[2040] = 1438423,
	[2041] = 1438462,
	[2042] = 1438501,
	[2043] = 1438539,
	[2044] = 1438575,
	[2045] = 1438613,
	[2116] = 1437500,
	[2117] = 1437543,
	[2118] = 1437585,
	[2119] = 1437632,
	[2120] = 1437677,
	[2121] = 1437722,
	[2122] = 1437771,
	[2123] = 1437817,
	[2124] = 1437865,
	[2125] = 1437912,
	[2126] = 1437950,
	[2127] = 1437982,
	[2128] = 1438013,
	[2129] = 1438044,
	[2130] = 1438074,
	[2131] = 1438109,
	[2132] = 1438139,
	[2133] = 1438171,
	[2134] = 1438203,
	[2135] = 1438239,
	[2136] = 1438273,
	[2137] = 1438309,
	[2138] = 1438347,
	[2139] = 1438385,
	[2140] = 1438424,
	[2141] = 1438463,
	[2142] = 1438502,
	[2143] = 1438540,
	[2144] = 1438576,
	[2145] = 1438615,
	[2216] = 1437502,
	[2217] = 1437545,
	[2218] = 1437586,
	[2219] = 1437633,
	[2220] = 1437679,
	[2221] = 1437723,
	[2222] = 1437772,
	[2223] = 1437819,
	[2224] = 1437866,
	[2225] = 1437914,
	[2226] = 1437951,
	[2227] = 1437983,
	[2228] = 1438014,
	[2229] = 1438045,
	[2230] = 1438075,
	[2231] = 1438110,
	[2232] = 1438140,
	[2233] = 1438172,
	[2234] = 1438204,
	[2235] = 1438240,
	[2236] = 1438274,
	[2237] = 1438310,
	[2238] = 1438348,
	[2239] = 1438386,
	[2240] = 1438425,
	[2241] = 1438466,
	[2242] = 1438503,
	[2243] = 1438542,
	[2244] = 1438577,
	[2245] = 1438617,
	[2316] = 1437503,
	[2317] = 1437546,
	[2318] = 1437588,
	[2319] = 1437635,
	[2320] = 1437681,
	[2321] = 1437725,
	[2322] = 1437773,
	[2323] = 1437821,
	[2324] = 1437869,
	[2325] = 1437915,
	[2326] = 1437952,
	[2327] = 1437984,
	[2328] = 1438015,
	[2329] = 1438046,
	[2330] = 1438076,
	[2331] = 1438111,
	[2332] = 1438141,
	[2333] = 1438173,
	[2334] = 1438205,
	[2335] = 1438241,
	[2336] = 1438275,
	[2337] = 1438311,
	[2338] = 1438349,
	[2339] = 1438387,
	[2340] = 1438426,
	[2341] = 1438467,
	[2342] = 1438504,
	[2343] = 1438543,
	[2344] = 1438578,
	[2345] = 1438618,
	[2416] = 1437504,
	[2417] = 1437548,
	[2418] = 1437589,
	[2419] = 1437636,
	[2420] = 1437682,
	[2421] = 1437727,
	[2422] = 1437774,
	[2423] = 1437822,
	[2424] = 1437870,
	[2425] = 1437917,
	[2426] = 1437953,
	[2427] = 1437985,
	[2428] = 1438016,
	[2429] = 1438047,
	[2430] = 1438079,
	[2431] = 1438112,
	[2432] = 1438142,
	[2433] = 1438175,
	[2434] = 1438206,
	[2435] = 1438242,
	[2436] = 1438276,
	[2437] = 1438312,
	[2438] = 1438350,
	[2439] = 1438389,
	[2440] = 1438428,
	[2441] = 1438468,
	[2442] = 1438505,
	[2443] = 1438545,
	[2444] = 1438579,
	[2445] = 1438619,
	[2516] = 1437506,
	[2517] = 1437549,
	[2518] = 1437592,
	[2519] = 1437637,
	[2520] = 1437684,
	[2521] = 1437729,
	[2522] = 1437778,
	[2523] = 1437823,
	[2524] = 1437871,
	[2525] = 1437918,
	[2526] = 1437954,
	[2527] = 1437986,
	[2528] = 1438017,
	[2529] = 1438048,
	[2530] = 1438080,
	[2531] = 1438113,
	[2532] = 1438143,
	[2533] = 1438176,
	[2534] = 1438207,
	[2535] = 1438243,
	[2536] = 1438277,
	[2537] = 1438313,
	[2538] = 1438352,
	[2539] = 1438390,
	[2540] = 1438429,
	[2541] = 1438470,
	[2542] = 1438506,
	[2543] = 1438546,
	[2544] = 1438580,
	[2545] = 1438621,
	[2616] = 1437508,
	[2617] = 1437550,
	[2618] = 1437594,
	[2619] = 1437638,
	[2620] = 1437686,
	[2621] = 1437730,
	[2622] = 1437779,
	[2623] = 1437826,
	[2624] = 1437872,
	[2625] = 1437919,
	[2626] = 1437955,
	[2627] = 1437987,
	[2628] = 1438018,
	[2629] = 1438049,
	[2630] = 1438081,
	[2631] = 1438114,
	[2632] = 1438144,
	[2633] = 1438177,
	[2634] = 1438208,
	[2635] = 1438244,
	[2636] = 1438279,
	[2637] = 1438315,
	[2638] = 1438353,
	[2639] = 1438391,
	[2640] = 1438430,
	[2641] = 1438472,
	[2642] = 1438508,
	[2643] = 1438547,
	[2644] = 1438582,
	[2645] = 1438622,
	[2716] = 1437509,
	[2717] = 1437551,
	[2718] = 1437595,
	[2719] = 1437639,
	[2720] = 1437688,
	[2721] = 1437731,
	[2722] = 1437780,
	[2723] = 1437827,
	[2724] = 1437874,
	[2725] = 1437921,
	[2726] = 1437956,
	[2727] = 1437988,
	[2728] = 1438019,
	[2729] = 1438050,
	[2730] = 1438082,
	[2731] = 1438115,
	[2732] = 1438145,
	[2733] = 1438178,
	[2734] = 1438209,
	[2735] = 1438245,
	[2736] = 1438281,
	[2737] = 1438317,
	[2738] = 1438354,
	[2739] = 1438392,
	[2740] = 1438431,
	[2741] = 1438473,
	[2742] = 1438510,
	[2743] = 1438548,
	[2744] = 1438583,
	[2745] = 1438623,
	[2816] = 1437511,
	[2817] = 1437552,
	[2818] = 1437596,
	[2819] = 1437640,
	[2820] = 1437689,
	[2821] = 1437733,
	[2822] = 1437781,
	[2823] = 1437828,
	[2824] = 1437876,
	[2825] = 1437922,
	[2826] = 1437957,
	[2827] = 1437989,
	[2828] = 1438020,
	[2829] = 1438051,
	[2830] = 1438083,
	[2831] = 1438116,
	[2832] = 1438146,
	[2833] = 1438179,
	[2834] = 1438211,
	[2835] = 1438246,
	[2836] = 1438283,
	[2837] = 1438318,
	[2838] = 1438355,
	[2839] = 1438393,
	[2840] = 1438432,
	[2841] = 1438474,
	[2842] = 1438511,
	[2843] = 1438549,
	[2844] = 1438584,
	[2845] = 1438624,
	[2916] = 1437512,
	[2917] = 1437553,
	[2918] = 1437597,
	[2919] = 1437642,
	[2920] = 1437691,
	[2921] = 1437734,
	[2922] = 1437785,
	[2923] = 1437831,
	[2924] = 1437878,
	[2925] = 1437923,
	[2926] = 1437959,
	[2927] = 1437990,
	[2928] = 1438021,
	[2929] = 1438052,
	[2930] = 1438084,
	[2931] = 1438117,
	[2932] = 1438147,
	[2933] = 1438180,
	[2934] = 1438212,
	[2935] = 1438247,
	[2936] = 1438284,
	[2937] = 1438319,
	[2938] = 1438357,
	[2939] = 1438395,
	[2940] = 1438433,
	[2941] = 1438475,
	[2942] = 1438513,
	[2943] = 1438550,
	[2944] = 1438585,
	[2945] = 1438625,
	[3016] = 1437513,
	[3017] = 1437556,
	[3018] = 1437600,
	[3019] = 1437644,
	[3020] = 1437693,
	[3021] = 1437735,
	[3022] = 1437786,
	[3023] = 1437832,
	[3024] = 1437880,
	[3025] = 1437925,
	[3026] = 1437960,
	[3027] = 1437991,
	[3028] = 1438022,
	[3029] = 1438053,
	[3030] = 1438085,
	[3031] = 1438118,
	[3032] = 1438148,
	[3033] = 1438181,
	[3034] = 1438214,
	[3035] = 1438248,
	[3036] = 1438285,
	[3037] = 1438321,
	[3038] = 1438359,
	[3039] = 1438396,
	[3040] = 1438434,
	[3041] = 1438476,
	[3042] = 1438514,
	[3043] = 1438551,
	[3044] = 1438587,
	[3045] = 1438627,
	[3116] = 1437514,
	[3117] = 1437557,
	[3118] = 1437601,
	[3119] = 1437646,
	[3120] = 1437694,
	[3121] = 1437736,
	[3122] = 1437787,
	[3123] = 1437833,
	[3124] = 1437881,
	[3125] = 1437926,
	[3126] = 1437961,
	[3127] = 1437992,
	[3128] = 1438023,
	[3129] = 1438054,
	[3130] = 1438086,
	[3131] = 1438119,
	[3132] = 1438149,
	[3133] = 1438182,
	[3134] = 1438215,
	[3135] = 1438250,
	[3136] = 1438286,
	[3137] = 1438322,
	[3138] = 1438360,
	[3139] = 1438397,
	[3140] = 1438435,
	[3141] = 1438478,
	[3142] = 1438516,
	[3143] = 1438552,
	[3144] = 1438589,
	[3145] = 1438628,
	[3216] = 1437515,
	[3217] = 1437559,
	[3218] = 1437603,
	[3219] = 1437647,
	[3220] = 1437696,
	[3221] = 1437737,
	[3222] = 1437788,
	[3223] = 1437836,
	[3224] = 1437882,
	[3225] = 1437927,
	[3226] = 1437962,
	[3227] = 1437993,
	[3228] = 1438024,
	[3229] = 1438055,
	[3230] = 1438087,
	[3231] = 1438120,
	[3232] = 1438150,
	[3233] = 1438183,
	[3234] = 1438216,
	[3235] = 1438251,
	[3236] = 1438287,
	[3237] = 1438324,
	[3238] = 1438361,
	[3239] = 1438398,
	[3240] = 1438436,
	[3241] = 1438479,
	[3242] = 1438517,
	[3243] = 1438553,
	[3244] = 1438590,
	[3245] = 1438630,
	[3316] = 1437516,
	[3317] = 1437560,
	[3318] = 1437604,
	[3319] = 1437649,
	[3320] = 1437697,
	[3321] = 1437739,
	[3322] = 1437790,
	[3323] = 1437837,
	[3324] = 1437885,
	[3325] = 1437928,
	[3326] = 1437963,
	[3327] = 1437994,
	[3328] = 1438025,
	[3329] = 1438056,
	[3330] = 1438088,
	[3331] = 1438121,
	[3332] = 1438151,
	[3333] = 1438184,
	[3334] = 1438218,
	[3335] = 1438253,
	[3336] = 1438288,
	[3337] = 1438325,
	[3338] = 1438363,
	[3339] = 1438400,
	[3340] = 1438437,
	[3341] = 1438481,
	[3342] = 1438518,
	[3343] = 1438554,
	[3344] = 1438591,
	[3345] = 1438631,
	[3416] = 1437517,
	[3417] = 1437562,
	[3418] = 1437606,
	[3419] = 1437650,
	[3420] = 1437699,
	[3421] = 1437740,
	[3422] = 1437791,
	[3423] = 1437838,
	[3424] = 1437886,
	[3425] = 1437929,
	[3426] = 1437964,
	[3427] = 1437995,
	[3428] = 1438026,
	[3429] = 1438057,
	[3430] = 1438089,
	[3431] = 1438122,
	[3432] = 1438152,
	[3433] = 1438185,
	[3434] = 1438219,
	[3435] = 1438255,
	[3436] = 1438289,
	[3437] = 1438326,
	[3438] = 1438364,
	[3439] = 1438401,
	[3440] = 1438439,
	[3441] = 1438482,
	[3442] = 1438519,
	[3443] = 1438555,
	[3444] = 1438592,
	[3445] = 1438632,
	[3516] = 1437518,
	[3517] = 1437563,
	[3518] = 1437608,
	[3519] = 1437651,
	[3520] = 1437700,
	[3521] = 1437742,
	[3522] = 1437793,
	[3523] = 1437839,
	[3524] = 1437887,
	[3525] = 1437931,
	[3526] = 1437965,
	[3527] = 1437996,
	[3528] = 1438027,
	[3529] = 1438058,
	[3530] = 1438090,
	[3531] = 1438123,
	[3532] = 1438153,
	[3533] = 1438186,
	[3534] = 1438220,
	[3535] = 1438256,
	[3536] = 1438290,
	[3537] = 1438327,
	[3538] = 1438365,
	[3539] = 1438402,
	[3540] = 1438440,
	[3541] = 1438483,
	[3542] = 1438521,
	[3543] = 1438557,
	[3544] = 1438593,
	[3545] = 1438633,
	[3616] = 1437520,
	[3617] = 1437565,
	[3618] = 1437609,
	[3619] = 1437652,
	[3620] = 1437701,
	[3621] = 1437744,
	[3622] = 1437795,
	[3623] = 1437841,
	[3624] = 1437888,
	[3625] = 1437932,
	[3626] = 1437966,
	[3627] = 1437997,
	[3628] = 1438028,
	[3629] = 1438059,
	[3630] = 1438091,
	[3631] = 1438124,
	[3632] = 1438154,
	[3633] = 1438188,
	[3634] = 1438221,
	[3635] = 1438257,
	[3636] = 1438291,
	[3637] = 1438329,
	[3638] = 1438366,
	[3639] = 1438403,
	[3640] = 1438441,
	[3641] = 1438484,
	[3642] = 1438522,
	[3643] = 1438558,
	[3644] = 1438595,
	[3645] = 1438635,
	[3716] = 1437521,
	[3717] = 1437567,
	[3718] = 1437611,
	[3719] = 1437655,
	[3720] = 1437702,
	[3721] = 1437746,
	[3722] = 1437796,
	[3723] = 1437843,
	[3724] = 1437890,
	[3725] = 1437934,
	[3726] = 1437967,
	[3727] = 1437998,
	[3728] = 1438029,
	[3729] = 1438060,
	[3730] = 1438092,
	[3731] = 1438125,
	[3732] = 1438155,
	[3733] = 1438189,
	[3734] = 1438222,
	[3735] = 1438258,
	[3736] = 1438292,
	[3737] = 1438330,
	[3738] = 1438367,
	[3739] = 1438405,
	[3740] = 1438443,
	[3741] = 1438485,
	[3742] = 1438523,
	[3743] = 1438559,
	[3744] = 1438596,
	[3745] = 1438636,
	[3816] = 1437524,
	[3817] = 1437568,
	[3818] = 1437612,
	[3819] = 1437657,
	[3820] = 1437703,
	[3821] = 1437747,
	[3822] = 1437797,
	[3823] = 1437845,
	[3824] = 1437892,
	[3825] = 1437935,
	[3826] = 1437968,
	[3827] = 1437999,
	[3828] = 1438030,
	[3829] = 1438061,
	[3830] = 1438093,
	[3831] = 1438126,
	[3832] = 1438156,
	[3833] = 1438190,
	[3834] = 1438223,
	[3835] = 1438259,
	[3836] = 1438294,
	[3837] = 1438331,
	[3838] = 1438369,
	[3839] = 1438406,
	[3840] = 1438444,
	[3841] = 1438486,
	[3842] = 1438524,
	[3843] = 1438560,
	[3844] = 1438597,
	[3845] = 1438638,
	[3916] = 1437525,
	[3917] = 1437570,
	[3918] = 1437613,
	[3919] = 1437658,
	[3920] = 1437704,
	[3921] = 1437749,
	[3922] = 1437799,
	[3923] = 1437846,
	[3924] = 1437894,
	[3925] = 1437936,
	[3926] = 1437969,
	[3927] = 1438000,
	[3928] = 1438031,
	[3929] = 1438062,
	[3930] = 1438094,
	[3931] = 1438127,
	[3932] = 1438157,
	[3933] = 1438191,
	[3934] = 1438224,
	[3935] = 1438260,
	[3936] = 1438295,
	[3937] = 1438332,
	[3938] = 1438370,
	[3939] = 1438409,
	[3940] = 1438446,
	[3941] = 1438487,
	[3942] = 1438525,
	[3943] = 1438561,
	[3944] = 1438598,
	[3945] = 1438639,
	[4016] = 1437526,
	[4017] = 1437572,
	[4018] = 1437614,
	[4019] = 1437659,
	[4020] = 1437705,
	[4021] = 1437751,
	[4022] = 1437801,
	[4023] = 1437847,
	[4024] = 1437895,
	[4025] = 1437937,
	[4026] = 1437970,
	[4027] = 1438001,
	[4028] = 1438032,
	[4029] = 1438063,
	[4030] = 1438095,
	[4031] = 1438128,
	[4032] = 1438158,
	[4033] = 1438192,
	[4034] = 1438225,
	[4035] = 1438261,
	[4036] = 1438296,
	[4037] = 1438334,
	[4038] = 1438372,
	[4039] = 1438410,
	[4040] = 1438447,
	[4041] = 1438488,
	[4042] = 1438526,
	[4043] = 1438563,
	[4044] = 1438599,
	[4045] = 1438640,
	[4116] = 1437527,
	[4117] = 1437573,
	[4118] = 1437615,
	[4119] = 1437661,
	[4120] = 1437706,
	[4121] = 1437752,
	[4122] = 1437802,
	[4123] = 1437849,
	[4124] = 1437896,
	[4125] = 1437938,
	[4126] = 1437971,
	[4127] = 1438002,
	[4128] = 1438033,
	[4129] = 1438064,
	[4130] = 1438096,
	[4131] = 1438129,
	[4132] = 1438159,
	[4133] = 1438193,
	[4134] = 1438226,
	[4135] = 1438262,
	[4136] = 1438297,
	[4137] = 1438335,
	[4138] = 1438373,
	[4139] = 1438411,
	[4140] = 1438448,
	[4141] = 1438489,
	[4142] = 1438528,
	[4143] = 1438564,
	[4144] = 1438601,
	[4145] = 1438641,
	[4216] = 1437528,
	[4217] = 1437574,
	[4218] = 1437616,
	[4219] = 1437664,
	[4220] = 1437707,
	[4221] = 1437755,
	[4222] = 1437804,
	[4223] = 1437851,
	[4224] = 1437898,
	[4225] = 1437939,
	[4226] = 1437972,
	[4227] = 1438003,
	[4228] = 1438034,
	[4229] = 1438065,
	[4230] = 1438097,
	[4231] = 1438130,
	[4232] = 1438160,
	[4233] = 1438194,
	[4234] = 1438227,
	[4235] = 1438263,
	[4236] = 1438299,
	[4237] = 1438336,
	[4238] = 1438374,
	[4239] = 1438412,
	[4240] = 1438449,
	[4241] = 1438490,
	[4242] = 1438529,
	[4243] = 1438565,
	[4244] = 1438602,
	[4245] = 1438642,
	[4316] = 1437530,
	[4317] = 1437575,
	[4318] = 1437618,
	[4319] = 1437665,
	[4320] = 1437708,
	[4321] = 1437756,
	[4322] = 1437805,
	[4323] = 1437853,
	[4324] = 1437900,
	[4325] = 1437941,
	[4326] = 1437973,
	[4327] = 1438004,
	[4328] = 1438035,
	[4329] = 1438066,
	[4330] = 1438098,
	[4331] = 1438131,
	[4332] = 1438161,
	[4333] = 1438195,
	[4334] = 1438228,
	[4335] = 1438264,
	[4336] = 1438300,
	[4337] = 1438338,
	[4338] = 1438375,
	[4339] = 1438413,
	[4340] = 1438451,
	[4341] = 1438492,
	[4342] = 1438530,
	[4343] = 1438566,
	[4344] = 1438604,
	[4345] = 1438644,
	[4416] = 1437533,
	[4417] = 1437576,
	[4418] = 1437620,
	[4419] = 1437667,
	[4420] = 1437709,
	[4421] = 1437758,
	[4422] = 1437806,
	[4423] = 1437854,
	[4424] = 1437902,
	[4425] = 1437942,
	[4426] = 1437974,
	[4427] = 1438005,
	[4428] = 1438036,
	[4429] = 1438067,
	[4430] = 1438099,
	[4431] = 1438132,
	[4432] = 1438162,
	[4433] = 1438196,
	[4434] = 1438229,
	[4435] = 1438265,
	[4436] = 1438301,
	[4437] = 1438339,
	[4438] = 1438376,
	[4439] = 1438414,
	[4440] = 1438456,
	[4441] = 1438493,
	[4442] = 1438531,
	[4443] = 1438567,
	[4444] = 1438605,
	[4445] = 1438645,
	[4516] = 1437534,
	[4517] = 1437577,
	[4518] = 1437622,
	[4519] = 1437668,
	[4520] = 1437713,
	[4521] = 1437759,
	[4522] = 1437809,
	[4523] = 1437855,
	[4524] = 1437903,
	[4525] = 1437943,
	[4526] = 1437975,
	[4527] = 1438006,
	[4528] = 1438037,
	[4529] = 1438068,
	[4530] = 1438101,
	[4531] = 1438133,
	[4532] = 1438163,
	[4533] = 1438197,
	[4534] = 1438230,
	[4535] = 1438266,
	[4536] = 1438302,
	[4537] = 1438340,
	[4538] = 1438377,
	[4539] = 1438415,
	[4540] = 1438457,
	[4541] = 1438495,
	[4542] = 1438532,
	[4543] = 1438568,
	[4544] = 1438606,
	[4545] = 1438647,
}

Map.KultirasMapBlks = {
	[1616] = 1436065,
	[1617] = 1436107,
	[1618] = 1436149,
	[1619] = 1436194,
	[1620] = 1436238,
	[1621] = 1436284,
	[1622] = 1436329,
	[1623] = 1436373,
	[1624] = 1436417,
	[1625] = 1436447,
	[1626] = 1436477,
	[1627] = 1436507,
	[1628] = 1436537,
	[1629] = 1436567,
	[1630] = 1436597,
	[1631] = 1436627,
	[1632] = 1436657,
	[1633] = 1436687,
	[1634] = 1436717,
	[1635] = 1436747,
	[1636] = 1436777,
	[1637] = 1436807,
	[1638] = 1436837,
	[1639] = 1436867,
	[1640] = 1436897,
	[1641] = 1436927,
	[1642] = 1436957,
	[1643] = 1436987,
	[1644] = 1437017,
	[1645] = 1437047,
	[1716] = 1436066,
	[1717] = 1436108,
	[1718] = 1436151,
	[1719] = 1436196,
	[1720] = 1436240,
	[1721] = 1436286,
	[1722] = 1436330,
	[1723] = 1436375,
	[1724] = 1436418,
	[1725] = 1436448,
	[1726] = 1436478,
	[1727] = 1436508,
	[1728] = 1436538,
	[1729] = 1436568,
	[1730] = 1436598,
	[1731] = 1436628,
	[1732] = 1436658,
	[1733] = 1436688,
	[1734] = 1436718,
	[1735] = 1436748,
	[1736] = 1436778,
	[1737] = 1436808,
	[1738] = 1436838,
	[1739] = 1436868,
	[1740] = 1436898,
	[1741] = 1436928,
	[1742] = 1436958,
	[1743] = 1436988,
	[1744] = 1437018,
	[1745] = 1437048,
	[1816] = 1436068,
	[1817] = 1436109,
	[1818] = 1436153,
	[1819] = 1436197,
	[1820] = 1436242,
	[1821] = 1436288,
	[1822] = 1436332,
	[1823] = 1436376,
	[1824] = 1436419,
	[1825] = 1436449,
	[1826] = 1436479,
	[1827] = 1436509,
	[1828] = 1436539,
	[1829] = 1436569,
	[1830] = 1436599,
	[1831] = 1436629,
	[1832] = 1436659,
	[1833] = 1436689,
	[1834] = 1436719,
	[1835] = 1436749,
	[1836] = 1436779,
	[1837] = 1436809,
	[1838] = 1436839,
	[1839] = 1436869,
	[1840] = 1436899,
	[1841] = 1436929,
	[1842] = 1436959,
	[1843] = 1436989,
	[1844] = 1437019,
	[1845] = 1437049,
	[1916] = 1436069,
	[1917] = 1436111,
	[1918] = 1436154,
	[1919] = 1436199,
	[1920] = 1436244,
	[1921] = 1436289,
	[1922] = 1436333,
	[1923] = 1436377,
	[1924] = 1436420,
	[1925] = 1436450,
	[1926] = 1436480,
	[1927] = 1436510,
	[1928] = 1436540,
	[1929] = 1436570,
	[1930] = 1436600,
	[1931] = 1436630,
	[1932] = 1436660,
	[1933] = 1436690,
	[1934] = 1436720,
	[1935] = 1436750,
	[1936] = 1436780,
	[1937] = 1436810,
	[1938] = 1436840,
	[1939] = 1436870,
	[1940] = 1436900,
	[1941] = 1436930,
	[1942] = 1436960,
	[1943] = 1436990,
	[1944] = 1437020,
	[1945] = 1437050,
	[2016] = 1436071,
	[2017] = 1436112,
	[2018] = 1436156,
	[2019] = 1436200,
	[2020] = 1436245,
	[2021] = 1436291,
	[2022] = 1436335,
	[2023] = 1436379,
	[2024] = 1436421,
	[2025] = 1436451,
	[2026] = 1436481,
	[2027] = 1436511,
	[2028] = 1436541,
	[2029] = 1436571,
	[2030] = 1436601,
	[2031] = 1436631,
	[2032] = 1436661,
	[2033] = 1436691,
	[2034] = 1436721,
	[2035] = 1436751,
	[2036] = 1436781,
	[2037] = 1436811,
	[2038] = 1436841,
	[2039] = 1436871,
	[2040] = 1436901,
	[2041] = 1436931,
	[2042] = 1436961,
	[2043] = 1436991,
	[2044] = 1437021,
	[2045] = 1437051,
	[2116] = 1436072,
	[2117] = 1436113,
	[2118] = 1436157,
	[2119] = 1436202,
	[2120] = 1436247,
	[2121] = 1436293,
	[2122] = 1436337,
	[2123] = 1436380,
	[2124] = 1436422,
	[2125] = 1436452,
	[2126] = 1436482,
	[2127] = 1436512,
	[2128] = 1436542,
	[2129] = 1436572,
	[2130] = 1436602,
	[2131] = 1436632,
	[2132] = 1436662,
	[2133] = 1436692,
	[2134] = 1436722,
	[2135] = 1436752,
	[2136] = 1436782,
	[2137] = 1436812,
	[2138] = 1436842,
	[2139] = 1436872,
	[2140] = 1436902,
	[2141] = 1436932,
	[2142] = 1436962,
	[2143] = 1436992,
	[2144] = 1437022,
	[2145] = 1437052,
	[2216] = 1436073,
	[2217] = 1436114,
	[2218] = 1436158,
	[2219] = 1436203,
	[2220] = 1436249,
	[2221] = 1436294,
	[2222] = 1436338,
	[2223] = 1436382,
	[2224] = 1436423,
	[2225] = 1436453,
	[2226] = 1436483,
	[2227] = 1436513,
	[2228] = 1436543,
	[2229] = 1436573,
	[2230] = 1436603,
	[2231] = 1436633,
	[2232] = 1436663,
	[2233] = 1436693,
	[2234] = 1436723,
	[2235] = 1436753,
	[2236] = 1436783,
	[2237] = 1436813,
	[2238] = 1436843,
	[2239] = 1436873,
	[2240] = 1436903,
	[2241] = 1436933,
	[2242] = 1436963,
	[2243] = 1436993,
	[2244] = 1437023,
	[2245] = 1437053,
	[2316] = 1436075,
	[2317] = 1436115,
	[2318] = 1436160,
	[2319] = 1436205,
	[2320] = 1436250,
	[2321] = 1436295,
	[2322] = 1436340,
	[2323] = 1436384,
	[2324] = 1436424,
	[2325] = 1436454,
	[2326] = 1436484,
	[2327] = 1436514,
	[2328] = 1436544,
	[2329] = 1436574,
	[2330] = 1436604,
	[2331] = 1436634,
	[2332] = 1436664,
	[2333] = 1436694,
	[2334] = 1436724,
	[2335] = 1436754,
	[2336] = 1436784,
	[2337] = 1436814,
	[2338] = 1436844,
	[2339] = 1436874,
	[2340] = 1436904,
	[2341] = 1436934,
	[2342] = 1436964,
	[2343] = 1436994,
	[2344] = 1437024,
	[2345] = 1437054,
	[2416] = 1436076,
	[2417] = 1436117,
	[2418] = 1436161,
	[2419] = 1436206,
	[2420] = 1436251,
	[2421] = 1436297,
	[2422] = 1436341,
	[2423] = 1436385,
	[2424] = 1436425,
	[2425] = 1436455,
	[2426] = 1436485,
	[2427] = 1436515,
	[2428] = 1436545,
	[2429] = 1436575,
	[2430] = 1436605,
	[2431] = 1436635,
	[2432] = 1436665,
	[2433] = 1436695,
	[2434] = 1436725,
	[2435] = 1436755,
	[2436] = 1436785,
	[2437] = 1436815,
	[2438] = 1436845,
	[2439] = 1436875,
	[2440] = 1436905,
	[2441] = 1436935,
	[2442] = 1436965,
	[2443] = 1436995,
	[2444] = 1437025,
	[2445] = 1437055,
	[2516] = 1436078,
	[2517] = 1436118,
	[2518] = 1436162,
	[2519] = 1436207,
	[2520] = 1436253,
	[2521] = 1436298,
	[2522] = 1436342,
	[2523] = 1436387,
	[2524] = 1436426,
	[2525] = 1436456,
	[2526] = 1436486,
	[2527] = 1436516,
	[2528] = 1436546,
	[2529] = 1436576,
	[2530] = 1436606,
	[2531] = 1436636,
	[2532] = 1436666,
	[2533] = 1436696,
	[2534] = 1436726,
	[2535] = 1436756,
	[2536] = 1436786,
	[2537] = 1436816,
	[2538] = 1436846,
	[2539] = 1436876,
	[2540] = 1436906,
	[2541] = 1436936,
	[2542] = 1436966,
	[2543] = 1436996,
	[2544] = 1437026,
	[2545] = 1437056,
	[2616] = 1436079,
	[2617] = 1436120,
	[2618] = 1436164,
	[2619] = 1436209,
	[2620] = 1436254,
	[2621] = 1436299,
	[2622] = 1436344,
	[2623] = 1436388,
	[2624] = 1436427,
	[2625] = 1436457,
	[2626] = 1436487,
	[2627] = 1436517,
	[2628] = 1436547,
	[2629] = 1436577,
	[2630] = 1436607,
	[2631] = 1436637,
	[2632] = 1436667,
	[2633] = 1436697,
	[2634] = 1436727,
	[2635] = 1436757,
	[2636] = 1436787,
	[2637] = 1436817,
	[2638] = 1436847,
	[2639] = 1436877,
	[2640] = 1436907,
	[2641] = 1436937,
	[2642] = 1436967,
	[2643] = 1436997,
	[2644] = 1437027,
	[2645] = 1437057,
	[2716] = 1436081,
	[2717] = 1436122,
	[2718] = 1436166,
	[2719] = 1436211,
	[2720] = 1436256,
	[2721] = 1436301,
	[2722] = 1436345,
	[2723] = 1436389,
	[2724] = 1436428,
	[2725] = 1436458,
	[2726] = 1436488,
	[2727] = 1436518,
	[2728] = 1436548,
	[2729] = 1436578,
	[2730] = 1436608,
	[2731] = 1436638,
	[2732] = 1436668,
	[2733] = 1436698,
	[2734] = 1436728,
	[2735] = 1436758,
	[2736] = 1436788,
	[2737] = 1436818,
	[2738] = 1436848,
	[2739] = 1436878,
	[2740] = 1436908,
	[2741] = 1436938,
	[2742] = 1436968,
	[2743] = 1436998,
	[2744] = 1437028,
	[2745] = 1437058,
	[2816] = 1436082,
	[2817] = 1436123,
	[2818] = 1436168,
	[2819] = 1436212,
	[2820] = 1436257,
	[2821] = 1436303,
	[2822] = 1436346,
	[2823] = 1436391,
	[2824] = 1436429,
	[2825] = 1436459,
	[2826] = 1436489,
	[2827] = 1436519,
	[2828] = 1436549,
	[2829] = 1436579,
	[2830] = 1436609,
	[2831] = 1436639,
	[2832] = 1436669,
	[2833] = 1436699,
	[2834] = 1436729,
	[2835] = 1436759,
	[2836] = 1436789,
	[2837] = 1436819,
	[2838] = 1436849,
	[2839] = 1436879,
	[2840] = 1436909,
	[2841] = 1436939,
	[2842] = 1436969,
	[2843] = 1436999,
	[2844] = 1437029,
	[2845] = 1437059,
	[2916] = 1436083,
	[2917] = 1436124,
	[2918] = 1436169,
	[2919] = 1436214,
	[2920] = 1436259,
	[2921] = 1436304,
	[2922] = 1436348,
	[2923] = 1436392,
	[2924] = 1436430,
	[2925] = 1436460,
	[2926] = 1436490,
	[2927] = 1436520,
	[2928] = 1436550,
	[2929] = 1436580,
	[2930] = 1436610,
	[2931] = 1436640,
	[2932] = 1436670,
	[2933] = 1436700,
	[2934] = 1436730,
	[2935] = 1436760,
	[2936] = 1436790,
	[2937] = 1436820,
	[2938] = 1436850,
	[2939] = 1436880,
	[2940] = 1436910,
	[2941] = 1436940,
	[2942] = 1436970,
	[2943] = 1437000,
	[2944] = 1437030,
	[2945] = 1437060,
	[3016] = 1436085,
	[3017] = 1436126,
	[3018] = 1436171,
	[3019] = 1436215,
	[3020] = 1436261,
	[3021] = 1436306,
	[3022] = 1436350,
	[3023] = 1436393,
	[3024] = 1436431,
	[3025] = 1436461,
	[3026] = 1436491,
	[3027] = 1436521,
	[3028] = 1436551,
	[3029] = 1436581,
	[3030] = 1436611,
	[3031] = 1436641,
	[3032] = 1436671,
	[3033] = 1436701,
	[3034] = 1436731,
	[3035] = 1436761,
	[3036] = 1436791,
	[3037] = 1436821,
	[3038] = 1436851,
	[3039] = 1436881,
	[3040] = 1436911,
	[3041] = 1436941,
	[3042] = 1436971,
	[3043] = 1437001,
	[3044] = 1437031,
	[3045] = 1437061,
	[3116] = 1436086,
	[3117] = 1436127,
	[3118] = 1436172,
	[3119] = 1436216,
	[3120] = 1436262,
	[3121] = 1436307,
	[3122] = 1436352,
	[3123] = 1436394,
	[3124] = 1436432,
	[3125] = 1436462,
	[3126] = 1436492,
	[3127] = 1436522,
	[3128] = 1436552,
	[3129] = 1436582,
	[3130] = 1436612,
	[3131] = 1436642,
	[3132] = 1436672,
	[3133] = 1436702,
	[3134] = 1436732,
	[3135] = 1436762,
	[3136] = 1436792,
	[3137] = 1436822,
	[3138] = 1436852,
	[3139] = 1436882,
	[3140] = 1436912,
	[3141] = 1436942,
	[3142] = 1436972,
	[3143] = 1437002,
	[3144] = 1437032,
	[3145] = 1437062,
	[3216] = 1436088,
	[3217] = 1436129,
	[3218] = 1436174,
	[3219] = 1436218,
	[3220] = 1436264,
	[3221] = 1436309,
	[3222] = 1436353,
	[3223] = 1436396,
	[3224] = 1436433,
	[3225] = 1436463,
	[3226] = 1436493,
	[3227] = 1436523,
	[3228] = 1436553,
	[3229] = 1436583,
	[3230] = 1436613,
	[3231] = 1436643,
	[3232] = 1436673,
	[3233] = 1436703,
	[3234] = 1436733,
	[3235] = 1436763,
	[3236] = 1436793,
	[3237] = 1436823,
	[3238] = 1436853,
	[3239] = 1436883,
	[3240] = 1436913,
	[3241] = 1436943,
	[3242] = 1436973,
	[3243] = 1437003,
	[3244] = 1437033,
	[3245] = 1437063,
	[3316] = 1436089,
	[3317] = 1436130,
	[3318] = 1436175,
	[3319] = 1436219,
	[3320] = 1436265,
	[3321] = 1436310,
	[3322] = 1436354,
	[3323] = 1436398,
	[3324] = 1436434,
	[3325] = 1436464,
	[3326] = 1436494,
	[3327] = 1436524,
	[3328] = 1436554,
	[3329] = 1436584,
	[3330] = 1436614,
	[3331] = 1436644,
	[3332] = 1436674,
	[3333] = 1436704,
	[3334] = 1436734,
	[3335] = 1436764,
	[3336] = 1436794,
	[3337] = 1436824,
	[3338] = 1436854,
	[3339] = 1436884,
	[3340] = 1436914,
	[3341] = 1436944,
	[3342] = 1436974,
	[3343] = 1437004,
	[3344] = 1437034,
	[3345] = 1437064,
	[3416] = 1436091,
	[3417] = 1436131,
	[3418] = 1436176,
	[3419] = 1436221,
	[3420] = 1436267,
	[3421] = 1436312,
	[3422] = 1436356,
	[3423] = 1436400,
	[3424] = 1436435,
	[3425] = 1436465,
	[3426] = 1436495,
	[3427] = 1436525,
	[3428] = 1436555,
	[3429] = 1436585,
	[3430] = 1436615,
	[3431] = 1436645,
	[3432] = 1436675,
	[3433] = 1436705,
	[3434] = 1436735,
	[3435] = 1436765,
	[3436] = 1436795,
	[3437] = 1436825,
	[3438] = 1436855,
	[3439] = 1436885,
	[3440] = 1436915,
	[3441] = 1436945,
	[3442] = 1436975,
	[3443] = 1437005,
	[3444] = 1437035,
	[3445] = 1437065,
	[3516] = 1436092,
	[3517] = 1436133,
	[3518] = 1436178,
	[3519] = 1436222,
	[3520] = 1436268,
	[3521] = 1436313,
	[3522] = 1436357,
	[3523] = 1436401,
	[3524] = 1436436,
	[3525] = 1436466,
	[3526] = 1436496,
	[3527] = 1436526,
	[3528] = 1436556,
	[3529] = 1436586,
	[3530] = 1436616,
	[3531] = 1436646,
	[3532] = 1436676,
	[3533] = 1436706,
	[3534] = 1436736,
	[3535] = 1436766,
	[3536] = 1436796,
	[3537] = 1436826,
	[3538] = 1436856,
	[3539] = 1436886,
	[3540] = 1436916,
	[3541] = 1436946,
	[3542] = 1436976,
	[3543] = 1437006,
	[3544] = 1437036,
	[3545] = 1437066,
	[3616] = 1436093,
	[3617] = 1436134,
	[3618] = 1436179,
	[3619] = 1436223,
	[3620] = 1436269,
	[3621] = 1436314,
	[3622] = 1436358,
	[3623] = 1436403,
	[3624] = 1436437,
	[3625] = 1436467,
	[3626] = 1436497,
	[3627] = 1436527,
	[3628] = 1436557,
	[3629] = 1436587,
	[3630] = 1436617,
	[3631] = 1436647,
	[3632] = 1436677,
	[3633] = 1436707,
	[3634] = 1436737,
	[3635] = 1436767,
	[3636] = 1436797,
	[3637] = 1436827,
	[3638] = 1436857,
	[3639] = 1436887,
	[3640] = 1436917,
	[3641] = 1436947,
	[3642] = 1436977,
	[3643] = 1437007,
	[3644] = 1437037,
	[3645] = 1437067,
	[3716] = 1436094,
	[3717] = 1436136,
	[3718] = 1436181,
	[3719] = 1436225,
	[3720] = 1436271,
	[3721] = 1436316,
	[3722] = 1436360,
	[3723] = 1436404,
	[3724] = 1436438,
	[3725] = 1436468,
	[3726] = 1436498,
	[3727] = 1436528,
	[3728] = 1436558,
	[3729] = 1436588,
	[3730] = 1436618,
	[3731] = 1436648,
	[3732] = 1436678,
	[3733] = 1436708,
	[3734] = 1436738,
	[3735] = 1436768,
	[3736] = 1436798,
	[3737] = 1436828,
	[3738] = 1436858,
	[3739] = 1436888,
	[3740] = 1436918,
	[3741] = 1436948,
	[3742] = 1436978,
	[3743] = 1437008,
	[3744] = 1437038,
	[3745] = 1437068,
	[3816] = 1436096,
	[3817] = 1436138,
	[3818] = 1436182,
	[3819] = 1436227,
	[3820] = 1436272,
	[3821] = 1436317,
	[3822] = 1436361,
	[3823] = 1436405,
	[3824] = 1436439,
	[3825] = 1436469,
	[3826] = 1436499,
	[3827] = 1436529,
	[3828] = 1436559,
	[3829] = 1436589,
	[3830] = 1436619,
	[3831] = 1436649,
	[3832] = 1436679,
	[3833] = 1436709,
	[3834] = 1436739,
	[3835] = 1436769,
	[3836] = 1436799,
	[3837] = 1436829,
	[3838] = 1436859,
	[3839] = 1436889,
	[3840] = 1436919,
	[3841] = 1436949,
	[3842] = 1436979,
	[3843] = 1437009,
	[3844] = 1437039,
	[3845] = 1437069,
	[3916] = 1436097,
	[3917] = 1436139,
	[3918] = 1436184,
	[3919] = 1436229,
	[3920] = 1436274,
	[3921] = 1436319,
	[3922] = 1436362,
	[3923] = 1436406,
	[3924] = 1436440,
	[3925] = 1436470,
	[3926] = 1436500,
	[3927] = 1436530,
	[3928] = 1436560,
	[3929] = 1436590,
	[3930] = 1436620,
	[3931] = 1436650,
	[3932] = 1436680,
	[3933] = 1436710,
	[3934] = 1436740,
	[3935] = 1436770,
	[3936] = 1436800,
	[3937] = 1436830,
	[3938] = 1436860,
	[3939] = 1436890,
	[3940] = 1436920,
	[3941] = 1436950,
	[3942] = 1436980,
	[3943] = 1437010,
	[3944] = 1437040,
	[3945] = 1437070,
	[4016] = 1436099,
	[4017] = 1436141,
	[4018] = 1436186,
	[4019] = 1436230,
	[4020] = 1436276,
	[4021] = 1436321,
	[4022] = 1436364,
	[4023] = 1436408,
	[4024] = 1436441,
	[4025] = 1436471,
	[4026] = 1436501,
	[4027] = 1436531,
	[4028] = 1436561,
	[4029] = 1436591,
	[4030] = 1436621,
	[4031] = 1436651,
	[4032] = 1436681,
	[4033] = 1436711,
	[4034] = 1436741,
	[4035] = 1436771,
	[4036] = 1436801,
	[4037] = 1436831,
	[4038] = 1436861,
	[4039] = 1436891,
	[4040] = 1436921,
	[4041] = 1436951,
	[4042] = 1436981,
	[4043] = 1437011,
	[4044] = 1437041,
	[4045] = 1437071,
	[4116] = 1436100,
	[4117] = 1436142,
	[4118] = 1436187,
	[4119] = 1436232,
	[4120] = 1436277,
	[4121] = 1436322,
	[4122] = 1436365,
	[4123] = 1436409,
	[4124] = 1436442,
	[4125] = 1436472,
	[4126] = 1436502,
	[4127] = 1436532,
	[4128] = 1436562,
	[4129] = 1436592,
	[4130] = 1436622,
	[4131] = 1436652,
	[4132] = 1436682,
	[4133] = 1436712,
	[4134] = 1436742,
	[4135] = 1436772,
	[4136] = 1436802,
	[4137] = 1436832,
	[4138] = 1436862,
	[4139] = 1436892,
	[4140] = 1436922,
	[4141] = 1436952,
	[4142] = 1436982,
	[4143] = 1437012,
	[4144] = 1437042,
	[4145] = 1437072,
	[4216] = 1436102,
	[4217] = 1436144,
	[4218] = 1436188,
	[4219] = 1436233,
	[4220] = 1436279,
	[4221] = 1436324,
	[4222] = 1436367,
	[4223] = 1436410,
	[4224] = 1436443,
	[4225] = 1436473,
	[4226] = 1436503,
	[4227] = 1436533,
	[4228] = 1436563,
	[4229] = 1436593,
	[4230] = 1436623,
	[4231] = 1436653,
	[4232] = 1436683,
	[4233] = 1436713,
	[4234] = 1436743,
	[4235] = 1436773,
	[4236] = 1436803,
	[4237] = 1436833,
	[4238] = 1436863,
	[4239] = 1436893,
	[4240] = 1436923,
	[4241] = 1436953,
	[4242] = 1436983,
	[4243] = 1437013,
	[4244] = 1437043,
	[4245] = 1437073,
	[4316] = 1436103,
	[4317] = 1436145,
	[4318] = 1436190,
	[4319] = 1436234,
	[4320] = 1436280,
	[4321] = 1436325,
	[4322] = 1436369,
	[4323] = 1436412,
	[4324] = 1436444,
	[4325] = 1436474,
	[4326] = 1436504,
	[4327] = 1436534,
	[4328] = 1436564,
	[4329] = 1436594,
	[4330] = 1436624,
	[4331] = 1436654,
	[4332] = 1436684,
	[4333] = 1436714,
	[4334] = 1436744,
	[4335] = 1436774,
	[4336] = 1436804,
	[4337] = 1436834,
	[4338] = 1436864,
	[4339] = 1436894,
	[4340] = 1436924,
	[4341] = 1436954,
	[4342] = 1436984,
	[4343] = 1437014,
	[4344] = 1437044,
	[4345] = 1437074,
	[4416] = 1436104,
	[4417] = 1436146,
	[4418] = 1436191,
	[4419] = 1436236,
	[4420] = 1436282,
	[4421] = 1436326,
	[4422] = 1436370,
	[4423] = 1436414,
	[4424] = 1436445,
	[4425] = 1436475,
	[4426] = 1436505,
	[4427] = 1436535,
	[4428] = 1436565,
	[4429] = 1436595,
	[4430] = 1436625,
	[4431] = 1436655,
	[4432] = 1436685,
	[4433] = 1436715,
	[4434] = 1436745,
	[4435] = 1436775,
	[4436] = 1436805,
	[4437] = 1436835,
	[4438] = 1436865,
	[4439] = 1436895,
	[4440] = 1436925,
	[4441] = 1436955,
	[4442] = 1436985,
	[4443] = 1437015,
	[4444] = 1437045,
	[4445] = 1437075,
	[4516] = 1436106,
	[4517] = 1436148,
	[4518] = 1436192,
	[4519] = 1436237,
	[4520] = 1436283,
	[4521] = 1436328,
	[4522] = 1436372,
	[4523] = 1436415,
	[4524] = 1436446,
	[4525] = 1436476,
	[4526] = 1436506,
	[4527] = 1436536,
	[4528] = 1436566,
	[4529] = 1436596,
	[4530] = 1436626,
	[4531] = 1436656,
	[4532] = 1436686,
	[4533] = 1436716,
	[4534] = 1436746,
	[4535] = 1436776,
	[4536] = 1436806,
	[4537] = 1436836,
	[4538] = 1436866,
	[4539] = 1436896,
	[4540] = 1436926,
	[4541] = 1436956,
	[4542] = 1436986,
	[4543] = 1437016,
	[4544] = 1437046,
	[4545] = 1437076,
}

Map.BloodelfMapBlks = {
	[4116] = 207095,
	[4117] = 207096,
	[4118] = 207097,
	[4211] = 207107,
	[4212] = 207108,
	[4213] = 207109,
	[4214] = 207110,
	[4215] = 207111,
	[4216] = 207112,
	[4217] = 207113,
	[4218] = 207114,
	[4219] = 207115,
	[4220] = 207116,
	[4221] = 207117,
	[4306] = 207119,
	[4307] = 207120,
	[4308] = 207121,
	[4309] = 207122,
	[4310] = 207123,
	[4311] = 207124,
	[4312] = 207125,
	[4313] = 207126,
	[4314] = 207127,
	[4315] = 207128,
	[4316] = 207129,
	[4317] = 207130,
	[4318] = 207131,
	[4319] = 207132,
	[4320] = 207133,
	[4321] = 207134,
	[4406] = 207136,
	[4407] = 207137,
	[4408] = 207138,
	[4409] = 207139,
	[4410] = 207140,
	[4411] = 207141,
	[4412] = 207142,
	[4413] = 207143,
	[4414] = 207144,
	[4415] = 207145,
	[4416] = 207146,
	[4417] = 207147,
	[4418] = 207148,
	[4419] = 207149,
	[4420] = 207150,
	[4421] = 207151,
	[4506] = 207153,
	[4507] = 207154,
	[4508] = 207155,
	[4509] = 207156,
	[4510] = 207157,
	[4511] = 207158,
	[4512] = 207159,
	[4513] = 207160,
	[4514] = 207161,
	[4515] = 207162,
	[4516] = 207163,
	[4517] = 207164,
	[4518] = 207165,
	[4519] = 207166,
	[4520] = 207167,
	[4521] = 207168,
	[4606] = 207170,
	[4607] = 207171,
	[4608] = 207172,
	[4609] = 207173,
	[4610] = 207174,
	[4611] = 207175,
	[4612] = 207176,
	[4613] = 207177,
	[4614] = 207178,
	[4615] = 207179,
	[4616] = 207180,
	[4617] = 207181,
	[4618] = 207182,
	[4619] = 207183,
	[4620] = 207184,
	[4621] = 207185,
	[4713] = 207194,
	[4714] = 207195,
	[4715] = 207196,
	[4716] = 207197,
	[4717] = 207198,
	[4718] = 207199,
	[4719] = 207200,
	[4720] = 207201,
}

Map.DraeneiMapBlks = {
	[5034] = 207234,
	[5035] = 207235,
	[5133] = 207247,
	[5134] = 207248,
	[5135] = 207249,
	[5136] = 207250,
	[5137] = 207251,
	[5140] = 207254,
	[5141] = 207255,
	[5142] = 207256,
	[5233] = 207261,
	[5234] = 207262,
	[5235] = 207263,
	[5236] = 207264,
	[5237] = 207265,
	[5238] = 207266,
	[5239] = 207267,
	[5240] = 207268,
	[5241] = 207269,
	[5242] = 207270,
	[5333] = 207275,
	[5334] = 207276,
	[5335] = 207277,
	[5336] = 207278,
	[5337] = 207279,
	[5338] = 207280,
	[5339] = 207281,
	[5340] = 207282,
	[5341] = 207283,
	[5342] = 207284,
	[5433] = 207289,
	[5434] = 207290,
	[5435] = 207291,
	[5436] = 207292,
	[5437] = 207293,
	[5438] = 207294,
	[5439] = 207295,
	[5440] = 207296,
	[5441] = 207297,
	[5533] = 207303,
	[5534] = 207304,
	[5535] = 207305,
	[5536] = 207306,
	[5537] = 207307,
	[5538] = 207308,
	[5539] = 207309,
	[5540] = 207310,
	[5541] = 207311,
	[5633] = 207317,
	[5634] = 207318,
	[5635] = 207319,
	[5636] = 207320,
	[5637] = 207321,
	[5638] = 207322,
	[5639] = 207323,
	[5640] = 207324,
	[5641] = 207325,
	[5737] = 207335,
	[5738] = 207336,
	[5739] = 207337,
	[5740] = 207338,
	[5741] = 207339,
	[5837] = 207349,
	[5838] = 207350,
	[5839] = 207351,
	[5840] = 207352,
	[5841] = 207353,
	[5938] = 207359,
	[5939] = 207360,
	[5940] = 207361,
}

Map.TolBaradMapBlks = {
	[2731] = 400328,
	[2732] = 400334,
	[2733] = 400340,
	[2734] = 400346,
	[2735] = 400352,
	[2831] = 400329,
	[2832] = 400335,
	[2833] = 400341,
	[2834] = 400347,
	[2835] = 400353,
	[2931] = 400330,
	[2932] = 400336,
	[2933] = 400342,
	[2934] = 400348,
	[2935] = 400354,
	[3031] = 400331,
	[3032] = 400337,
	[3033] = 400343,
	[3034] = 400349,
	[3035] = 400355,
	[3131] = 400332,
	[3132] = 400338,
	[3133] = 400344,
	[3134] = 400350,
	[3135] = 400356,
}

Map.KezanMapBlks = {
	[2648] = 308609,
	[2649] = 308616,
	[2650] = 308623,
	[2651] = 308630,
	[2746] = 308596,
	[2747] = 308603,
	[2748] = 308610,
	[2749] = 308617,
	[2750] = 308624,
	[2751] = 308631,
	[2846] = 308597,
	[2847] = 308604,
	[2848] = 308611,
	[2849] = 308618,
	[2850] = 308625,
	[2851] = 308632,
	[2946] = 308598,
	[2947] = 308605,
	[2948] = 308612,
	[2949] = 308619,
	[2950] = 308626,
	[2951] = 308633,
	[3046] = 308599,
	[3047] = 308606,
	[3048] = 308613,
	[3049] = 308620,
	[3050] = 308627,
	[3051] = 308634,
	[3148] = 308614,
	[3149] = 308621,
	[3150] = 308628,
	[3151] = 308635,
}

Map.DeepholmMapBlks = {
	[2728] = 358428,
	[2729] = 358433,
	[2730] = 358438,
	[2731] = 358443,
	[2827] = 358424,
	[2828] = 358429,
	[2829] = 358434,
	[2830] = 358439,
	[2831] = 358444,
	[2832] = 358449,
	[2927] = 358425,
	[2928] = 358430,
	[2929] = 358435,
	[2930] = 358440,
	[2931] = 358445,
	[2932] = 358450,
	[3027] = 358426,
	[3028] = 358431,
	[3029] = 358436,
	[3030] = 358441,
	[3031] = 358446,
	[3032] = 358451,
	[3127] = 362428,
	[3128] = 358677,
	[3129] = 358679,
	[3130] = 358681,
	[3131] = 358683,
	[3132] = 358857,
	[3227] = 362429,
	[3228] = 358678,
	[3229] = 358680,
	[3230] = 358682,
	[3231] = 358684,
	[3232] = 358858,
	[3328] = 362433,
	[3329] = 361120,
	[3330] = 361121,
	[3331] = 361122,
}

Map.MoltenFrontMapBlks = {
	[3028] = 512517,
	[3029] = 512521,
	[3030] = 512525,
	[3031] = 514571,
	[3128] = 512518,
	[3129] = 512522,
	[3130] = 512526,
	[3131] = 514572,
	[3228] = 512519,
	[3229] = 512523,
	[3230] = 512527,
	[3231] = 514573,
	[3328] = 514558,
	[3329] = 514562,
	[3330] = 514566,
	[3331] = 514574,
}

Map.TheWanderingIsleMapBlks = {
	[2328] = 511569,
	[2329] = 511579,
	[2330] = 511589,
	[2331] = 511599,
	[2428] = 511570,
	[2429] = 511580,
	[2430] = 511590,
	[2431] = 511600,
	[2528] = 511571,
	[2529] = 511581,
	[2530] = 511591,
	[2531] = 511601,
	[2628] = 511572,
	[2629] = 511582,
	[2630] = 511592,
	[2631] = 511602,
	[2728] = 511573,
	[2729] = 511583,
	[2730] = 511593,
	[2731] = 511603,
}

Map.DarkMoonFaireBlks = {
	[1636] = 535785,
	[1637] = 535792,
	[1638] = 535794,
	[1639] = 535796,
	[1640] = 535798,
	[1641] = 535800,
	[1642] = 535802,
	[1736] = 535786,
	[1737] = 532859,
	[1738] = 532864,
	[1739] = 532869,
	[1740] = 532874,
	[1741] = 532879,
	[1742] = 535803,
	[1836] = 535787,
	[1837] = 532860,
	[1838] = 532865,
	[1839] = 532870,
	[1840] = 532875,
	[1841] = 532880,
	[1842] = 535804,
	[1936] = 535788,
	[1937] = 532861,
	[1938] = 532866,
	[1939] = 532871,
	[1940] = 532876,
	[1941] = 532881,
	[1942] = 535805,
	[2036] = 535789,
	[2037] = 532862,
	[2038] = 532867,
	[2039] = 532872,
	[2040] = 532877,
	[2041] = 532882,
	[2042] = 535806,
	[2136] = 535790,
	[2137] = 532863,
	[2138] = 532868,
	[2139] = 532873,
	[2140] = 532878,
	[2141] = 532883,
	[2142] = 535807,
	[2236] = 535791,
	[2237] = 535793,
	[2238] = 535795,
	[2239] = 535797,
	[2240] = 535799,
	[2241] = 535801,
	[2242] = 535808,
}

Map.Argus1MapBlks = {
	[2627] = 1598155,
	[2628] = 1544297,
	[2629] = 1544302,
	[2630] = 1544307,
	[2631] = 1605209,
	[2727] = 1598156,
	[2728] = 1544298,
	[2729] = 1544303,
	[2730] = 1544308,
	[2731] = 1605210,
	[2827] = 1598157,
	[2828] = 1544299,
	[2829] = 1544304,
	[2830] = 1544309,
	[2831] = 1605211,
	[2927] = 1598158,
	[2928] = 1544300,
	[2929] = 1544305,
	[2930] = 1544310,
	[2931] = 1605212,
	[3027] = 1598159,
	[3028] = 1544301,
	[3029] = 1544306,
	[3030] = 1544311,
	[3031] = 1605213,
}

Map.Argus3MapBlks = {
	[1119] = 1543434,
	[1120] = 1543440,
	[1121] = 1543446,
	[1122] = 1543452,
	[1123] = 1580764,
	[1219] = 1543435,
	[1220] = 1543441,
	[1221] = 1543447,
	[1222] = 1543453,
	[1223] = 1580765,
	[1319] = 1543436,
	[1320] = 1543442,
	[1321] = 1543448,
	[1322] = 1543454,
	[1323] = 1580766,
	[1419] = 1543437,
	[1420] = 1543443,
	[1421] = 1543449,
	[1422] = 1543455,
	[1423] = 1580767,
	[1519] = 1580758,
	[1520] = 1580759,
	[1521] = 1580760,
	[1522] = 1580761,
	[1523] = 1580768,
}

Map.Argus2MapBlks = {
	[1135] = 1598120,
	[1136] = 1598126,
	[1137] = 1598132,
	[1138] = 1598138,
	[1139] = 1598144,
	[1235] = 1598121,
	[1236] = 1598127,
	[1237] = 1598133,
	[1238] = 1598139,
	[1239] = 1598145,
	[1335] = 1598122,
	[1336] = 1598128,
	[1337] = 1598134,
	[1338] = 1598140,
	[1339] = 1598146,
	[1435] = 1598123,
	[1436] = 1598129,
	[1437] = 1598135,
	[1438] = 1598141,
	[1439] = 1598147,
	[1535] = 1598124,
	[1536] = 1598130,
	[1537] = 1598136,
	[1538] = 1598142,
	[1539] = 1598148,
	[1635] = 1598160,
	[1636] = 1598161,
	[1637] = 1598162,
	[1638] = 1598163,
	[1639] = 1598164,
}

Map.NazjatarBlks = {
	[2824] = 1573161,
	[2924] = 1573162,
	[3024] = 1573163,
	[3124] = 1573164,
	[3224] = 1573165,
	[3324] = 1573166,
	[3424] = 1573167,
	[3524] = 1573168,
	[2825] = 1573169,
	[2925] = 1573170,
	[3025] = 1573171,
	[3125] = 1573172,
	[3225] = 1573173,
	[3325] = 1573174,
	[3425] = 1573175,
	[3525] = 1573176,
	[2826] = 1573177,
	[2926] = 1573178,
	[3026] = 1573179,
	[3126] = 1573180,
	[3226] = 1573181,
	[3326] = 1573182,
	[3426] = 1573183,
	[3526] = 1573184,
	[2827] = 1573185,
	[2927] = 1573186,
	[3027] = 1573187,
	[3127] = 1573188,
	[3227] = 1573189,
	[3327] = 1573190,
	[3427] = 1573191,
	[3527] = 1573192,
	[2828] = 1573193,
	[2928] = 1573194,
	[3028] = 1573195,
	[3128] = 1573196,
	[3228] = 1573197,
	[3328] = 1573198,
	[3428] = 1573199,
	[3528] = 1573200,
	[2829] = 1573201,
	[2929] = 1573202,
	[3029] = 1573203,
	[3129] = 1573204,
	[3229] = 1573205,
	[3329] = 1573206,
	[3429] = 1573207,
	[3529] = 1573208,
	[2830] = 1573209,
	[2930] = 1573210,
	[3030] = 1573211,
	[3130] = 1573212,
	[3230] = 1573213,
	[3330] = 1573214,
	[3430] = 1573215,
	[3530] = 1573216,
	[2831] = 1573217,
	[2931] = 1573218,
	[3031] = 1573219,
	[3131] = 1573220,
	[3231] = 1573221,
	[3331] = 1573222,
	[3431] = 1573223,
	[3531] = 1573224,
}

Map.NPEBlks = {
	[2038] = 3541361,
	[2039] = 3541367,
	[2040] = 3541377,
	[2041] = 3541379,
	[2042] = 3541483,
	[2043] = 3541487,
	[2044] = 3541491,
	[2045] = 3541501,
	[2046] = 3541601,
	[2047] = 3541605,
	[2048] = 3541611,
	[2049] = 3541619,
	[2050] = 3541723,
	[2051] = 3541727,
	[2052] = 3541733,
	[2053] = 3541737,
	[2054] = 3541845,
	[2055] = 3541849,
	[2056] = 3541853,
	[2057] = 3541861,
	[2058] = 3541961,
	[2059] = 3541967,
	[2138] = 3541365,
	[2139] = 3541369,
	[2140] = 3541375,
	[2141] = 3541381,
	[2142] = 3541481,
	[2143] = 3541489,
	[2144] = 3541493,
	[2145] = 3541499,
	[2146] = 3541607,
	[2147] = 3541609,
	[2148] = 3541615,
	[2149] = 3541621,
	[2150] = 3541721,
	[2151] = 3541729,
	[2152] = 3541735,
	[2153] = 3541739,
	[2154] = 3541841,
	[2155] = 3541847,
	[2156] = 3541855,
	[2157] = 3541859,
	[2158] = 3541965,
	[2159] = 3541969,
	[2238] = 3541363,
	[2239] = 3541371,
	[2240] = 3541373,
	[2241] = 3541383,
	[2242] = 3541485,
	[2243] = 3541495,
	[2244] = 3541497,
	[2245] = 3541503,
	[2246] = 3541603,
	[2247] = 3541613,
	[2248] = 3541617,
	[2249] = 3541623,
	[2250] = 3541725,
	[2251] = 3541731,
	[2252] = 3541741,
	[2253] = 3541743,
	[2254] = 3541843,
	[2255] = 3541851,
	[2256] = 3541857,
	[2257] = 3541863,
	[2258] = 3541963,
	[2259] = 3541971,
	[2338] = 3541435,
	[2339] = 3541437,
	[2340] = 3541445,
	[2341] = 3541441,
	[2342] = 3541553,
	[2343] = 3541557,
	[2344] = 3541561,
	[2345] = 3541565,
	[2346] = 3541675,
	[2347] = 3541673,
	[2348] = 3541681,
	[2349] = 3541685,
	[2350] = 3541797,
	[2351] = 3541795,
	[2352] = 3541799,
	[2353] = 3541807,
	[2354] = 3541915,
	[2355] = 3541917,
	[2356] = 3541921,
	[2357] = 3541925,
	[2358] = 3541999,
	[2359] = 3542001,
	[2438] = 3541433,
	[2439] = 3541439,
	[2440] = 3541443,
	[2441] = 3541447,
	[2442] = 3541555,
	[2443] = 3541559,
	[2444] = 3541563,
	[2445] = 3541567,
	[2446] = 3541677,
	[2447] = 3541679,
	[2448] = 3541683,
	[2449] = 3541687,
	[2450] = 3541793,
	[2451] = 3541803,
	[2452] = 3541801,
	[2453] = 3541805,
	[2454] = 3541913,
	[2455] = 3541919,
	[2456] = 3541923,
	[2457] = 3541927,
	[2458] = 3541997,
	[2459] = 3542003,
	[2508] = 3206412,
	[2509] = 3206420,
	[2510] = 3206422,
	[2511] = 3206428,
	[2512] = 3206560,
	[2513] = 3206558,
	[2514] = 3206564,
	[2515] = 3206572,
	[2516] = 3206698,
	[2517] = 3206704,
	[2518] = 3206710,
	[2519] = 3206716,
	[2520] = 3206849,
	[2521] = 3206855,
	[2522] = 3206861,
	[2523] = 3206867,
	[2524] = 3206993,
	[2525] = 3206999,
	[2526] = 3234045,
	[2527] = 3234053,
	[2528] = 3234057,
	[2529] = 3234063,
	[2530] = 3234191,
	[2531] = 3234197,
	[2532] = 3234201,
	[2533] = 3234209,
	[2534] = 3234333,
	[2535] = 3234343,
	[2536] = 3234345,
	[2537] = 3234351,
	[2538] = 3494516,
	[2539] = 3494522,
	[2540] = 3494530,
	[2541] = 3494538,
	[2542] = 3495020,
	[2543] = 3495024,
	[2544] = 3495034,
	[2545] = 3495046,
	[2546] = 3495522,
	[2547] = 3495530,
	[2548] = 3495538,
	[2549] = 3495546,
	[2550] = 3496026,
	[2551] = 3496032,
	[2552] = 3496042,
	[2553] = 3496052,
	[2554] = 3496530,
	[2555] = 3496536,
	[2556] = 3496546,
	[2557] = 3496554,
	[2558] = 3497041,
	[2559] = 3497045,
	[2608] = 3206414,
	[2609] = 3206416,
	[2610] = 3206426,
	[2611] = 3206430,
	[2612] = 3206556,
	[2613] = 3206562,
	[2614] = 3206570,
	[2615] = 3206574,
	[2616] = 3206700,
	[2617] = 3206706,
	[2618] = 3206712,
	[2619] = 3206718,
	[2620] = 3206851,
	[2621] = 3206857,
	[2622] = 3206863,
	[2623] = 3206869,
	[2624] = 3206995,
	[2625] = 3207001,
	[2626] = 3234047,
	[2627] = 3234051,
	[2628] = 3234061,
	[2629] = 3234065,
	[2630] = 3234189,
	[2631] = 3234195,
	[2632] = 3234203,
	[2633] = 3234207,
	[2634] = 3234335,
	[2635] = 3234339,
	[2636] = 3234347,
	[2637] = 3234353,
	[2638] = 3494514,
	[2639] = 3494524,
	[2640] = 3494532,
	[2641] = 3494542,
	[2642] = 3495022,
	[2643] = 3495028,
	[2644] = 3495040,
	[2645] = 3495042,
	[2646] = 3495526,
	[2647] = 3495532,
	[2648] = 3495540,
	[2649] = 3495548,
	[2650] = 3496028,
	[2651] = 3496036,
	[2652] = 3496046,
	[2653] = 3496050,
	[2654] = 3496534,
	[2655] = 3496540,
	[2656] = 3496548,
	[2657] = 3496558,
	[2658] = 3497039,
	[2659] = 3497049,
	[2708] = 3206410,
	[2709] = 3206418,
	[2710] = 3206424,
	[2711] = 3206432,
	[2712] = 3206554,
	[2713] = 3206566,
	[2714] = 3206568,
	[2715] = 3206576,
	[2716] = 3206702,
	[2717] = 3206708,
	[2718] = 3206714,
	[2719] = 3206720,
	[2720] = 3206853,
	[2721] = 3206859,
	[2722] = 3206865,
	[2723] = 3206871,
	[2724] = 3206997,
	[2725] = 3207003,
	[2726] = 3234049,
	[2727] = 3234055,
	[2728] = 3234059,
	[2729] = 3234067,
	[2730] = 3234193,
	[2731] = 3234199,
	[2732] = 3234205,
	[2733] = 3234211,
	[2734] = 3234337,
	[2735] = 3234341,
	[2736] = 3234349,
	[2737] = 3234355,
	[2738] = 3494518,
	[2739] = 3494526,
	[2740] = 3494534,
	[2741] = 3494540,
	[2742] = 3495018,
	[2743] = 3495030,
	[2744] = 3495036,
	[2745] = 3495044,
	[2746] = 3495524,
	[2747] = 3495534,
	[2748] = 3495542,
	[2749] = 3495550,
	[2750] = 3496030,
	[2751] = 3496038,
	[2752] = 3496044,
	[2753] = 3496054,
	[2754] = 3496532,
	[2755] = 3496542,
	[2756] = 3496550,
	[2757] = 3496556,
	[2758] = 3497043,
	[2759] = 3497051,
	[2808] = 3206486,
	[2809] = 3206488,
	[2810] = 3206494,
	[2811] = 3206500,
	[2812] = 3206626,
	[2813] = 3206632,
	[2814] = 3206636,
	[2815] = 3206644,
	[2816] = 3206773,
	[2817] = 3206781,
	[2818] = 3206785,
	[2819] = 3206791,
	[2820] = 3206921,
	[2821] = 3206927,
	[2822] = 3206929,
	[2823] = 3206937,
	[2824] = 3207029,
	[2825] = 3207037,
	[2826] = 3234117,
	[2827] = 3234123,
	[2828] = 3234127,
	[2829] = 3234133,
	[2830] = 3234263,
	[2831] = 3234267,
	[2832] = 3234273,
	[2833] = 3234277,
	[2834] = 3234405,
	[2835] = 3234409,
	[2836] = 3234417,
	[2837] = 3234421,
	[2838] = 3494520,
	[2839] = 3494528,
	[2840] = 3494536,
	[2841] = 3494544,
	[2842] = 3495026,
	[2843] = 3495032,
	[2844] = 3495038,
	[2845] = 3495048,
	[2846] = 3495528,
	[2847] = 3495536,
	[2848] = 3495544,
	[2849] = 3495552,
	[2850] = 3496034,
	[2851] = 3496040,
	[2852] = 3496048,
	[2853] = 3496056,
	[2854] = 3496538,
	[2855] = 3496544,
	[2856] = 3496552,
	[2857] = 3496560,
	[2858] = 3497047,
	[2859] = 3497053,
	[2908] = 3206482,
	[2909] = 3206490,
	[2910] = 3206496,
	[2911] = 3206502,
	[2912] = 3206630,
	[2913] = 3206638,
	[2914] = 3206640,
	[2915] = 3206646,
	[2916] = 3206775,
	[2917] = 3206787,
	[2918] = 3206795,
	[2919] = 3206797,
	[2920] = 3206925,
	[2921] = 3206931,
	[2922] = 3206935,
	[2923] = 3206939,
	[2924] = 3207031,
	[2925] = 3207039,
	[2926] = 3234119,
	[2927] = 3234125,
	[2928] = 3234129,
	[2929] = 3234137,
	[2930] = 3234261,
	[2931] = 3234271,
	[2932] = 3234275,
	[2933] = 3234283,
	[2934] = 3234411,
	[2935] = 3234415,
	[2936] = 3234423,
	[2937] = 3234425,
	[2938] = 3494614,
	[2939] = 3494616,
	[2940] = 3494626,
	[2941] = 3494634,
	[2942] = 3495118,
	[2943] = 3495122,
	[2944] = 3495126,
	[2945] = 3495140,
	[2946] = 3495618,
	[2947] = 3495626,
	[2948] = 3495634,
	[2949] = 3495642,
	[2950] = 3496124,
	[2951] = 3496128,
	[2952] = 3496138,
	[2953] = 3496146,
	[2954] = 3496631,
	[2955] = 3496639,
	[2956] = 3496647,
	[2957] = 3496655,
	[2958] = 3497089,
	[2959] = 3497093,
	[3008] = 3206484,
	[3009] = 3206492,
	[3010] = 3206498,
	[3011] = 3206504,
	[3012] = 3206628,
	[3013] = 3206634,
	[3014] = 3206642,
	[3015] = 3206648,
	[3016] = 3206777,
	[3017] = 3206789,
	[3018] = 3206793,
	[3019] = 3206807,
	[3020] = 3206923,
	[3021] = 3206933,
	[3022] = 3206955,
	[3023] = 3206943,
	[3024] = 3207033,
	[3025] = 3207035,
	[3026] = 3234121,
	[3027] = 3234131,
	[3028] = 3234135,
	[3029] = 3234139,
	[3030] = 3234265,
	[3031] = 3234269,
	[3032] = 3234279,
	[3033] = 3234281,
	[3034] = 3234407,
	[3035] = 3234413,
	[3036] = 3234419,
	[3037] = 3234427,
	[3038] = 3494610,
	[3039] = 3494620,
	[3040] = 3494630,
	[3041] = 3494636,
	[3042] = 3495114,
	[3043] = 3495124,
	[3044] = 3495134,
	[3045] = 3495138,
	[3046] = 3495620,
	[3047] = 3495628,
	[3048] = 3495638,
	[3049] = 3495644,
	[3050] = 3496122,
	[3051] = 3496130,
	[3052] = 3496140,
	[3053] = 3496148,
	[3054] = 3496635,
	[3055] = 3496641,
	[3056] = 3496649,
	[3057] = 3496657,
	[3058] = 3497087,
	[3059] = 3497097,
	[3108] = 3197588,
	[3109] = 3197596,
	[3110] = 3197604,
	[3111] = 3197860,
	[3112] = 3197864,
	[3113] = 3156741,
	[3114] = 3156751,
	[3115] = 3156755,
	[3116] = 3157011,
	[3117] = 3157019,
	[3118] = 3157027,
	[3119] = 3157283,
	[3120] = 3157291,
	[3121] = 3157297,
	[3122] = 3156340,
	[3123] = 3156344,
	[3124] = 3156352,
	[3125] = 2626044,
	[3126] = 2626054,
	[3127] = 2626064,
	[3128] = 2626074,
	[3129] = 2626084,
	[3130] = 2626094,
	[3131] = 2626104,
	[3132] = 2626114,
	[3133] = 2626124,
	[3134] = 2626134,
	[3135] = 3199115,
	[3136] = 3199123,
	[3137] = 3199131,
	[3138] = 3494612,
	[3139] = 3494622,
	[3140] = 3494628,
	[3141] = 3494638,
	[3142] = 3495116,
	[3143] = 3495130,
	[3144] = 3495132,
	[3145] = 3495142,
	[3146] = 3495622,
	[3147] = 3495630,
	[3148] = 3495636,
	[3149] = 3495646,
	[3150] = 3496126,
	[3151] = 3496134,
	[3152] = 3496142,
	[3153] = 3496150,
	[3154] = 3496633,
	[3155] = 3496643,
	[3156] = 3496651,
	[3157] = 3496659,
	[3158] = 3497091,
	[3159] = 3497099,
	[3208] = 3197590,
	[3209] = 3197598,
	[3210] = 3197606,
	[3211] = 3197862,
	[3212] = 3197868,
	[3213] = 3156743,
	[3214] = 3156749,
	[3215] = 3156759,
	[3216] = 3157013,
	[3217] = 3157021,
	[3218] = 3157029,
	[3219] = 3157281,
	[3220] = 3157287,
	[3221] = 3157299,
	[3222] = 3156338,
	[3223] = 3156346,
	[3224] = 3156354,
	[3225] = 2626045,
	[3226] = 2626055,
	[3227] = 2626065,
	[3228] = 2626075,
	[3229] = 2626085,
	[3230] = 2626095,
	[3231] = 2626105,
	[3232] = 2626115,
	[3233] = 2626125,
	[3234] = 2626135,
	[3235] = 3199119,
	[3236] = 3199125,
	[3237] = 3199133,
	[3238] = 3494618,
	[3239] = 3494624,
	[3240] = 3494632,
	[3241] = 3494640,
	[3242] = 3495120,
	[3243] = 3495128,
	[3244] = 3495136,
	[3245] = 3495144,
	[3246] = 3495624,
	[3247] = 3495632,
	[3248] = 3495640,
	[3249] = 3495648,
	[3250] = 3496132,
	[3251] = 3496136,
	[3252] = 3496144,
	[3253] = 3496152,
	[3254] = 3496637,
	[3255] = 3496645,
	[3256] = 3496653,
	[3257] = 3496661,
	[3258] = 3497095,
	[3259] = 3497101,
	[3308] = 3197592,
	[3309] = 3197602,
	[3310] = 3197608,
	[3311] = 3197858,
	[3312] = 3197872,
	[3313] = 3156745,
	[3314] = 3156757,
	[3315] = 3156761,
	[3316] = 3157015,
	[3317] = 3157023,
	[3318] = 3157031,
	[3319] = 3157285,
	[3320] = 3157293,
	[3321] = 3157303,
	[3322] = 3156336,
	[3323] = 3156348,
	[3324] = 3156356,
	[3325] = 2626046,
	[3326] = 2626056,
	[3327] = 2626066,
	[3328] = 2626076,
	[3329] = 2626086,
	[3330] = 2626096,
	[3331] = 2626106,
	[3332] = 2626116,
	[3333] = 2626126,
	[3334] = 2626136,
	[3335] = 3199117,
	[3336] = 3199127,
	[3337] = 3199135,
	[3338] = 3494708,
	[3339] = 3494714,
	[3340] = 3494722,
	[3341] = 3494732,
	[3342] = 3495210,
	[3343] = 3495218,
	[3344] = 3495226,
	[3345] = 3495230,
	[3346] = 3495714,
	[3347] = 3495724,
	[3348] = 3495728,
	[3349] = 3495738,
	[3350] = 3496218,
	[3351] = 3496226,
	[3352] = 3496232,
	[3353] = 3496242,
	[3354] = 3496727,
	[3355] = 3496735,
	[3356] = 3496743,
	[3357] = 3496751,
	[3358] = 3497139,
	[3359] = 3497141,
	[3408] = 3197594,
	[3409] = 3197600,
	[3410] = 3197610,
	[3411] = 3197866,
	[3412] = 3197870,
	[3413] = 3156747,
	[3414] = 3156753,
	[3415] = 3156763,
	[3416] = 3157017,
	[3417] = 3157025,
	[3418] = 3157033,
	[3419] = 3157289,
	[3420] = 3157295,
	[3421] = 3157301,
	[3422] = 3156342,
	[3423] = 3156350,
	[3424] = 3156358,
	[3425] = 2626047,
	[3426] = 2626057,
	[3427] = 2626067,
	[3428] = 2626077,
	[3429] = 2626087,
	[3430] = 2626097,
	[3431] = 2626107,
	[3432] = 2626117,
	[3433] = 2626127,
	[3434] = 2626137,
	[3435] = 3199121,
	[3436] = 3199129,
	[3437] = 3199137,
	[3438] = 3494710,
	[3439] = 3494716,
	[3440] = 3494724,
	[3441] = 3494730,
	[3442] = 3495214,
	[3443] = 3495222,
	[3444] = 3495228,
	[3445] = 3495236,
	[3446] = 3495716,
	[3447] = 3495722,
	[3448] = 3495732,
	[3449] = 3495740,
	[3450] = 3496222,
	[3451] = 3496228,
	[3452] = 3496236,
	[3453] = 3496244,
	[3454] = 3496731,
	[3455] = 3496737,
	[3456] = 3496745,
	[3457] = 3496753,
	[3458] = 3497135,
	[3459] = 3497145,
	[3508] = 3197662,
	[3509] = 3197666,
	[3510] = 3197676,
	[3511] = 3197910,
	[3512] = 3197912,
	[3513] = 3156813,
	[3514] = 3156821,
	[3515] = 3156829,
	[3516] = 3157083,
	[3517] = 3157091,
	[3518] = 3157099,
	[3519] = 3157353,
	[3520] = 3157359,
	[3521] = 3157367,
	[3522] = 3156410,
	[3523] = 3156416,
	[3524] = 3156424,
	[3525] = 2626048,
	[3526] = 2626058,
	[3527] = 2626068,
	[3528] = 2626078,
	[3529] = 2626088,
	[3530] = 2626098,
	[3531] = 2626108,
	[3532] = 2626118,
	[3533] = 2626128,
	[3534] = 2626138,
	[3535] = 3199187,
	[3536] = 3199195,
	[3537] = 3199203,
	[3538] = 3494706,
	[3539] = 3494718,
	[3540] = 3494726,
	[3541] = 3494734,
	[3542] = 3495212,
	[3543] = 3495220,
	[3544] = 3495234,
	[3545] = 3495240,
	[3546] = 3495718,
	[3547] = 3495726,
	[3548] = 3495736,
	[3549] = 3495742,
	[3550] = 3496220,
	[3551] = 3496230,
	[3552] = 3496238,
	[3553] = 3496248,
	[3554] = 3496729,
	[3555] = 3496739,
	[3556] = 3496747,
	[3557] = 3496755,
	[3558] = 3497137,
	[3559] = 3497147,
	[3608] = 3197660,
	[3609] = 3197668,
	[3610] = 3197678,
	[3611] = 3197906,
	[3612] = 3197914,
	[3613] = 3156817,
	[3614] = 3156825,
	[3615] = 3156833,
	[3616] = 3157085,
	[3617] = 3157093,
	[3618] = 3157103,
	[3619] = 3157357,
	[3620] = 3157363,
	[3621] = 3157371,
	[3622] = 3156408,
	[3623] = 3156418,
	[3624] = 3156426,
	[3625] = 2626049,
	[3626] = 2626059,
	[3627] = 2626069,
	[3628] = 2626079,
	[3629] = 2626089,
	[3630] = 2626099,
	[3631] = 2626109,
	[3632] = 2626119,
	[3633] = 2626129,
	[3634] = 2626139,
	[3635] = 3199191,
	[3636] = 3199199,
	[3637] = 3199205,
	[3638] = 3494712,
	[3639] = 3494720,
	[3640] = 3494728,
	[3641] = 3494736,
	[3642] = 3495216,
	[3643] = 3495224,
	[3644] = 3495232,
	[3645] = 3495238,
	[3646] = 3495720,
	[3647] = 3495730,
	[3648] = 3495734,
	[3649] = 3495744,
	[3650] = 3496224,
	[3651] = 3496234,
	[3652] = 3496240,
	[3653] = 3496246,
	[3654] = 3496733,
	[3655] = 3496741,
	[3656] = 3496749,
	[3657] = 3496757,
	[3658] = 3497143,
	[3659] = 3497149,
	[3708] = 3197664,
	[3709] = 3197674,
	[3710] = 3197680,
	[3711] = 3197908,
	[3712] = 3197918,
	[3713] = 3156815,
	[3714] = 3156823,
	[3715] = 3156831,
	[3716] = 3157087,
	[3717] = 3157095,
	[3718] = 3157101,
	[3719] = 3157355,
	[3720] = 3157369,
	[3721] = 3157373,
	[3722] = 3156412,
	[3723] = 3156420,
	[3724] = 3156430,
	[3725] = 2626050,
	[3726] = 2626060,
	[3727] = 2626070,
	[3728] = 2626080,
	[3729] = 2626090,
	[3730] = 2626100,
	[3731] = 2626110,
	[3732] = 2626120,
	[3733] = 2626130,
	[3734] = 2626140,
	[3735] = 3199189,
	[3736] = 3199197,
	[3737] = 3199207,
	[3738] = 3494804,
	[3739] = 3494812,
	[3740] = 3494818,
	[3741] = 3494826,
	[3742] = 3495308,
	[3743] = 3495314,
	[3744] = 3495322,
	[3745] = 3495330,
	[3746] = 3495814,
	[3747] = 3495818,
	[3748] = 3495822,
	[3749] = 3495834,
	[3750] = 3496318,
	[3751] = 3496324,
	[3752] = 3496330,
	[3753] = 3496338,
	[3754] = 3496823,
	[3755] = 3496831,
	[3756] = 3496839,
	[3757] = 3496849,
	[3758] = 3497185,
	[3759] = 3497191,
	[3808] = 3197670,
	[3809] = 3197672,
	[3810] = 3197682,
	[3811] = 3197916,
	[3812] = 3197920,
	[3813] = 3156819,
	[3814] = 3156827,
	[3815] = 3156835,
	[3816] = 3157089,
	[3817] = 3157097,
	[3818] = 3157105,
	[3819] = 3157361,
	[3820] = 3157365,
	[3821] = 3157375,
	[3822] = 3156414,
	[3823] = 3156422,
	[3824] = 3156428,
	[3825] = 2626051,
	[3826] = 2626061,
	[3827] = 2626071,
	[3828] = 2626081,
	[3829] = 2626091,
	[3830] = 2626101,
	[3831] = 2626111,
	[3832] = 2626121,
	[3833] = 2626131,
	[3834] = 2626141,
	[3835] = 3199193,
	[3836] = 3199201,
	[3837] = 3199209,
	[3838] = 3494806,
	[3839] = 3494808,
	[3840] = 3494822,
	[3841] = 3494828,
	[3842] = 3495310,
	[3843] = 3495316,
	[3844] = 3495324,
	[3845] = 3495332,
	[3846] = 3495812,
	[3847] = 3495816,
	[3848] = 3495828,
	[3849] = 3495836,
	[3850] = 3496316,
	[3851] = 3496322,
	[3852] = 3496332,
	[3853] = 3496340,
	[3854] = 3496827,
	[3855] = 3496833,
	[3856] = 3496841,
	[3857] = 3496847,
	[3858] = 3497183,
	[3859] = 3497193,
	[3908] = 3197732,
	[3909] = 3197740,
	[3910] = 3197746,
	[3911] = 3197954,
	[3912] = 3197962,
	[3913] = 3156885,
	[3914] = 3156895,
	[3915] = 3156901,
	[3916] = 3157155,
	[3917] = 3157167,
	[3918] = 3157171,
	[3919] = 3157425,
	[3920] = 3157433,
	[3921] = 3157443,
	[3922] = 3156484,
	[3923] = 3156486,
	[3924] = 3156494,
	[3925] = 2626052,
	[3926] = 2626062,
	[3927] = 2626072,
	[3928] = 2626082,
	[3929] = 2626092,
	[3930] = 2626102,
	[3931] = 2626112,
	[3932] = 2626122,
	[3933] = 2626132,
	[3934] = 2626142,
	[3935] = 3199259,
	[3936] = 3199267,
	[3937] = 3199275,
	[3938] = 3494802,
	[3939] = 3494814,
	[3940] = 3494820,
	[3941] = 3494832,
	[3942] = 3495306,
	[3943] = 3495318,
	[3944] = 3495328,
	[3945] = 3495334,
	[3946] = 3495810,
	[3947] = 3495824,
	[3948] = 3495830,
	[3949] = 3495838,
	[3950] = 3496314,
	[3951] = 3496326,
	[3952] = 3496334,
	[3953] = 3496342,
	[3954] = 3496825,
	[3955] = 3496835,
	[3956] = 3496843,
	[3957] = 3496851,
	[3958] = 3497187,
	[3959] = 3497195,
	[4008] = 3197734,
	[4009] = 3197742,
	[4010] = 3197750,
	[4011] = 3197958,
	[4012] = 3197964,
	[4013] = 3156887,
	[4014] = 3156893,
	[4015] = 3156899,
	[4016] = 3157161,
	[4017] = 3157163,
	[4018] = 3157173,
	[4019] = 3157429,
	[4020] = 3157435,
	[4021] = 3157441,
	[4022] = 3156482,
	[4023] = 3156488,
	[4024] = 3156498,
	[4025] = 2626053,
	[4026] = 2626063,
	[4027] = 2626073,
	[4028] = 2626083,
	[4029] = 2626093,
	[4030] = 2626103,
	[4031] = 2626113,
	[4032] = 2626123,
	[4033] = 2626133,
	[4034] = 2626143,
	[4035] = 3199261,
	[4036] = 3199269,
	[4037] = 3199277,
	[4038] = 3494810,
	[4039] = 3494816,
	[4040] = 3494824,
	[4041] = 3494830,
	[4042] = 3495312,
	[4043] = 3495320,
	[4044] = 3495326,
	[4045] = 3495336,
	[4046] = 3495820,
	[4047] = 3495826,
	[4048] = 3495832,
	[4049] = 3495840,
	[4050] = 3496320,
	[4051] = 3496328,
	[4052] = 3496336,
	[4053] = 3496344,
	[4054] = 3496829,
	[4055] = 3496837,
	[4056] = 3496845,
	[4057] = 3496853,
	[4058] = 3497189,
	[4059] = 3497197,
	[4108] = 3197736,
	[4109] = 3197744,
	[4110] = 3197754,
	[4111] = 3197956,
	[4112] = 3197966,
	[4113] = 3156889,
	[4114] = 3156897,
	[4115] = 3156905,
	[4116] = 3157157,
	[4117] = 3157165,
	[4118] = 3157175,
	[4119] = 3157427,
	[4120] = 3157437,
	[4121] = 3157445,
	[4122] = 3156480,
	[4123] = 3156496,
	[4124] = 3156500,
	[4125] = 2829444,
	[4126] = 2829445,
	[4127] = 2829446,
	[4128] = 2829447,
	[4129] = 2829448,
	[4130] = 2829449,
	[4131] = 2829450,
	[4132] = 2829451,
	[4133] = 2829452,
	[4134] = 2829453,
	[4135] = 3199263,
	[4136] = 3199271,
	[4137] = 3199279,
	[4138] = 3494900,
	[4139] = 3494906,
	[4140] = 3494914,
	[4141] = 3494922,
	[4142] = 3495404,
	[4143] = 3495408,
	[4144] = 3495418,
	[4145] = 3495426,
	[4146] = 3495906,
	[4147] = 3495914,
	[4148] = 3495922,
	[4149] = 3495930,
	[4150] = 3496410,
	[4151] = 3496416,
	[4152] = 3496426,
	[4153] = 3496434,
	[4154] = 3496921,
	[4155] = 3496925,
	[4156] = 3496935,
	[4157] = 3496943,
	[4158] = 3497231,
	[4159] = 3497239,
	[4208] = 3197738,
	[4209] = 3197748,
	[4210] = 3197752,
	[4211] = 3197960,
	[4212] = 3197968,
	[4213] = 3156891,
	[4214] = 3156903,
	[4215] = 3156907,
	[4216] = 3157159,
	[4217] = 3157169,
	[4218] = 3157177,
	[4219] = 3157431,
	[4220] = 3157439,
	[4221] = 3157447,
	[4222] = 3156490,
	[4223] = 3156492,
	[4224] = 3156502,
	[4225] = 3156055,
	[4226] = 3156057,
	[4227] = 3156067,
	[4228] = 3156077,
	[4229] = 3156147,
	[4230] = 3156155,
	[4231] = 3156163,
	[4232] = 3156171,
	[4233] = 3156243,
	[4234] = 3156249,
	[4235] = 3199265,
	[4236] = 3199273,
	[4237] = 3199281,
	[4238] = 3494898,
	[4239] = 3494908,
	[4240] = 3494916,
	[4241] = 3494924,
	[4242] = 3495402,
	[4243] = 3495412,
	[4244] = 3495420,
	[4245] = 3495430,
	[4246] = 3495908,
	[4247] = 3495916,
	[4248] = 3495924,
	[4249] = 3495932,
	[4250] = 3496412,
	[4251] = 3496420,
	[4252] = 3496428,
	[4253] = 3496436,
	[4254] = 3496919,
	[4255] = 3496929,
	[4256] = 3496937,
	[4257] = 3496945,
	[4258] = 3497233,
	[4259] = 3497241,
	[4308] = 3197808,
	[4309] = 3197810,
	[4310] = 3197816,
	[4311] = 3198004,
	[4312] = 3198008,
	[4313] = 3156957,
	[4314] = 3156965,
	[4315] = 3156969,
	[4316] = 3157229,
	[4317] = 3157235,
	[4318] = 3157239,
	[4319] = 3157497,
	[4320] = 3157503,
	[4321] = 3157509,
	[4322] = 3156552,
	[4323] = 3156558,
	[4324] = 3156564,
	[4325] = 3156053,
	[4326] = 3156059,
	[4327] = 3156069,
	[4328] = 3156075,
	[4329] = 3156151,
	[4330] = 3156157,
	[4331] = 3156165,
	[4332] = 3156173,
	[4333] = 3156247,
	[4334] = 3156251,
	[4335] = 3199331,
	[4336] = 3199337,
	[4337] = 3199343,
	[4338] = 3494902,
	[4339] = 3494910,
	[4340] = 3494920,
	[4341] = 3494926,
	[4342] = 3495406,
	[4343] = 3495414,
	[4344] = 3495424,
	[4345] = 3495428,
	[4346] = 3495910,
	[4347] = 3495918,
	[4348] = 3495926,
	[4349] = 3495934,
	[4350] = 3496414,
	[4351] = 3496422,
	[4352] = 3496430,
	[4353] = 3496440,
	[4354] = 3496923,
	[4355] = 3496933,
	[4356] = 3496941,
	[4357] = 3496947,
	[4358] = 3497235,
	[4359] = 3497243,
	[4408] = 3197804,
	[4409] = 3197812,
	[4410] = 3197820,
	[4411] = 3198002,
	[4412] = 3198010,
	[4413] = 3156961,
	[4414] = 3156963,
	[4415] = 3156971,
	[4416] = 3157231,
	[4417] = 3157233,
	[4418] = 3157241,
	[4419] = 3157499,
	[4420] = 3157507,
	[4421] = 3157511,
	[4422] = 3156554,
	[4423] = 3156560,
	[4424] = 3156566,
	[4425] = 3156051,
	[4426] = 3156063,
	[4427] = 3156071,
	[4428] = 3156079,
	[4429] = 3156149,
	[4430] = 3156159,
	[4431] = 3156169,
	[4432] = 3156175,
	[4433] = 3156245,
	[4434] = 3156255,
	[4435] = 3199335,
	[4436] = 3199341,
	[4437] = 3199345,
	[4438] = 3494904,
	[4439] = 3494912,
	[4440] = 3494918,
	[4441] = 3494928,
	[4442] = 3495410,
	[4443] = 3495416,
	[4444] = 3495422,
	[4445] = 3495432,
	[4446] = 3495912,
	[4447] = 3495920,
	[4448] = 3495928,
	[4449] = 3495936,
	[4450] = 3496418,
	[4451] = 3496424,
	[4452] = 3496432,
	[4453] = 3496438,
	[4454] = 3496927,
	[4455] = 3496931,
	[4456] = 3496939,
	[4457] = 3496949,
	[4458] = 3497237,
	[4459] = 3497245,
	[4508] = 3197806,
	[4509] = 3197814,
	[4510] = 3197818,
	[4511] = 3198006,
	[4512] = 3198012,
	[4513] = 3156959,
	[4514] = 3156967,
	[4515] = 3156973,
	[4516] = 3157227,
	[4517] = 3157237,
	[4518] = 3157243,
	[4519] = 3157501,
	[4520] = 3157505,
	[4521] = 3157513,
	[4522] = 3156556,
	[4523] = 3156562,
	[4524] = 3156568,
	[4525] = 3156061,
	[4526] = 3156065,
	[4527] = 3156073,
	[4528] = 3156081,
	[4529] = 3156153,
	[4530] = 3156161,
	[4531] = 3156167,
	[4532] = 3156177,
	[4533] = 3156253,
	[4534] = 3156257,
	[4535] = 3199333,
	[4536] = 3199339,
	[4537] = 3199347,
	[4538] = 3494996,
	[4539] = 3494994,
	[4540] = 3494998,
	[4541] = 3495000,
	[4542] = 3495502,
	[4543] = 3495498,
	[4544] = 3495500,
	[4545] = 3495504,
	[4546] = 3496006,
	[4547] = 3496002,
	[4548] = 3496004,
	[4549] = 3496008,
	[4550] = 3496506,
	[4551] = 3496510,
	[4552] = 3496508,
	[4553] = 3496512,
	[4554] = 3497015,
	[4555] = 3497019,
	[4556] = 3497017,
	[4557] = 3497021,
	[4558] = 3497279,
	[4559] = 3497281,
}

Map.MiniMapBlks = {
	[1] = {
		Map.KalMapBlks,
		1908,
		19, 8,
		 Map.MapWorldInfo[13].X + Map.MapInfo[1].X + 2025.753921875 + 222, Map.MapWorldInfo[13].Y + Map.MapInfo[1].Y + -0.476021875 - 324,
		"World\\Minimaps\\Kalimdor"
	},
	[2] = {
		Map.EkMapBlks,
		2420,
		24, 20,
		Map.MapWorldInfo[14].X + Map.MapInfo[2].X -1080, Map.MapWorldInfo[14].Y + Map.MapInfo[2].Y - 1308,
		"World\\Minimaps\\Azeroth"
	},
	[3] = {
		Map.OLMapBlks,
		1221,
		12, 21,
		Map.MapWorldInfo[101].X + Map.MapInfo[3].X + 465.4, Map.MapWorldInfo[101].Y + Map.MapInfo[3].Y + -9.7,
		"World\\Minimaps\\Expansion01"
	},
	[4] = {
		Map.NRMapBlks,
		1109,
		11, 09,
		Map.MapWorldInfo[113].X + Map.MapInfo[4].X + -397.1, Map.MapWorldInfo[113].Y + Map.MapInfo[4].Y + -334.1,
		"World\\Minimaps\\Northrend"
	},
	[5] = {
		Map.LIMapBlks,
		2324,
		23, 24,
		Map.MapWorldInfo[948].X + Map.MapInfo[5].X + -178.84, Map.MapWorldInfo[948].Y + Map.MapInfo[5].Y + 401.76665039063,
		"World\\Minimaps\\LostIsles"
	},
	[6] = {
		Map.PandariaMapBlks,
		1816,
		18, 16,
		Map.MapWorldInfo[424].X + Map.MapInfo[6].X + 256.3, Map.MapWorldInfo[424].Y + Map.MapInfo[6].Y + -371.0,
		"World\\Minimaps\\HawaiiMainLand"
	},
	[7] = {
		Map.DraenorMapBlks,
		1220,
		12, 20,
		Map.MapWorldInfo[572].X + Map.MapInfo[7].X + 314.8, Map.MapWorldInfo[572].Y + Map.MapInfo[7].Y + 958.6,
		"World\\Minimaps\\Draenor"
	},
	[8] = {
		Map.BrokenIslesMapBlks,
		1117,
		11, 17,
		Map.MapWorldInfo[619].X + Map.MapInfo[8].X + 380, Map.MapWorldInfo[619].Y + Map.MapInfo[8].Y - 147.8,
		"World\\Minimaps\\Troll Raid"
	},
	[10] = {
		Map.ZandalarMapBlks,
		1616,
		16, 16,
		Map.MapWorldInfo[875].X + Map.MapInfo[10].X + 38.80, Map.MapWorldInfo[875].Y + Map.MapInfo[10].Y - 801.10,
		"World\\Minimaps\\zandalar"
	},
	[11] = {
		Map.KultirasMapBlks,
		1616,
		16, 16,
		Map.MapWorldInfo[876].X + Map.MapInfo[11].X + 38.80 - 257.30 + 16.51, Map.MapWorldInfo[876].Y + Map.MapInfo[11].Y - 801.10 + 150.95 + 39.22,
		"World\\Minimaps\\kultiras"
	},
	[12] = {
		Map.NazjatarBlks,
		2824,
		28, 24,
		Map.MapWorldInfo[1355].X + Map.MapInfo[12].X - 106.85, Map.MapWorldInfo[1355].Y + Map.MapInfo[12].Y - 295.44,
		"World\\Minimaps\\nazjatar"
	},	
	[94] = {
		Map.BloodelfMapBlks,
		4111,
		41, 11,
		Map.MapWorldInfo[14].X + Map.MapInfo[2].X + 231.60, Map.MapWorldInfo[14].Y + Map.MapInfo[2].Y - 1751.40,
		"World\\Minimaps\\Expansion01"
	},	
	[97] = {
		Map.DraeneiMapBlks,
		5033,
		50, 33,
		Map.MapWorldInfo[13].X + Map.MapInfo[1].X + 1833.076104875 + 221.20 , Map.MapWorldInfo[13].Y + Map.MapInfo[1].Y + 656.598490125 - 325.10,
		"World\\Minimaps\\Expansion01"
	},
	[244] = {
		Map.TolBaradMapBlks,
		2731,
		27, 31,
		Map.MapWorldInfo[14].X + Map.MapInfo[2].X + 2500.940740625, Map.MapWorldInfo[14].Y + Map.MapInfo[2].Y + 2448.61535,
		"World\\Minimaps\\TolBarad"
	},
	[194] = {
		Map.KezanMapBlks,
		2324,
		23, 24,
		Map.MapWorldInfo[948].X + Map.MapInfo[5].X + 297.05, Map.MapWorldInfo[948].Y + Map.MapInfo[5].Y + -1411.53334960937,
		"World\\Minimaps\\LostIsles"
	},	
	[207] = {		-- 2625 to 3534
		Map.DeepholmMapBlks,
		2625,
		26, 25,
		Map.MapWorldInfo[948].X + Map.MapInfo[5].X + 1251.16, Map.MapWorldInfo[948].Y + Map.MapInfo[5].Y + 228.97665039063,
		"World\\Minimaps\\Deephome"
	},	
	[338] = {
		Map.MoltenFrontMapBlks,
		2725,		-- 2725 to 3531
		27, 25,
		Map.MapWorldInfo[338].X + Map.MapInfo[1].X + 3152.92266259766, Map.MapWorldInfo[338].Y + Map.MapInfo[1].Y + -2105.97034960937,
		"World\\Minimaps\\FirelandsDailies"
	},
	[378] = {
		Map.TheWanderingIsleMapBlks,
		 2328,
		 23,28,
		 Map.MapWorldInfo[378].X + Map.MapWorldInfo[378].XOff + Map.MapInfo[6].X  + 35.7, Map.MapWorldInfo[378].Y + Map.MapWorldInfo[378].YOff + Map.MapInfo[6].Y-69.55,
		 "World\\Minimaps\\NewRaceStartZone"
	},
	[407] = {
		Map.DarkMoonFaireBlks,
		1636,
		16, 36,
		Map.MapWorldInfo[407].X + Map.MapInfo[5].X + -253,Map.MapWorldInfo[407].Y + Map.MapInfo[5].Y + -238,
		"World\\Minimaps\\DarkmoonFaire"
	},	
	[830] = {
		Map.Argus1MapBlks,
		2627,
		26, 27,
		Map.MapWorldInfo[830].X + Map.MapWorldInfo[830].XOff + Map.MapInfo[9].X + 114.1, Map.MapWorldInfo[830].Y + Map.MapWorldInfo[830].YOff + Map.MapInfo[9].Y + -2.6,
		"World\\Minimaps\\Argus 1"
	},
	[882] = {
		Map.Argus3MapBlks,
		1119,
		11, 19,
		Map.MapWorldInfo[882].X + Map.MapWorldInfo[882].XOff + Map.MapInfo[9].X + 69.1, Map.MapWorldInfo[882].Y + Map.MapWorldInfo[882].YOff + Map.MapInfo[9].Y + -62.6,
		"World\\Minimaps\\Argus 1"
	},
	[885] = {
		Map.Argus2MapBlks,
		1135,
		11, 35,
		Map.MapWorldInfo[885].X + Map.MapWorldInfo[885].XOff + Map.MapInfo[9].X + 15.7, Map.MapWorldInfo[885].Y + Map.MapWorldInfo[885].YOff + Map.MapInfo[9].Y + -37.6,
		"World\\Minimaps\\Argus 1"
	},
	[1409] = {
		Map.NPEBlks,
		2038,
		20, 38,
		Map.MapWorldInfo[1409].X - 1383.72, Map.MapWorldInfo[1409].Y + 927.67,
		"World\\Minimaps\\2175"
	},	
}

--------
-- Get minimap info for map
-- (map id)
-- ret: table, x, y

function Nx.Map:GetMiniInfo (mapId)

	local winfo = self.MapWorldInfo[mapId]
	if not winfo then return end
	local id = winfo.MId

	if not id then
		id = winfo.Cont

		if not id then
			return
		end

		if id == 9 then		-- BGs?
			return
		end

		local info = self.MapInfo[id]
		if not info then
			return
		end
	end

	local t = self.MiniMapBlks[id]

	if not t then			-- "Isle of Quel'Danas"??

--		if NxData.DebugMap then
--			Nx.prt ("GetMiniInfo: missing %s", id)
--		end
		return
	end

	return t, t[5], t[6]
end

--------
-- Get minimap block file name (256x256 texture)

function Nx.Map:GetMiniBlkName (miniT, x, y)

	local off = x * 100 + y

--	Nx.prtCtrl ("%s, %s, %s = %s", x, y, off, off + miniT[2])

	--V4

	local v = miniT[1][off + miniT[2]]

	if v then

		if #v > 0 then
			return format ("%s\\noLiquid_map%02d_%02d", miniT[7], x + miniT[3], y + miniT[4])
		end
		if (strfind(miniT[7],"HawaiiMainLand")) then
			local hasFac = false
			for factionIndex = 1, GetNumFactions() do
				local name, description, standingId, bottomValue, topValue, earnedValue, atWarWith,canToggleAtWar, isHeader, isCollapsed, hasRep, isWatched, isChild = GetFactionInfo(factionIndex)
				if (name == "Operation: Shieldwall") or (name == "Dominance Offensive") then
					hasFac = true
				end
			end
			if (hasFac) then
				if ((x + miniT[3] == 33) or (x + miniT[3] == 34)) and ((y + miniT[4] == 33) or (y + miniT[4] == 34)) then
					return format("World\\Minimaps\\AllianceBeachDailyArea\\map%02d_%02d", x + miniT[3], y + miniT[4])
				end
				if ((x + miniT[3] == 27) or (x + miniT[3] == 28)) and ((y + miniT[4] == 35) or (y + miniT[4] == 36) or (y + miniT[4] == 37) or (y + miniT[4] == 38)) then
					return format("World\\Minimaps\\HordeBeachDailyArea\\map%02d_%02d", x + miniT[3], y + miniT[4])
				end
			end
			if (x + miniT[3] >= 18) and (x + miniT[3] <= 25) and (y + miniT[4] >= 17) and (y + miniT[4] <= 24) then
				return format("World\\Minimaps\\MoguIslandDailyArea\\map%02d_%02d",x+miniT[3], y + miniT[4]-2)
			end
		  return format ("%s\\map%02d_%02d", miniT[7], x + miniT[3], y + miniT[4])
		else
			return format ("%s\\map%02d_%02d", miniT[7], x + miniT[3], y + miniT[4])
		end

	end
end

function Nx.Map:GetZoneInfo (mapid)
	local vec, vec2 = CreateVector2D(0,0), CreateVector2D(0.5,0.5)
	local winfo = Nx.Map:GetMap(1).MapWorldInfo
	if not winfo or (winfo[mapid] and winfo[mapid].Scale) then	
		return
	end
	local _,topLeft = C_Map.GetWorldPosFromMapPos(mapid,vec)
	local _,bottomRight = C_Map.GetWorldPosFromMapPos(mapid,vec2)
	if topLeft and bottomRight then
		local top, left = topLeft:GetXY()
        local bottom, right = bottomRight:GetXY()
		bottom = top + (bottom - top) * 2
		right = left + (right - left) * 2
		winfo[mapid] = {}
		winfo[mapid].X = ((left * -1) / 5)
		winfo[mapid].Y = ((top * -1) / 5)
		winfo[mapid].Scale = ((right * -1) + left) / 500
		winfo[mapid].MapArt = C_Map.GetMapArtID(mapid)
		
		local mapinfo = C_Map.GetMapInfo(mapid)
		if mapinfo and (mapinfo.mapType == 5 or mapinfo.mapType == 4) then				
			winfo[mapid].Instance = true
		end
	end	
	
	return winfo[mapid]
end

Map.MapLevels={
	[811] = { [3] = 6010, [4] = 6011, },
	[903] = { [1] = 6012, [2] = 6013, },
	[905] = { [3] = 6010, [4] = 6011, },
	[504] = { [2] = 4014, },
	[321] = { [2] = 1034, },
}

--[[ !!!!!!!!!!!!!!!! PLEASE DONT REMOVE THIS !!!!!!!!!!!!!!!!
function Nx.Map:ConvertMapData()

	local data = {}
	Nx.DumpZoneOverlays = data

	local areas = {}
	Nx.DumpMapAreas = areas

	local wma = { strsplit ("\n", self.WorldMapArea) }
	local wmo = { strsplit ("\n", self.WorldMapOverlay) }

	for n, s in ipairs (wma) do

		local aid, map, _, aname, ay1, ay2, ax1, ax2 = strsplit (",", s)
		aid = tonumber (aid)
		map = tonumber (map)

		aname = gsub (aname, '"', "")
		aname = strlower (aname)
		Nx.prt(aid)
		local nxid = aid
		if nxid and nxid > 0 then

--			local name, minLvl, maxLvl, faction, cont = strsplit ("|", Nx.Zones[nxid])

--			if faction ~= "3" then		-- Not instance

				ay1 = tonumber (ay1)
				ay2 = tonumber (ay2)
				ax1 = tonumber (ax1)
				ax2 = tonumber (ax2)

				local scale = (-ay2 + ay1) / 500
				Nx.prt(scale)
				if scale > 0 then
					local t = {}
					areas[nxid] = t
					t[1] = scale
					t[2] = -ay1 / 5		-- X
					t[3] = -ax1 / 5		-- Y
					t[4] = aname
					Nx.prt("%s %s %s %s",t[4],t[2],t[3],t[1])
				end
--			end
		end

--		if map == 0 or map == 1 then
--		if map == 648 or map == 646 or map == 730 then		-- Maelstrom
--		if map == 654 then					-- Gilneas
--		if map == 571 or map == 609 then			-- Northrend, DK start
		if map == 1064 or map == 870 then
--			Nx.prt ("%s %s %s", aid, map, aname)

			local area = {}

			for n, os in ipairs (wmo) do

				-- 84,41,736,0,0,0,"BanethilHollow",175,235,374,221,292,430,375,497,0x0,

				local _, oaid, _, _, _, _, oname, w, h, x, y = strsplit (",", os)

				oname = gsub (oname, '"', "")

				if tonumber (oaid) == aid and #oname > 0 then
					oname = strlower (oname)
					area[oname] = format ("%s,%s,%s,%s", x, y, w, h)
				end
			end

			if next (area) then				-- Not empty?
				data[aname] = area
			end
		end
	end
end
]]--

-- Copied from HereBeDragons-Migrate all credit goes to HereBeDragons team
local SetupMigrationData
local MapMigrationData, mapFileToIdMap, uiMapIdToIdMap
function Nx.Map:GetLegacyMapInfo(uiMapId)
    if not uiMapId then return nil end
    if not uiMapIdToIdMap then SetupMigrationData() end
    local c = uiMapIdToIdMap[uiMapId]
    if not c then return end
    
    local m, f = floor(c / 10000), (c % 10000)
    return m, f, MapMigrationData[m].mapFile
end
MapMigrationData = {
    [4] = { mapFile = "Durotar", [0] = 1, [8] = 2, [12] = 5, [19] = 6, [11] = 4, [10] = 3},
    [9] = { mapFile = "Mulgore", [0] = 7, [6] = 8, [7] = 9},
    [11] = { mapFile = "Barrens", [0] = 10, [20] = 11},
    [13] = { mapFile = "Kalimdor", [0] = 12},
    [14] = { mapFile = "Azeroth", [0] = 13},
    [16] = { mapFile = "Arathi", [0] = 14},
    [17] = { mapFile = "Badlands", [0] = 15, [18] = 16},
    [19] = { mapFile = "BlastedLands", [0] = 17},
    [20] = { mapFile = "Tirisfal", [0] = 18, [13] = 19, [25] = 20},
    [21] = { mapFile = "Silverpine", [0] = 21},
    [22] = { mapFile = "WesternPlaguelands", [0] = 22},
    [23] = { mapFile = "EasternPlaguelands", [0] = 23, [20] = 24},
    [24] = { mapFile = "HillsbradFoothills", [0] = 25},
    [26] = { mapFile = "Hinterlands", [0] = 26},
    [27] = { mapFile = "DunMorogh", [6] = 28, [7] = 29, [11] = 31, [10] = 30, [0] = 27},
    [28] = { mapFile = "SearingGorge", [0] = 32, [15] = 34, [14] = 33, [16] = 35},
    [29] = { mapFile = "BurningSteppes", [0] = 36},
    [30] = { mapFile = "Elwynn", [1] = 38, [2] = 39, [0] = 37, [19] = 40, [21] = 41},
    [32] = { mapFile = "DeadwindPass", [0] = 42, [24] = 45, [22] = 43, [23] = 44, [27] = 46},
    [758] = { mapFile = "TheBastionofTwilight", [1] = 294, [2] = 295, [3] = 296},
    [886] = { mapFile = "TerraceOfEndlessSpring", [0] = 456},
    [1014] = { mapFile = "Dalaran70", [0] = 625, [12] = 629, [4] = 626, [11] = 628, [10] = 627},
    [759] = { mapFile = "HallsofOrigination", [1] = 297, [2] = 298, [3] = 299},
    [887] = { mapFile = "SiegeofNiuzaoTemple", [1] = 458, [2] = 459, [0] = 457},
    [1015] = { mapFile = "Azsuna", [0] = 630, [17] = 631, [19] = 633, [18] = 632},
    [760] = { mapFile = "RazorfenDowns", [1] = 300},
    [888] = { mapFile = "ShadowglenStart", [0] = 460},
    [761] = { mapFile = "RazorfenKraul", [1] = 301},
    [889] = { mapFile = "ValleyofTrialsStart", [0] = 461},
    [1017] = { mapFile = "Stormheim", [1] = 635, [0] = 634, [28] = 640, [27] = 639, [26] = 638, [9] = 636, [25] = 637},
    [762] = { mapFile = "ScarletMonastery", [1] = 302, [2] = 303, [3] = 304, [4] = 305},
    [890] = { mapFile = "CampNaracheStart", [0] = 462},
    [1018] = { mapFile = "Valsharah", [0] = 641, [13] = 642, [15] = 644, [14] = 643},
    [763] = { mapFile = "Scholomance", [1] = 306, [2] = 307, [3] = 308, [4] = 309},
    [891] = { mapFile = "EchoIslesStart", [0] = 463, [9] = 464},
    [510] = { mapFile = "CrystalsongForest", [0] = 127},
    [40] = { mapFile = "Wetlands", [0] = 56},
    [764] = { mapFile = "ShadowfangKeep", [1] = 310, [2] = 311, [3] = 312, [4] = 313, [5] = 314, [6] = 315, [7] = 316},
    [892] = { mapFile = "DeathknellStart", [0] = 465, [12] = 466},
    [1020] = { mapFile = "TwistingNether70", [0] = 645},
    [765] = { mapFile = "Stratholme", [1] = 317, [2] = 318},
    [893] = { mapFile = "SunstriderIsleStart", [0] = 467},
    [1021] = { mapFile = "BrokenShore", [1] = 647, [2] = 648, [0] = 646},
    [766] = { mapFile = "AhnQiraj", [1] = 319, [2] = 320, [3] = 321},
    [894] = { mapFile = "AmmenValeStart", [0] = 468},
    [1022] = { mapFile = "Helheim", [0] = 649},
    [767] = { mapFile = "ThroneofTides", [1] = 322, [2] = 323},
    [895] = { mapFile = "NewTinkertownStart", [0] = 469, [8] = 470},
    [512] = { mapFile = "StrandoftheAncients", [0] = 128},
    [640] = { mapFile = "Deepholm", [1] = 208, [2] = 209, [0] = 207},
    [768] = { mapFile = "TheStonecore", [1] = 324},
    [896] = { mapFile = "MogushanVaults", [1] = 471, [2] = 472, [3] = 473},
    [1024] = { mapFile = "Highmountain", [0] = 650, [29] = 657, [8] = 653, [16] = 654, [5] = 651, [40] = 660, [20] = 655, [21] = 656, [6] = 652, [31] = 659, [30] = 658},
    [321] = { mapFile = "Orgrimmar", [1] = 86, [0] = 85},
    [769] = { mapFile = "Skywall", [1] = 325},
    [897] = { mapFile = "HeartofFear", [1] = 474, [2] = 475},
    [1026] = { mapFile = "HellfireRaid", [1] = 662, [2] = 663, [3] = 664, [4] = 665, [5] = 666, [6] = 667, [7] = 668, [8] = 669, [9] = 670, [0] = 661},
    [161] = { mapFile = "Tanaris", [0] = 71, [17] = 74, [15] = 72, [16] = 73, [18] = 75},
    [1027] = { mapFile = "AraukNashalIntroScenario", [0] = 671},
    [898] = { mapFile = "Scholomance", [1] = 476, [2] = 477, [3] = 478, [4] = 479},
    [1028] = { mapFile = "MardumtheShatteredAbyss", [1] = 673, [2] = 674, [3] = 675, [0] = 672},
    [899] = { mapFile = "ProvingGrounds", [1] = 480},
    [772] = { mapFile = "AhnQirajTheFallenKingdom", [0] = 327},
    [900] = { mapFile = "AncientMoguCrypt", [1] = 481, [2] = 482},
    [1032] = { mapFile = "VaultOfTheWardensDH", [1] = 677, [2] = 678, [3] = 679},
    [81] = { mapFile = "StonetalonMountains", [0] = 65},
    [773] = { mapFile = "ThroneoftheFourWinds", [1] = 328},
    [1034] = { mapFile = "HelmouthShallows", [0] = 694},
    [1035] = { mapFile = "ValhallasWarriorOrderHome", [1] = 695},
    [775] = { mapFile = "CoTMountHyjal", [0] = 329},
    [520] = { mapFile = "TheNexus", [1] = 129},
    [776] = { mapFile = "GruulsLair", [1] = 330},
    [521] = { mapFile = "CoTStratholme", [1] = 131, [0] = 130},
    [1041] = { mapFile = "HallsofValor", [1] = 704, [2] = 705, [0] = 703},
    [522] = { mapFile = "Ahnkahet", [1] = 132},
    [906] = { mapFile = "DustwallowMarshScenarioAlliance", [0] = 483},
    [523] = { mapFile = "UtgardeKeep", [1] = 133, [2] = 134, [3] = 135},
    [779] = { mapFile = "MagtheridonsLair", [1] = 331},
    [524] = { mapFile = "UtgardePinnacle", [1] = 136, [2] = 137},
    [41] = { mapFile = "Teldrassil", [2] = 58, [3] = 59, [4] = 60, [0] = 57, [5] = 61},
    [780] = { mapFile = "CoilfangReservoir", [1] = 332},
    [525] = { mapFile = "HallsofLightning", [1] = 138, [2] = 139},
    [781] = { mapFile = "ZulAman", [0] = 333},
    [526] = { mapFile = "Ulduar77", [1] = 140},
    [782] = { mapFile = "TempestKeep", [1] = 334},
    [527] = { mapFile = "TheEyeofEternity", [1] = 141},
    [911] = { mapFile = "KrasarangAlliance", [0] = 486},
    [528] = { mapFile = "Nexus80", [1] = 143, [2] = 144, [3] = 145, [4] = 146, [0] = 142},
    [912] = { mapFile = "KrasarangPatience", [0] = 487},
    [529] = { mapFile = "Ulduar", [1] = 148, [2] = 149, [3] = 150, [4] = 151, [5] = 152, [0] = 147},
    [1057] = { mapFile = "MaelstromShaman", [0] = 726},
    [530] = { mapFile = "Gundrak", [1] = 154, [0] = 153},
    [1059] = { mapFile = "TerraceofEndlessSpringScenario", [0] = 728},
    [914] = { mapFile = "VoljinScenario", [1] = 489, [0] = 488},
    [531] = { mapFile = "TheObsidianSanctum", [0] = 155},
    [532] = { mapFile = "VaultofArchavon", [1] = 156},
    [533] = { mapFile = "AzjolNerub", [1] = 157, [2] = 158, [3] = 159},
    [789] = { mapFile = "SunwellPlateau", [1] = 336, [0] = 335},
    [534] = { mapFile = "DrakTharonKeep", [1] = 160, [2] = 161},
    [1067] = { mapFile = "DarkheartThicket", [0] = 733},
    [535] = { mapFile = "Naxxramas", [1] = 162, [2] = 163, [3] = 164, [4] = 165, [5] = 166, [6] = 167},
    [1069] = { mapFile = "TheBeyond", [1] = 736},
    [919] = { mapFile = "BlackTempleScenario", [1] = 491, [2] = 492, [3] = 493, [4] = 494, [5] = 495, [6] = 496, [7] = 497, [0] = 490},
    [536] = { mapFile = "VioletHold", [1] = 168},
    [1071] = { mapFile = "FirelandsShaman", [0] = 738},
    [920] = { mapFile = "KrasarangHorde", [0] = 498},
    [1072] = { mapFile = "TrueshotLodge", [0] = 739},
    [793] = { mapFile = "ZulGurub", [0] = 337},
    [461] = { mapFile = "ArathiBasin", [0] = 93},
    [1075] = { mapFile = "AbyssalMawShamanAcquisition", [1] = 742, [2] = 743},
    [922] = { mapFile = "DeeprunTram", [1] = 499, [2] = 500},
    [1076] = { mapFile = "UlduarMagni", [1] = 744, [2] = 745, [3] = 746},
    [795] = { mapFile = "MoltenFront", [0] = 338},
    [462] = { mapFile = "EversongWoods", [0] = 94},
    [34] = { mapFile = "Duskwood", [0] = 47},
    [42] = { mapFile = "Darkshore", [0] = 62},
    [796] = { mapFile = "BlackTemple", [1] = 340, [2] = 341, [3] = 342, [4] = 343, [5] = 344, [6] = 345, [7] = 346, [0] = 339},
    [924] = { mapFile = "DalaranCity", [1] = 501, [2] = 502},
    [541] = { mapFile = "HrothgarsLanding", [0] = 170},
    [797] = { mapFile = "HellfireRamparts", [1] = 347},
    [925] = { mapFile = "BrawlgarArena", [1] = 503},
    [542] = { mapFile = "TheArgentColiseum", [1] = 171},
    [798] = { mapFile = "MagistersTerrace", [1] = 348, [2] = 349},
    [543] = { mapFile = "TheArgentColiseum", [1] = 172, [2] = 173},
    [799] = { mapFile = "Karazhan", [1] = 350, [2] = 351, [3] = 352, [4] = 353, [5] = 354, [6] = 355, [7] = 356, [8] = 357, [9] = 358, [10] = 359, [11] = 360, [12] = 361, [13] = 362, [14] = 363, [15] = 364, [16] = 365, [17] = 366},
    [464] = { mapFile = "AzuremystIsle", [0] = 97, [2] = 98, [3] = 99},
    [544] = { mapFile = "TheLostIsles", [1] = 175, [2] = 176, [3] = 177, [4] = 178, [0] = 174},
    [800] = { mapFile = "Firelands", [1] = 368, [2] = 369, [0] = 367},
    [928] = { mapFile = "IsleoftheThunderKing", [1] = 505, [2] = 506, [0] = 504},
    [545] = { mapFile = "Gilneas", [1] = 180, [2] = 181, [3] = 182, [0] = 179},
    [673] = { mapFile = "TheCapeOfStranglethorn", [0] = 210},
    [401] = { mapFile = "AlteracValley", [0] = 91},
    [929] = { mapFile = "IsleOfGiants", [0] = 507},
    [1090] = { mapFile = "TolBaradWarlockScenario", [1] = 774, [0] = 773},
    [201] = { mapFile = "UngoroCrater", [0] = 78, [14] = 79},
    [930] = { mapFile = "ThunderKingRaid", [1] = 508, [2] = 509, [3] = 510, [4] = 511, [5] = 512, [6] = 513, [7] = 514, [8] = 515},
    [1092] = { mapFile = "AzuremystIsleScenario", [0] = 776},
    [803] = { mapFile = "TheNexusLegendary", [1] = 370},
    [466] = { mapFile = "Expansion01", [0] = 101},
    [1094] = { mapFile = "NightmareRaid", [1] = 777, [2] = 778, [3] = 779, [4] = 780, [5] = 781, [6] = 782, [7] = 783, [8] = 784, [9] = 785, [10] = 786, [11] = 787, [12] = 788, [13] = 789},
    [1096] = { mapFile = "AszunaDungeonExterior", [0] = 790},
    [101] = { mapFile = "Desolace", [0] = 66, [22] = 68, [21] = 67},
    [933] = { mapFile = "IsleoftheThunderKingScenario", [1] = 517, [0] = 516},
    [806] = { mapFile = "TheJadeForest", [6] = 372, [7] = 373, [15] = 374, [16] = 375, [0] = 371},
    [934] = { mapFile = "ThunderKingLootRoom", [1] = 518},
    [1100] = { mapFile = "KarazhanScenario", [1] = 794, [2] = 795, [3] = 796, [4] = 797},
    [807] = { mapFile = "ValleyoftheFourWinds", [0] = 376, [14] = 377},
    [935] = { mapFile = "GoldRush", [0] = 519},
    [1102] = { mapFile = "ArcwayScenario", [1] = 798},
    [680] = { mapFile = "Ragefire", [1] = 213},
    [808] = { mapFile = "TheWanderingIsle", [0] = 378},
    [1104] = { mapFile = "MageCampaignTheOculus", [1] = 800, [2] = 801, [3] = 802, [4] = 803, [0] = 799},
    [341] = { mapFile = "Ironforge", [0] = 87},
    [809] = { mapFile = "KunLaiSummit", [0] = 379, [8] = 380, [9] = 381, [10] = 382, [20] = 386, [11] = 383, [21] = 387, [12] = 384, [17] = 385},
    [937] = { mapFile = "ValeOfEternalBlossomsScenario", [1] = 521, [0] = 520},
    [810] = { mapFile = "TownlongWastes", [0] = 388, [13] = 389},
    [938] = { mapFile = "EmberdeepScenario", [1] = 522},
    [811] = { mapFile = "ValeofEternalBlossoms", [1] = 391, [2] = 392, [3] = 393, [4] = 394, [0] = 390, [19] = 396, [18] = 395},
    [939] = { mapFile = "DunMoroghScenario", [0] = 523},
    [35] = { mapFile = "LochModan", [0] = 48},
    [43] = { mapFile = "Ashenvale", [0] = 63},
    [940] = { mapFile = "tempKrasarangHordeBase", [0] = 524},
    [685] = { mapFile = "RuinsofGilneasCity", [0] = 218},
    [813] = { mapFile = "NetherstormArena", [0] = 397},
    [471] = { mapFile = "TheExodar", [0] = 103},
    [1114] = { mapFile = "HelheimRaid", [1] = 807, [2] = 808, [0] = 806},
    [686] = { mapFile = "ZulFarrak", [0] = 219},
    [1115] = { mapFile = "LegionKarazhanDungeon", [1] = 809, [2] = 810, [3] = 811, [4] = 812, [5] = 813, [6] = 814, [7] = 815, [8] = 816, [9] = 817, [10] = 818, [11] = 819, [12] = 820, [13] = 821, [14] = 822},
    [1116] = { mapFile = "PitofSaronDK", [0] = 823},
    [687] = { mapFile = "TheTempleOfAtalHakkar", [1] = 220},
    [688] = { mapFile = "BlackfathomDeeps", [1] = 221, [2] = 222, [3] = 223},
    [816] = { mapFile = "WellofEternity", [0] = 398},
    [281] = { mapFile = "Winterspring", [0] = 83},
    [689] = { mapFile = "StranglethornVale", [0] = 224},
    [473] = { mapFile = "ShadowmoonValley", [0] = 104},
    [141] = { mapFile = "Dustwallow", [0] = 70},
    [690] = { mapFile = "TheStockade", [1] = 225},
    [946] = { mapFile = "Talador", [0] = 535, [13] = 536, [14] = 537, [30] = 538},
    [691] = { mapFile = "Gnomeregan", [1] = 226, [2] = 227, [3] = 228, [4] = 229},
    [819] = { mapFile = "HourofTwilight", [1] = 400, [0] = 399},
    [947] = { mapFile = "ShadowmoonValleyDR", [0] = 539, [22] = 541, [15] = 540},
    [1126] = {[0] = 824},
    [692] = { mapFile = "Uldaman", [1] = 230, [2] = 231},
    [820] = { mapFile = "EndTime", [1] = 402, [2] = 403, [3] = 404, [4] = 405, [5] = 406, [0] = 401},
    [948] = { mapFile = "SpiresOfArak", [0] = 542},
    [181] = { mapFile = "Aszhara", [0] = 76},
    [1220] = {[0] = 981},
    [1129] = { mapFile = "CaveoftheBloodtotemScenario", [1] = 826},
    [949] = { mapFile = "Gorgrond", [0] = 543, [17] = 545, [21] = 549, [20] = 548, [19] = 547, [16] = 544, [18] = 546},
    [1130] = { mapFile = "StratholmePaladinClassMount", [1] = 827},
    [1219] = {[1] = 975, [2] = 976, [3] = 977, [4] = 978, [5] = 979, [6] = 980, [0] = 974},
    [1131] = { mapFile = "TheEyeofEternityMageClassMount", [1] = 828},
    [950] = { mapFile = "NagrandDraenor", [11] = 552, [12] = 553, [0] = 550, [10] = 551},
    [1132] = { mapFile = "HallsOfValorWarriorClassMount", [1] = 829},
    [1050] = { mapFile = "WarlockClassShrine", [0] = 717},
    [823] = { mapFile = "DarkmoonFaireIsland", [1] = 408, [0] = 407},
    [476] = { mapFile = "BloodmystIsle", [0] = 106},
    [1216] = { mapFile = "VoidElfScenario", [0] = 972},
    [696] = { mapFile = "MoltenCore", [1] = 232},
    [824] = { mapFile = "DragonSoul", [1] = 410, [2] = 411, [3] = 412, [4] = 413, [5] = 414, [6] = 415, [0] = 409},
    [1215] = { mapFile = "VoidElfHub", [0] = 971},
    [1136] = { mapFile = "ColdridgeValleyScenario", [0] = 834},
    [697] = { mapFile = "ZulGurub", [0] = 233},
    [1137] = { mapFile = "TheDeadminesPetBattle", [1] = 835, [2] = 836},
    [477] = { mapFile = "Nagrand", [0] = 107},
    [1052] = { mapFile = "DemonHunterOrderHallTerrain", [1] = 720, [2] = 721, [0] = 719},
    [1054] = { mapFile = "TheVioletHoldAcquisition", [1] = 723},
    [1139] = { mapFile = "ArathiBasinWinter", [0] = 837},
    [1212] = { mapFile = "LightforgedVindicaar", [1] = 940, [2] = 941},
    [1140] = { mapFile = "BattleforBlackrockMountain", [0] = 838},
    [699] = { mapFile = "DireMaul", [1] = 235, [2] = 236, [3] = 237, [4] = 238, [5] = 239, [6] = 240, [0] = 234},
    [1211] = {[0] = 939},
    [478] = { mapFile = "TerokkarForest", [0] = 108},
    [36] = { mapFile = "Redridge", [0] = 49},
    [700] = { mapFile = "TwilightHighlands", [0] = 241},
    [1143] = { mapFile = "GnomereganPetBattle", [1] = 840, [2] = 841, [3] = 842},
    [1210] = {[0] = 938},
    [1144] = { mapFile = "SmallBattlegroundC", [0] = 843},
    [1066] = { mapFile = "LegionVioletHoldDungeon", [1] = 732},
    [1145] = {[0] = 844},
    [479] = { mapFile = "Netherstorm", [0] = 109},
    [1146] = { mapFile = "TombofSargerasDungeon", [1] = 845, [2] = 846, [3] = 847, [4] = 848, [5] = 849},
    [1204] = {[1] = 934, [2] = 935},
    [1147] = { mapFile = "TombRaid", [1] = 850, [2] = 851, [3] = 852, [4] = 853, [5] = 854, [6] = 855, [7] = 856},
    [1202] = { mapFile = "LightforgedDraeneiSwamp", [0] = 933},
    [1148] = { mapFile = "ThroneoftheFourWinds", [1] = 857},
    [1201] = { mapFile = "InvasionPointVal", [0] = 932},
    [1149] = { mapFile = "AssaultonBrokenShoreScenario", [0] = 858},
    [480] = { mapFile = "SilvermoonCity", [0] = 110},
    [1150] = {[0] = 859},
    [704] = { mapFile = "BlackrockDepths", [1] = 242, [2] = 243},
    [1151] = { mapFile = "TheRubySanctumDKMountScenario", [0] = 860},
    [1200] = { mapFile = "InvasionPointSangua", [0] = 931},
    [1152] = { mapFile = "FelwingLedgeMardumArea", [0] = 861},
    [1199] = { mapFile = "InvasionPointNaigtal", [0] = 930},
    [1153] = {[0] = 862},
    [481] = { mapFile = "ShattrathCity", [0] = 111},
    [1154] = {[0] = 863},
    [1068] = { mapFile = "MageClassShrine", [1] = 734, [2] = 735},
    [1155] = {[0] = 864},
    [241] = { mapFile = "Moonglade", [0] = 80},
    [1156] = { mapFile = "StormheimInvasionScenario", [1] = 865, [2] = 866},
    [1070] = { mapFile = "TheVortexPinnacle", [1] = 737},
    [1157] = { mapFile = "AzsunaInvasionScenario", [1] = 867},
    [482] = { mapFile = "NetherstormArena", [0] = 112},
    [1158] = { mapFile = "ValsharahInvasionScenario", [1] = 868},
    [708] = { mapFile = "TolBarad", [0] = 244},
    [1159] = { mapFile = "HighmountainInvasionScenario", [1] = 869, [2] = 870},
    [964] = { mapFile = "OgreMines", [1] = 573},
    [1160] = { mapFile = "LostGlacierDKMountScenario", [0] = 871},
    [709] = { mapFile = "TolBaradDailyArea", [0] = 245},
    [1161] = { mapFile = "StormstoutBreweryScenario", [1] = 873, [2] = 874, [0] = 872},
    [121] = { mapFile = "Feralas", [0] = 69},
    [1162] = {[0] = 875},
    [710] = { mapFile = "TheShatteredHalls", [1] = 246},
    [1163] = {[0] = 876},
    [1073] = { mapFile = "ArtifactSubtletyRogueAcquisition", [1] = 740, [2] = 741},
    [1164] = { mapFile = "HallsofValor", [0] = 877},
    [1078] = { mapFile = "Niskara", [0] = 748},
    [1165] = { mapFile = "DemonHunterOrderHallTerrain", [1] = 879, [2] = 880, [0] = 878},
    [1079] = { mapFile = "SuamarCatacombsDungeon", [1] = 749},
    [1166] = { mapFile = "TheEyeofEternityMageClassMount", [1] = 881},
    [1080] = { mapFile = "ThunderTotem", [0] = 750},
    [1081] = { mapFile = "BlackRookHoldDungeon", [1] = 751, [2] = 752, [3] = 753, [4] = 754, [5] = 755, [6] = 756},
    [1082] = { mapFile = "UrsocsLairScenario", [0] = 757},
    [1084] = { mapFile = "GloamingReef", [0] = 758},
    [1085] = { mapFile = "70BlackTempleLegion", [1] = 759},
    [1086] = { mapFile = "MalornesNightmare", [0] = 760},
    [485] = { mapFile = "Northrend", [0] = 113},
    [1170] = { mapFile = "ArgusMacAree", [0] = 882, [3] = 883, [4] = 884},
    [1087] = { mapFile = "SuramarNoblesDistrict", [1] = 762, [2] = 763, [0] = 761},
    [1171] = { mapFile = "ArgusCore", [0] = 885, [6] = 887, [5] = 886},
    [970] = { mapFile = "TanaanJungleIntro", [1] = 578, [0] = 577},
    [1172] = { mapFile = "HallOfCommunion", [1] = 888},
    [1091] = { mapFile = "TheExodar", [0] = 775},
    [1173] = { mapFile = "TKArcatrazScenario", [1] = 889, [2] = 890},
    [486] = { mapFile = "BoreanTundra", [0] = 114},
    [37] = { mapFile = "StranglethornJungle", [0] = 50},
    [1097] = { mapFile = "ArtifactBrewmasterScenario", [1] = 791, [2] = 792},
    [1175] = {[0] = 895},
    [61] = { mapFile = "ThousandNeedles", [0] = 64},
    [1176] = {[0] = 896},
    [717] = { mapFile = "RuinsofAhnQiraj", [0] = 247},
    [1177] = { mapFile = "DragonblightChromieScenario", [1] = 898, [2] = 899, [3] = 900, [4] = 901, [5] = 902, [0] = 897},
    [973] = { mapFile = "garrisonsmvalliance_tier1", [0] = 582},
    [1178] = { mapFile = "ArgusDungeon", [0] = 903},
    [718] = { mapFile = "OnyxiasLair", [1] = 248},
    [1099] = { mapFile = "BlackRookHoldScenario", [0] = 793},
    [1174] = { mapFile = "AzuremystScenario", [1] = 892, [2] = 893, [3] = 894, [0] = 891},
    [1142] = { mapFile = "PriestClassMountScenario", [1] = 839},
    [1135] = { mapFile = "ArgusSurface", [1] = 831, [2] = 832, [0] = 830, [7] = 833},
    [1127] = { mapFile = "WailingCavernsPetBattle", [1] = 825},
    [488] = { mapFile = "Dragonblight", [0] = 115},
    [1105] = { mapFile = "ScarletMonestaryDK", [1] = 804, [2] = 805},
    [720] = { mapFile = "Uldum", [0] = 249},
    [1183] = { mapFile = "SilithusBrawl", [0] = 904},
    [976] = { mapFile = "garrisonffhorde", [27] = 586, [28] = 587, [26] = 585},
    [1184] = { mapFile = "Argus", [0] = 994},
    [721] = { mapFile = "BlackrockSpire", [1] = 250, [2] = 251, [3] = 252, [4] = 253, [5] = 254, [6] = 255},
    [1185] = {[0] = 906},
    [1088] = { mapFile = "SuramarRaid", [1] = 764, [2] = 765, [3] = 766, [4] = 767, [5] = 768, [6] = 769, [7] = 770, [8] = 771, [9] = 772},
    [1186] = { mapFile = "AzeriteBG", [0] = 907},
    [722] = { mapFile = "AuchenaiCrypts", [1] = 256, [2] = 257},
    [1187] = {[0] = 908},
    [978] = { mapFile = "Ashran", [0] = 588, [29] = 589},
    [1188] = { mapFile = "ArgusRaid", [1] = 910, [2] = 911, [3] = 912, [4] = 913, [5] = 914, [6] = 915, [7] = 916, [8] = 917, [9] = 918, [10] = 919, [11] = 920, [0] = 909},
    [723] = { mapFile = "SethekkHalls", [1] = 258, [2] = 259},
    [851] = { mapFile = "DustwallowMarshScenario", [0] = 416},
    [490] = { mapFile = "GrizzlyHills", [0] = 116},
    [1190] = { mapFile = "InvasionPointAurinor", [0] = 921},
    [724] = { mapFile = "ShadowLabyrinth", [1] = 260},
    [1191] = { mapFile = "InvasionPointBonich", [0] = 922},
    [980] = { mapFile = "garrisonffhorde_tier1", [0] = 590},
    [1192] = { mapFile = "InvasionPointCengar", [0] = 923},
    [725] = { mapFile = "TheBloodFurnace", [1] = 261},
    [1193] = { mapFile = "InvasionPointNaigtal", [0] = 924},
    [491] = { mapFile = "HowlingFjord", [0] = 117},
    [1194] = { mapFile = "InvasionPointSangua", [0] = 925},
    [726] = { mapFile = "TheUnderbog", [1] = 262},
    [1195] = { mapFile = "InvasionPointVal", [0] = 926},
    [1077] = { mapFile = "TheDreamgrove", [0] = 747},
    [1196] = { mapFile = "InvasionPointAurinor", [0] = 927},
    [727] = { mapFile = "TheSteamvault", [1] = 263, [2] = 264},
    [1197] = { mapFile = "InvasionPointBonich", [0] = 928},
    [492] = { mapFile = "IcecrownGlacier", [0] = 118},
    [1198] = { mapFile = "InvasionPointCengar", [0] = 929},
    [728] = { mapFile = "TheSlavePens", [1] = 265},
    [856] = { mapFile = "TempleofKotmogu", [0] = 417},
    [984] = { mapFile = "DraenorAuchindoun", [1] = 593},
    [601] = { mapFile = "TheForgeofSouls", [1] = 183},
    [729] = { mapFile = "TheBotanica", [1] = 266},
    [857] = { mapFile = "Krasarang", [1] = 419, [2] = 420, [3] = 421, [0] = 418},
    [493] = { mapFile = "SholazarBasin", [0] = 119},
    [602] = { mapFile = "PitofSaron", [0] = 184},
    [730] = { mapFile = "TheMechanar", [1] = 267, [2] = 268},
    [858] = { mapFile = "DreadWastes", [0] = 422},
    [986] = { mapFile = "TaladorScenario", [0] = 594},
    [603] = { mapFile = "HallsofReflection", [1] = 185},
    [731] = { mapFile = "TheArcatraz", [1] = 269, [2] = 270, [3] = 271},
    [1205] = {[0] = 936},
    [987] = { mapFile = "IronDocks", [1] = 595},
    [38] = { mapFile = "SwampOfSorrows", [0] = 51},
    [732] = { mapFile = "ManaTombs", [1] = 272},
    [860] = { mapFile = "STVDiamondMineBG", [1] = 423},
    [988] = { mapFile = "FoundryRaid", [1] = 596, [2] = 597, [3] = 598, [4] = 599, [5] = 600},
    [605] = { mapFile = "Kezan", [6] = 196, [7] = 197, [5] = 195, [0] = 194},
    [733] = { mapFile = "CoTTheBlackMorass", [0] = 273},
    [1065] = { mapFile = "NeltharionsLair", [0] = 731},
    [495] = { mapFile = "TheStormPeaks", [0] = 120},
    [606] = { mapFile = "Hyjal", [0] = 198},
    [734] = { mapFile = "CoTHillsbradFoothills", [0] = 274},
    [862] = { mapFile = "Pandaria", [0] = 424},
    [1060] = { mapFile = "DeepholmShamanAcquisition", [1] = 729},
    [607] = { mapFile = "SouthernBarrens", [0] = 199},
    [1056] = { mapFile = "MaelstromShamanHubIntro", [0] = 725},
    [1213] = {[0] = 942},
    [496] = { mapFile = "ZulDrak", [0] = 121},
    [1214] = {[0] = 943},
    [736] = { mapFile = "GilneasBattleground2", [0] = 275},
    [864] = { mapFile = "Northshire", [0] = 425, [3] = 426},
    [1051] = { mapFile = "DreadscarRift", [0] = 718},
    [609] = { mapFile = "TheRubySanctum", [0] = 200},
    [737] = { mapFile = "TheMaelstrom", [0] = 276},
    [1217] = { mapFile = "TheSunwellUnlockScenario", [1] = 973},
    [993] = { mapFile = "BlackrockTrainDepotDungeon", [1] = 606, [2] = 607, [3] = 608, [4] = 609},
    [610] = { mapFile = "VashjirKelpForest", [0] = 201},
    [1049] = { mapFile = "ArtifactSkywall", [1] = 716},
    [866] = { mapFile = "ColdridgeValley", [0] = 427, [9] = 428},
    [994] = { mapFile = "HighmaulRaid", [1] = 611, [2] = 612, [3] = 613, [4] = 614, [5] = 615, [0] = 610},
    [611] = { mapFile = "GilneasCity", [0] = 202},
    [1048] = { mapFile = "EmeraldDreamway", [0] = 715},
    [867] = { mapFile = "EastTemple", [1] = 429, [2] = 430},
    [995] = { mapFile = "UpperBlackrockSpire", [1] = 616, [2] = 617, [3] = 618},
    [1047] = { mapFile = "Niskara", [0] = 714},
    [1046] = { mapFile = "AszunaDungeon", [0] = 713},
    [1045] = { mapFile = "VaultOfTheWardens", [1] = 710, [2] = 711, [3] = 712},
    [1044] = { mapFile = "MonkOrderHallTheWanderingIsle", [0] = 709},
    [613] = { mapFile = "Vashjir", [0] = 203},
    [1042] = { mapFile = "HelheimDungeonDock", [1] = 707, [2] = 708, [0] = 706},
    [1040] = { mapFile = "NetherlightTemple", [1] = 702},
    [499] = { mapFile = "Sunwell", [0] = 122},
    [614] = { mapFile = "VashjirDepths", [0] = 204},
    [1039] = { mapFile = "IcecrownCitadelDeathKnight", [1] = 698, [2] = 699, [3] = 700, [4] = 701},
    [1038] = { mapFile = "HulnFlashback", [0] = 697},
    [1037] = { mapFile = "StormheimArtifactProtWarrior", [0] = 696},
    [615] = { mapFile = "VashjirRuins", [0] = 205},
    [1033] = { mapFile = "Suramar", [24] = 683, [33] = 685, [35] = 687, [39] = 691, [41] = 692, [42] = 693, [32] = 684, [34] = 686, [36] = 688, [38] = 690, [37] = 689, [22] = 681, [23] = 682, [0] = 680},
    [871] = { mapFile = "ScarletHalls", [1] = 431, [2] = 432},
    [1031] = { mapFile = "BrokenShorePaladin", [0] = 676},
    [301] = { mapFile = "StormwindCity", [0] = 84},
    [475] = { mapFile = "BladesEdgeMountains", [0] = 105},
    [382] = { mapFile = "Undercity", [0] = 998},
    [953] = { mapFile = "OrgrimmarRaid", [1] = 557, [2] = 558, [3] = 559, [4] = 560, [5] = 561, [6] = 562, [7] = 563, [8] = 564, [9] = 565, [10] = 566, [11] = 567, [12] = 568, [13] = 569, [14] = 570, [0] = 556},
    [1007] = { mapFile = "BrokenIsles", [0] = 619},
    [989] = { mapFile = "SpiresofArakDungeon", [1] = 601, [2] = 602},
    [873] = { mapFile = "TheHiddenPass", [0] = 433, [5] = 434},
    [501] = { mapFile = "LakeWintergrasp", [0] = 123},
    [983] = { mapFile = "DefenseofKarabor", [0] = 592},
    [971] = { mapFile = "garrisonsmvalliance", [24] = 580, [25] = 581, [23] = 579},
    [874] = { mapFile = "ScarletCathedral", [1] = 435, [2] = 436},
    [969] = { mapFile = "ShadowmoonDungeon", [1] = 574, [2] = 575, [3] = 576},
    [261] = { mapFile = "Silithus", [0] = 81, [13] = 82},
    [747] = { mapFile = "LostCityofTolvir", [0] = 277},
    [875] = { mapFile = "TheGreatWall", [1] = 437, [2] = 438},
    [502] = { mapFile = "ScarletEnclave", [0] = 124},
    [39] = { mapFile = "Westfall", [0] = 52, [17] = 55, [4] = 53, [5] = 54},
    [962] = { mapFile = "Draenor", [0] = 572},
    [876] = { mapFile = "StormstoutBrewery", [1] = 439, [2] = 440, [3] = 441, [4] = 442},
    [955] = { mapFile = "CelestialChallenge", [0] = 571},
    [951] = { mapFile = "TimelessIsle", [0] = 554, [22] = 555},
    [749] = { mapFile = "WailingCaverns", [1] = 279},
    [877] = { mapFile = "ShadowpanHideout", [1] = 444, [2] = 445, [3] = 446, [0] = 443},
    [945] = { mapFile = "TanaanJungle", [0] = 534},
    [941] = { mapFile = "FrostfireRidge", [1] = 526, [2] = 527, [3] = 528, [4] = 529, [6] = 530, [7] = 531, [8] = 532, [0] = 525, [9] = 533},
    [750] = { mapFile = "Maraudon", [1] = 280, [2] = 281},
    [878] = { mapFile = "BrewmasterScenario01", [0] = 447},
    [684] = { mapFile = "RuinsofGilneas", [0] = 217},
    [362] = { mapFile = "ThunderBluff", [0] = 88},
    [751] = { mapFile = "TheMaelstromContinent", [0] = 948},
    [182] = { mapFile = "Felwood", [0] = 77},
    [504] = { mapFile = "Dalaran", [1] = 125, [2] = 126},
    [465] = { mapFile = "Hellfire", [0] = 100},
    [752] = { mapFile = "BaradinHold", [1] = 282},
    [880] = { mapFile = "TheJadeForestScenario", [0] = 448},
    [1008] = { mapFile = "OvergrownOutpost", [1] = 621, [0] = 620},
    [443] = { mapFile = "WarsongGulch", [0] = 92},
    [753] = { mapFile = "BlackrockCaverns", [1] = 283, [2] = 284},
    [881] = { mapFile = "ValleyOfPowerScenario", [0] = 449},
    [1009] = { mapFile = "AshranAllianceFactionHub", [0] = 622},
    [626] = { mapFile = "TwinPeaks", [0] = 206},
    [754] = { mapFile = "BlackwingDescent", [1] = 285, [2] = 286},
    [882] = { mapFile = "BrewmasterScenario03", [0] = 450},
    [1010] = { mapFile = "HillsbradFoothillsBG", [0] = 623},
    [463] = { mapFile = "Ghostlands", [1] = 96, [0] = 95},
    [755] = { mapFile = "BlackwingLair", [1] = 287, [2] = 288, [3] = 289, [4] = 290},
    [883] = { mapFile = "Tyrivess", [0] = 451},
    [1011] = { mapFile = "AshranHordeFactionHub", [0] = 624},
    [381] = { mapFile = "Darnassus", [0] = 89},
    [756] = { mapFile = "TheDeadmines", [1] = 291, [2] = 292},
    [884] = { mapFile = "KunLaiPassScenario", [0] = 452},
    [540] = { mapFile = "IsleofConquest", [0] = 169},
    [604] = { mapFile = "IcecrownCitadel", [1] = 186, [2] = 187, [3] = 188, [4] = 189, [5] = 190, [6] = 191, [7] = 192, [8] = 193},
    [757] = { mapFile = "GrimBatol", [1] = 293},
    [885] = { mapFile = "MogushanPalace", [1] = 453, [2] = 454, [3] = 455},
    [467] = { mapFile = "Zangarmarsh", [0] = 102},
}
function SetupMigrationData()
    mapFileToIdMap = {}
    for id, t in pairs(MapMigrationData) do
        if t.mapFile then
            mapFileToIdMap[t.mapFile] = id
        end
    end

    uiMapIdToIdMap = {}
    for id, t in pairs(MapMigrationData) do
        for floor, uiMapId in pairs(t) do
            if floor ~= "mapFile" and floor ~= "defaultFloor" then
                uiMapIdToIdMap[uiMapId] = id * 10000 + floor
            end
        end
    end
end
-------------------------------------------------------------------------------
-- EOF
